(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1365873,      24929]
NotebookOptionsPosition[   1350585,      24436]
NotebookOutlinePosition[   1350925,      24451]
CellTagsIndexPosition[   1350882,      24448]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Pre-evaluation code", "Section",
 CellChangeTimes->{{3.465210433319615*^9, 3.465210438805502*^9}, {
  3.465215939556241*^9, 3.46521594024406*^9}}],

Cell[CellGroupData[{

Cell["Pre-evaluation Home Trajectory Demo", "Subsection",
 CellChangeTimes->{{3.4641993712513437`*^9, 3.4641993762407293`*^9}, {
  3.465208267860056*^9, 3.465208274057745*^9}, {3.465208359892836*^9, 
  3.465208365646865*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection",
 CellChangeTimes->{{3.464199384274931*^9, 3.464199387721652*^9}}],

Cell["\<\
This notebook was started before the Oct. 2009 Binaural Gang meeting.  The \
goal is to bundle functions for the phase plane manipulation demo used at the \
Mathematica summer school 2009 into a compact notebook.\
\>", "Text",
 CellChangeTimes->{{3.4641993910874434`*^9, 3.4641994473730593`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Defaults", "Subsubsection"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"$HistoryLength", "=", "0"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.4541722714948483`*^9, 3.454172275256866*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "=", 
   RowBox[{"{", 
    RowBox[{"True", ",", " ", "True", ",", " ", "False", ",", " ", "False"}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ListPlot", ",", " ", "ListLogPlot", ",", " ", "ListLogLogPlot", ",", 
      " ", "Plot", ",", " ", "LogPlot", ",", " ", "ParametricPlot"}], "}"}], 
    ",", " ", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", "fm"}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"AbsoluteThickness", "[", "0.5", "]"}]}], ",", "  ", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4250481029254737`*^9, 3.4250481052287855`*^9}, {
  3.425062110167573*^9, 3.4250621789865294`*^9}, {3.425303920673715*^9, 
  3.425303923868309*^9}, {3.42530433059315*^9, 3.4253043309937267`*^9}, {
  3.4318823438938723`*^9, 3.431882344314477*^9}, {3.4319665718251886`*^9, 
  3.4319665807680483`*^9}, {3.432154490583699*^9, 3.4321544913247647`*^9}, {
  3.43247291260952*^9, 3.432472919649643*^9}, {3.4329195760279183`*^9, 
  3.4329195766788545`*^9}, {3.4333274411328096`*^9, 3.4333274419640045`*^9}}]
}, Open  ]],

Cell["General parameters", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[CellGroupData[{

Cell["Threshold and spike identification parameters", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A\[Theta]", "=", "0.6023486832959924"}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tr", "=", "3.660637667467016`"}], ";", " ", 
  RowBox[{"x\[Theta]", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell["\<\
These are the same identification parameters used in \
RelativeSpread1SpikeAnalysis.nb.\
\>", "Text",
 CellChangeTimes->{3.4105389925978465`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference stimulus parameters", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Aref", "=", "0.6823310565208429"}], ";", 
   RowBox[{"Tref", "=", "3.5777087639996634`"}], ";"}], " "}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["System parameters and resting conditions", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"restCond", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.199408035244027"}], ",", " ", 
     RowBox[{"-", "0.6242600440550339"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "=", "0.7536174776529205`"}], ",", " ", 
    RowBox[{"b", "=", "0.7453384466666666"}], ",", " ", 
    RowBox[{"c", "=", "3.280762663367654`"}]}], "}"}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute the home trajectory", "Subsubsection",
 CellChangeTimes->{{3.453811048098934*^9, 3.4538110556181602`*^9}}],

Cell["\<\
Recomputing the trajectory used to approximate the home trajectory in \
MapGeneration1:\
\>", "Text",
 CellChangeTimes->{{3.45374576401268*^9, 3.45374579935464*^9}, {
  3.454083154974017*^9, 3.454083168812688*^9}, {3.454172826270878*^9, 
  3.4541728323415947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HTtraj1", "=", 
  RowBox[{"First", "[", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"c", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], "-", 
           RowBox[{
            FractionBox["1", "3"], 
            SuperscriptBox[
             RowBox[{"x", "[", "t", "]"}], "3"]}], "-", 
           RowBox[{"y", "[", "t", "]"}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "c"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], "+", "a", "-", 
           RowBox[{"b", " ", 
            RowBox[{"y", "[", "t", "]"}]}]}], ")"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
        RowBox[{"-", "5"}]}], ",", " ", 
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "\[Equal]", " ", 
        RowBox[{"-", "10"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "30"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.453745725222678*^9, 3.45374572703522*^9}, {
   3.453745910077889*^9, 3.4537459217259083`*^9}, {3.454075072113729*^9, 
   3.454075115609201*^9}, 3.454083149144436*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
      "]"}],
     False,
     Editable->False]}], ",", 
   RowBox[{"y", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
      "]"}],
     False,
     Editable->False]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537459283905897`*^9, 3.453822563024613*^9, 
  3.454172845497025*^9, 3.454181417941701*^9, 3.454401442271394*^9, 
  3.464205179904229*^9, 3.4642129957066717`*^9, 3.464298123762899*^9, 
  3.464313309927615*^9, 3.4643139876420794`*^9, 3.464317322055788*^9, 
  3.4643420156074047`*^9, 3.4643467460779467`*^9, 3.4643507787670593`*^9, 
  3.4644315549648037`*^9, 3.464432265156279*^9, 3.4652076431352663`*^9, 
  3.4652082769017467`*^9, 3.465209022162056*^9, 3.465209862308305*^9, 
  3.4652221531137667`*^9, 3.465226016327033*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], ",", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}]}], "}"}], "/.", "HTtraj1"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "]"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453746050875828*^9, 3.45374606495859*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwd13k8VF8UAHBEpNJi30eWyj6DwVjeQSXSJoSERKgsIUv4hZCE0GKpqIgW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     "]], 
    LineBox[CompressedData["
1:eJwd13k8VF8UAHBZCkX23dj3dZjBIO+kfkKy7yl7aJGlCC22UFFIWbJVtlJC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.453746066116218*^9, 3.453822570710825*^9, {3.4541728503601522`*^9, 
   3.454172878087193*^9}, 3.4541814205196247`*^9, 3.454401442426218*^9, 
   3.464205180513975*^9, 3.464212995757065*^9, 3.4642981268358393`*^9, 
   3.464313309980811*^9, 3.464313990047204*^9, 3.464317322115099*^9, 
   3.464342015668997*^9, 3.464346746135202*^9, 3.4643507788201942`*^9, 
   3.4644315550207243`*^9, 3.4644322652117558`*^9, 3.465207643196782*^9, 
   3.465208276950087*^9, 3.4652090222178383`*^9, 3.465209862383627*^9, 
   3.46522215317089*^9, 3.4652260164013443`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], ",", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}]}], "}"}], "/.", "HTtraj1"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "]"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4537460237326307`*^9, 3.453746035849173*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi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     "]]}},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.453746024798872*^9, 3.453746036152706*^9}, 
   3.4538225711186934`*^9, 3.454172881929145*^9, 3.454181423491259*^9, 
   3.45440144247057*^9, 3.4642051805717783`*^9, 3.464212995807905*^9, 
   3.464298150931881*^9, 3.464313310011286*^9, 3.4643139932922297`*^9, 
   3.4643173221568823`*^9, 3.464342015706602*^9, 3.464346746165223*^9, 
   3.4643507788550386`*^9, 3.464431555050755*^9, 3.464432265241249*^9, 
   3.4652076432583647`*^9, 3.4652082769783278`*^9, 3.465209022253311*^9, 
   3.4652098624142838`*^9, 3.465222153203559*^9, 3.465226016426311*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], ",", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}]}], "}"}], "/.", "HTtraj1"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4537460237326307`*^9, 3.453746035849173*^9}, {
  3.4537463220730743`*^9, 3.453746324905489*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi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     "]]}},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{-5., 3.340997971145882}, {-1.4180111814120693`, 
   1.0330479622680582`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4537463252564*^9, 3.4538225711991367`*^9, 
  3.454172893527965*^9, 3.4541814271746607`*^9, 3.454401442520193*^9, 
  3.464205180638565*^9, 3.46421299589003*^9, 3.4642981608750963`*^9, 
  3.464313310038588*^9, 3.464313996536934*^9, 3.464317322194216*^9, 
  3.4643420157400417`*^9, 3.464346746196766*^9, 3.464350778888157*^9, 
  3.46443155508385*^9, 3.464432265272184*^9, 3.465207643325918*^9, 
  3.465208277006317*^9, 3.465209022297997*^9, 3.465209862447524*^9, 
  3.46522215323668*^9, 3.465226016461157*^9}]
}, Open  ]],

Cell["Naming the individual components", "Text",
 CellChangeTimes->{{3.453813933612364*^9, 3.453813941298808*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xHT1", "=", 
  RowBox[{"x", "/.", "HTtraj1"}]}]], "Input",
 CellChangeTimes->{{3.453747397932858*^9, 3.453747408152252*^9}, {
  3.45374791136265*^9, 3.453747937259171*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.453747943535266*^9, 3.453822571243973*^9, 
  3.454181433851179*^9, 3.454401442570882*^9, 3.464205180687385*^9, 
  3.4642129959385967`*^9, 3.46429816117402*^9, 3.4643133100627337`*^9, 
  3.464313999063792*^9, 3.464317322222493*^9, 3.464342015770509*^9, 
  3.464346746228488*^9, 3.464350778916606*^9, 3.4644315551144876`*^9, 
  3.464432265299883*^9, 3.465207643392426*^9, 3.465208277035534*^9, 
  3.465209022328747*^9, 3.4652098624785337`*^9, 3.465222153267023*^9, 
  3.465226016495468*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yHT1", "=", 
  RowBox[{"y", "/.", "HTtraj1"}]}]], "Input",
 CellChangeTimes->{{3.45374794539493*^9, 3.4537479572156553`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.4537479585190496`*^9, 3.453822571292322*^9, 
  3.4541814343218718`*^9, 3.4544014426241283`*^9, 3.464205180737892*^9, 
  3.464212995987142*^9, 3.4642981612069407`*^9, 3.464313310096057*^9, 
  3.4643140016064987`*^9, 3.464317322266679*^9, 3.4643420158196487`*^9, 
  3.46434674626633*^9, 3.464350778971929*^9, 3.464431555172471*^9, 
  3.464432265335602*^9, 3.465207643438623*^9, 3.4652082770760803`*^9, 
  3.465209022382625*^9, 3.4652098625491333`*^9, 3.465222153321382*^9, 
  3.465226016585061*^9}]
}, Open  ]],

Cell["\<\
Defining a function called home such that home[0] is the previously computed \
reference\
\>", "Text",
 CellChangeTimes->{{3.45411359141816*^9, 3.454113659472299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"home", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xHT1", "[", "#", "]"}], ",", 
     RowBox[{"yHT1", "[", "#", "]"}]}], "}"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.4540833194813004`*^9, 3.454083332659219*^9}, {
  3.454083382987233*^9, 3.454083441044841*^9}, {3.4642981973597517`*^9, 
  3.46429820103049*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"xHT1", "[", "#1", "]"}], ",", 
    RowBox[{"yHT1", "[", "#1", "]"}]}], "}"}], "&"}]], "Output",
 CellChangeTimes->{
  3.45408333307767*^9, 3.4540833981533737`*^9, {3.45408343110296*^9, 
   3.45408344128566*^9}, 3.454192614670822*^9, 3.454401442809772*^9, 
   3.464205181268827*^9, 3.464212996202985*^9, 3.4642982029890537`*^9, 
   3.464313310133553*^9, 3.464314004069862*^9, 3.4643173223082047`*^9, 
   3.464342015852414*^9, 3.4643467463127604`*^9, 3.464350779017139*^9, 
   3.464431555215775*^9, 3.464432265368277*^9, 3.465207643492605*^9, 
   3.465208277105803*^9, 3.465209022435718*^9, 3.465209862599084*^9, 
   3.4652221534349327`*^9, 3.465226016651729*^9}]
}, Open  ]],

Cell["\<\
In checking, we note that the x-value corresponds to the right branch of the \
home trajectory and the refractory variable is approximately equal to the \
rest condition.  \
\>", "Text",
 CellChangeTimes->{{3.4541137260663013`*^9, 3.4541137756327333`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tstart", "=", "4.646244127779736`"}]], "Input",
 CellChangeTimes->{{3.464313532036881*^9, 3.464313534673753*^9}}],

Cell[BoxData["4.646244127779736`"], "Output",
 CellChangeTimes->{3.4643135354762373`*^9, 3.464314054614644*^9, 
  3.464317322345429*^9, 3.464342015894224*^9, 3.464346746349987*^9, 
  3.464350779070187*^9, 3.4644315552702217`*^9, 3.464432265402502*^9, 
  3.465207643535591*^9, 3.4652082771428957`*^9, 3.4652090224782143`*^9, 
  3.4652098626480503`*^9, 3.465222153489019*^9, 3.465226016719648*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"home", "[", "tstart", "]"}]], "Input",
 CellChangeTimes->{{3.45411366915998*^9, 3.454113677883379*^9}, {
  3.4643140465280313`*^9, 3.464314047998686*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.0180148089123664`", ",", 
   RowBox[{"-", "0.6242600440550341`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.454113678584404*^9, 3.454192617381983*^9, 3.454401442859967*^9, 
   3.464205181319113*^9, 3.464212996371171*^9, 3.464298206099537*^9, 
   3.464313310166499*^9, 3.4643140069107037`*^9, {3.4643140485322247`*^9, 
   3.464314057595248*^9}, 3.464317322374401*^9, 3.4643420159295883`*^9, 
   3.464346746395605*^9, 3.464350779121674*^9, 3.464431555321347*^9, 
   3.464432265436108*^9, 3.465207643590852*^9, 3.4652082771723003`*^9, 
   3.46520902253463*^9, 3.465209862699642*^9, 3.465222153539751*^9, 
   3.4652260167856817`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resampling the home trajectory", "Subsubsection",
 CellChangeTimes->{{3.453814545562943*^9, 3.453814551104187*^9}}],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " represent a small amount of time elapsed since the previous sample point.  \
We want to choose ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["\[CapitalDelta]x", "2"], "+", 
      SuperscriptBox["\[CapitalDelta]y", "2"]}]], "<", 
    SubscriptBox["\[ScriptCapitalD]", "crit"]}], TraditionalForm]]],
 ", which implies ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]t", "=", 
    FractionBox[
     SubscriptBox["\[ScriptCapitalD]", "crit"], 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], 
        SuperscriptBox[
         RowBox[{"(", 
          SubscriptBox["t", "0"], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"y", "'"}], 
        SuperscriptBox[
         RowBox[{"(", 
          SubscriptBox["t", "0"], ")"}], "2"]}]}]]]}], TraditionalForm]]],
 ".  Note we also want a safety margin so we should make the criterion used \
in the definition of ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " some fraction of Dcrit.  Specifically, since in MapGeneration1 the \
criterion was ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Dcrit", "=", "0.01"}], TraditionalForm]]],
 ", the value used in the ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " calculation should be ",
 Cell[BoxData[
  FormBox[
   RowBox[{"D0", "=", "0.002"}], TraditionalForm]]],
 ", implying a safety factor of five.  "
}], "Text",
 CellChangeTimes->{{3.453748119605771*^9, 3.45374840251996*^9}, 
   3.453748468393743*^9, {3.45374854115889*^9, 3.453748695137249*^9}, {
   3.4537487577183743`*^9, 3.453748833056801*^9}, {3.4538146184348783`*^9, 
   3.453814653455407*^9}, {3.454173659305275*^9, 3.454173669199872*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D0", "=", "0.002"}]], "Input",
 CellChangeTimes->{{3.453748908324545*^9, 3.453748915299923*^9}, {
  3.453769935753728*^9, 3.453769937046278*^9}}],

Cell[BoxData["0.002`"], "Output",
 CellChangeTimes->{3.453748917665125*^9, 3.453770003217607*^9, 
  3.453814656648157*^9, 3.453822577218586*^9, 3.454181437754908*^9, 
  3.454401446050334*^9, 3.4642051813700047`*^9, 3.4642073829699717`*^9, 
  3.464213175078126*^9, 3.464313310226522*^9, 3.464314063611946*^9, 
  3.464317322408132*^9, 3.464342015969927*^9, 3.46434674643288*^9, 
  3.464350779166511*^9, 3.464431555369144*^9, 3.46443226546801*^9, 
  3.465207643637097*^9, 3.465208277209765*^9, 3.4652090225793533`*^9, 
  3.465209862750181*^9, 3.465222153587041*^9, 3.465226016852763*^9}]
}, Open  ]],

Cell["\<\
We continue and make a function for computing the next time from a previous \
one:\
\>", "Text",
 CellChangeTimes->{{3.453767814475751*^9, 3.453767836281683*^9}, {
  3.454173696906568*^9, 3.454173720824835*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nextTime", "[", "t_", "]"}], ":=", 
  RowBox[{"t", "+", 
   RowBox[{"D0", "/", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{"xHT1", "'"}], "[", "t", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{"yHT1", "'"}], "[", "t", "]"}], "2"]}]]}]}]}]], "Input",
 CellChangeTimes->{{3.453768219676928*^9, 3.453768250406127*^9}, {
  3.453814906167219*^9, 3.453814908982147*^9}}],

Cell["Computing the sample times:", "Text",
 CellChangeTimes->{{3.454173742876844*^9, 3.454173748435767*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"timeList2", "=", 
    RowBox[{"Drop", "[", 
     RowBox[{
      RowBox[{"NestWhileList", "[", 
       RowBox[{"nextTime", ",", " ", "tstart", ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#", "<", "30"}], ")"}], "&"}]}], "]"}], ",", " ", 
      RowBox[{"-", "1"}]}], "]"}]}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.453768271944023*^9, 3.4537683018075237`*^9}, {
  3.453768352795725*^9, 3.4537683966524563`*^9}, {3.4537685137219267`*^9, 
  3.4537685139755163`*^9}, {3.453769993164446*^9, 3.453769993264888*^9}, {
  3.453819647461437*^9, 3.453819661643528*^9}, {3.453821850787465*^9, 
  3.4538218661226387`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.12522900000000003`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.453821867439487*^9, 3.453822598119401*^9, 
  3.454181443919351*^9, 3.4544014463317537`*^9, 3.464205181553652*^9, 
  3.4642073832289352`*^9, 3.464213175353858*^9, 3.46431331029261*^9, 
  3.464314069469966*^9, 3.4643173225759907`*^9, 3.464342016153408*^9, 
  3.464346746609778*^9, 3.46435077933027*^9, 3.464431555549488*^9, 
  3.464432265631205*^9, 3.465207643819233*^9, 3.465208277369109*^9, 
  3.465209022762038*^9, 3.46520986292675*^9, 3.465222153790979*^9, 
  3.46522601705121*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "timeList2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"xHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"], "+", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"yHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"yHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"]}], ")"}]}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", 
       RowBox[{
        RowBox[{"Length", "[", "timeList2", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
   RowBox[{"Prolog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Min", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Max", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}]}], 
       "}"}], "]"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823739151227*^9, 3.453823767014176*^9}, {
  3.453823852034616*^9, 3.453823853146299*^9}, {3.4541738338688297`*^9, 
  3.454173992551697*^9}, {3.454175576409442*^9, 3.454175637855646*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwc2nk4VU0YAHBEixS5+0bWFiElkuS1JGuFIkQSiRJK1mSNIiH7WtZSoUT2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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRangeClipping->True,
  Prolog->{
    LineBox[{{4.646244127779736, 0.002}, {22.287392336552358`, 
     0.002}}]}]], "Output",
 CellChangeTimes->{{3.45382384168848*^9, 3.453823853519643*^9}, {
   3.454173943317503*^9, 3.454173993169683*^9}, {3.4541755780286007`*^9, 
   3.4541756389253073`*^9}, 3.4541814467637663`*^9, 3.454401446426609*^9, 
   3.464205181642201*^9, 3.464207383305908*^9, 3.464213175437656*^9, 
   3.464313310399087*^9, 3.464314073347733*^9, 3.464317322956688*^9, 
   3.464342016257061*^9, 3.464346746691424*^9, 3.464350779408125*^9, 
   3.464431555632476*^9, 3.4644322657205143`*^9, 3.465207643897113*^9, 
   3.465208277448266*^9, 3.465209022843854*^9, 3.4652098630180902`*^9, 
   3.465222153891863*^9, 3.465226017130578*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "timeList2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"xHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"], "+", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"yHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"yHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"]}], ")"}]}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", 
       RowBox[{
        RowBox[{"Length", "[", "timeList2", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}], ",", " ", 
   RowBox[{"Prolog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Min", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Max", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}]}], 
       "}"}], "]"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823739151227*^9, 3.453823767014176*^9}, {
  3.453823852034616*^9, 3.453823853146299*^9}, {3.4541738338688297`*^9, 
  3.454173992551697*^9}, {3.454175576409442*^9, 3.4541756651388693`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwc2nk4VU0YAHBEixS5+0bWFiElkuS1JGuFIkQSiRJK1mSNIiH7WtZSoUT2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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True,
  Prolog->{
    LineBox[{{4.646244127779736, 0.002}, {22.287392336552358`, 
     0.002}}]}]], "Output",
 CellChangeTimes->{3.454175665654237*^9, 3.454181449840543*^9, 
  3.454401446577572*^9, 3.464205181737328*^9, 3.464207383390275*^9, 
  3.464213175582222*^9, 3.464313310429921*^9, 3.464314076889995*^9, 
  3.464317323043562*^9, 3.4643420163452187`*^9, 3.4643467467767*^9, 
  3.464350779596891*^9, 3.464431555719262*^9, 3.4644322658064337`*^9, 
  3.465207644059433*^9, 3.4652082775305767`*^9, 3.4652090229248333`*^9, 
  3.465209863103038*^9, 3.465222153976521*^9, 3.4652260172078114`*^9}]
}, Open  ]],

Cell["Here the spacing only goes slightly above 0.002. ", "Text",
 CellChangeTimes->{{3.454175681323826*^9, 3.4541756949626913`*^9}}],

Cell["Sampling the Home Trajectory:", "Text",
 CellChangeTimes->{{3.4541815231261044`*^9, 3.45418152922863*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HTsample2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"t", "\[Function]", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", 
        RowBox[{"xHT1", "[", "t", "]"}], ",", " ", 
        RowBox[{"yHT1", "[", "t", "]"}]}], "}"}]}], ")"}], "/@", 
    "timeList2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.453822750786233*^9, 3.453822780407332*^9}, {
  3.453822812895875*^9, 3.4538228235744553`*^9}, {3.453822867587119*^9, 
  3.4538228738013268`*^9}, {3.453823016358951*^9, 3.4538230164519653`*^9}}],

Cell["\<\
The corresponding values read of the graph: {{10.02, -1.777}} and {{10.02, \
0.01432}}.\
\>", "Text",
 CellChangeTimes->{{3.4541122204150543`*^9, 3.454112247238606*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"htPlot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"HTsample2", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{";;", ";;", "100"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.454112288676467*^9, 3.45411230634689*^9}, {
  3.454112341798265*^9, 3.454112357723218*^9}, {3.4541936699761553`*^9, 
  3.454193670482093*^9}, {3.454193711138239*^9, 3.454193715888603*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAAevq48uQkAED6Ti0z8Pnjv7+nCtuq
RP8/uwDtRhPT27/qB1zBESr+PxjOn9k3oc+/tgl+TEr1/D+U4EGynLavv0SY
vo7zn/s/lpVM5b+pvj8ju+QMQyH6P1jq7gPf+dI/+CdNKRxt+D8TKNVBRc3d
P5H1Yxelc/Y/mSCE/k3u4z9M8iTbDyT0P3cYzLIsWeg/u0K6eOd38T9EGDr0
N9vrP2gTif0rA+0/QwG9V95F7j8ZVPvZGsbmP8lDEZ8aue8/pFsWZhNq4D9H
XtkBTUHwP6HZgncQCdQ/N2U256ty8D91jUIpZeW8P6j+U82EhfA/GCLvJ31a
tr/Q5JUrgYXwP2wEccaUZdK/9i42F/Z48D9v8XO4JzPfvwciONs6Y/A//7KB
rZT/5b/3qhrd3kXwP52WO+6rZOy/gWRaJTYh8D8zk8KhS2Txv9V5HCXt6O8/
x4ArB2WV9L9BINuVw3rvP/3PkSj+xPe/edNSKhvu7j/BVqBVO/H6vy/x/cyn
K+4/Ot8pKVMR/r9HFBwuRejsP15BZAAEPADA6aM/8UtB6T96LoU1pOL/v0J5
UPGGBeM/5zP3ZhbT/r/T20fex/nZP+Uy6Vdwp/2/s2XThXclzD8W9CIEgFv8
v7rFESepEqM/jD79+Gjl+r8J+X1bwvjBv8EwO7XONfm/v931VcfW079MD+6+
1TP3v0yOVBLGwd2/sXwXC/W39L9w1XJad9Xivy2aJn0=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.454112285680174*^9, 3.4541123591794453`*^9, 
  3.454193671129228*^9, 3.454193716234417*^9, 3.4544014467775497`*^9, 
  3.46420518179978*^9, 3.464207383451765*^9, 3.464213175831071*^9, 
  3.464313310795081*^9, 3.464314087370098*^9, 3.464317323103489*^9, 
  3.464342016442359*^9, 3.4643467468179626`*^9, 3.464350779648591*^9, 
  3.464431555760543*^9, 3.4644322658455257`*^9, 3.465207644143428*^9, 
  3.465208277589118*^9, 3.465209023026884*^9, 3.465209863148089*^9, 
  3.4652221540733843`*^9, 3.465226017301051*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"htPlot2", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"HTsample2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.454112288676467*^9, 3.45411230634689*^9}, {
  3.454112341798265*^9, 3.454112357723218*^9}, {3.4541936699761553`*^9, 
  3.454193682882255*^9}, {3.454193719042749*^9, 3.454193723672675*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwUV3c8lu8XJpVIVBSlpKIkGiJJXJQyIl9RUikqhCgVWZWKIiSyMlLSVPaK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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.454193683197153*^9, 3.454193724269754*^9, 
  3.454401446804146*^9, 3.464205181826288*^9, 3.464207383504792*^9, 
  3.464213175859626*^9, 3.464313310831889*^9, 3.464314090180372*^9, 
  3.464317323137031*^9, 3.46434201648209*^9, 3.464346746847516*^9, 
  3.464350779682681*^9, 3.464431555790053*^9, 3.46443226589554*^9, 
  3.465207644215395*^9, 3.46520827760585*^9, 3.465209023062159*^9, 
  3.465209863195037*^9, 3.4652221541098757`*^9, 3.46522601733104*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function for computing the distance to the home trajectory", \
"Subsubsection",
 CellChangeTimes->{{3.454175778712042*^9, 3.454175782438424*^9}, {
  3.454353143347899*^9, 3.454353155192384*^9}}],

Cell[TextData[{
 "This statement defines a function nf[x] where x is a two dimensional vector \
specifying the location of a point in phase space.  The function returns the \
list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]close", ",", " ", "xclose", ",", " ", "yclose"}], "}"}], 
     ",", "  ", "distance"}], "}"}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["\[Tau]close", TraditionalForm]]],
 " is the value of \[Tau] that is closest to x and xclose  and yclose are the \
corresponding coordinates in phase space.  The statement HTsample2[[All, {2, \
3}]] \[Rule] HTsample2 in the precomputed Nearest function labels the the \
matrix contructed from the second and third columns with elements of the full \
matrix which also has a leading column of the times along the hidden \
structure."
}], "Text",
 CellChangeTimes->{{3.454023609369185*^9, 3.4540236400378027`*^9}, {
  3.454023710045332*^9, 3.454023744005353*^9}, {3.4540239875443707`*^9, 
  3.454024074018815*^9}, {3.454024246407796*^9, 3.454024287225095*^9}, {
  3.4541094589517117`*^9, 3.454109505818973*^9}, {3.454109622548807*^9, 
  3.454109699935792*^9}}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"temp", "=", 
     RowBox[{"Nearest", "[", 
      RowBox[{
       RowBox[{"HTsample2", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "\[Rule]", 
       "HTsample2"}], "]"}]}], 
    RowBox[{"(*", 
     RowBox[{"Pre", "-", 
      RowBox[{"compute", " ", "the", " ", "Nearest", " ", "Function"}]}], 
     "*)"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "nf", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nf", "[", 
      RowBox[{"x_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"VectorQ", "[", 
          RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], "]"}], ":=", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"res", "=", 
         RowBox[{"First", "@", 
          RowBox[{"temp", "[", "x", "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
           RowBox[{"First", "[", "]"}], " ", "is", " ", "needed", " ", 
           "because", " ", "Nearest", " ", "returns", " ", "a", " ", "list"}],
           ",", " ", 
          RowBox[{
          "which", " ", "is", " ", "necessary", " ", "to", " ", "account", 
           " ", "for", " ", "multiple"}], ",", " ", 
          RowBox[{"equally", " ", "close", " ", "points"}]}], "*)"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"res", ",", 
         RowBox[{"Norm", "[", 
          RowBox[{"x", "-", 
           RowBox[{"res", "[", 
            RowBox[{"[", 
             RowBox[{"{", 
              RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}]}], "]"}]}], 
        "}"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453824880369479*^9, 3.4538248814708443`*^9}, {
   3.453824964487279*^9, 3.4538249653592443`*^9}, 3.4538250420478477`*^9, {
   3.453825074738001*^9, 3.453825088423801*^9}, {3.453825123825498*^9, 
   3.453825129512917*^9}, {3.453825175482459*^9, 3.453825279295473*^9}, {
   3.45382535412395*^9, 3.453825354946455*^9}, {3.454084824437039*^9, 
   3.454084869462948*^9}, {3.454089329455098*^9, 3.454089348284706*^9}, {
   3.454108979594144*^9, 3.4541090368011217`*^9}, {3.454110058560604*^9, 
   3.454110059232307*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define a function for computing the post-shock trajectories", \
"Subsubsection",
 CellChangeTimes->{{3.4541761190045633`*^9, 3.454176133107913*^9}, {
  3.454353208779581*^9, 3.4543532096975183`*^9}}],

Cell[TextData[{
 "The function G3 integrates the FN system starting from the initial state \
{x0, y0}, stopping when the distance from the transient attractor becomes \
less that 10^-2 or when time progresses beyond 100. The stopping event is \
defined by the statement \"Event\" \[RuleDelayed] 10^-2 > (end1 = nf[{x[t], \
y[t]}]; end1[[2]]).  At each step r.h.s. of the boolean expression in \
evaluated and the value of the boolean expression determined.  The r.h.s. in \
this implementation consists of a compound expression, the first component \
being an evaluation of the nearest function.  This value of the nearest \
function is stored in the global variable end1, which is overwritten except \
when the condition is satisfied.  When nf[{x[t], y[t]}] is evaluated, it \
returns ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]close", ",", " ", "xclose", ",", " ", "yclose"}], "}"}], 
     ",", "  ", 
     StyleBox["distance",
      FontSlant->"Italic"]}], "}"}], TraditionalForm]]],
 ".  The next statement in the compound expression simply takes the ",
 StyleBox["distance",
  FontSlant->"Italic"],
 ", which is the quantity that is relevant for the comparison.  The value of \
end1 is re-evaluated in the argument of Throw in \"EventAction\": \
\"EventAction\" \[RuleDelayed] Throw[end1 = nf[{x[t], y[t]}]; end2 = t, \
\"StopIntegration\"].  Apparently the convention for having an EventAction \
that stops the integration is to call a Throw with a tag \"StopIntegration\". \
 "
}], "Text",
 CellChangeTimes->{{3.454024557853074*^9, 3.4540246065254173`*^9}, {
  3.454024746367197*^9, 3.454024791097004*^9}, {3.454024875044945*^9, 
  3.454024940415872*^9}, {3.454025229320335*^9, 3.454025305439415*^9}, {
  3.454025341407782*^9, 3.454025716855399*^9}, {3.454089016913787*^9, 
  3.454089044150581*^9}, {3.4541102911117687`*^9, 3.4541104126886683`*^9}}],

Cell["\<\
In this revised function, the arguments are the starting location in phase \
space, the amplitude of the kick A, and the independent variable symbol.  The \
function returns a list {equivalent excitataion \[Tau], {xRule, yRule}, \
travel time, joining\[Tau]}\
\>", "Text",
 CellChangeTimes->{{3.4541139559580917`*^9, 3.454114010687345*^9}, {
  3.454192788311226*^9, 3.45419279526149*^9}, {3.454192842931642*^9, 
  3.4541928862521353`*^9}, {3.454192951626615*^9, 3.454192960880138*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"G3", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}], ",", "A_", ",", "t_Symbol"}], "]"}], 
  ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "x", ",", "y", ",", "end1", ",", "end2", ",", "tf", ",", " ", "ruleList",
       ",", "joining\[Tau]", ",", "traveltime"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"tf", "=", "100"}], ";", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "2"}]}], ">", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"end1", "=", 
           RowBox[{"nf", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x0", "+", "A"}], ",", "y0"}], "}"}], "]"}]}], ")"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"end1", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x0", "+", "A"}], ",", "y0"}], "}"}], ",", "0", ",", 
          RowBox[{"end1", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ruleList", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            RowBox[{"c", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "-", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"x", "[", "t", "]"}], "3"], "3"], "-", 
               RowBox[{"y", "[", "t", "]"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            FractionBox[
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "+", "a", "-", 
              RowBox[{"b", " ", 
               RowBox[{"y", "[", "t", "]"}]}]}], "c"]}], ",", 
           RowBox[{
            RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
            RowBox[{"x0", "+", "A"}]}], " ", ",", " ", 
           RowBox[{
            RowBox[{"y", "[", "0", "]"}], "\[Equal]", "y0"}]}], "}"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "y"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "0", ",", " ", "tf"}], "}"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"Method", "\[Rule]", "\[IndentingNewLine]", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"\"\<EventLocator\>\"", ",", "\[IndentingNewLine]", 
            RowBox[{"\"\<Event\>\"", "\[RuleDelayed]", 
             RowBox[{
              RowBox[{"10", "^", 
               RowBox[{"-", "2"}]}], ">", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"nf", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"x", "[", "t", "]"}], ",", 
                   RowBox[{"y", "[", "t", "]"}]}], "}"}], "]"}], 
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               ")"}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
            "\"\<EventAction\>\"", "\[RuleDelayed]", "\[IndentingNewLine]", 
             RowBox[{"Throw", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"end1", "=", 
                 RowBox[{"nf", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], ",", 
                    RowBox[{"y", "[", "t", "]"}]}], "}"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"end2", "=", "t"}]}], ",", "\[IndentingNewLine]", 
               "\"\<StopIntegration\>\""}], "\[IndentingNewLine]", "]"}]}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"\"\<EventLocationMethod\>\"", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<Brent\>\"", ",", 
               RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "}"}]}]}], 
           "}"}]}]}], "]"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"traveltime", "=", "end2"}], ";", "\[IndentingNewLine]", 
     RowBox[{"joining\[Tau]", "=", 
      RowBox[{"end1", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"joining\[Tau]", "-", "traveltime"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], ",", 
          RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", "ruleList"}], ",", 
       "traveltime", ",", "joining\[Tau]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4538254919715223`*^9, 3.4538255174836206`*^9}, {
   3.453825567427759*^9, 3.453825656367216*^9}, {3.453825690460688*^9, 
   3.4538257279722233`*^9}, 3.45382579167231*^9, {3.454083874205926*^9, 
   3.4540839563869143`*^9}, {3.454083997034318*^9, 3.454084012635948*^9}, {
   3.4540840548250017`*^9, 3.454084082790804*^9}, {3.454084137898355*^9, 
   3.454084151413535*^9}, {3.454084244580618*^9, 3.454084357940193*^9}, {
   3.454085120353753*^9, 3.454085122850245*^9}, {3.454107359345969*^9, 
   3.454107359519698*^9}, 3.454108264533277*^9, {3.4541789503444653`*^9, 
   3.454179024992454*^9}, {3.454180644193272*^9, 3.4541807860999813`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function for computing the distance to the home trajectory", \
"Subsubsection",
 CellChangeTimes->{{3.454175778712042*^9, 3.454175782438424*^9}, {
  3.454353143347899*^9, 3.454353155192384*^9}}],

Cell[TextData[{
 "This statement defines a function nf[x] where x is a two dimensional vector \
specifying the location of a point in phase space.  The function returns the \
list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]close", ",", " ", "xclose", ",", " ", "yclose"}], "}"}], 
     ",", "  ", "distance"}], "}"}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["\[Tau]close", TraditionalForm]]],
 " is the value of \[Tau] that is closest to x and xclose  and yclose are the \
corresponding coordinates in phase space.  The statement HTsample2[[All, {2, \
3}]] \[Rule] HTsample2 in the precomputed Nearest function labels the the \
matrix contructed from the second and third columns with elements of the full \
matrix which also has a leading column of the times along the hidden \
structure."
}], "Text",
 CellChangeTimes->{{3.454023609369185*^9, 3.4540236400378027`*^9}, {
  3.454023710045332*^9, 3.454023744005353*^9}, {3.4540239875443707`*^9, 
  3.454024074018815*^9}, {3.454024246407796*^9, 3.454024287225095*^9}, {
  3.4541094589517117`*^9, 3.454109505818973*^9}, {3.454109622548807*^9, 
  3.454109699935792*^9}}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"temp", "=", 
     RowBox[{"Nearest", "[", 
      RowBox[{
       RowBox[{"HTsample2", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "\[Rule]", 
       "HTsample2"}], "]"}]}], 
    RowBox[{"(*", 
     RowBox[{"Pre", "-", 
      RowBox[{"compute", " ", "the", " ", "Nearest", " ", "Function"}]}], 
     "*)"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "nf", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nf", "[", 
      RowBox[{"x_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"VectorQ", "[", 
          RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], "]"}], ":=", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"res", "=", 
         RowBox[{"First", "@", 
          RowBox[{"temp", "[", "x", "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
           RowBox[{"First", "[", "]"}], " ", "is", " ", "needed", " ", 
           "because", " ", "Nearest", " ", "returns", " ", "a", " ", "list"}],
           ",", " ", 
          RowBox[{
          "which", " ", "is", " ", "necessary", " ", "to", " ", "account", 
           " ", "for", " ", "multiple"}], ",", " ", 
          RowBox[{"equally", " ", "close", " ", "points"}]}], "*)"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"res", ",", 
         RowBox[{"Norm", "[", 
          RowBox[{"x", "-", 
           RowBox[{"res", "[", 
            RowBox[{"[", 
             RowBox[{"{", 
              RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}]}], "]"}]}], 
        "}"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453824880369479*^9, 3.4538248814708443`*^9}, {
   3.453824964487279*^9, 3.4538249653592443`*^9}, 3.4538250420478477`*^9, {
   3.453825074738001*^9, 3.453825088423801*^9}, {3.453825123825498*^9, 
   3.453825129512917*^9}, {3.453825175482459*^9, 3.453825279295473*^9}, {
   3.45382535412395*^9, 3.453825354946455*^9}, {3.454084824437039*^9, 
   3.454084869462948*^9}, {3.454089329455098*^9, 3.454089348284706*^9}, {
   3.454108979594144*^9, 3.4541090368011217`*^9}, {3.454110058560604*^9, 
   3.454110059232307*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define a function for computing the post-shock trajectories", \
"Subsubsection",
 CellChangeTimes->{{3.4541761190045633`*^9, 3.454176133107913*^9}, {
  3.454353208779581*^9, 3.4543532096975183`*^9}}],

Cell[TextData[{
 "The function G3 integrates the FN system starting from the initial state \
{x0, y0}, stopping when the distance from the transient attractor becomes \
less that 10^-2 or when time progresses beyond 100. The stopping event is \
defined by the statement \"Event\" \[RuleDelayed] 10^-2 > (end1 = nf[{x[t], \
y[t]}]; end1[[2]]).  At each step r.h.s. of the boolean expression in \
evaluated and the value of the boolean expression determined.  The r.h.s. in \
this implementation consists of a compound expression, the first component \
being an evaluation of the nearest function.  This value of the nearest \
function is stored in the global variable end1, which is overwritten except \
when the condition is satisfied.  When nf[{x[t], y[t]}] is evaluated, it \
returns ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]close", ",", " ", "xclose", ",", " ", "yclose"}], "}"}], 
     ",", "  ", 
     StyleBox["distance",
      FontSlant->"Italic"]}], "}"}], TraditionalForm]]],
 ".  The next statement in the compound expression simply takes the ",
 StyleBox["distance",
  FontSlant->"Italic"],
 ", which is the quantity that is relevant for the comparison.  The value of \
end1 is re-evaluated in the argument of Throw in \"EventAction\": \
\"EventAction\" \[RuleDelayed] Throw[end1 = nf[{x[t], y[t]}]; end2 = t, \
\"StopIntegration\"].  Apparently the convention for having an EventAction \
that stops the integration is to call a Throw with a tag \"StopIntegration\". \
 "
}], "Text",
 CellChangeTimes->{{3.454024557853074*^9, 3.4540246065254173`*^9}, {
  3.454024746367197*^9, 3.454024791097004*^9}, {3.454024875044945*^9, 
  3.454024940415872*^9}, {3.454025229320335*^9, 3.454025305439415*^9}, {
  3.454025341407782*^9, 3.454025716855399*^9}, {3.454089016913787*^9, 
  3.454089044150581*^9}, {3.4541102911117687`*^9, 3.4541104126886683`*^9}}],

Cell["\<\
In this revised function, the arguments are the starting location in phase \
space, the amplitude of the kick A, and the independent variable symbol.  The \
function returns a list {equivalent excitataion \[Tau], {xRule, yRule}, \
travel time, joining\[Tau]}\
\>", "Text",
 CellChangeTimes->{{3.4541139559580917`*^9, 3.454114010687345*^9}, {
  3.454192788311226*^9, 3.45419279526149*^9}, {3.454192842931642*^9, 
  3.4541928862521353`*^9}, {3.454192951626615*^9, 3.454192960880138*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"G3", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}], ",", "A_", ",", "t_Symbol"}], "]"}], 
  ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "x", ",", "y", ",", "end1", ",", "end2", ",", "tf", ",", " ", "ruleList",
       ",", "joining\[Tau]", ",", "traveltime"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"tf", "=", "100"}], ";", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "2"}]}], ">", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"end1", "=", 
           RowBox[{"nf", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x0", "+", "A"}], ",", "y0"}], "}"}], "]"}]}], ")"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"end1", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x0", "+", "A"}], ",", "y0"}], "}"}], ",", "0", ",", 
          RowBox[{"end1", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ruleList", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            RowBox[{"c", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "-", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"x", "[", "t", "]"}], "3"], "3"], "-", 
               RowBox[{"y", "[", "t", "]"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            FractionBox[
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "+", "a", "-", 
              RowBox[{"b", " ", 
               RowBox[{"y", "[", "t", "]"}]}]}], "c"]}], ",", 
           RowBox[{
            RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
            RowBox[{"x0", "+", "A"}]}], " ", ",", " ", 
           RowBox[{
            RowBox[{"y", "[", "0", "]"}], "\[Equal]", "y0"}]}], "}"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "y"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "0", ",", " ", "tf"}], "}"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"Method", "\[Rule]", "\[IndentingNewLine]", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"\"\<EventLocator\>\"", ",", "\[IndentingNewLine]", 
            RowBox[{"\"\<Event\>\"", "\[RuleDelayed]", 
             RowBox[{
              RowBox[{"10", "^", 
               RowBox[{"-", "2"}]}], ">", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"nf", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"x", "[", "t", "]"}], ",", 
                   RowBox[{"y", "[", "t", "]"}]}], "}"}], "]"}], 
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               ")"}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
            "\"\<EventAction\>\"", "\[RuleDelayed]", "\[IndentingNewLine]", 
             RowBox[{"Throw", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"end1", "=", 
                 RowBox[{"nf", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], ",", 
                    RowBox[{"y", "[", "t", "]"}]}], "}"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"end2", "=", "t"}]}], ",", "\[IndentingNewLine]", 
               "\"\<StopIntegration\>\""}], "\[IndentingNewLine]", "]"}]}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"\"\<EventLocationMethod\>\"", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<Brent\>\"", ",", 
               RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "}"}]}]}], 
           "}"}]}]}], "]"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"traveltime", "=", "end2"}], ";", "\[IndentingNewLine]", 
     RowBox[{"joining\[Tau]", "=", 
      RowBox[{"end1", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"joining\[Tau]", "-", "traveltime"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], ",", 
          RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", "ruleList"}], ",", 
       "traveltime", ",", "joining\[Tau]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4538254919715223`*^9, 3.4538255174836206`*^9}, {
   3.453825567427759*^9, 3.453825656367216*^9}, {3.453825690460688*^9, 
   3.4538257279722233`*^9}, 3.45382579167231*^9, {3.454083874205926*^9, 
   3.4540839563869143`*^9}, {3.454083997034318*^9, 3.454084012635948*^9}, {
   3.4540840548250017`*^9, 3.454084082790804*^9}, {3.454084137898355*^9, 
   3.454084151413535*^9}, {3.454084244580618*^9, 3.454084357940193*^9}, {
   3.454085120353753*^9, 3.454085122850245*^9}, {3.454107359345969*^9, 
   3.454107359519698*^9}, 3.454108264533277*^9, {3.4541789503444653`*^9, 
   3.454179024992454*^9}, {3.454180644193272*^9, 3.4541807860999813`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the home trajectory with labels", "Subsubsection",
 CellChangeTimes->{{3.464212710371677*^9, 3.4642127173304453`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tstart", "=", "4.646244127779736`"}]], "Input",
 CellChangeTimes->{{3.464313532036881*^9, 3.464313534673753*^9}}],

Cell[BoxData["4.646244127779736`"], "Output",
 CellChangeTimes->{3.4643135354762373`*^9, 3.464317323235215*^9, 
  3.46434201655239*^9, 3.464346746913526*^9, 3.4643507798482018`*^9, 
  3.46443155598549*^9, 3.4644322660121717`*^9, 3.46520764438902*^9, 
  3.465208277822741*^9, 3.465209023199965*^9, 3.4652098633652554`*^9, 
  3.465222154218869*^9, 3.465226017429545*^9}]
}, Open  ]],

Cell["\<\
We want to sample the home trajectory uniformly in TIME yeilding nonuniform \
spacial sampling, that way the point density can be used to judge the phase \
velocity.  \
\>", "Text",
 CellChangeTimes->{{3.454337928807325*^9, 3.454337978758976*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleHome", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"home", "[", "t", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "30", ",", " ", "0.5"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.454338199744258*^9, 3.4543382667258873`*^9}, {
   3.454338297363022*^9, 3.454338297953177*^9}, 3.464213214687809*^9, {
   3.4643022449605913`*^9, 3.464302251221789*^9}, 3.464302676273066*^9, 
   3.46434540969519*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"tstart", ",", " ", "6", ",", " ", "20"}], "}"}]], "Input",
 CellChangeTimes->{{3.46430241699787*^9, 3.4643024309709597`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.646244127779736`", ",", "6", ",", "20"}], "}"}]], "Output",
 CellChangeTimes->{3.464302338654313*^9, 3.464302435477496*^9, 
  3.464313311024987*^9, 3.464313557573832*^9, 3.46431411374282*^9, 
  3.464317323335429*^9, 3.464342016652494*^9, 3.464346746991503*^9, 
  3.464350779914143*^9, 3.464431556046875*^9, 3.46443226610501*^9, 
  3.465207644473008*^9, 3.4652082778721247`*^9, 3.465209023267702*^9, 
  3.465209863432378*^9, 3.465222154289105*^9, 3.4652260175738573`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"home", "/@", 
  RowBox[{"{", 
   RowBox[{"4", ",", " ", "6", ",", "15", ",", " ", "20"}], "}"}]}]], "Input",\

 CellChangeTimes->{{3.464302285149034*^9, 3.4643023197578993`*^9}, 
   3.464302447448503*^9, {3.464302510768528*^9, 3.464302511771138*^9}, 
   3.464302726609606*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.219643130711698`", ",", 
     RowBox[{"-", "1.332049064664961`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.543977089178004`", ",", "0.440327804070218`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.266285287369231`"}], ",", 
     RowBox[{"-", "0.6027661646416459`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2134130592290726`"}], ",", 
     RowBox[{"-", "0.6177189799887469`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.464302320616192*^9, 3.46430244827806*^9, 
  3.464302512777923*^9, 3.464302727636747*^9, 3.4643133110657578`*^9, 
  3.46431355766029*^9, 3.464314113789065*^9, 3.464317323376471*^9, 
  3.464342016688998*^9, 3.46434674702983*^9, 3.464350779947898*^9, 
  3.464431556086747*^9, 3.4644322661443167`*^9, 3.4652076445271997`*^9, 
  3.4652082779162416`*^9, 3.4652090233165007`*^9, 3.46520986348633*^9, 
  3.4652221543436327`*^9, 3.4652260176425667`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Text", "[", 
  RowBox[{"\"\<\[Tau]=4\>\"", ",", " ", 
   RowBox[{"home", "[", "4", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Text", "[", 
  RowBox[{"\<\"\[Tau]=4\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2.219643130711698`", ",", 
     RowBox[{"-", "1.332049064664961`"}]}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.464302827273375*^9, 3.4643133111107063`*^9, 
  3.464313557714877*^9, 3.464314116352165*^9, 3.4643173234216757`*^9, 
  3.464342016735955*^9, 3.464346747065364*^9, 3.464350779992338*^9, 
  3.464431556125779*^9, 3.4644322661785107`*^9, 3.465207644578888*^9, 
  3.465208277941927*^9, 3.4652090233537083`*^9, 3.465209863540324*^9, 
  3.4652221543902884`*^9, 3.465226017706761*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"homePic", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ParametricPlot", "[", 
     RowBox[{
      RowBox[{"home", "[", "t", "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", " ", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "]"}]}], ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.2"}], ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "1.25"}], "}"}]}], "}"}]}]}], "]"}], ",", 
    " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"sampleHome", ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", " ", "Red"}], 
        "]"}]}]}], "]"}], ",", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Directive", "[", 
        RowBox[{"FontSize", "\[Rule]", "12"}], "]"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[Tau]=4\>\"", ",", " ", 
         RowBox[{"home", "[", "4", "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=5\>\"", ",", " ", 
           RowBox[{"home", "[", "5", "]"}]}], "]"}], ",", " ", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=6\>\"", ",", " ", 
           RowBox[{"home", "[", "6", "]"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=10\>\"", ",", " ", 
           RowBox[{"home", "[", "10", "]"}]}], "]"}], ",", "  ", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=20\>\"", ",", " ", 
           RowBox[{"home", "[", "20", "]"}]}], "]"}]}], "}"}]}], "}"}], "]"}],
     ",", " ", 
    RowBox[{"FrameLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<x (voltage)\>\"", ",", " ", "\"\<y (refractoriness)\>\""}],
       "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.454403467982409*^9, 3.454403529433229*^9}, {
   3.46430226220428*^9, 3.464302269878208*^9}, {3.464302351692335*^9, 
   3.464302373791965*^9}, {3.4643024583048897`*^9, 3.464302469553069*^9}, {
   3.464302521062746*^9, 3.464302570416223*^9}, {3.464302707179512*^9, 
   3.464302737496312*^9}, 3.464302769679715*^9, {3.4643028550257273`*^9, 
   3.46430285686576*^9}, 3.464302893486408*^9, 3.464345157914706*^9, {
   3.464345371701696*^9, 3.464345382201085*^9}, 3.464345465864626*^9, {
   3.464345522178081*^9, 3.4643455311892433`*^9}, {3.464350923215569*^9, 
   3.4643509685255127`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi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      "]]}}, 
   {RGBColor[1, 0, 0], PointSize[0.02], PointBox[CompressedData["
1:eJwlzXtUUwUcB/DBVGzQY0hDQNjG8IGHhR7IHAe4y+gYZjE48wHi42zykKED
G1EQ8cjHJNGNYGHRiYyAhWh0sIKw30UbAwYi8ppzPNqFxbEE8o7BNhjde/yd
8zvf8/nj+/uxRdKEFFcKhRJFLJnPxwt9nkEow0IrCzlB49fW2rxDfNnosKj1
yBWfF/irdftfLY/ehNZ1qm7P6t3465X5sjmqN5oeetg/9pt1/IKdGWHPpJ5o
rAc9Q5iylt825abtmfRATXrOryWha/jJYvs7bz9Ziy65S/wmbK782NzPBz+F
VWBU2t4c6nDhC2SMm56CBTDeTZnVfEbhtzd9zxC1zECWJClcJXMi5yNrHzAn
HkKxoCrao9WBvF/b8S7z7O9Iwq3leHbLEtJGL2oUvmZE4n4OVmX6LyAeDT4v
KtVmhAcu5y+w5pGTthh0yu8pEjqVE7dqGEHEug4/W8Y8sseq3sjLdkDivSPn
qtfMImJV37zWl4I+zMunnw6cRrp/E8ibJ5xgLtUZZMUGhGV9pTRMsQIwJrrZ
nN6DMAoc2w3xyyDM20Krv1SDnIkYRiM2O6B6l/XZul/a4cHHx7krNDu47eMc
lFzuA6ep4UsL1QaIM1zg/t8Q9NWwZP70JfiwPUj0w+QjMLOUloqwRfBd7aIO
3h2DJ0P+9ouZVtBrmzHFiUmYjnBd9LqzANciNQ510V+wVR5SxtyyABuC+9mG
BBP8YaVWMxosUHxVGvOd2QT7SkqTW/ZYYLRJHmOMxYAhz1zfZcFByek9dFuO
Ab2bWhLQjkMSEqIsbcKA5XPyfnUlDon6oLOjKAbUrwIUigIcqG2HZDu6MRhb
bKgPysKBW8e7mqzDwKg4MDJyCgdftY53pQcD97Gjwt40HN4LXkpp6cLA8LUb
1UJ4+BR2a7ATg/vXUm/Y03GYfCzGDmswGHg03s/JwGE0e3NV0p8YaEeieb4S
HECQ+0/nPQwc5kabhrCUuzGqkLBUYqjiZuLArm8SpRLuLUeviwj/tJvFJV1x
IzU5l3A4Ms7MIszxnovLI8yo3O35CeHH+hphDmHNJteoC4RfDunZfoZw/p0d
uWWETRtaG9MI9146N6MkvG1gYJy8vy1JFVlBmLlrpf844adb43dWkv+5eQHH
CO+1dolJz7zOPnaU8KxL2huk1YFeoaRbC/3+JfvO69NvkT7ACVST/vag/TRp
WqHPR6T/zun7grTXXFwi6cv28mbSPwoL9pLOjuFpSeteco8mvf+D5UHSjUXG
CNL/A/06GXE=
     "]]}, 
   StyleBox[{
     InsetBox["\<\"\[Tau]=4\"\>", {2.219643130711698, -1.332049064664961}], {
      InsetBox["\<\"\[Tau]=5\"\>", {1.903463558678336, -0.2948684251322862}], 
      InsetBox["\<\"\[Tau]=6\"\>", {1.543977089178004, 0.440327804070218}], 
      InsetBox["\<\"\[Tau]=10\"\>", \
{-1.7699834517478101`, 0.03230020522027091}], 
      InsetBox["\<\"\[Tau]=20\"\>", \
{-1.2134130592290726`, -0.6177189799887469}]}},
    FontSize->12]},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox["\"x (voltage)\"", TraditionalForm], 
    FormBox["\"y (refractoriness)\"", TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{-2.2, 3}, {-2, 1.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.454403498365636*^9, 3.4544035312138977`*^9, 3.454404222975378*^9, 
   3.454404414638691*^9, 3.454404801567255*^9, 3.4642128209588213`*^9, 
   3.464213219525332*^9, 3.464213562962798*^9, 3.4642137123153667`*^9, 
   3.464213847456972*^9, 3.464214931135415*^9, 3.464215113112249*^9, 
   3.464280564260029*^9, 3.4642913417368507`*^9, 3.464302495815267*^9, {
   3.464302531546275*^9, 3.464302571335929*^9}, {3.464302682708273*^9, 
   3.464302707946349*^9}, 3.464302738605901*^9, 3.464302770301959*^9, {
   3.464302848620085*^9, 3.464302858065358*^9}, 3.464302894890439*^9, 
   3.464313311199771*^9, 3.464313557762064*^9, 3.46431411874034*^9, 
   3.464317323479332*^9, 3.464342016789616*^9, 3.464345159802806*^9, {
   3.464345372895403*^9, 3.464345383006947*^9}, 3.464345415211446*^9, 
   3.4643454665872498`*^9, 3.464345532483973*^9, 3.4643467471087523`*^9, 
   3.4643507800435343`*^9, 3.464350969663878*^9, 3.46443155617458*^9, 
   3.4644322662776937`*^9, 3.4652076446326733`*^9, 3.4652082780027122`*^9, 
   3.465209023405054*^9, 3.465209863609413*^9, 3.4652221544476833`*^9, 
   3.465226017774928*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define starting point at locator", "Subsubsection",
 CellChangeTimes->{{3.4642148908474207`*^9, 3.4642148987693167`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"startPt", "=", "restCond"}]], "Input",
 CellChangeTimes->{{3.4642149019742203`*^9, 3.4642149114217987`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.199408035244027`"}], ",", 
   RowBox[{"-", "0.6242600440550339`"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.464214913781212*^9, 3.464214931169609*^9}, 
   3.464215113139292*^9, 3.464280564285508*^9, 3.464310533227355*^9, 
   3.4643483493821907`*^9, 3.464350780078475*^9, 3.4644315562197523`*^9, 
   3.464432266297249*^9, 3.46520764472815*^9, 3.465208278023131*^9, 
   3.465209023433997*^9, 3.465209863637525*^9, 3.4652221544717293`*^9, 
   3.465226017799581*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pre-evaluation Pulse Resetting Demo ", "Subsection",
 CellChangeTimes->{{3.4641993712513437`*^9, 3.4641993762407293`*^9}, {
  3.465208339204925*^9, 3.4652083773726387`*^9}, {3.4652084152559643`*^9, 
  3.4652084156462317`*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection",
 CellChangeTimes->{{3.464199384274931*^9, 3.464199387721652*^9}}],

Cell["\<\
This notebook continues FN_Reset_Demo_2 and FN_Phase_Plane_Manipulate-v3.  It \
attempt to make the time resetting animation used in the Oct. 2009 Binuaral \
Gang talk.  \
\>", "Text",
 CellChangeTimes->{{3.4642910396154346`*^9, 3.464291062180572*^9}, {
  3.4642911010183992`*^9, 3.464291177594282*^9}, {3.4642982313194723`*^9, 
  3.464298231489682*^9}}],

Cell["\<\
Oct 9, 2009.  This version doesn't employ the zero reference of \[Tau] used \
by Rabinovitch et al. \
\>", "Text",
 CellChangeTimes->{{3.464298234202386*^9, 3.4642982408276787`*^9}, {
  3.464299660733815*^9, 3.4642996915924807`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Defaults", "Subsubsection"],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"$HistoryLength", "=", "0"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.4541722714948483`*^9, 3.454172275256866*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "=", 
   RowBox[{"{", 
    RowBox[{"True", ",", " ", "True", ",", " ", "False", ",", " ", "False"}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ListPlot", ",", " ", "ListLogPlot", ",", " ", "ListLogLogPlot", ",", 
      " ", "Plot", ",", " ", "LogPlot", ",", " ", "ParametricPlot"}], "}"}], 
    ",", " ", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", "fm"}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"AbsoluteThickness", "[", "0.5", "]"}]}], ",", "  ", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4250481029254737`*^9, 3.4250481052287855`*^9}, {
  3.425062110167573*^9, 3.4250621789865294`*^9}, {3.425303920673715*^9, 
  3.425303923868309*^9}, {3.42530433059315*^9, 3.4253043309937267`*^9}, {
  3.4318823438938723`*^9, 3.431882344314477*^9}, {3.4319665718251886`*^9, 
  3.4319665807680483`*^9}, {3.432154490583699*^9, 3.4321544913247647`*^9}, {
  3.43247291260952*^9, 3.432472919649643*^9}, {3.4329195760279183`*^9, 
  3.4329195766788545`*^9}, {3.4333274411328096`*^9, 3.4333274419640045`*^9}}]
}, Open  ]],

Cell["General parameters", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[CellGroupData[{

Cell["Threshold and spike identification parameters", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"A\[Theta]", "=", "0.6023486832959924"}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"tr", "=", "3.660637667467016`"}], ";", " ", 
  RowBox[{"x\[Theta]", "=", "1"}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell["\<\
These are the same identification parameters used in \
RelativeSpread1SpikeAnalysis.nb.\
\>", "Text",
 CellChangeTimes->{3.4105389925978465`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference stimulus parameters", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Aref", "=", "0.6823310565208429"}], ";", 
   RowBox[{"Tref", "=", "3.5777087639996634`"}], ";"}], " "}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["System parameters and resting conditions", "Subsubsection",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"restCond", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.199408035244027"}], ",", " ", 
     RowBox[{"-", "0.6242600440550339"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"a", "=", "0.7536174776529205`"}], ",", " ", 
    RowBox[{"b", "=", "0.7453384466666666"}], ",", " ", 
    RowBox[{"c", "=", "3.280762663367654`"}]}], "}"}], ";"}]], "Input",
 CellChangeTimes->{3.4105389925978465`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Compute the home trajectory", "Subsubsection",
 CellChangeTimes->{{3.453811048098934*^9, 3.4538110556181602`*^9}}],

Cell["\<\
Recomputing the trajectory used to approximate the home trajectory in \
MapGeneration1:\
\>", "Text",
 CellChangeTimes->{{3.45374576401268*^9, 3.45374579935464*^9}, {
  3.454083154974017*^9, 3.454083168812688*^9}, {3.454172826270878*^9, 
  3.4541728323415947`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HTtraj1", "=", 
  RowBox[{"First", "[", 
   RowBox[{"NDSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["x", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
        RowBox[{"c", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], "-", 
           RowBox[{
            FractionBox["1", "3"], 
            SuperscriptBox[
             RowBox[{"x", "[", "t", "]"}], "3"]}], "-", 
           RowBox[{"y", "[", "t", "]"}]}], ")"}]}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["y", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
        RowBox[{
         FractionBox["1", "c"], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"x", "[", "t", "]"}], "+", "a", "-", 
           RowBox[{"b", " ", 
            RowBox[{"y", "[", "t", "]"}]}]}], ")"}]}]}], ",", " ", 
       RowBox[{
        RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
        RowBox[{"-", "5"}]}], ",", " ", 
       RowBox[{
        RowBox[{"y", "[", "0", "]"}], "\[Equal]", " ", 
        RowBox[{"-", "10"}]}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"x", ",", " ", "y"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "30"}], "}"}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.453745725222678*^9, 3.45374572703522*^9}, {
   3.453745910077889*^9, 3.4537459217259083`*^9}, {3.454075072113729*^9, 
   3.454075115609201*^9}, 3.454083149144436*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"x", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
      "]"}],
     False,
     Editable->False]}], ",", 
   RowBox[{"y", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], 
      "]"}],
     False,
     Editable->False]}]}], "}"}]], "Output",
 CellChangeTimes->{3.4537459283905897`*^9, 3.453822563024613*^9, 
  3.454172845497025*^9, 3.454181417941701*^9, 3.454401442271394*^9, 
  3.464205179904229*^9, 3.4642129957066717`*^9, 3.464298123762899*^9, 
  3.464313309927615*^9, 3.4643139876420794`*^9, 3.464317322055788*^9, 
  3.4643420156074047`*^9, 3.4643467460779467`*^9, 3.464352172572607*^9, 
  3.4644315854034863`*^9, 3.465207754716876*^9, 3.465208381943446*^9, 
  3.465209023598686*^9, 3.465209863804088*^9, 3.4652221546249933`*^9, 
  3.465226017981718*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], ",", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}]}], "}"}], "/.", "HTtraj1"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "]"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453746050875828*^9, 3.45374606495859*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwd13k8VF8UAHBEpNJi30eWyj6DwVjeQSXSJoSERKgsIUv4hZCE0GKpqIgW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     "]], 
    LineBox[CompressedData["
1:eJwd13k8VF8UAHBZCkX23dj3dZjBIO+kfkKy7yl7aJGlCC22UFFIWbJVtlJC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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.453746066116218*^9, 3.453822570710825*^9, {3.4541728503601522`*^9, 
   3.454172878087193*^9}, 3.4541814205196247`*^9, 3.454401442426218*^9, 
   3.464205180513975*^9, 3.464212995757065*^9, 3.4642981268358393`*^9, 
   3.464313309980811*^9, 3.464313990047204*^9, 3.464317322115099*^9, 
   3.464342015668997*^9, 3.464346746135202*^9, 3.464352172649458*^9, 
   3.464431585457605*^9, 3.465207754766749*^9, 3.465208381985058*^9, 
   3.4652090236576767`*^9, 3.465209863878332*^9, 3.465222154680162*^9, 
   3.465226018060247*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], ",", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}]}], "}"}], "/.", "HTtraj1"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "]"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4537460237326307`*^9, 3.453746035849173*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi
+3yQUTIjKfva83LNSL9z/Pzj9X7dzzjnOc95zvMRuuRiaEdHIpEi6Ekk/P//
fzuJ//8XJew/3qu6c5+NONY6yJL0R4Rg3CkuHKLBQnRPq6Us00SItkUG2RgT
RiJV6YV8wqQIYTFnyde6j55Q8ZRRixkUIU7RxXfTHEjEh6zIM5u7RIiFD2Jd
GR2rcF15zxHm7yKE0tLpx/sOLsFsMbagjC8ihOZLz9y4N3PwTjpf9W8oQoR/
T2QscZ2E5C93Pr7PFyH616OOwRAKHONqWhLPEiE8mVhPrRs9hxJePqPj90SI
3K8vFDe1NAPXzTxM8lEixDlF2u1t8gNAJt/FiNtPhNjb/KPFhZcGtAQm8h5c
FiEyRLQyuxiWgf5Br7vyxiJEeepJ3j5iDSxdFAl0OiVCiL/+PdN3j0RmolLy
VJVEiGJZeYXziXTkTQmL9OUHRIjkfR7Wu/U3k+3LP7pOCogQzwaHPnDWMpC1
Y8HhTlYRQr/jcLrnKiPZTZ/hQ/y6MOG09GgNzm4ha+e/qdwzI0ysXpPnn3jP
RNZo5h+J7RUmtvVeeTqiwUy+lfaUd6RJmLgkeTbO/gMzWXgpJe8IIUyMaiUv
HGJgIetlL8a75woT0mdT9jeSWchDx5zU3z8VJljbzR7EXWMhe+oOnJyOFyba
N/t/fxrFQtYQkj8hFSRMBATMeyimsZCpLHZCrm7CREvc9qe1WSxkvviWK4U2
wsSx85s1RD6ykC8piglvMRQmEqR/WLwuZCHPDf3afVFNmLB5SBW9WMxCvnLp
8VSxjDCx5G6yY72IhRxMvFvbKyJMUPv+qOxC1wdyRiTHcQoT3Br217nzWcid
KQXLjJuFiYZX23+ovmchO7O+0IiYFyLeM5tYfH/LQh5+1P+QfUiIqPat3jr/
ioXc8dOAIb1diGDy07I895iFfJGmZEEpECI0+41+aoSj8fRSXFpvCxH1Yslp
5wJZyKI/O+VeXBUiIiTCNcy8WcjfOA33BZkLEd33SkoMr7OQX740jTmvIkQ4
WasrihqzkAXCRb47bBIi5GAI10cxFnJuJ01L/c5e4liFgrWYIAtZVkgyx8ln
L6HaHHryIS8LWX2XcPTTa3sJwZtGa75bWciGeunBErp7ieCvxpYGs8zkP8UZ
Le9Z9xKd96PjecqYyTmGSXvtxASJ0O9HssSMmMmTL30Ebp7aTXA/unpaNIKJ
/JNqMAHqdhGd/uVDZ7dtIW+5sEfuyBonMb07eDknjYH89FT7OKG5nQjPydMo
49pMvnVna/NXawbiRUSIMAP7ZnJbfkJioBoDIRN+hXSGZTP5AOfLQh1RBoJb
+X1h1zo9We33VXqB0c3E0Q9vSGsj9GT1fScuv3fdTGwT1+Q6VkxPrvy1rfNx
GD1xIvMG+aUlPfm+kJiVbPkmwlPBRYDtFR150bVXW6J5DZ7aftPh+1M6ss+p
30pdyWvQpWDY6uF/dGSGb4LcJTZrMFJdWWfPXWSPmwcWaatQkDv5t8RNOvLK
64uKVnyr0KSiyGKfOh1ZfFz57Oj1FeisPBXW0rOJHEl7flv+6CLMZ3/6MuLn
JnIK0Zb1h34RnsivkVNp3UTuOSE2OdyyAAeFe+NfVm8iayQLArnrC5D7rC3z
jbebyPw8Ri1PMuehtc3PP2O3N5GTZ0HvK1EalEuq/qK7cxP5qZVh7agiFSoc
Mf7CvH0T+fePrV+VtlHh0sXl6eotm8hS0grdVnAGRhlPPDu+SiJ3ktjSGbfP
wBQ5aCowQCJ/e1E5lZw9Bd3MBmNzc0jkdcG76rlr49Cp7UTVdh0S2bOu+3x2
/RB836Dw7Y06iSzvxmLW5j0Exf+mPdRUIZEtPYQklSWH4IXVp/aeh0lkuqDU
N81Rg7Be4E1IPTeJ7JWm5s+sS4H5nxbTbGv+gWcPHgc97uqD3pYvjxcvrIPZ
ijjq7ws/oe7t3/Dm2DpoeJr8frC1AzaG/ict3b0OftiFbzE73QHNno1m3f+8
Do52tL4LUfkBAwM5FE8kod/vJGf+Fm+DStnnZ6cOrQNr5zqqE2szVCBtcw67
8hcIfdhilHmWgM+uZER8M/sLvEJEY9o/lcOA+4fPs535C4xqODjnGkoh15xf
W4TsX+DjecllZr0QBvVt269O+gsMjYO3j7m/h+NXtnP+TF4D/Xe/3TPQCYM2
RRaH+WpWwa2kiJd+lUXguY/w9sefVkFBxqUSx2cl4FMTZwXv61UQmkrijfUv
A7suNZ35c2cVdAe8lC1PIYB3EKv/5bOrgH3gHTeTxmfwK3SlrPDXH3AkWT5G
73o9SC5ZfP12eAW4wRdvemLbgKaOmSJPxwrYnFvR9nSpDZxTP7nJs3YF1Pi/
8l6wbgc6zu9fcWWuAAfJG2+NZX6A9tv3GeodVoDYyHjNalMHaMoPDJkdWQZL
HAuzI4u/wH3H3ZZdv5eAdWSJKfV2HxD/J+9SWr8E1O/HqW960Qf6mYoexpYs
geyPB+9SmvqAFA/vKbrUJSAs815PQKwfKGiytEibLYGL5OlGy4Z+wJFuwXax
dREoFx1a3cdFATePHH18pGIR6BxbKDFQoYBG+zhRWs4iiBG5O6JtRwGXT18e
PR67CGIN6G/mfqSAYOOjkb9PLoIZDwZOvbODIPhqfNTmggXQPDB1uyZoCPRM
3DsQmL4APl3m+kD3agjEHRf+MxC/ABgnm+bYvg0Bzo8kJ4trC6Dg2nbLx1zD
IGuv5CcOwQXw9FFAbPDLYZBGyzHgDJoHttZ9ux3hCNg9QWuocZoHfMYvVHL6
RwC98QKDmek84Dy9z66afhRsuh0/zH1oHhinBDvaaI2CajvPwcFfNFCf+v2O
0bdRkJ38WG33ARqI3e6wn6thDJzU/8vXvpMGdg+co8+bGAMl8xbe1utzwEs/
cWIPyzjQ4y/aPt08B/5xhxg6nBwHhYlcErXuc0ChMqHzY+k4iJzXeLNuPgdU
XYPeNnSOAzNjr92bNObAdDyjbP7iOOBbvPTbhnMOEH72cTOHJkDusLjt9ZxZ
4Jb+9ePWpxNA+mzy2M/7s8Dkk5ruvZIJ8Ij2yJvedxa4WtL9HPsxAULvy2gk
as2ChJS4ij/bJsGvPfsTrvymgsNr2pJvb02Cmcvm7O6jM+Av2x8BJvIU4Nv9
hDk6awacidYXVzadAox5hcy9zjNAqd20X8F1CngIFthLUaeBV/PWotAnU+BC
0/OnH8enQHGA2NKV1SlAc/sAeF5NgQZj58p6jmnAUL2lOuzSFOANplrNS0wD
/y/pJx1/TAL+oLWOu+emwbk/irL27yfAwOHKzI5X0+AW9W6rtt0EUK7OltUp
nQZfmv6BeZ4JcP35zts+zdPgqB+V3+v2ODDSDVDmWUbPV3d+fnzfOPj7QkAk
cOsMCC3YtJTaPgYa0r49z9gzAxyNuzXpDo6BZxlK0wIaMyDFvq5gum0UlOz8
NnLdeAZ8VWj/p+E7CpzmNv30cpgB2xRTWuarR0CdlkJY7p0Z4JVr2JCtPgxk
noU2xDfOAO3dFcP+7UOA7bTv49+9M+BDe+KrVtsh8EZPMq+GOgN8ygxK0nwG
QZ4Kg2UJExU8ep52tJduEHyt111JZaeCoSpShnwEBbxdTNyizUsF134/ms8I
HwD0cLvmZgkq6CUrlflsGgCEUaImuzQVdMm/jBvw6gebD6nqDcpRgWIf/38f
JvsAxSZOOOA4FTi/L/mvzqIPTO68GtyrSgXZ/13Nm0noBT/GuHZsPkUFR9wc
+w5c6gEaZncdJs5Qwbmo7KAfo79B+wny/TVTKvAMn3UPTvsFzoNANRFLKggL
2KYdq9MJ2GQY/BkvUwFrpSM1erIDXHLsDMmwpwLvGK/P20J/ABXjc6Gr16iA
WahtJY29HRR4ijxkdqUC0cfnIr4kfAfcqV7wmzsV2EPHB+xbWsG9xZoJNU8q
mP7e0U9zaQYp05Wzjt5UoOQydrXnYQPo0k66C/yogLOasF6U+wpsmFscKwKo
IME/ompXQQ0Q+MO2fSqICvi2HrsszVcFJD/+m4EhVMDu5jl5gCgHFs9THRTC
qED6Hgy2Zv0E5Ha4FRiEU8FEWQbbTdls8Px2yTpTBBUoT4rcWr2TCsLIrboX
kTPpE+344m/DHa8iE3SQdwhNdNYUZsDfZikvGtD9TRLPFvc5foD9d2/qUNDz
Y17fWJSuKIUS1cwHIkOpgJQ4rsIhWwXbHGx7CoOpIC6oa7boYB3kWzMddwtE
658gby2q1wDZtlXX5KD5BZ9fZf59ugWym93pv47m75lcb9O0uQ2m7D6fnnWL
ClQfnNw62vIDJkaz3Lx0gwr2mP/tWMzrhCbjYrVxzlTgfvJb88tXXfBX7TrP
YQcq8PCwvHgjpxf2KF79Cy5RwXxb32CTbT8cZm+WKjWngtLq6i93kgfh5Ijl
gSldKnAyviHcpzIM68/9cnykQQUHBj3W4dgINKLtoL5F+bS6eUmb+ewEtHkn
bjSO8nE+ny6Rg2UK2ly6HbFzNxX4nb3JPvx5Gp5+KF35HwcVPM7rE1kQmIXc
5IxYz9kZMJ7eoOq2PAs7SvaH5/6YASxzCpHPWuagHaPM3cziGeBUoT/59hUN
5p7ij7J9PAO8/0t8Vnp7HnZ9is0Y958Bfzp8+TZpLUCri6lWalYzQKwi+lr+
9kXo8CTO0uPEDFAd3LfwMnoJfuds04pbmQbbVJMCF44sw8tSa+b/OqZB4WXy
bevWZWh1p5FyP38aTNaxCKZeW4H0MXO+FxOnQWf+nIjD3xW4Xfwau831aZAW
VfDf04g/cOSU+I8sbVR/+izIh1hWoSyXjLi26DQoT6a/fXZ5FWr7GkxkdkyB
HDoOcTbbNai1M2UsKHcK/JdDS7hRtwa/q5tc/BU5BWr9WCXei/2FOUP+86XW
U6Di1RFDZt+/8ImDLKOc4hRoEZXcUVH/F869VIzUZpsCjvdexYpyrUPm1ld/
GIcnQYceX02I6Tpc89vldLN0Etj3htoeebAOD7fKeD5OnATi+99dDGpch028
RyUiHCbB+eRdn2o3/YOyB1vFlE5MAkvhOCOTw/8gf9CZ0DLOSRC1rSw96MI/
+Pb67TmesQng1KyvdT/wHxy+zPtAv3wCsMZKK/U8/wcNKsiHryZNAJP9EbMZ
Ff9gcrbXNmcHdL543dKR7v4HGUyb2C6qTABff9bIkoV/UOx2JTyxYwL8iRf/
9ZmBRJiYRytzj4yDS1Pd6o5sJGLlas2FkZJxoMSY+t8QD4mwr8u9mx8/DtZn
+v8ZCpKIiiQv9lC7cfC18rB5nRiJkB9hqzBSGgeEk4aG+QESEfKlTV+KbRw8
STyuLXiYRKg0KwqxDo6BzfwHCXE5EuGWL319qXAM3DhzWDVYgUQsKqfKTMeO
ATOOZkVVJRJx6oKNGu3SGHjySvWNmzKJ6Bv9pMqkOAbWI8Zu7T1BIjI9LuRI
s46BYe08ezNAIs7uZxu2HxgFJ4snpSTIJGKnseHu/E+j4MzypfQk5Jj3qW48
saMg/tmud6+QGSgc/XGXRsF1FTvPa8hHaLznBBVHQcGZLbbD6HkBIhYPalhH
gfaN9qOCyPvh+SvhlBFgXv1zmwB6v/YHk6tWRSMg0XTYdwCNb+z5g2OGcSPg
vMbkPc/jJILzX9cFK7sR0B17erb3GIkwinPUijg+Am4o+5ULKpIIDvf9175y
jIDGLNUvSkdJBN/aO/H9o8MgdPwoK7sMieiyic9Tuj8MhPlsTzQfIhE6Jdk7
pq8NA/LSsSxPKRJBnak8UK42DFg41M+H7SMRZTu3nMunDgEZ28z0GbQeqsp9
n7pqh0D+taXT2iIk4vTpiSChJ0Og+sWd0ebdJGJWYbyIXm8IrJlNHzTaQSK8
Un1XDr4bBNyGMiGCaP3rdmRojAUNggLFatC/lUS4mkgX1RkPAkaB4Xg9lC9B
QV8Oz5IGgaBI9o6vM//gvjoT9VFjCjjtGKQ+XIjybWu2swPzABDp5Mgr1v4H
C6oWmuLZe8HtOcs+hevr8EK2/SvL1nZAzTSIaW1dg9yFnxT+Pi8C/7Xs+bV2
bRVe7236yeH2EVYHvlljo/8DQ0UNQrnmGmAx3wkuxvUVeH7N9nyATCMU2K3V
83d5BcpfL3J4faMRmh4kh8xNr8Dvgk+3g7lG6M2QKUL9tQIZmBZ5bk43wQ83
33KpfFiBIp1VgilTzXBezDlqr90KPGQo33K3qhWK787kEGtchm12lqGTvD9g
dCwz574vy/BGdva+QdkfMHWi7pDU52Woy1nsV6r3A0Y8KCtTKV6GXGL9qWyh
PyB3Lr2y18tl+Iotykht6gdkO3rg5LmAZcivyCAxU9QBTWcFP72QWYaM++6Y
s6t0wiqJOL6eJ0tQYGbgXdLMb6jv1W4dlLoER/badnDTd0EYn9Um/nAJsjv0
uwdxd8EnMs5aXneX4Ou7D01YVbrgjwn2q/J+SzD3hR0jXVQX9IGHJHeZL0FP
VdEhV4FuOPX8GRHNuwSdWrRr5470wE+/TxxW+G8RyqZps42z9sEjkmc/ZD1Y
hL4v1vNdd/bBpK97lIWTFqH19dqGab4+eM662JorZhH6hD+83iLRBzlfmNLt
9F+EvdD+5BHVPtj79SmT+6VFWFupBm1u9EFfA8c9JQcX4d0Ao+nCxj7YYuOU
HFW7AA3efGVtdO2HPUtH0lQ/L8ByCY6ybzf7YW1ynNAasQA/u8m6VXn3wyOm
Kc+9ihfgtVwqc0poP/Q3TUqOe7cA/xQljg897IeDvGYv5O8tQNG7q3WsZf3w
ip2tq+3lBRgQWvG2adMAjFwLfWnGvAArnfZ2d90agOc9ZEX7GBfg8/3kkaHb
A3D2775Oh80LMGzMrnDMdwBKv30zGvhvHgba+9f2Bw/A3OOGj+oX5qEROwnc
uzsA8ywDT9UPzEPuggOft7wYgCvfuLndy+eh4Pc3ZoaNAzC2+8x2M995eC/Z
vjuPkwKze0qbbnrPQ2e7h14JXBQYRpPLuOc1Dy8tmjo48VDgGVOH0J8e8zBm
bc2Uh58CV1jnd952noe+FUWMasIUqOirxbbbah7m8rp8nz5EgXYe919Nqs9D
Os1nurWnKDBK5s83HbV5eCGaVnhMhwKFXnfT3pDn4a0jvuyvT1Ogk/dddTeV
ebi3wSrJX48C7z5/1M6lMA+5XqdfYjhPgZYFmfzlkvNwMO77YpglBS42f60M
45yH0pWTB93cKDBe5Uv85h3ofgtTtmc3KPDsoa5HYezzUITh7VyDOwUGb6u4
epcVzadVpGXPLQosTa4oLd4yD713nfN/7E2BldumBPzWaJCkabmyI4QC1+Lv
ZT4ZocE5+v0LpEQK/PaeseLyMA3KiVDSfiHvHeKa2j9Eg4KVw0PvkygwcJeB
d+kADToohFia3afAHCdn8KebBg+2ZXrFJFNgipImV0cbDa4OaUhEpFHgQpN5
DctnGmQLYHk7mUmBPr9yeQSraNCv1SDM6zUFurMpbJWvpEH5fwkVdG8o0GWR
+7sdQYPREg9cdmRR4H+Zg2W/SmmwOjJtZc87Cnxo9aiMvYAG81qehM7kUmBZ
GIk3/TUNju2IexDyiQLbTOV+j2bSYIv6QGk/sujEfo7DyIK+0S9OFFJgwrcD
TZUvaZBf+HfdPHKjuKbDSjoNXuQJyzAspkDWbRl5r9NosNGlk7GjlAIz96un
bL1PgxxGTno7KyhQZsdyues9GrTUOgPPIwdyPrXoSKLBqYOb+e4hM39LXspM
pEHWa1XJbJUUKM3YeeNiPJr/oNz2P8jis+15zDE0WEMSuvDkMwVG+pbahN2h
QaWIIqIJ+ZZogz0dMtEYq/IP+WU3cCNFo/F/Oh1qXk2BUgGHydsiaXAlov4u
cw0F/jT4SW8TSoM5rQWdKrUUaL86cGg2hAadtvL+tEZ+xO2QGIzsxR+9MwRZ
/3vDXGYwimfmC4Nq5H1tvqP0QTS4ub5rp2odBWouslOofmg8nQY1PF8o8Op+
19Ak5LGZ+Q+HkJWMtysrIOsG8dFrIbP/pzAc5EuDxtIvG9yR/xbEzoj40GC6
w6B2DfLB17V7U7xo0I5HON7gKwVaD/1+egaZl0HnmBWypCYTGz2yX4CXvTOy
6/dT2a6eNBio1m8WiVzP/KvG+BYNbo9+UlmIXB0SGrYDuWLJoKIK+bE0l2jT
TZQ/eR/PNiJHl1BWdJDpliqlBpA/y7B36HrQYJOIzvrmegrc87HmMhsyl3l3
/jbklBzTylZ3GryaF7x1J/KDIuZpc+ThN7IPhZAd+V5+EkLuI5s0SyBb+/Ho
jt5A6/eo+J0Usl3Uk0ZP5DeJZRcU8e9hTkVkZIfO2YMqyJ1b7RxYkIncN5mq
yAXaQ51tbjQIBGWaNPHv17S3PUV2P9D6TBtZ/MnU32vIY7/bhM4gB7NLv1NE
llYINTBAbpq8wsvohvNb8tA55FnreZU2Vxq0YuKARsjfUmQE0pFt7wRvMkVW
/+z3/gayy/e6JTPk46wya2rIrCNS6ebID59l/eFErv+2uvkislL2yawhFxpU
uOO7xxKZydpqWyFy774/VOwhylmBO8j6b8v9rJDzr3h3WiJzCeyswZ5aklOT
Rf5koVGPndXZe54JWdsv7C42NWGOrec6qj8SY+zYeV0Tbh+R+577ncPPn7ip
c/sO8sSxsyZ4PEm7YkUvI4vK39htgfwsRObGceS73dMvLyCzuRZZ70Q+6Ns+
j+fb9t/T6SlnGtx0QY7JBHkcXuGrQ2Yndg2cR9ZKjR54jmyxlBRiiDw8Gq3p
jzxy6v2UPnKZ7bDqBeSPfwM24l/9lf/HUeRay+17dZB1NdmIWSca/KqdHqSO
XNzydUczMrSrGQY4vormS9nIDIYDfMrIxiELLteR46HKvCyy5MAaSR95cCUx
9RC+//To7sPIm/xHuQ4gV7avLtCu0eA2qZVwnH81Rd7PfyIvppt0CCDzG275
XIbsH+NJz4scLd9vE4VM6SqdZUWOO/3ntwvyv061fCbkwqzCGmNkBffTJvR4
/H2lY2LIHhkvji2j/fE8oFFwO3Jxi4nPHPLMukDl4lUaTK4+kzaJrC3LpPUF
Oe1ATXQfctUdZVl3ZDLfEY5aZPpdF95aIj/cre1KIO+QHI/UQean31lQhOxI
cnEQQT5OP72UhXza3sWRHVnPZsdCBjKrwuKXv46o/gbu/P0Y+fL57BedyOaR
XZfjkBPUJ/bUIVd8/LQF14PWnmpaATLb/tQHgciExbW395HPub7wdEPO1eU7
YYI8t3/WyBD5940Rr1PIvCcVbXSQA+oDtyghkwq7zNWQr5gcEtiDzCjqICSD
rHrQ4Ck78n82tlP7ked3nvWgR/aXG3sjhMzySYhp3AHl59tba+zIZi2gpht5
ydgggQlZ4UJhcwtyQui1XSQcL1eL2mJk110MDDOoHopXjIvEI3fO8Rt9Q562
MpYKRzYJNo2rQo7rvezri3yZxkkUIwcpMY06Ikvsf8n4Gtl2jkpng2ylqbv7
KbKmhqC1KbLYHNvBh/j5LtRuLWTLt3dlw5ALRYfWALI+xy4pX2RnqaoLisjN
+VZ7cb22m+1p2o/s50QsWCOPJatEsiHXBXy/oox8xFmRiRn5hJbDDRnk+5YF
X+mQD9vO3d6H3M7xlnPJHu8fU/+dyBrsFsmzyN1Dkz4syEsZ/8wnkXOCR2+R
kM+wJD4aQNa5En5lEp03oTxFPD3IGsH95gPIYnIajZ3IPqe4DH4i+/jrw3bk
CBF/9Ubk5p1LYy3IdP5eRz8jO3OZnGlEDqm03l+M/DjtzuhX5HTzJIFc5K6q
gcrPyHuPajM8Qg58pEKqRM7WDVtNQO651e0GkY9f8qNFIJPderjLkK37Y6f8
kGdfW0wXIxfIcY67IweNeywVIlcvXxlzRC5qMjnyCbmL+mXCCpmPcjo1H/lu
tOesEbJHdbLcRzxeg7d/TiOn8ISv5eHn12dsUUO+4G0+9x65MfwxryJy9F1r
Luyb275LSSOvzHfZ5uJ4DAdpieJ46PH25SAzPxm240PuPX4hHFuTUIlix9df
HDfGNmmres+I32fEfhb7il1+7xo67xOrOD2w//urx0lD/nhKGWLzSTTojiF/
D2s5gt+33ckpphcZ8vPXYz82dmxtR9bOso7G45t2JQl+Q9ZsH7uO5yOpef1G
JXKw0rrnB+RbF2e+FSK3+Qxl4PmvqhPSOcjblEbmcXz6gncnv0Be5Tptj+N3
JkOd+RFyVa7pKo5vvLRLcCLysJdVLo4/l0IzfRQyD7UurBS5IjEiNgD5KONm
n3Kcb8uFgreQixrfVOL1vV3Ba3kZ+Zf1PGc1zp/EuywXkC+frQ+uRd59mpUw
QJZi7S74hryu//HkCWTJwgXvJuR2FlFeeeStQSYXWpH1ow/QDiAvHMhz+Inz
9WN8zS7kkqnIB7+RdRvkITtyX4xtN85njshNlVuQPwsPfxhCHoepwwuoX9Mf
k/OYx/PTqMppRd5ao8uzjBxaDxK+IptXan1bxetzKNq3EjnI2+wqPdpvuw6W
ueYhR4VxOHPielHB3ZKIrOnBcZ8H14N4H7o7yPzlPN/4kXuC+E+EIAdaNNmJ
Ih8x1mhzRxZ7sOPEUeT6qHI/I+SMQ85tSsjiMkF0eshcPOu3cL34zT6dcBJZ
4cuF3lPI2qt/mxWQ3WMkZC2QG7V9WviQc/QqHoUi13ZaDQ2g/tSG8U1jFLLc
7J9dXci9Bj1b4pA5PlSatSMnsQjFpSAzlVL+1CILbPk+lo3sFlNa9Q656QfT
g1+4vrjr3fBBbj5eIyqH6q/HHpKmIHL7Jfa3x5AFviqu7ULWCgyXBcgGLzjL
dyK/LzVX00FuzHtgw4JsxXbd3Bp5/wshiUXUTy8cbDGLQe7Z/e4l7rc/lk88
H0BOdgkF0cjqYdqTI8grfjnK4cg1N7qPTCEzBXioByOXcp58v4QceTLd2Rv5
4EqC/zZ0njFNeMheQ76XaKUmj6y6hdlHD/n0sbClYGT5fJdMfuRDylLMkcj3
9hwJ5UV2TqdxxiL3votw5EIu6szb+RBZ7EGeARvyYmB3xRvkP/OycfTIXCJr
Fc3Icr/ulk9VofXWXhHjQed3+Cknjzpkoz+Wp/mRY/4TvFyDXDnF7SiITERe
NPuM/CvOO1YCOVJG0YJA9nZbva2AbBL1rKgQ+axDe78Rvp/fpPoNsmDt5r8x
yEM/2D8kIVurhC3HIX+d/BiViOz/X9pUIu4vOpTtEpDNAnI+JyN7/q2TjEOe
kGoVz0CWuxA5HY0cufciLEJ2Tz6rF4JslV9oXIps8+iNczAydx3daDnyneeS
CUHIFsy+y1XIdLGegwHII1cLWhqQbcsPlPgiN4kPX+1D9sqT2+uJx/NIMmMA
uYZX2+8W8hLv545B5L89lO6byCF1bNJjyPcvhb72QP7PrezhLLKFpKnjDeSj
sRczcP815h7e74bMMR+WtYCs+G3cAjtqa/LrFeT8tP0XXZFvsbfYbUL921Xn
m8HXkVOzS7TokQ9LqnJiKxt5iDIgX+pYfumM3JB/vZEJ2fk1c4cTMnuK9RAb
ckEhYXoNmd7gXhoHsn/Y6r+ryKL0bYacyDfiul9jfzZ58JYbWXnTTQbsa3H/
xHYjL4+SfjsgH4tg+rUH+YVrbzz2g4nIyL3I+o+jtbH1XXnaRZB7hPmr7JGv
Dx9zF0PmDx4PwXbT+7dVAnnLxAUtbPWPj6QkkZnL/7RfQe76GllwAFnNlPcZ
dk0UWUkKeZvsh+vYojLHZXA/e59FhQP7klziyyPItxT4hu2Qw9i7uWSRJRnO
lmHviLw1JI9sSHl1A/ukcqemAvKISIEB9vyqyTNF5CS7P4exg76vLR1Dtieu
cWKfa2rRPo7srrtp2Ra5cbXvgTJynVBeD7apnVyvCrKX6c1abGPeH8IAP49J
LQ9bSqjZhozHo8P2BFst5uAjVeQz8m2x2H/sFlrUkFkHIvyxi4vl6DWQfRyE
3LBHHswf0kTO7Htoh827BZieRH5yacAcu/KVoK8WcpzE8jlsjvvPUk8hM5a2
nME20W8s0EaOlHbQxuY+qNd3GrloJEcT+yF5YvkMskbtw1PYcYFr63rIHx1v
6WK7xc2SDJC1VEfPbvw+9X0dO8Bi2BRbhf/d8lnkgS+ONtgNyeHThsi0h9eu
YScNO/adQz7aPngLuy/UuvE88qH4xhBs5nn3QqON/BVKxLb5+C7NGPlcUccz
bKWTPEEmyOEaYxvxHNlfbGWK3x+hX41d0vtEyQy5Mp6+E5tltIXjAvL36+tT
2OJVZkPY8oePbcbreXmWnG+O9wflLf9GftDigyyQSQ8N5bAjT53TuYjsYiai
h81UksBmidyqwOuIbVCWFWeFXDhk9Bzb9VGyjjXy2y33COw2bnE6G2QxWm8v
9lGahv0l5CNTd4Rwvu6xHtl5Gee7Vb86Np+/LsSmWh+yxxaiBLLYId/+/SQX
W9Cu9Sk26ZtkG3bilutyV5CBhu8y9pnrT87Z4/0UaqOO91PTDvVe7IxXk47Y
Ssm6Dg7Ie7ZKJWzsN8Z3NxyRG7RL+7H5mjjmsbmC6LZu7N9jyzeuIlvlTsph
n8qzc7yGLJiTGo2tEBV+zBl535EJZUfkN6Olr7Br6TqvYhclveXE36PdRjop
2HO6TYPYE+pZS9hq/Nt1XJCfEfckcH3xyt/9Dvt08IIJ9u+GGidX5JWH7MXY
UtucvmCXNnyewM5+sCLihuO1dXA3rmfh7EOt2JJ2JiHYkbue87ojn6eUGOL6
Z3Bc2g6bPf9GBHbn65Yc7GPcvqXYt6duAg9kPR1vCVw/PwQHh2IvrztcxF4e
LKvFjmVMS8KejP956iZ+f0sjCdff8v+qwrH9PT8rYA/Nzldie8jOX8d+w6V2
9BZy48uFbuxOm33Mnrjeyh0qd0G2Cxs8hg0YXi1ie9VxOGJnb9E8hOu/5o7v
ldhK7yaeYofVu05hKxpTO7EvMidxeyE/VubkxOdHv6eXLbZ1Q1YYNpe5ZhT2
E7/dEHtG4s1bbGbPF8vYGRS9Gey9Z6nX8PnEFJa8/TZyjkLOC2zhm7EHsQ+6
+/Zih76MscUumD92zh2Z+LHXHxsE08dgBwkEPsB+r/T9M7bRobwqbM93fkfx
efhV8O5PbNvM8y7Y4U5ak9h2+pKZ2A9tbNm9kTuEv+7C5+kTyZa92IXu8YbY
tiJSh7F7SGfuYH/+5XMCO9p8vQo7uJ04jb3VPn0N2yr5nwn2O8bj8vi8Fsg8
fhmb2P3ZGdsnyssZOyFO5SW2SkXRLezr4GUPtmgbXQD2C/a/3Pj8nz1pEo4d
OkzWx7ZLK47BNs1wjcBWtzqciO0mdQdi624vfYDNbxe3hK162Oa/jedJ+x7y
QqZoizzGvuhsYI+90MvwZGM8m7c+wb52T+kpdvoX6e23kXPc+dOwTyf3+GKr
gfZUbO/jTB+xG9I/J2OvRHNMYO8Qn7qHzXV1RcgbuUXHMB57d2m5KXbDg6Vo
bEtb6zjs2rt9odjiJ7ursQM/sftjV2nIrWEX37+zEZ8QdVsZH1wPss9fx84X
c3LAFgt3sdsYb4NOGjbTo8yz2I8iwphxP+Vz+9tJbAfYewLbaYve8Y3x3dzm
ga36zEMYm3fP725sG8oeLmxXms8OP2RPtSNbsLNZpk5ir1clj+H8GahUycHO
EqB1Yv/SFKBgV6/DL9hljXXc/shl9SWvsLULovyw1wNCL2KnKqaewv3fZf5S
bWxWrV/e2OK7fOSxPSgDb7FPZKZsxRaL1mMPRP679Xke3j/yEwFt2I+TrFOw
L5ruZMb9perq6wBs2SuXVbBl903oYB/4KvUCu77cpwvv59rQC264P/U8PQyx
TbSz07FVS2efY9MUCtux1+G8PXbe8ylF3N92RE5N4frSt+vnKra4y7NGbLf/
fhwIRZYXY87BbrgcZY5tfevvdWytPpZi7Iyhkglcr7ombrmHIVecefwL1zs1
I9gRjlz1Nv0TtsKZEboIXH8NA+9he8URUti316rOYPOWhwdj34x8XY7r601D
632RyHXhSak3kOu+KdtFIUcR5bq4nlvF8mbcQb63oimJbdijUoX94mPbFuwA
g70D2JdiWKvw+aA1KCAYg8zZQFLCTgxcvY99wUhDEp8vp8oeecYiS6eP7HLC
1xv1b8XfB5YZn1bw+aWtKyKCvdc5vRObOUZSCdswtTkFm7YQZY8tcz6BH3tg
MAliOxtIiuHzkDLKZheP3M4lb4jP0wdfBiPw90j9lVFZ7K+8RAr22qUvXNha
RTZZ2Lmy3L/webzoutKA3bNz1BZbVj+MHX/fTJ9uDsHnOaXs8h1sL9MYB+wj
Zq0p2Kq2nmewzw+zZmJrT/7iwTb1marClur/lY37A0WuCyvYx251DNni/Dqk
aY6/p0RH4xuwMzU/XsHeJ+qTj81EWXTDlnceCMMuMFmOwLa58m8fdtq7pffY
Lp0BXrg/eZ6ito7dlAWVcD8jJpfofQ/HK7p8H3bI/I4gbGmuMW5s72ceEdix
nQQN90OHjnYlYTMUeuVgl/mdzMKmGo1KYws7tbRh1wXFCWLLkyM7scUmLdmx
HYpEe7Cvlt+cw/2WaCfbCPYuCf9C7NyAT0vYb7yaT2PzLSXsvI+ccmroBDan
dR0PNqOVoAw245UxPmzTZ3S7sNvDJ/diN2sHjuL+rqnh3wHsdP7iLmzL5iRp
bOonnhbsHxM7j2BH0pSKsd8Z9MtjUwb/xmIn7is5gf1CVyUEO+v4VzL2wYOP
vLDTYr+oYYcbFl7GZp9OPontpnz1OLbEM+8z2JtIpH3Y32gxBhvjec7Jhd2h
an0Oe0/YRyruT/c2a5tiF/9w7MNOkzhxAVsmN6YZuzNz1XxjvBy7K7BbzgVf
xJZ6sysPu8rouyW2n4DofexVSzob7E/f7t7Gbpp6fgl7ajj0JLb+I0Vb7Mbl
VV5sdZt7l7HTerQ2Y++Lcdq4/lpCPxX30xKdVdbY+2vjerDFEz5vvK/bXq8B
O7PIzWJjfO67y7DfGtabYUuOr73DlrVoMcZ+2ND6cuP+rfJG2JX1k0+wj/8I
2YhH1qBOCrZrWdlZ7LO8U4nY1cSAPrZ3l2EM9ok9dRvxPXqUKRy7+e+909g3
3ZgDsY9q6mhjqx04743NTx7bWB8pp2EP7CZ5dw3sOuVyF+w05zFVbP2co1ew
q4gnytgXL323wf5wdeAYtmXtu4vY8+7cChv5Mlxlht0qoiKH7fuF0xg7tcJk
I79KPFMNsR/ds9/Iv8N/TPWxhQedN/KTlOasjU3juiy2sX7NxEnszvDzwtju
K6oa2F4JqoIb8xOaUcXe63dAAJvjbA3AFkjg3IX9K75aBbt45yoXts3Y+HFs
LX3KDuxRxqeK2HaMJduwt3YfUMCO53jHjC093S6P3UvNYMQeVHskh/10Ip1+
Yz4UX9mN92tnkTb2g/y9I9i1TV//4P07syJ7GHuFdXweu01sSRpbQ2h5DLt2
i/Yh7MpIkV7sI1WLGz5qVr9RLyZ3zW/cz84UslFPjpsryWDXOJ9pwrb9Ubnx
/vpLUl+xs36Fb4w3CYpVY5//FPD/+VgcI7CTemM35lt3srEMO73k5TFsxR3X
SrB7ji5sxOdvYVkB9s/9+zfi56Lj8RFboN/uBPbAc5k87C0862Tsb4/hO2yi
JGVjvfRiBV5gq+/Zdgq7O39bOnbx+9CN9XWJoXu2MT+VcF1s7th/j7B3vC3Z
yI/aHvJ9bJGhm1bYfj+o4diP15k38i/eRyMMOyUx9dKG59NCsH3XPtpt5HOW
QyD2M5nCaxvx+Ky/Ud9dvaM8N/ZPtoYL9mJw7sZ+6A2JcMLODG30w5Y7OOyI
ffThaAg2U+KiLbbxnG0cdvqctQX26zLOjf3Y/yzgArYuT+69jf0Rnm+KfYD7
68b+rf6sZ4QdZRaWvnG9oLw+9uVHP19hJydk62KPtDG93YiHooXOxnmUO/8B
+xSb3smN88iVs2RjvbWn1bB59C0rsA0MjpE3np/q/W0j/t8dlDfG4772HTsr
sEsJ+3+TVqLG
     "]]}},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.453746024798872*^9, 3.453746036152706*^9}, 
   3.4538225711186934`*^9, 3.454172881929145*^9, 3.454181423491259*^9, 
   3.45440144247057*^9, 3.4642051805717783`*^9, 3.464212995807905*^9, 
   3.464298150931881*^9, 3.464313310011286*^9, 3.4643139932922297`*^9, 
   3.4643173221568823`*^9, 3.464342015706602*^9, 3.464346746165223*^9, 
   3.4643521726945257`*^9, 3.464431585488019*^9, 3.465207754801991*^9, 
   3.465208382013632*^9, 3.465209023692071*^9, 3.465209863907996*^9, 
   3.465222154727309*^9, 3.4652260180884333`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ParametricPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x", "[", "\[Tau]", "]"}], ",", " ", 
      RowBox[{"y", "[", "\[Tau]", "]"}]}], "}"}], "/.", "HTtraj1"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"\[Tau]", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"RGBColor", "[", 
     RowBox[{"1", ",", " ", "0", ",", " ", "0"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4537460237326307`*^9, 3.453746035849173*^9}, {
  3.4537463220730743`*^9, 3.453746324905489*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi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     "]]}},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{-5., 3.340997971145882}, {-1.4180111814120693`, 
   1.0330479622680582`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.4537463252564*^9, 3.4538225711991367`*^9, 
  3.454172893527965*^9, 3.4541814271746607`*^9, 3.454401442520193*^9, 
  3.464205180638565*^9, 3.46421299589003*^9, 3.4642981608750963`*^9, 
  3.464313310038588*^9, 3.464313996536934*^9, 3.464317322194216*^9, 
  3.4643420157400417`*^9, 3.464346746196766*^9, 3.464352172735262*^9, 
  3.4644315855215797`*^9, 3.4652077548343687`*^9, 3.465208382042246*^9, 
  3.4652090237245617`*^9, 3.465209863937531*^9, 3.4652221547593317`*^9, 
  3.465226018117723*^9}]
}, Open  ]],

Cell["Naming the individual components", "Text",
 CellChangeTimes->{{3.453813933612364*^9, 3.453813941298808*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xHT1", "=", 
  RowBox[{"x", "/.", "HTtraj1"}]}]], "Input",
 CellChangeTimes->{{3.453747397932858*^9, 3.453747408152252*^9}, {
  3.45374791136265*^9, 3.453747937259171*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.453747943535266*^9, 3.453822571243973*^9, 
  3.454181433851179*^9, 3.454401442570882*^9, 3.464205180687385*^9, 
  3.4642129959385967`*^9, 3.46429816117402*^9, 3.4643133100627337`*^9, 
  3.464313999063792*^9, 3.464317322222493*^9, 3.464342015770509*^9, 
  3.464346746228488*^9, 3.464352172754815*^9, 3.464431585552017*^9, 
  3.465207754854958*^9, 3.465208382058919*^9, 3.4652090237512207`*^9, 
  3.465209863970303*^9, 3.465222154790522*^9, 3.465226018134645*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"yHT1", "=", 
  RowBox[{"y", "/.", "HTtraj1"}]}]], "Input",
 CellChangeTimes->{{3.45374794539493*^9, 3.4537479572156553`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"InterpolatingFunction", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"0.`", ",", "30.`"}], "}"}], "}"}], ",", "\<\"<>\"\>"}], "]"}],
  False,
  Editable->False]], "Output",
 CellChangeTimes->{3.4537479585190496`*^9, 3.453822571292322*^9, 
  3.4541814343218718`*^9, 3.4544014426241283`*^9, 3.464205180737892*^9, 
  3.464212995987142*^9, 3.4642981612069407`*^9, 3.464313310096057*^9, 
  3.4643140016064987`*^9, 3.464317322266679*^9, 3.4643420158196487`*^9, 
  3.46434674626633*^9, 3.464352172791266*^9, 3.464431585606533*^9, 
  3.465207754891582*^9, 3.465208382095913*^9, 3.465209023805974*^9, 
  3.465209864041432*^9, 3.4652221548225183`*^9, 3.465226018209365*^9}]
}, Open  ]],

Cell["\<\
Defining a function called home such that home[0] is the previously computed \
reference\
\>", "Text",
 CellChangeTimes->{{3.45411359141816*^9, 3.454113659472299*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"home", "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"xHT1", "[", "#", "]"}], ",", 
     RowBox[{"yHT1", "[", "#", "]"}]}], "}"}], "&"}]}]], "Input",
 CellChangeTimes->{{3.4540833194813004`*^9, 3.454083332659219*^9}, {
  3.454083382987233*^9, 3.454083441044841*^9}, {3.4642981973597517`*^9, 
  3.46429820103049*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"xHT1", "[", "#1", "]"}], ",", 
    RowBox[{"yHT1", "[", "#1", "]"}]}], "}"}], "&"}]], "Output",
 CellChangeTimes->{
  3.45408333307767*^9, 3.4540833981533737`*^9, {3.45408343110296*^9, 
   3.45408344128566*^9}, 3.454192614670822*^9, 3.454401442809772*^9, 
   3.464205181268827*^9, 3.464212996202985*^9, 3.4642982029890537`*^9, 
   3.464313310133553*^9, 3.464314004069862*^9, 3.4643173223082047`*^9, 
   3.464342015852414*^9, 3.4643467463127604`*^9, 3.4643521728183527`*^9, 
   3.464431585656152*^9, 3.4652077549203777`*^9, 3.465208382128806*^9, 
   3.465209023856882*^9, 3.465209864106646*^9, 3.465222154878384*^9, 
   3.465226018275703*^9}]
}, Open  ]],

Cell["\<\
In checking, we note that the x-value corresponds to the right branch of the \
home trajectory and the refractory variable is approximately equal to the \
rest condition.  \
\>", "Text",
 CellChangeTimes->{{3.4541137260663013`*^9, 3.4541137756327333`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tstart", "=", "4.646244127779736`"}]], "Input",
 CellChangeTimes->{{3.464313532036881*^9, 3.464313534673753*^9}}],

Cell[BoxData["4.646244127779736`"], "Output",
 CellChangeTimes->{3.4643135354762373`*^9, 3.464314054614644*^9, 
  3.464317322345429*^9, 3.464342015894224*^9, 3.464346746349987*^9, 
  3.464352172857122*^9, 3.4644315856989317`*^9, 3.465207754958029*^9, 
  3.46520838216709*^9, 3.465209023902597*^9, 3.465209864156815*^9, 
  3.465222154928543*^9, 3.4652260184066973`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"home", "[", "tstart", "]"}]], "Input",
 CellChangeTimes->{{3.45411366915998*^9, 3.454113677883379*^9}, {
  3.4643140465280313`*^9, 3.464314047998686*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.0180148089123664`", ",", 
   RowBox[{"-", "0.6242600440550341`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.454113678584404*^9, 3.454192617381983*^9, 3.454401442859967*^9, 
   3.464205181319113*^9, 3.464212996371171*^9, 3.464298206099537*^9, 
   3.464313310166499*^9, 3.4643140069107037`*^9, {3.4643140485322247`*^9, 
   3.464314057595248*^9}, 3.464317322374401*^9, 3.4643420159295883`*^9, 
   3.464346746395605*^9, 3.464352172892003*^9, 3.4644315857568913`*^9, 
   3.465207754986586*^9, 3.465208382200029*^9, 3.465209023955946*^9, 
   3.465209864206698*^9, 3.465222154978326*^9, 3.4652260184780893`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Resampling the home trajectory", "Subsubsection",
 CellChangeTimes->{{3.453814545562943*^9, 3.453814551104187*^9}}],

Cell[TextData[{
 "Let ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " represent a small amount of time elapsed since the previous sample point.  \
We want to choose ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " so that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SqrtBox[
     RowBox[{
      SuperscriptBox["\[CapitalDelta]x", "2"], "+", 
      SuperscriptBox["\[CapitalDelta]y", "2"]}]], "<", 
    SubscriptBox["\[ScriptCapitalD]", "crit"]}], TraditionalForm]]],
 ", which implies ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[CapitalDelta]t", "=", 
    FractionBox[
     SubscriptBox["\[ScriptCapitalD]", "crit"], 
     SqrtBox[
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], 
        SuperscriptBox[
         RowBox[{"(", 
          SubscriptBox["t", "0"], ")"}], "2"]}], "+", 
       RowBox[{
        RowBox[{"y", "'"}], 
        SuperscriptBox[
         RowBox[{"(", 
          SubscriptBox["t", "0"], ")"}], "2"]}]}]]]}], TraditionalForm]]],
 ".  Note we also want a safety margin so we should make the criterion used \
in the definition of ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " some fraction of Dcrit.  Specifically, since in MapGeneration1 the \
criterion was ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Dcrit", "=", "0.01"}], TraditionalForm]]],
 ", the value used in the ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]t", TraditionalForm]]],
 " calculation should be ",
 Cell[BoxData[
  FormBox[
   RowBox[{"D0", "=", "0.002"}], TraditionalForm]]],
 ", implying a safety factor of five.  "
}], "Text",
 CellChangeTimes->{{3.453748119605771*^9, 3.45374840251996*^9}, 
   3.453748468393743*^9, {3.45374854115889*^9, 3.453748695137249*^9}, {
   3.4537487577183743`*^9, 3.453748833056801*^9}, {3.4538146184348783`*^9, 
   3.453814653455407*^9}, {3.454173659305275*^9, 3.454173669199872*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D0", "=", "0.002"}]], "Input",
 CellChangeTimes->{{3.453748908324545*^9, 3.453748915299923*^9}, {
  3.453769935753728*^9, 3.453769937046278*^9}}],

Cell[BoxData["0.002`"], "Output",
 CellChangeTimes->{3.453748917665125*^9, 3.453770003217607*^9, 
  3.453814656648157*^9, 3.453822577218586*^9, 3.454181437754908*^9, 
  3.454401446050334*^9, 3.4642051813700047`*^9, 3.4642073829699717`*^9, 
  3.464213175078126*^9, 3.464313310226522*^9, 3.464314063611946*^9, 
  3.464317322408132*^9, 3.464342015969927*^9, 3.46434674643288*^9, 
  3.464352172936042*^9, 3.464431585807537*^9, 3.4652077550240097`*^9, 
  3.4652083822479553`*^9, 3.465209024009445*^9, 3.465209864302236*^9, 
  3.4652221550288486`*^9, 3.4652260185433187`*^9}]
}, Open  ]],

Cell["\<\
We continue and make a function for computing the next time from a previous \
one:\
\>", "Text",
 CellChangeTimes->{{3.453767814475751*^9, 3.453767836281683*^9}, {
  3.454173696906568*^9, 3.454173720824835*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"nextTime", "[", "t_", "]"}], ":=", 
  RowBox[{"t", "+", 
   RowBox[{"D0", "/", 
    SqrtBox[
     RowBox[{
      SuperscriptBox[
       RowBox[{
        RowBox[{"xHT1", "'"}], "[", "t", "]"}], "2"], "+", 
      SuperscriptBox[
       RowBox[{
        RowBox[{"yHT1", "'"}], "[", "t", "]"}], "2"]}]]}]}]}]], "Input",
 CellChangeTimes->{{3.453768219676928*^9, 3.453768250406127*^9}, {
  3.453814906167219*^9, 3.453814908982147*^9}}],

Cell["Computing the sample times:", "Text",
 CellChangeTimes->{{3.454173742876844*^9, 3.454173748435767*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Timing", "[", 
  RowBox[{
   RowBox[{"timeList2", "=", 
    RowBox[{"Drop", "[", 
     RowBox[{
      RowBox[{"NestWhileList", "[", 
       RowBox[{"nextTime", ",", " ", "tstart", ",", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"#", "<", "30"}], ")"}], "&"}]}], "]"}], ",", " ", 
      RowBox[{"-", "1"}]}], "]"}]}], ";"}], "]"}]], "Input",
 CellChangeTimes->{{3.453768271944023*^9, 3.4537683018075237`*^9}, {
  3.453768352795725*^9, 3.4537683966524563`*^9}, {3.4537685137219267`*^9, 
  3.4537685139755163`*^9}, {3.453769993164446*^9, 3.453769993264888*^9}, {
  3.453819647461437*^9, 3.453819661643528*^9}, {3.453821850787465*^9, 
  3.4538218661226387`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.12318399999999996`", ",", "Null"}], "}"}]], "Output",
 CellChangeTimes->{3.453821867439487*^9, 3.453822598119401*^9, 
  3.454181443919351*^9, 3.4544014463317537`*^9, 3.464205181553652*^9, 
  3.4642073832289352`*^9, 3.464213175353858*^9, 3.46431331029261*^9, 
  3.464314069469966*^9, 3.4643173225759907`*^9, 3.464342016153408*^9, 
  3.464346746609778*^9, 3.4643521731016693`*^9, 3.464431585979841*^9, 
  3.4652077551845627`*^9, 3.465208382412012*^9, 3.465209024230949*^9, 
  3.4652098644850483`*^9, 3.465222155252479*^9, 3.465226018736623*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "timeList2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"xHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"], "+", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"yHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"yHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"]}], ")"}]}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", 
       RowBox[{
        RowBox[{"Length", "[", "timeList2", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
   RowBox[{"Prolog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Min", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Max", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}]}], 
       "}"}], "]"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823739151227*^9, 3.453823767014176*^9}, {
  3.453823852034616*^9, 3.453823853146299*^9}, {3.4541738338688297`*^9, 
  3.454173992551697*^9}, {3.454175576409442*^9, 3.454175637855646*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwc2nk4VU0YAHBEixS5+0bWFiElkuS1JGuFIkQSiRJK1mSNIiH7WtZSoUT2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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRangeClipping->True,
  Prolog->{
    LineBox[{{4.646244127779736, 0.002}, {22.287392336552358`, 
     0.002}}]}]], "Output",
 CellChangeTimes->{{3.45382384168848*^9, 3.453823853519643*^9}, {
   3.454173943317503*^9, 3.454173993169683*^9}, {3.4541755780286007`*^9, 
   3.4541756389253073`*^9}, 3.4541814467637663`*^9, 3.454401446426609*^9, 
   3.464205181642201*^9, 3.464207383305908*^9, 3.464213175437656*^9, 
   3.464313310399087*^9, 3.464314073347733*^9, 3.464317322956688*^9, 
   3.464342016257061*^9, 3.464346746691424*^9, 3.464352173180252*^9, 
   3.464431586066955*^9, 3.465207755265746*^9, 3.465208382488076*^9, 
   3.465209024317513*^9, 3.4652098645742702`*^9, 3.4652221553403187`*^9, 
   3.465226018810708*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
       "timeList2", "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
       ",", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"xHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"xHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"], "+", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"yHT1", "[", 
              RowBox[{"timeList2", "\[LeftDoubleBracket]", 
               RowBox[{"j", "+", "1"}], "\[RightDoubleBracket]"}], "]"}], "-", 
             RowBox[{"yHT1", "[", 
              RowBox[{
              "timeList2", "\[LeftDoubleBracket]", "j", 
               "\[RightDoubleBracket]"}], "]"}]}], ")"}], "2"]}], ")"}]}]}], 
      "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"j", ",", " ", 
       RowBox[{
        RowBox[{"Length", "[", "timeList2", "]"}], "-", "1"}]}], "}"}]}], 
    "]"}], ",", " ", 
   RowBox[{"Prolog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Line", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Min", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Max", "[", "timeList2", "]"}], ",", " ", "D0"}], "}"}]}], 
       "}"}], "]"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.453823739151227*^9, 3.453823767014176*^9}, {
  3.453823852034616*^9, 3.453823853146299*^9}, {3.4541738338688297`*^9, 
  3.454173992551697*^9}, {3.454175576409442*^9, 3.4541756651388693`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwc2nk4VU0YAHBEixS5+0bWFiElkuS1JGuFIkQSiRJK1mSNIiH7WtZSoUT2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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True,
  Prolog->{
    LineBox[{{4.646244127779736, 0.002}, {22.287392336552358`, 
     0.002}}]}]], "Output",
 CellChangeTimes->{3.454175665654237*^9, 3.454181449840543*^9, 
  3.454401446577572*^9, 3.464205181737328*^9, 3.464207383390275*^9, 
  3.464213175582222*^9, 3.464313310429921*^9, 3.464314076889995*^9, 
  3.464317323043562*^9, 3.4643420163452187`*^9, 3.4643467467767*^9, 
  3.464352173264687*^9, 3.464431586151574*^9, 3.465207755352703*^9, 
  3.465208382565607*^9, 3.465209024403639*^9, 3.465209864659747*^9, 
  3.4652221554264097`*^9, 3.465226018884259*^9}]
}, Open  ]],

Cell["Here the spacing only goes slightly above 0.002. ", "Text",
 CellChangeTimes->{{3.454175681323826*^9, 3.4541756949626913`*^9}}],

Cell["Sampling the Home Trajectory:", "Text",
 CellChangeTimes->{{3.4541815231261044`*^9, 3.45418152922863*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"HTsample2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"t", "\[Function]", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", 
        RowBox[{"xHT1", "[", "t", "]"}], ",", " ", 
        RowBox[{"yHT1", "[", "t", "]"}]}], "}"}]}], ")"}], "/@", 
    "timeList2"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.453822750786233*^9, 3.453822780407332*^9}, {
  3.453822812895875*^9, 3.4538228235744553`*^9}, {3.453822867587119*^9, 
  3.4538228738013268`*^9}, {3.453823016358951*^9, 3.4538230164519653`*^9}}],

Cell["\<\
The corresponding values read of the graph: {{10.02, -1.777}} and {{10.02, \
0.01432}}.\
\>", "Text",
 CellChangeTimes->{{3.4541122204150543`*^9, 3.454112247238606*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"htPlot1", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"HTsample2", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{";;", ";;", "100"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.454112288676467*^9, 3.45411230634689*^9}, {
  3.454112341798265*^9, 3.454112357723218*^9}, {3.4541936699761553`*^9, 
  3.454193670482093*^9}, {3.454193711138239*^9, 3.454193715888603*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwBMQLO/SFib1JlAgAAACIAAAACAAAAevq48uQkAED6Ti0z8Pnjv7+nCtuq
RP8/uwDtRhPT27/qB1zBESr+PxjOn9k3oc+/tgl+TEr1/D+U4EGynLavv0SY
vo7zn/s/lpVM5b+pvj8ju+QMQyH6P1jq7gPf+dI/+CdNKRxt+D8TKNVBRc3d
P5H1Yxelc/Y/mSCE/k3u4z9M8iTbDyT0P3cYzLIsWeg/u0K6eOd38T9EGDr0
N9vrP2gTif0rA+0/QwG9V95F7j8ZVPvZGsbmP8lDEZ8aue8/pFsWZhNq4D9H
XtkBTUHwP6HZgncQCdQ/N2U256ty8D91jUIpZeW8P6j+U82EhfA/GCLvJ31a
tr/Q5JUrgYXwP2wEccaUZdK/9i42F/Z48D9v8XO4JzPfvwciONs6Y/A//7KB
rZT/5b/3qhrd3kXwP52WO+6rZOy/gWRaJTYh8D8zk8KhS2Txv9V5HCXt6O8/
x4ArB2WV9L9BINuVw3rvP/3PkSj+xPe/edNSKhvu7j/BVqBVO/H6vy/x/cyn
K+4/Ot8pKVMR/r9HFBwuRejsP15BZAAEPADA6aM/8UtB6T96LoU1pOL/v0J5
UPGGBeM/5zP3ZhbT/r/T20fex/nZP+Uy6Vdwp/2/s2XThXclzD8W9CIEgFv8
v7rFESepEqM/jD79+Gjl+r8J+X1bwvjBv8EwO7XONfm/v931VcfW079MD+6+
1TP3v0yOVBLGwd2/sXwXC/W39L9w1XJad9Xivy2aJn0=
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.454112285680174*^9, 3.4541123591794453`*^9, 
  3.454193671129228*^9, 3.454193716234417*^9, 3.4544014467775497`*^9, 
  3.46420518179978*^9, 3.464207383451765*^9, 3.464213175831071*^9, 
  3.464313310795081*^9, 3.464314087370098*^9, 3.464317323103489*^9, 
  3.464342016442359*^9, 3.4643467468179626`*^9, 3.464352173455216*^9, 
  3.464431586188044*^9, 3.465207755420856*^9, 3.465208382629092*^9, 
  3.465209024440218*^9, 3.465209864893486*^9, 3.465222155462618*^9, 
  3.46522601892804*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"htPlot2", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"HTsample2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.454112288676467*^9, 3.45411230634689*^9}, {
  3.454112341798265*^9, 3.454112357723218*^9}, {3.4541936699761553`*^9, 
  3.454193682882255*^9}, {3.454193719042749*^9, 3.454193723672675*^9}}],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJwUV3c8lu8XJpVIVBSlpKIkGiJJXJQyIl9RUikqhCgVWZWKIiSyMlLSVPaK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    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.454193683197153*^9, 3.454193724269754*^9, 
  3.454401446804146*^9, 3.464205181826288*^9, 3.464207383504792*^9, 
  3.464213175859626*^9, 3.464313310831889*^9, 3.464314090180372*^9, 
  3.464317323137031*^9, 3.46434201648209*^9, 3.464346746847516*^9, 
  3.4643521734851503`*^9, 3.4644315862274723`*^9, 3.46520775545695*^9, 
  3.465208382645913*^9, 3.465209024485011*^9, 3.4652098650295362`*^9, 
  3.4652221555074463`*^9, 3.465226018957198*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A function for computing the distance to the home trajectory", \
"Subsubsection",
 CellChangeTimes->{{3.454175778712042*^9, 3.454175782438424*^9}, {
  3.454353143347899*^9, 3.454353155192384*^9}}],

Cell[TextData[{
 "This statement defines a function nf[x] where x is a two dimensional vector \
specifying the location of a point in phase space.  The function returns the \
list ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]close", ",", " ", "xclose", ",", " ", "yclose"}], "}"}], 
     ",", "  ", "distance"}], "}"}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox["\[Tau]close", TraditionalForm]]],
 " is the value of \[Tau] that is closest to x and xclose  and yclose are the \
corresponding coordinates in phase space.  The statement HTsample2[[All, {2, \
3}]] \[Rule] HTsample2 in the precomputed Nearest function labels the the \
matrix contructed from the second and third columns with elements of the full \
matrix which also has a leading column of the times along the hidden \
structure."
}], "Text",
 CellChangeTimes->{{3.454023609369185*^9, 3.4540236400378027`*^9}, {
  3.454023710045332*^9, 3.454023744005353*^9}, {3.4540239875443707`*^9, 
  3.454024074018815*^9}, {3.454024246407796*^9, 3.454024287225095*^9}, {
  3.4541094589517117`*^9, 3.454109505818973*^9}, {3.454109622548807*^9, 
  3.454109699935792*^9}}],

Cell[BoxData[
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"temp", "=", 
     RowBox[{"Nearest", "[", 
      RowBox[{
       RowBox[{"HTsample2", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"{", 
           RowBox[{"2", ",", "3"}], "}"}]}], "]"}], "]"}], "\[Rule]", 
       "HTsample2"}], "]"}]}], 
    RowBox[{"(*", 
     RowBox[{"Pre", "-", 
      RowBox[{"compute", " ", "the", " ", "Nearest", " ", "Function"}]}], 
     "*)"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Clear", "[", "nf", "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"nf", "[", 
      RowBox[{"x_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"VectorQ", "[", 
          RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], "]"}], ":=", 
     RowBox[{"With", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"res", "=", 
         RowBox[{"First", "@", 
          RowBox[{"temp", "[", "x", "]"}]}]}], 
        RowBox[{"(*", 
         RowBox[{
          RowBox[{
           RowBox[{"First", "[", "]"}], " ", "is", " ", "needed", " ", 
           "because", " ", "Nearest", " ", "returns", " ", "a", " ", "list"}],
           ",", " ", 
          RowBox[{
          "which", " ", "is", " ", "necessary", " ", "to", " ", "account", 
           " ", "for", " ", "multiple"}], ",", " ", 
          RowBox[{"equally", " ", "close", " ", "points"}]}], "*)"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"res", ",", 
         RowBox[{"Norm", "[", 
          RowBox[{"x", "-", 
           RowBox[{"res", "[", 
            RowBox[{"[", 
             RowBox[{"{", 
              RowBox[{"2", ",", "3"}], "}"}], "]"}], "]"}]}], "]"}]}], 
        "}"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.453824880369479*^9, 3.4538248814708443`*^9}, {
   3.453824964487279*^9, 3.4538249653592443`*^9}, 3.4538250420478477`*^9, {
   3.453825074738001*^9, 3.453825088423801*^9}, {3.453825123825498*^9, 
   3.453825129512917*^9}, {3.453825175482459*^9, 3.453825279295473*^9}, {
   3.45382535412395*^9, 3.453825354946455*^9}, {3.454084824437039*^9, 
   3.454084869462948*^9}, {3.454089329455098*^9, 3.454089348284706*^9}, {
   3.454108979594144*^9, 3.4541090368011217`*^9}, {3.454110058560604*^9, 
   3.454110059232307*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define a function for computing the post-shock trajectories", \
"Subsubsection",
 CellChangeTimes->{{3.4541761190045633`*^9, 3.454176133107913*^9}, {
  3.454353208779581*^9, 3.4543532096975183`*^9}}],

Cell[TextData[{
 "The function G3 integrates the FN system starting from the initial state \
{x0, y0}, stopping when the distance from the transient attractor becomes \
less that 10^-2 or when time progresses beyond 100. The stopping event is \
defined by the statement \"Event\" \[RuleDelayed] 10^-2 > (end1 = nf[{x[t], \
y[t]}]; end1[[2]]).  At each step r.h.s. of the boolean expression in \
evaluated and the value of the boolean expression determined.  The r.h.s. in \
this implementation consists of a compound expression, the first component \
being an evaluation of the nearest function.  This value of the nearest \
function is stored in the global variable end1, which is overwritten except \
when the condition is satisfied.  When nf[{x[t], y[t]}] is evaluated, it \
returns ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Tau]close", ",", " ", "xclose", ",", " ", "yclose"}], "}"}], 
     ",", "  ", 
     StyleBox["distance",
      FontSlant->"Italic"]}], "}"}], TraditionalForm]]],
 ".  The next statement in the compound expression simply takes the ",
 StyleBox["distance",
  FontSlant->"Italic"],
 ", which is the quantity that is relevant for the comparison.  The value of \
end1 is re-evaluated in the argument of Throw in \"EventAction\": \
\"EventAction\" \[RuleDelayed] Throw[end1 = nf[{x[t], y[t]}]; end2 = t, \
\"StopIntegration\"].  Apparently the convention for having an EventAction \
that stops the integration is to call a Throw with a tag \"StopIntegration\". \
 "
}], "Text",
 CellChangeTimes->{{3.454024557853074*^9, 3.4540246065254173`*^9}, {
  3.454024746367197*^9, 3.454024791097004*^9}, {3.454024875044945*^9, 
  3.454024940415872*^9}, {3.454025229320335*^9, 3.454025305439415*^9}, {
  3.454025341407782*^9, 3.454025716855399*^9}, {3.454089016913787*^9, 
  3.454089044150581*^9}, {3.4541102911117687`*^9, 3.4541104126886683`*^9}}],

Cell["\<\
In this revised function, the arguments are the starting location in phase \
space, the amplitude of the kick A, and the independent variable symbol.  The \
function returns a list {equivalent excitataion \[Tau], {xRule, yRule}, \
travel time, joining\[Tau]}\
\>", "Text",
 CellChangeTimes->{{3.4541139559580917`*^9, 3.454114010687345*^9}, {
  3.454192788311226*^9, 3.45419279526149*^9}, {3.454192842931642*^9, 
  3.4541928862521353`*^9}, {3.454192951626615*^9, 3.454192960880138*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"G3", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}], ",", "A_", ",", "t_Symbol"}], "]"}], 
  ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "x", ",", "y", ",", "end1", ",", "end2", ",", "tf", ",", " ", "ruleList",
       ",", "joining\[Tau]", ",", "traveltime"}], "}"}], ",", " ", 
    RowBox[{
     RowBox[{"tf", "=", "100"}], ";", " ", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"10", "^", 
         RowBox[{"-", "2"}]}], ">", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"end1", "=", 
           RowBox[{"nf", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"x0", "+", "A"}], ",", "y0"}], "}"}], "]"}]}], ")"}], 
         "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"Return", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"end1", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x0", "+", "A"}], ",", "y0"}], "}"}], ",", "0", ",", 
          RowBox[{"end1", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "1"}], "]"}], "]"}]}], "}"}], "]"}]}], "]"}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"ruleList", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["x", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            RowBox[{"c", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "-", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"x", "[", "t", "]"}], "3"], "3"], "-", 
               RowBox[{"y", "[", "t", "]"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{
             SuperscriptBox["y", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            FractionBox[
             RowBox[{
              RowBox[{"x", "[", "t", "]"}], "+", "a", "-", 
              RowBox[{"b", " ", 
               RowBox[{"y", "[", "t", "]"}]}]}], "c"]}], ",", 
           RowBox[{
            RowBox[{"x", "[", "0", "]"}], "\[Equal]", 
            RowBox[{"x0", "+", "A"}]}], " ", ",", " ", 
           RowBox[{
            RowBox[{"y", "[", "0", "]"}], "\[Equal]", "y0"}]}], "}"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"x", ",", " ", "y"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "0", ",", " ", "tf"}], "}"}], ",", 
         "\[IndentingNewLine]", " ", 
         RowBox[{"Method", "\[Rule]", "\[IndentingNewLine]", 
          RowBox[{"{", "\[IndentingNewLine]", 
           RowBox[{"\"\<EventLocator\>\"", ",", "\[IndentingNewLine]", 
            RowBox[{"\"\<Event\>\"", "\[RuleDelayed]", 
             RowBox[{
              RowBox[{"10", "^", 
               RowBox[{"-", "2"}]}], ">", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"nf", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"x", "[", "t", "]"}], ",", 
                   RowBox[{"y", "[", "t", "]"}]}], "}"}], "]"}], 
                "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
               ")"}]}]}], ",", "\[IndentingNewLine]", 
            RowBox[{
            "\"\<EventAction\>\"", "\[RuleDelayed]", "\[IndentingNewLine]", 
             RowBox[{"Throw", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"end1", "=", 
                 RowBox[{"nf", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"x", "[", "t", "]"}], ",", 
                    RowBox[{"y", "[", "t", "]"}]}], "}"}], "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"end2", "=", "t"}]}], ",", "\[IndentingNewLine]", 
               "\"\<StopIntegration\>\""}], "\[IndentingNewLine]", "]"}]}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"\"\<EventLocationMethod\>\"", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"\"\<Brent\>\"", ",", 
               RowBox[{"PrecisionGoal", "\[Rule]", "2"}]}], "}"}]}]}], 
           "}"}]}]}], "]"}], "]"}]}], ";", " ", "\[IndentingNewLine]", 
     RowBox[{"traveltime", "=", "end2"}], ";", "\[IndentingNewLine]", 
     RowBox[{"joining\[Tau]", "=", 
      RowBox[{"end1", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"joining\[Tau]", "-", "traveltime"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "[", "t", "]"}], ",", 
          RowBox[{"y", "[", "t", "]"}]}], "}"}], "/.", "ruleList"}], ",", 
       "traveltime", ",", "joining\[Tau]"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.4538254919715223`*^9, 3.4538255174836206`*^9}, {
   3.453825567427759*^9, 3.453825656367216*^9}, {3.453825690460688*^9, 
   3.4538257279722233`*^9}, 3.45382579167231*^9, {3.454083874205926*^9, 
   3.4540839563869143`*^9}, {3.454083997034318*^9, 3.454084012635948*^9}, {
   3.4540840548250017`*^9, 3.454084082790804*^9}, {3.454084137898355*^9, 
   3.454084151413535*^9}, {3.454084244580618*^9, 3.454084357940193*^9}, {
   3.454085120353753*^9, 3.454085122850245*^9}, {3.454107359345969*^9, 
   3.454107359519698*^9}, 3.454108264533277*^9, {3.4541789503444653`*^9, 
   3.454179024992454*^9}, {3.454180644193272*^9, 3.4541807860999813`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Computing the home trajectory with labels", "Subsubsection",
 CellChangeTimes->{{3.464212710371677*^9, 3.4642127173304453`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tstart", "=", "4.646244127779736`"}]], "Input",
 CellChangeTimes->{{3.464313532036881*^9, 3.464313534673753*^9}}],

Cell[BoxData["4.646244127779736`"], "Output",
 CellChangeTimes->{3.4643135354762373`*^9, 3.464317323235215*^9, 
  3.46434201655239*^9, 3.464346746913526*^9, 3.464352173565794*^9, 
  3.464431586302217*^9, 3.4652077556233397`*^9, 3.4652083828007812`*^9, 
  3.465209024531391*^9, 3.465209865104553*^9, 3.4652221555741053`*^9, 
  3.465226019015448*^9}]
}, Open  ]],

Cell["\<\
We want to sample the home trajectory uniformly in TIME yeilding nonuniform \
spacial sampling, that way the point density can be used to judge the phase \
velocity.  \
\>", "Text",
 CellChangeTimes->{{3.454337928807325*^9, 3.454337978758976*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleHome", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"home", "[", "t", "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "0", ",", " ", "30", ",", " ", "0.5"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.454338199744258*^9, 3.4543382667258873`*^9}, {
   3.454338297363022*^9, 3.454338297953177*^9}, 3.464213214687809*^9, {
   3.4643022449605913`*^9, 3.464302251221789*^9}, 3.464302676273066*^9, 
   3.46434540969519*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"tstart", ",", " ", "6", ",", " ", "20"}], "}"}]], "Input",
 CellChangeTimes->{{3.46430241699787*^9, 3.4643024309709597`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.646244127779736`", ",", "6", ",", "20"}], "}"}]], "Output",
 CellChangeTimes->{3.464302338654313*^9, 3.464302435477496*^9, 
  3.464313311024987*^9, 3.464313557573832*^9, 3.46431411374282*^9, 
  3.464317323335429*^9, 3.464342016652494*^9, 3.464346746991503*^9, 
  3.464352173614904*^9, 3.46443158637801*^9, 3.4652077556878853`*^9, 
  3.465208382862685*^9, 3.465209024578093*^9, 3.465209865188013*^9, 
  3.4652221556161737`*^9, 3.46522601908505*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"home", "/@", 
  RowBox[{"{", 
   RowBox[{"4", ",", " ", "6", ",", "15", ",", " ", "20"}], "}"}]}]], "Input",\

 CellChangeTimes->{{3.464302285149034*^9, 3.4643023197578993`*^9}, 
   3.464302447448503*^9, {3.464302510768528*^9, 3.464302511771138*^9}, 
   3.464302726609606*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.219643130711698`", ",", 
     RowBox[{"-", "1.332049064664961`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1.543977089178004`", ",", "0.440327804070218`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.266285287369231`"}], ",", 
     RowBox[{"-", "0.6027661646416459`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.2134130592290726`"}], ",", 
     RowBox[{"-", "0.6177189799887469`"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.464302320616192*^9, 3.46430244827806*^9, 
  3.464302512777923*^9, 3.464302727636747*^9, 3.4643133110657578`*^9, 
  3.46431355766029*^9, 3.464314113789065*^9, 3.464317323376471*^9, 
  3.464342016688998*^9, 3.46434674702983*^9, 3.464352173653823*^9, 
  3.464431586422524*^9, 3.465207755723983*^9, 3.465208382902958*^9, 
  3.46520902462201*^9, 3.46520986526304*^9, 3.465222155661991*^9, 
  3.465226019146142*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Text", "[", 
  RowBox[{"\"\<\[Tau]=4\>\"", ",", " ", 
   RowBox[{"home", "[", "4", "]"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Text", "[", 
  RowBox[{"\<\"\[Tau]=4\"\>", ",", 
   RowBox[{"{", 
    RowBox[{"2.219643130711698`", ",", 
     RowBox[{"-", "1.332049064664961`"}]}], "}"}]}], "]"}]], "Output",
 CellChangeTimes->{3.464302827273375*^9, 3.4643133111107063`*^9, 
  3.464313557714877*^9, 3.464314116352165*^9, 3.4643173234216757`*^9, 
  3.464342016735955*^9, 3.464346747065364*^9, 3.464352173684621*^9, 
  3.464431586455749*^9, 3.465207755761252*^9, 3.465208382932293*^9, 
  3.465209024661261*^9, 3.4652098653921843`*^9, 3.465222155700304*^9, 
  3.465226019213669*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"homePic", "=", 
  RowBox[{"Show", "[", 
   RowBox[{
    RowBox[{"ParametricPlot", "[", 
     RowBox[{
      RowBox[{"home", "[", "t", "]"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", "0", ",", " ", "30"}], "}"}], ",", " ", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Red", ",", " ", 
         RowBox[{"Thickness", "[", "0.01", "]"}]}], "]"}]}], ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2.2"}], ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "2"}], ",", "1.25"}], "}"}]}], "}"}]}]}], "]"}], ",", 
    " ", 
    RowBox[{"ListPlot", "[", 
     RowBox[{"sampleHome", ",", " ", 
      RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{
         RowBox[{"PointSize", "[", "0.02", "]"}], ",", " ", "Red"}], 
        "]"}]}]}], "]"}], ",", " ", 
    RowBox[{"Graphics", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Directive", "[", 
        RowBox[{"FontSize", "\[Rule]", "12"}], "]"}], ",", " ", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<\[Tau]=4\>\"", ",", " ", 
         RowBox[{"home", "[", "4", "]"}]}], "]"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=5\>\"", ",", " ", 
           RowBox[{"home", "[", "5", "]"}]}], "]"}], ",", " ", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=6\>\"", ",", " ", 
           RowBox[{"home", "[", "6", "]"}]}], "]"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=10\>\"", ",", " ", 
           RowBox[{"home", "[", "10", "]"}]}], "]"}], ",", "  ", 
         RowBox[{"Text", "[", 
          RowBox[{"\"\<\[Tau]=20\>\"", ",", " ", 
           RowBox[{"home", "[", "20", "]"}]}], "]"}]}], "}"}]}], "}"}], 
     "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.454403467982409*^9, 3.454403529433229*^9}, {
   3.46430226220428*^9, 3.464302269878208*^9}, {3.464302351692335*^9, 
   3.464302373791965*^9}, {3.4643024583048897`*^9, 3.464302469553069*^9}, {
   3.464302521062746*^9, 3.464302570416223*^9}, {3.464302707179512*^9, 
   3.464302737496312*^9}, 3.464302769679715*^9, {3.4643028550257273`*^9, 
   3.46430285686576*^9}, 3.464302893486408*^9, 3.464345157914706*^9, {
   3.464345371701696*^9, 3.464345382201085*^9}, 3.464345465864626*^9, {
   3.464345522178081*^9, 3.4643455311892433`*^9}}],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[1, 0, 0], Thickness[0.01], LineBox[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi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      "]]}}, 
   {RGBColor[1, 0, 0], PointSize[0.02], PointBox[CompressedData["
1:eJwlzXtUUwUcB/DBVGzQY0hDQNjG8IGHhR7IHAe4y+gYZjE48wHi42zykKED
G1EQ8cjHJNGNYGHRiYyAhWh0sIKw30UbAwYi8ppzPNqFxbEE8o7BNhjde/yd
8zvf8/nj+/uxRdKEFFcKhRJFLJnPxwt9nkEow0IrCzlB49fW2rxDfNnosKj1
yBWfF/irdftfLY/ehNZ1qm7P6t3465X5sjmqN5oeetg/9pt1/IKdGWHPpJ5o
rAc9Q5iylt825abtmfRATXrOryWha/jJYvs7bz9Ziy65S/wmbK782NzPBz+F
VWBU2t4c6nDhC2SMm56CBTDeTZnVfEbhtzd9zxC1zECWJClcJXMi5yNrHzAn
HkKxoCrao9WBvF/b8S7z7O9Iwq3leHbLEtJGL2oUvmZE4n4OVmX6LyAeDT4v
KtVmhAcu5y+w5pGTthh0yu8pEjqVE7dqGEHEug4/W8Y8sseq3sjLdkDivSPn
qtfMImJV37zWl4I+zMunnw6cRrp/E8ibJ5xgLtUZZMUGhGV9pTRMsQIwJrrZ
nN6DMAoc2w3xyyDM20Krv1SDnIkYRiM2O6B6l/XZul/a4cHHx7krNDu47eMc
lFzuA6ep4UsL1QaIM1zg/t8Q9NWwZP70JfiwPUj0w+QjMLOUloqwRfBd7aIO
3h2DJ0P+9ouZVtBrmzHFiUmYjnBd9LqzANciNQ510V+wVR5SxtyyABuC+9mG
BBP8YaVWMxosUHxVGvOd2QT7SkqTW/ZYYLRJHmOMxYAhz1zfZcFByek9dFuO
Ab2bWhLQjkMSEqIsbcKA5XPyfnUlDon6oLOjKAbUrwIUigIcqG2HZDu6MRhb
bKgPysKBW8e7mqzDwKg4MDJyCgdftY53pQcD97Gjwt40HN4LXkpp6cLA8LUb
1UJ4+BR2a7ATg/vXUm/Y03GYfCzGDmswGHg03s/JwGE0e3NV0p8YaEeieb4S
HECQ+0/nPQwc5kabhrCUuzGqkLBUYqjiZuLArm8SpRLuLUeviwj/tJvFJV1x
IzU5l3A4Ms7MIszxnovLI8yo3O35CeHH+hphDmHNJteoC4RfDunZfoZw/p0d
uWWETRtaG9MI9146N6MkvG1gYJy8vy1JFVlBmLlrpf844adb43dWkv+5eQHH
CO+1dolJz7zOPnaU8KxL2huk1YFeoaRbC/3+JfvO69NvkT7ACVST/vag/TRp
WqHPR6T/zun7grTXXFwi6cv28mbSPwoL9pLOjuFpSeteco8mvf+D5UHSjUXG
CNL/A/06GXE=
     "]]}, 
   StyleBox[{
     InsetBox["\<\"\[Tau]=4\"\>", {2.219643130711698, -1.332049064664961}], {
      InsetBox["\<\"\[Tau]=5\"\>", {1.903463558678336, -0.2948684251322862}], 
      InsetBox["\<\"\[Tau]=6\"\>", {1.543977089178004, 0.440327804070218}], 
      InsetBox["\<\"\[Tau]=10\"\>", \
{-1.7699834517478101`, 0.03230020522027091}], 
      InsetBox["\<\"\[Tau]=20\"\>", \
{-1.2134130592290726`, -0.6177189799887469}]}},
    FontSize->12]},
  AxesOrigin->{0, 0},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{-2.2, 3}, {-2, 1.25}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.454403498365636*^9, 3.4544035312138977`*^9, 3.454404222975378*^9, 
   3.454404414638691*^9, 3.454404801567255*^9, 3.4642128209588213`*^9, 
   3.464213219525332*^9, 3.464213562962798*^9, 3.4642137123153667`*^9, 
   3.464213847456972*^9, 3.464214931135415*^9, 3.464215113112249*^9, 
   3.464280564260029*^9, 3.4642913417368507`*^9, 3.464302495815267*^9, {
   3.464302531546275*^9, 3.464302571335929*^9}, {3.464302682708273*^9, 
   3.464302707946349*^9}, 3.464302738605901*^9, 3.464302770301959*^9, {
   3.464302848620085*^9, 3.464302858065358*^9}, 3.464302894890439*^9, 
   3.464313311199771*^9, 3.464313557762064*^9, 3.46431411874034*^9, 
   3.464317323479332*^9, 3.464342016789616*^9, 3.464345159802806*^9, {
   3.464345372895403*^9, 3.464345383006947*^9}, 3.464345415211446*^9, 
   3.4643454665872498`*^9, 3.464345532483973*^9, 3.4643467471087523`*^9, 
   3.4643521737260103`*^9, 3.464431586518585*^9, 3.465207755808257*^9, 
   3.465208382970272*^9, 3.46520902471054*^9, 3.465209865450062*^9, 
   3.4652221557494507`*^9, 3.465226019281363*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Define starting point at locator", "Subsubsection",
 CellChangeTimes->{{3.4642148908474207`*^9, 3.4642148987693167`*^9}, 
   3.464302931286633*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"startPt", "=", "restCond"}]], "Input",
 CellChangeTimes->{{3.4642149019742203`*^9, 3.4642149114217987`*^9}, 
   3.464302931287751*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "1.199408035244027`"}], ",", 
   RowBox[{"-", "0.6242600440550339`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.464352173766737*^9, 3.46443158653862*^9, 
  3.465207755838101*^9, 3.465208383001046*^9, 3.465209024739594*^9, 
  3.4652098654719276`*^9, 3.4652221557775517`*^9, 3.465226019323411*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Pre-evaluation Cobweb Demo", "Subsection",
 CellChangeTimes->{{3.4652045242064943`*^9, 3.4652045273720512`*^9}, {
  3.465208881989534*^9, 3.4652088869470463`*^9}}],

Cell[CellGroupData[{

Cell["Introduction", "Subsubsection",
 CellChangeTimes->{{3.4651753521910763`*^9, 3.465175354468511*^9}}],

Cell["\<\
Here we make an animation of the cobweb orbit created by the FN map.  \
Behavior is tied to the lce and discharge rate map.\
\>", "Text",
 CellChangeTimes->{{3.465175364044517*^9, 3.4651754105243797`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Set Defaults", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"$HistoryLength", "=", "0"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fm", "=", 
   RowBox[{"{", 
    RowBox[{"True", ",", " ", "True", ",", " ", "False", ",", " ", "False"}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ListPlot", ",", " ", "ListLogPlot", ",", " ", "ListLogLogPlot", ",", 
      " ", "Plot", ",", " ", "LogPlot", ",", " ", "ParametricPlot"}], "}"}], 
    ",", " ", 
    RowBox[{"Axes", "\[Rule]", "False"}], ",", " ", 
    RowBox[{"Frame", "\[Rule]", "fm"}], ",", 
    RowBox[{"FrameStyle", "\[Rule]", 
     RowBox[{"AbsoluteThickness", "[", "0.5", "]"}]}], ",", "  ", 
    RowBox[{"BaseStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Arial\>\""}], "}"}]}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.4250481029254737`*^9, 3.4250481052287855`*^9}, {
  3.425062110167573*^9, 3.4250621789865294`*^9}, {3.425303920673715*^9, 
  3.425303923868309*^9}, {3.42530433059315*^9, 3.4253043309937267`*^9}, {
  3.4318823438938723`*^9, 3.431882344314477*^9}, {3.4319665718251886`*^9, 
  3.4319665807680483`*^9}, {3.432154490583699*^9, 3.4321544913247647`*^9}, {
  3.43247291260952*^9, 3.432472919649643*^9}, {3.4329195760279183`*^9, 
  3.4329195766788545`*^9}, {3.4333274411328096`*^9, 3.4333274419640045`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference stimulus parameters", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Aref", "=", "0.6823310565208429"}], ";", 
   RowBox[{"Tref", "=", "3.5777087639996634`"}], ";"}], " "}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tr", "=", "3.660637667467016`"}], ";"}]], "Input",
 CellChangeTimes->{3.465134197685763*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Load the resetting map, lce(T), and R(T) plots", "Subsubsection",
 CellChangeTimes->{{3.465175704701756*^9, 3.4651757188680773`*^9}, {
  3.465175796780182*^9, 3.465175835009399*^9}}],

Cell["Load data from FN_Uniform_Resetting_1:", "Text",
 CellChangeTimes->{{3.4651241741359367`*^9, 3.465124190888155*^9}, {
  3.465175841114567*^9, 3.465175855481251*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "<<", "\"\</Users/davidogorman/Documents/Mathematica/Map_Making_Notebooks/\
FN_Uniform_ResetDATA\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.465124171093224*^9, 3.465124193987268*^9}, {
  3.465176424639763*^9, 3.465176448874878*^9}}],

Cell["\<\
Note: the FN resetting map is in FNMap, the map R(T) function is in \
rateMapDatab, and the map lce(T) function is in lceMapDatab.  The lce(T) \
predicted for the ODE is in TLambdaList1chop.  The first component of the \
elements in this list contains the sampled values of T.  The countList1 gives \
the spike count at each value of T.  The count applies to a stimulus duration \
of 200 pulses. \
\>", "Text",
 CellChangeTimes->{{3.46517586912158*^9, 3.465176069732317*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference stimulus parameters", "Subsubsection",
 CellChangeTimes->{{3.4651763149253187`*^9, 3.465176322018754*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Tchaos1", "=", "5.7"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Talt", "=", "8.785530401920838"}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Tau]ListRef", "=", 
   RowBox[{"NestList", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FNMap", "[", "#", "]"}], "+", "Tref"}], ")"}], "&"}], ",", 
     " ", "18", ",", " ", "200"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.437186406097488*^9, 3.437186449627118*^9}, {
   3.437187094731392*^9, 3.4371870951748457`*^9}, 3.465124535751631*^9, {
   3.465177954419116*^9, 3.465177956158276*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Tau]ListChaos1", "=", 
   RowBox[{"NestList", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"FNMap", "[", "#", "]"}], "+", "Tchaos1"}], ")"}], "&"}], ",",
      " ", "18", ",", " ", "200"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.437186406097488*^9, 3.437186449627118*^9}, {
   3.437187094731392*^9, 3.4371870951748457`*^9}, {3.437187963448254*^9, 
   3.437187979175521*^9}, 3.465124537879904*^9, {3.4651779592167797`*^9, 
   3.465177960208034*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot map", "Subsubsection",
 CellChangeTimes->{{3.4651778376039877`*^9, 3.4651778465459957`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"FNMap", "[", "t", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", 
     RowBox[{"First", "[", 
      RowBox[{"FNMap", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], "]"}], ",", " ", 
     RowBox[{"Last", "[", 
      RowBox[{"FNMap", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], "]"}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.465177869568268*^9, 3.465177878885366*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwl13c81d8fB3CrMi9l731t7r24uNZL4iupkITsNJQKkaJSKpmVUDKSktBA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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  AxesOrigin->{10., 2.},
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{1.6462441277797364`, 42.546244127779744`}, {
   1.6491702659507717`, 11.48049595748608}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.465177879406952*^9, 3.465181329118116*^9, 
  3.465207950862739*^9, 3.465208892812057*^9, 3.465209024931683*^9, 
  3.465209865764413*^9, 3.465222155967051*^9, 3.4652260195576353`*^9}]
}, Open  ]],

Cell["The domain of the map:", "Text",
 CellChangeTimes->{{3.4651780175301733`*^9, 3.465178024905732*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"dom1", ",", " ", "dom2"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"First", "[", 
     RowBox[{"FNMap", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], "]"}], ",", " ", 
    RowBox[{"Last", "[", 
     RowBox[{"FNMap", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", " ", "1"}], "]"}], "]"}], "]"}]}], "}"}]}]], "Input",\

 CellChangeTimes->{{3.465178087064082*^9, 3.4651781168303337`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1.6462441277797364`", ",", "42.546244127779744`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.465178087813154*^9, 3.465178118204126*^9, 
  3.46518133255035*^9, 3.4652079508882637`*^9, 3.465208892866479*^9, 
  3.465209024957724*^9, 3.4652098658127737`*^9, 3.465222155996427*^9, 
  3.465226019591807*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The cobweb function for a uniform stimulus", "Subsubsection",
 CellChangeTimes->{{3.464383382166238*^9, 3.464383395716345*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobweb", "[", "\[Tau]List_", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "tmpList", "}"}], ",", " ", 
    RowBox[{
     RowBox[{"tmpList", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Partition", "[", 
          RowBox[{"\[Tau]List", ",", " ", "2", ",", " ", "1"}], "]"}], "/.", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"\[Tau]1_", ",", " ", "\[Tau]2_"}], "}"}], "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\[Tau]1", ",", " ", "\[Tau]2"}], "}"}], ",", " ", 
            RowBox[{"{", 
             RowBox[{"\[Tau]2", ",", " ", "\[Tau]2"}], "}"}]}], "}"}]}]}], 
        ",", " ", "1"}], "]"}]}], ";", " ", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"ListPlot", "[", 
        RowBox[{"tmpList", ",", " ", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"PointSize", "[", "0.01", "]"}]}]}], "]"}], ",", " ", 
       RowBox[{"Graphics", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", " ", 
          RowBox[{"GrayLevel", "[", "0.3", "]"}], ",", " ", 
          RowBox[{"Line", "/@", 
           RowBox[{"Partition", "[", 
            RowBox[{"tmpList", ",", " ", "2", ",", " ", "1"}], "]"}]}]}], 
         "}"}], "]"}], ",", " ", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.437186524394224*^9, 3.437186554664662*^9}, {
  3.4371867790957623`*^9, 3.437186795613858*^9}, {3.4371877461054373`*^9, 
  3.43718775503932*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Testing cobweb", "Subsubsection",
 CellChangeTimes->{{3.465177884980592*^9, 3.465177888866062*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"cobweb", "[", "\[Tau]ListRef", "]"}], ",", " ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FNMap", "[", "t", "]"}], "+", "Tref"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "dom1", ",", " ", "30"}], "}"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"AbsoluteThickness", "[", "1.5", "]"}], ",", " ", 
        RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}]}]}], "]"}], ",", " ", 
   RowBox[{"Prolog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", " ", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"15", ",", " ", "15"}], "}"}]}], "}"}], "]"}]}], "}"}]}], 
   ",", " ", 
   RowBox[{"AspectRatio", "\[Rule]", "Automatic"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4651781391501427`*^9, 3.465178146888357*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.67, 0.6, 0.6], PointSize[0.01], PointBox[CompressedData["
1:eJx10n1UDXYcx/GIGlGXHm51S5zdsrrdaglHaVYdM0JJKkckKdzWgx5krgm3
9CRlUkR5yDLq3Fm1dTOOpNJQRw9MhaImDCvGbaL2e+ivnfP5/vP6930+5ztj
Q5RP6FgNDY3sMRoaVH6OX35sXLcj/bY59J+jXxxKVYuhO5sFG2uqJVCfyO6I
dQ9toVqF86y2+EmgdQPrh/PdpFDD8aeKG76xgQbqtORM7JBC+2OmBW1PMYG+
rBxSdV39FBrm7zAQrrSBts/YuVmkkkJ1XNtUq/tmQo01V7rJGqXQjXGpS7fk
WULL7Zpy5ItsobuKb51e7YbN6Ek+YLYYK1VPSvdcgN0vX6ir8sTe+JBebzwf
O/jTnKHrXthx+evjA+di/ddON2lchW3c3jbT0QFb8ap+ytN12IFwzxXtYuwu
3Vu33SOwk2/K8gwE2Nm1afbX92Hr3yqS059JoKa1oXuflNlC/QIz42pPS6A1
Wi5eaz7YQsUXuvt9hRKoaWS9ZUKsFJqULavwuGoNVfbc/kNvqh10ieKSjkW8
COoUE+p66HMxVJHtW9ykL4GalW4K0dsmhaad25xj9Ks1VNlQaCI0sIM+Hey2
Cf5OBHU29bQxnSWGDm4SKJ0NJdD7XRvGj4uXQh9aRp8vuGgNDXO1qF2ibwcN
iYr+bdoOEbRzT9OTREcxNOKsXKfEQALVK7xWEEE6kVWVJaI7KmvowjVCl+Ok
E3lDOPK3TC6Cfvzew+cy6UR6ty2a30s6kQZlYbkepBP5Z1aPZkaVNfSee/sL
OelE7g98Pr2P7Iz8oeDBmzOkE9lXlJbRSDqR9RnNHr6kE5lR1XnfnXQiF7wN
vpZKOpG5rl8nisjOyCxZ3Gkl6UQuzonKuks6kernBUXLSCcyPHtrahDpRD5f
GnleQTqRhdFl5VqkE7nc3PnGedKJDM7/+L6FdCIT66QLvUknslphaOVLOpE1
S65cSCadyJFQs3e6pBNpt1K8opR0IktfDYW1kU5kyODZeV6kE9lx5WRJAOlE
7nfte5xE/xzo3R6s1CGdSMeNvb+UkE5kiVHE3VbSiZS1Pimincilzn91+ZFO
5HKtH53ozsj1dj1Dk0gnUqqd+YZ2ImUld/XozsjJuRXf0k5kmVVirj/pROqa
OxjQTqTAJyqBdkLNBZ20E3lEPuFfujOy8uK2dNqJDPrqwzLaiexxMZxBO5H3
RiaU0k7konu/99JOpF+1cCzdGVnU3aSgncjYwgYZ7UTa270T0U5kYbFlHu1E
Hpvwspt2IjMmJg7TnZE3D8buo53ImHMBQbQTObVr2Jx2Io/VbT3BOoGzrsQ/
pp3IvIoXI7QTGdcclkw7kQmKnhDaiTyh78A6ka9trI7TTuSd6+2PaCeyf8ca
1olsyWxmncgUpeEG2omsddrLOpF7ZscX0E6kpErIdkbO+eww60S2Wp9lncgL
Jo2sE5mWG8w6kQGW/WxnZKDFCNsZafHlLtaJvDxSyTqRbm5JrBP5ID2SdSIF
w2K2MzKr9xO2M3LK6hTWiZzo/TPrRB6wP8U6kXWhW1gnUn+MgHUiHTXHs06k
+SUF60R2qMtZJ9K47DDrRD6IDud7AzX8jVknUpWpxTqR2yXJrBPZ+ayMdSJX
ueezTqTZKRnrRMq1DVknUnuA74w8eDSJdSKFq/jOyICYI6wTefIN70SaBBix
TqSHPd8ZmdTKO5G7bXgn8oTNUdaJ7GjhnciwFr4zMsOIdyJ3XxrtBMpceCcy
+hHfGfmwi3ciE7X5zsjA6bwTeaaOdyLLnHgncu8w70SWd/BOpOw13xm5zYx3
IjVreCdy7VzeiVS/5p3I6vu8E9nwnncix07jncjYa7wT6TWHdyJT1LwT2d/J
O5EJat6JDDXnnchHozsjL452IlVveSfSY3Tn//sfx4o53w==
      "]]}, 
    {GrayLevel[0.3], AbsoluteThickness[1], 
     LineBox[{{18, 7.453653251682678}, {7.453653251682678, 
       7.453653251682678}}], 
     LineBox[{{7.453653251682678, 7.453653251682678}, {7.453653251682678, 
      10.4834638608854}}], 
     LineBox[{{7.453653251682678, 10.4834638608854}, {10.4834638608854, 
      10.4834638608854}}], 
     LineBox[{{10.4834638608854, 10.4834638608854}, {10.4834638608854, 
      13.876483084729209`}}], 
     LineBox[{{10.4834638608854, 13.876483084729209`}, {13.876483084729209`, 
      13.876483084729209`}}], 
     LineBox[{{13.876483084729209`, 13.876483084729209`}, {
      13.876483084729209`, 14.434314187666278`}}], 
     LineBox[{{13.876483084729209`, 14.434314187666278`}, {
      14.434314187666278`, 14.434314187666278`}}], 
     LineBox[{{14.434314187666278`, 14.434314187666278`}, {
      14.434314187666278`, 13.668770975621566`}}], 
     LineBox[{{14.434314187666278`, 13.668770975621566`}, {
      13.668770975621566`, 13.668770975621566`}}], 
     LineBox[{{13.668770975621566`, 13.668770975621566`}, {
      13.668770975621566`, 14.628135632833514`}}], 
     LineBox[{{13.668770975621566`, 14.628135632833514`}, {
      14.628135632833514`, 14.628135632833514`}}], 
     LineBox[{{14.628135632833514`, 14.628135632833514`}, {
      14.628135632833514`, 13.212468344836944`}}], 
     LineBox[{{14.628135632833514`, 13.212468344836944`}, {
      13.212468344836944`, 13.212468344836944`}}], 
     LineBox[{{13.212468344836944`, 13.212468344836944`}, {
      13.212468344836944`, 14.925861979141409`}}], 
     LineBox[{{13.212468344836944`, 14.925861979141409`}, {
      14.925861979141409`, 14.925861979141409`}}], 
     LineBox[{{14.925861979141409`, 14.925861979141409`}, {
      14.925861979141409`, 6.382295118554552}}], 
     LineBox[{{14.925861979141409`, 6.382295118554552}, {6.382295118554552, 
      6.382295118554552}}], 
     LineBox[{{6.382295118554552, 6.382295118554552}, {6.382295118554552, 
      9.878659992911674}}], 
     LineBox[{{6.382295118554552, 9.878659992911674}, {9.878659992911674, 
      9.878659992911674}}], 
     LineBox[{{9.878659992911674, 9.878659992911674}, {9.878659992911674, 
      13.340667283202219`}}], 
     LineBox[{{9.878659992911674, 13.340667283202219`}, {13.340667283202219`, 
      13.340667283202219`}}], 
     LineBox[{{13.340667283202219`, 13.340667283202219`}, {
      13.340667283202219`, 14.859584107544764`}}], 
     LineBox[{{13.340667283202219`, 14.859584107544764`}, {
      14.859584107544764`, 14.859584107544764`}}], 
     LineBox[{{14.859584107544764`, 14.859584107544764`}, {
      14.859584107544764`, 11.951856399448408`}}], 
     LineBox[{{14.859584107544764`, 11.951856399448408`}, {
      11.951856399448408`, 11.951856399448408`}}], 
     LineBox[{{11.951856399448408`, 11.951856399448408`}, {
      11.951856399448408`, 14.901201287635146`}}], 
     LineBox[{{11.951856399448408`, 14.901201287635146`}, {
      14.901201287635146`, 14.901201287635146`}}], 
     LineBox[{{14.901201287635146`, 14.901201287635146`}, {
      14.901201287635146`, 10.795725242287695`}}], 
     LineBox[{{14.901201287635146`, 10.795725242287695`}, {
      10.795725242287695`, 10.795725242287695`}}], 
     LineBox[{{10.795725242287695`, 10.795725242287695`}, {
      10.795725242287695`, 14.13961472527385}}], 
     LineBox[{{10.795725242287695`, 14.13961472527385}, {14.13961472527385, 
      14.13961472527385}}], 
     LineBox[{{14.13961472527385, 14.13961472527385}, {14.13961472527385, 
      14.127636992913946`}}], 
     LineBox[{{14.13961472527385, 14.127636992913946`}, {14.127636992913946`, 
      14.127636992913946`}}], 
     LineBox[{{14.127636992913946`, 14.127636992913946`}, {
      14.127636992913946`, 14.142795995563366`}}], 
     LineBox[{{14.127636992913946`, 14.142795995563366`}, {
      14.142795995563366`, 14.142795995563366`}}], 
     LineBox[{{14.142795995563366`, 14.142795995563366`}, {
      14.142795995563366`, 14.12362319381972}}], 
     LineBox[{{14.142795995563366`, 14.12362319381972}, {14.12362319381972, 
      14.12362319381972}}], 
     LineBox[{{14.12362319381972, 14.12362319381972}, {14.12362319381972, 
      14.147888608915103`}}], 
     LineBox[{{14.12362319381972, 14.147888608915103`}, {14.147888608915103`, 
      14.147888608915103`}}], 
     LineBox[{{14.147888608915103`, 14.147888608915103`}, {
      14.147888608915103`, 14.117376522508852`}}], 
     LineBox[{{14.147888608915103`, 14.117376522508852`}, {
      14.117376522508852`, 14.117376522508852`}}], 
     LineBox[{{14.117376522508852`, 14.117376522508852`}, {
      14.117376522508852`, 14.155822611261087`}}], 
     LineBox[{{14.117376522508852`, 14.155822611261087`}, {
      14.155822611261087`, 14.155822611261087`}}], 
     LineBox[{{14.155822611261087`, 14.155822611261087`}, {
      14.155822611261087`, 14.108127277414503`}}], 
     LineBox[{{14.155822611261087`, 14.108127277414503`}, {
      14.108127277414503`, 14.108127277414503`}}], 
     LineBox[{{14.108127277414503`, 14.108127277414503`}, {
      14.108127277414503`, 14.167580399704702`}}], 
     LineBox[{{14.108127277414503`, 14.167580399704702`}, {
      14.167580399704702`, 14.167580399704702`}}], 
     LineBox[{{14.167580399704702`, 14.167580399704702`}, {
      14.167580399704702`, 14.094132656752118`}}], 
     LineBox[{{14.167580399704702`, 14.094132656752118`}, {
      14.094132656752118`, 14.094132656752118`}}], 
     LineBox[{{14.094132656752118`, 14.094132656752118`}, {
      14.094132656752118`, 14.185364299329514`}}], 
     LineBox[{{14.094132656752118`, 14.185364299329514`}, {
      14.185364299329514`, 14.185364299329514`}}], 
     LineBox[{{14.185364299329514`, 14.185364299329514`}, {
      14.185364299329514`, 14.07197050138163}}], 
     LineBox[{{14.185364299329514`, 14.07197050138163}, {14.07197050138163, 
      14.07197050138163}}], 
     LineBox[{{14.07197050138163, 14.07197050138163}, {14.07197050138163, 
      14.213400387677435`}}], 
     LineBox[{{14.07197050138163, 14.213400387677435`}, {14.213400387677435`, 
      14.213400387677435`}}], 
     LineBox[{{14.213400387677435`, 14.213400387677435`}, {
      14.213400387677435`, 14.031407100473666`}}], 
     LineBox[{{14.213400387677435`, 14.031407100473666`}, {
      14.031407100473666`, 14.031407100473666`}}], 
     LineBox[{{14.031407100473666`, 14.031407100473666`}, {
      14.031407100473666`, 14.263238416258995`}}], 
     LineBox[{{14.031407100473666`, 14.263238416258995`}, {
      14.263238416258995`, 14.263238416258995`}}], 
     LineBox[{{14.263238416258995`, 14.263238416258995`}, {
      14.263238416258995`, 13.956134960516362`}}], 
     LineBox[{{14.263238416258995`, 13.956134960516362`}, {
      13.956134960516362`, 13.956134960516362`}}], 
     LineBox[{{13.956134960516362`, 13.956134960516362`}, {
      13.956134960516362`, 14.349414896891222`}}], 
     LineBox[{{13.956134960516362`, 14.349414896891222`}, {
      14.349414896891222`, 14.349414896891222`}}], 
     LineBox[{{14.349414896891222`, 14.349414896891222`}, {
      14.349414896891222`, 13.817905084854072`}}], 
     LineBox[{{14.349414896891222`, 13.817905084854072`}, {
      13.817905084854072`, 13.817905084854072`}}], 
     LineBox[{{13.817905084854072`, 13.817905084854072`}, {
      13.817905084854072`, 14.49288413615739}}], 
     LineBox[{{13.817905084854072`, 14.49288413615739}, {14.49288413615739, 
      14.49288413615739}}], 
     LineBox[{{14.49288413615739, 14.49288413615739}, {14.49288413615739, 
      13.54556992285513}}], 
     LineBox[{{14.49288413615739, 13.54556992285513}, {13.54556992285513, 
      13.54556992285513}}], 
     LineBox[{{13.54556992285513, 13.54556992285513}, {13.54556992285513, 
      14.72551839873545}}], 
     LineBox[{{13.54556992285513, 14.72551839873545}, {14.72551839873545, 
      14.72551839873545}}], 
     LineBox[{{14.72551839873545, 14.72551839873545}, {14.72551839873545, 
      12.877469671257366`}}], 
     LineBox[{{14.72551839873545, 12.877469671257366`}, {12.877469671257366`, 
      12.877469671257366`}}], 
     LineBox[{{12.877469671257366`, 12.877469671257366`}, {
      12.877469671257366`, 15.035277122735206`}}], 
     LineBox[{{12.877469671257366`, 15.035277122735206`}, {
      15.035277122735206`, 15.035277122735206`}}], 
     LineBox[{{15.035277122735206`, 15.035277122735206`}, {
      15.035277122735206`, 6.864376243000899}}], 
     LineBox[{{15.035277122735206`, 6.864376243000899}, {6.864376243000899, 
      6.864376243000899}}], 
     LineBox[{{6.864376243000899, 6.864376243000899}, {6.864376243000899, 
      10.09682647574764}}], 
     LineBox[{{6.864376243000899, 10.09682647574764}, {10.09682647574764, 
      10.09682647574764}}], 
     LineBox[{{10.09682647574764, 10.09682647574764}, {10.09682647574764, 
      13.538685987303557`}}], 
     LineBox[{{10.09682647574764, 13.538685987303557`}, {13.538685987303557`, 
      13.538685987303557`}}], 
     LineBox[{{13.538685987303557`, 13.538685987303557`}, {
      13.538685987303557`, 14.73058615341693}}], 
     LineBox[{{13.538685987303557`, 14.73058615341693}, {14.73058615341693, 
      14.73058615341693}}], 
     LineBox[{{14.73058615341693, 14.73058615341693}, {14.73058615341693, 
      12.85564101960769}}], 
     LineBox[{{14.73058615341693, 12.85564101960769}, {12.85564101960769, 
      12.85564101960769}}], 
     LineBox[{{12.85564101960769, 12.85564101960769}, {12.85564101960769, 
      15.039238739617158`}}], 
     LineBox[{{12.85564101960769, 15.039238739617158`}, {15.039238739617158`, 
      15.039238739617158`}}], 
     LineBox[{{15.039238739617158`, 15.039238739617158`}, {
      15.039238739617158`, 6.8724409770786465`}}], 
     LineBox[{{15.039238739617158`, 6.8724409770786465`}, {
      6.8724409770786465`, 6.8724409770786465`}}], 
     LineBox[{{6.8724409770786465`, 6.8724409770786465`}, {
      6.8724409770786465`, 10.099808999698428`}}], 
     LineBox[{{6.8724409770786465`, 10.099808999698428`}, {
      10.099808999698428`, 10.099808999698428`}}], 
     LineBox[{{10.099808999698428`, 10.099808999698428`}, {
      10.099808999698428`, 13.541463317396833`}}], 
     LineBox[{{10.099808999698428`, 13.541463317396833`}, {
      13.541463317396833`, 13.541463317396833`}}], 
     LineBox[{{13.541463317396833`, 13.541463317396833`}, {
      13.541463317396833`, 14.728546303100238`}}], 
     LineBox[{{13.541463317396833`, 14.728546303100238`}, {
      14.728546303100238`, 14.728546303100238`}}], 
     LineBox[{{14.728546303100238`, 14.728546303100238`}, {
      14.728546303100238`, 12.864484144391948`}}], 
     LineBox[{{14.728546303100238`, 12.864484144391948`}, {
      12.864484144391948`, 12.864484144391948`}}], 
     LineBox[{{12.864484144391948`, 12.864484144391948`}, {
      12.864484144391948`, 15.037679795087296`}}], 
     LineBox[{{12.864484144391948`, 15.037679795087296`}, {
      15.037679795087296`, 15.037679795087296`}}], 
     LineBox[{{15.037679795087296`, 15.037679795087296`}, {
      15.037679795087296`, 6.869257858979696}}], 
     LineBox[{{15.037679795087296`, 6.869257858979696}, {6.869257858979696, 
      6.869257858979696}}], 
     LineBox[{{6.869257858979696, 6.869257858979696}, {6.869257858979696, 
      10.098632061680226`}}], 
     LineBox[{{6.869257858979696, 10.098632061680226`}, {10.098632061680226`, 
      10.098632061680226`}}], 
     LineBox[{{10.098632061680226`, 10.098632061680226`}, {
      10.098632061680226`, 13.540367468685611`}}], 
     LineBox[{{10.098632061680226`, 13.540367468685611`}, {
      13.540367468685611`, 13.540367468685611`}}], 
     LineBox[{{13.540367468685611`, 13.540367468685611`}, {
      13.540367468685611`, 14.729351930741386`}}], 
     LineBox[{{13.540367468685611`, 14.729351930741386`}, {
      14.729351930741386`, 14.729351930741386`}}], 
     LineBox[{{14.729351930741386`, 14.729351930741386`}, {
      14.729351930741386`, 12.861000885688428`}}], 
     LineBox[{{14.729351930741386`, 12.861000885688428`}, {
      12.861000885688428`, 12.861000885688428`}}], 
     LineBox[{{12.861000885688428`, 12.861000885688428`}, {
      12.861000885688428`, 15.038301321602953`}}], 
     LineBox[{{12.861000885688428`, 15.038301321602953`}, {
      15.038301321602953`, 15.038301321602953`}}], 
     LineBox[{{15.038301321602953`, 15.038301321602953`}, {
      15.038301321602953`, 6.870525121636044}}], 
     LineBox[{{15.038301321602953`, 6.870525121636044}, {6.870525121636044, 
      6.870525121636044}}], 
     LineBox[{{6.870525121636044, 6.870525121636044}, {6.870525121636044, 
      10.099100657223511`}}], 
     LineBox[{{6.870525121636044, 10.099100657223511`}, {10.099100657223511`, 
      10.099100657223511`}}], 
     LineBox[{{10.099100657223511`, 10.099100657223511`}, {
      10.099100657223511`, 13.540803798454505`}}], 
     LineBox[{{10.099100657223511`, 13.540803798454505`}, {
      13.540803798454505`, 13.540803798454505`}}], 
     LineBox[{{13.540803798454505`, 13.540803798454505`}, {
      13.540803798454505`, 14.729031276737295`}}], 
     LineBox[{{13.540803798454505`, 14.729031276737295`}, {
      14.729031276737295`, 14.729031276737295`}}], 
     LineBox[{{14.729031276737295`, 14.729031276737295`}, {
      14.729031276737295`, 12.862388726738525`}}], 
     LineBox[{{14.729031276737295`, 12.862388726738525`}, {
      12.862388726738525`, 12.862388726738525`}}], 
     LineBox[{{12.862388726738525`, 12.862388726738525`}, {
      12.862388726738525`, 15.038054849167949`}}], 
     LineBox[{{12.862388726738525`, 15.038054849167949`}, {
      15.038054849167949`, 15.038054849167949`}}], 
     LineBox[{{15.038054849167949`, 15.038054849167949`}, {
      15.038054849167949`, 6.870022310547153}}], 
     LineBox[{{15.038054849167949`, 6.870022310547153}, {6.870022310547153, 
      6.870022310547153}}], 
     LineBox[{{6.870022310547153, 6.870022310547153}, {6.870022310547153, 
      10.09891473846694}}], 
     LineBox[{{6.870022310547153, 10.09891473846694}, {10.09891473846694, 
      10.09891473846694}}], 
     LineBox[{{10.09891473846694, 10.09891473846694}, {10.09891473846694, 
      13.540630684425151`}}], 
     LineBox[{{10.09891473846694, 13.540630684425151`}, {13.540630684425151`, 
      13.540630684425151`}}], 
     LineBox[{{13.540630684425151`, 13.540630684425151`}, {
      13.540630684425151`, 14.729158515290589`}}], 
     LineBox[{{13.540630684425151`, 14.729158515290589`}, {
      14.729158515290589`, 14.729158515290589`}}], 
     LineBox[{{14.729158515290589`, 14.729158515290589`}, {
      14.729158515290589`, 12.861838247129318`}}], 
     LineBox[{{14.729158515290589`, 12.861838247129318`}, {
      12.861838247129318`, 12.861838247129318`}}], 
     LineBox[{{12.861838247129318`, 12.861838247129318`}, {
      12.861838247129318`, 15.038152795512927`}}], 
     LineBox[{{12.861838247129318`, 15.038152795512927`}, {
      15.038152795512927`, 15.038152795512927`}}], 
     LineBox[{{15.038152795512927`, 15.038152795512927`}, {
      15.038152795512927`, 6.870222080978598}}], 
     LineBox[{{15.038152795512927`, 6.870222080978598}, {6.870222080978598, 
      6.870222080978598}}], 
     LineBox[{{6.870222080978598, 6.870222080978598}, {6.870222080978598, 
      10.098988606177299`}}], 
     LineBox[{{6.870222080978598, 10.098988606177299`}, {10.098988606177299`, 
      10.098988606177299`}}], 
     LineBox[{{10.098988606177299`, 10.098988606177299`}, {
      10.098988606177299`, 13.540699465151322`}}], 
     LineBox[{{10.098988606177299`, 13.540699465151322`}, {
      13.540699465151322`, 13.540699465151322`}}], 
     LineBox[{{13.540699465151322`, 13.540699465151322`}, {
      13.540699465151322`, 14.72910796454151}}], 
     LineBox[{{13.540699465151322`, 14.72910796454151}, {14.72910796454151, 
      14.72910796454151}}], 
     LineBox[{{14.72910796454151, 14.72910796454151}, {14.72910796454151, 
      12.862056983816919`}}], 
     LineBox[{{14.72910796454151, 12.862056983816919`}, {12.862056983816919`, 
      12.862056983816919`}}], 
     LineBox[{{12.862056983816919`, 12.862056983816919`}, {
      12.862056983816919`, 15.038113904919062`}}], 
     LineBox[{{12.862056983816919`, 15.038113904919062`}, {
      15.038113904919062`, 15.038113904919062`}}], 
     LineBox[{{15.038113904919062`, 15.038113904919062`}, {
      15.038113904919062`, 6.870142753378017}}], 
     LineBox[{{15.038113904919062`, 6.870142753378017}, {6.870142753378017, 
      6.870142753378017}}], 
     LineBox[{{6.870142753378017, 6.870142753378017}, {6.870142753378017, 
      10.09895927390485}}], 
     LineBox[{{6.870142753378017, 10.09895927390485}, {10.09895927390485, 
      10.09895927390485}}], 
     LineBox[{{10.09895927390485, 10.09895927390485}, {10.09895927390485, 
      13.54067215295544}}], 
     LineBox[{{10.09895927390485, 13.54067215295544}, {13.54067215295544, 
      13.54067215295544}}], 
     LineBox[{{13.54067215295544, 13.54067215295544}, {13.54067215295544, 
      14.729128038251245`}}], 
     LineBox[{{13.54067215295544, 14.729128038251245`}, {14.729128038251245`, 
      14.729128038251245`}}], 
     LineBox[{{14.729128038251245`, 14.729128038251245`}, {
      14.729128038251245`, 12.86197012913351}}], 
     LineBox[{{14.729128038251245`, 12.86197012913351}, {12.86197012913351, 
      12.86197012913351}}], 
     LineBox[{{12.86197012913351, 12.86197012913351}, {12.86197012913351, 
      15.038129351950719`}}], 
     LineBox[{{12.86197012913351, 15.038129351950719`}, {15.038129351950719`, 
      15.038129351950719`}}], 
     LineBox[{{15.038129351950719`, 15.038129351950719`}, {
      15.038129351950719`, 6.870174260600378}}], 
     LineBox[{{15.038129351950719`, 6.870174260600378}, {6.870174260600378, 
      6.870174260600378}}], 
     LineBox[{{6.870174260600378, 6.870174260600378}, {6.870174260600378, 
      10.098970924076266`}}], 
     LineBox[{{6.870174260600378, 10.098970924076266`}, {10.098970924076266`, 
      10.098970924076266`}}], 
     LineBox[{{10.098970924076266`, 10.098970924076266`}, {
      10.098970924076266`, 13.54068300080629}}], 
     LineBox[{{10.098970924076266`, 13.54068300080629}, {13.54068300080629, 
      13.54068300080629}}], 
     LineBox[{{13.54068300080629, 13.54068300080629}, {13.54068300080629, 
      14.729120065454657`}}], 
     LineBox[{{13.54068300080629, 14.729120065454657`}, {14.729120065454657`, 
      14.729120065454657`}}], 
     LineBox[{{14.729120065454657`, 14.729120065454657`}, {
      14.729120065454657`, 12.862004626629574`}}], 
     LineBox[{{14.729120065454657`, 12.862004626629574`}, {
      12.862004626629574`, 12.862004626629574`}}], 
     LineBox[{{12.862004626629574`, 12.862004626629574`}, {
      12.862004626629574`, 15.038123217322912`}}], 
     LineBox[{{12.862004626629574`, 15.038123217322912`}, {
      15.038123217322912`, 15.038123217322912`}}], 
     LineBox[{{15.038123217322912`, 15.038123217322912`}, {
      15.038123217322912`, 6.870161747667524}}], 
     LineBox[{{15.038123217322912`, 6.870161747667524}, {6.870161747667524, 
      6.870161747667524}}], 
     LineBox[{{6.870161747667524, 6.870161747667524}, {6.870161747667524, 
      10.098966297273453`}}], 
     LineBox[{{6.870161747667524, 10.098966297273453`}, {10.098966297273453`, 
      10.098966297273453`}}], 
     LineBox[{{10.098966297273453`, 10.098966297273453`}, {
      10.098966297273453`, 13.540678692642663`}}], 
     LineBox[{{10.098966297273453`, 13.540678692642663`}, {
      13.540678692642663`, 13.540678692642663`}}], 
     LineBox[{{13.540678692642663`, 13.540678692642663`}, {
      13.540678692642663`, 14.729123231818182`}}], 
     LineBox[{{13.540678692642663`, 14.729123231818182`}, {
      14.729123231818182`, 14.729123231818182`}}], 
     LineBox[{{14.729123231818182`, 14.729123231818182`}, {
      14.729123231818182`, 12.861990926231691`}}], 
     LineBox[{{14.729123231818182`, 12.861990926231691`}, {
      12.861990926231691`, 12.861990926231691`}}], 
     LineBox[{{12.861990926231691`, 12.861990926231691`}, {
      12.861990926231691`, 15.038125653754062`}}], 
     LineBox[{{12.861990926231691`, 15.038125653754062`}, {
      15.038125653754062`, 15.038125653754062`}}], 
     LineBox[{{15.038125653754062`, 15.038125653754062`}, {
      15.038125653754062`, 6.870166717282331}}], 
     LineBox[{{15.038125653754062`, 6.870166717282331}, {6.870166717282331, 
      6.870166717282331}}], 
     LineBox[{{6.870166717282331, 6.870166717282331}, {6.870166717282331, 
      10.098968134847008`}}], 
     LineBox[{{6.870166717282331, 10.098968134847008`}, {10.098968134847008`, 
      10.098968134847008`}}], 
     LineBox[{{10.098968134847008`, 10.098968134847008`}, {
      10.098968134847008`, 13.54068040366629}}], 
     LineBox[{{10.098968134847008`, 13.54068040366629}, {13.54068040366629, 
      13.54068040366629}}], 
     LineBox[{{13.54068040366629, 13.54068040366629}, {13.54068040366629, 
      14.72912197427197}}], 
     LineBox[{{13.54068040366629, 14.72912197427197}, {14.72912197427197, 
      14.72912197427197}}], 
     LineBox[{{14.72912197427197, 14.72912197427197}, {14.72912197427197, 
      12.86199636747492}}], 
     LineBox[{{14.72912197427197, 12.86199636747492}, {12.86199636747492, 
      12.86199636747492}}], 
     LineBox[{{12.86199636747492, 12.86199636747492}, {12.86199636747492, 
      15.038124686120252`}}], 
     LineBox[{{12.86199636747492, 15.038124686120252`}, {15.038124686120252`, 
      15.038124686120252`}}], 
     LineBox[{{15.038124686120252`, 15.038124686120252`}, {
      15.038124686120252`, 6.870164743585079}}], 
     LineBox[{{15.038124686120252`, 6.870164743585079}, {6.870164743585079, 
      6.870164743585079}}], 
     LineBox[{{6.870164743585079, 6.870164743585079}, {6.870164743585079, 
      10.098967405049308`}}], 
     LineBox[{{6.870164743585079, 10.098967405049308`}, {10.098967405049308`, 
      10.098967405049308`}}], 
     LineBox[{{10.098967405049308`, 10.098967405049308`}, {
      10.098967405049308`, 13.54067972412831}}], 
     LineBox[{{10.098967405049308`, 13.54067972412831}, {13.54067972412831, 
      13.54067972412831}}], 
     LineBox[{{13.54067972412831, 13.54067972412831}, {13.54067972412831, 
      14.729122473710374`}}], 
     LineBox[{{13.54067972412831, 14.729122473710374`}, {14.729122473710374`, 
      14.729122473710374`}}], 
     LineBox[{{14.729122473710374`, 14.729122473710374`}, {
      14.729122473710374`, 12.861994206471705`}}], 
     LineBox[{{14.729122473710374`, 12.861994206471705`}, {
      12.861994206471705`, 12.861994206471705`}}], 
     LineBox[{{12.861994206471705`, 12.861994206471705`}, {
      12.861994206471705`, 15.03812507042125}}], 
     LineBox[{{12.861994206471705`, 15.03812507042125}, {15.03812507042125, 
      15.03812507042125}}], 
     LineBox[{{15.03812507042125, 15.03812507042125}, {15.03812507042125, 
      6.870165527448954}}], 
     LineBox[{{15.03812507042125, 6.870165527448954}, {6.870165527448954, 
      6.870165527448954}}], 
     LineBox[{{6.870165527448954, 6.870165527448954}, {6.870165527448954, 
      10.09896769489218}}], 
     LineBox[{{6.870165527448954, 10.09896769489218}, {10.09896769489218, 
      10.09896769489218}}], 
     LineBox[{{10.09896769489218, 10.09896769489218}, {10.09896769489218, 
      13.540679994010286`}}], 
     LineBox[{{10.09896769489218, 13.540679994010286`}, {13.540679994010286`, 
      13.540679994010286`}}], 
     LineBox[{{13.540679994010286`, 13.540679994010286`}, {
      13.540679994010286`, 14.72912227535591}}], 
     LineBox[{{13.540679994010286`, 14.72912227535591}, {14.72912227535591, 
      14.72912227535591}}], 
     LineBox[{{14.72912227535591, 14.72912227535591}, {14.72912227535591, 
      12.86199506472551}}], 
     LineBox[{{14.72912227535591, 12.86199506472551}, {12.86199506472551, 
      12.86199506472551}}], 
     LineBox[{{12.86199506472551, 12.86199506472551}, {12.86199506472551, 
      15.038124917794532`}}], 
     LineBox[{{12.86199506472551, 15.038124917794532`}, {15.038124917794532`, 
      15.038124917794532`}}], 
     LineBox[{{15.038124917794532`, 15.038124917794532`}, {
      15.038124917794532`, 6.870165216134096}}], 
     LineBox[{{15.038124917794532`, 6.870165216134096}, {6.870165216134096, 
      6.870165216134096}}], 
     LineBox[{{6.870165216134096, 6.870165216134096}, {6.870165216134096, 
      10.098967579779858`}}], 
     LineBox[{{6.870165216134096, 10.098967579779858`}, {10.098967579779858`, 
      10.098967579779858`}}], 
     LineBox[{{10.098967579779858`, 10.098967579779858`}, {
      10.098967579779858`, 13.54067988682552}}], 
     LineBox[{{10.098967579779858`, 13.54067988682552}, {13.54067988682552, 
      13.54067988682552}}], 
     LineBox[{{13.54067988682552, 13.54067988682552}, {13.54067988682552, 
      14.72912235413323}}], 
     LineBox[{{13.54067988682552, 14.72912235413323}, {14.72912235413323, 
      14.72912235413323}}], 
     LineBox[{{14.72912235413323, 14.72912235413323}, {14.72912235413323, 
      12.861994723866449`}}], 
     LineBox[{{14.72912235413323, 12.861994723866449`}, {12.861994723866449`, 
      12.861994723866449`}}], 
     LineBox[{{12.861994723866449`, 12.861994723866449`}, {
      12.861994723866449`, 15.038124978410938`}}], 
     LineBox[{{12.861994723866449`, 15.038124978410938`}, {
      15.038124978410938`, 15.038124978410938`}}], 
     LineBox[{{15.038124978410938`, 15.038124978410938`}, {
      15.038124978410938`, 6.870165339774213}}], 
     LineBox[{{15.038124978410938`, 6.870165339774213}, {6.870165339774213, 
      6.870165339774213}}], 
     LineBox[{{6.870165339774213, 6.870165339774213}, {6.870165339774213, 
      10.098967625497243`}}], 
     LineBox[{{6.870165339774213, 10.098967625497243`}, {10.098967625497243`, 
      10.098967625497243`}}], 
     LineBox[{{10.098967625497243`, 10.098967625497243`}, {
      10.098967625497243`, 13.540679929394441`}}], 
     LineBox[{{10.098967625497243`, 13.540679929394441`}, {
      13.540679929394441`, 13.540679929394441`}}], 
     LineBox[{{13.540679929394441`, 13.540679929394441`}, {
      13.540679929394441`, 14.729122322846457`}}], 
     LineBox[{{13.540679929394441`, 14.729122322846457`}, {
      14.729122322846457`, 14.729122322846457`}}], 
     LineBox[{{14.729122322846457`, 14.729122322846457`}, {
      14.729122322846457`, 12.861994859240196`}}], 
     LineBox[{{14.729122322846457`, 12.861994859240196`}, {
      12.861994859240196`, 12.861994859240196`}}], 
     LineBox[{{12.861994859240196`, 12.861994859240196`}, {
      12.861994859240196`, 15.038124954336864`}}], 
     LineBox[{{12.861994859240196`, 15.038124954336864`}, {
      15.038124954336864`, 15.038124954336864`}}], 
     LineBox[{{15.038124954336864`, 15.038124954336864`}, {
      15.038124954336864`, 6.8701652906699895`}}], 
     LineBox[{{15.038124954336864`, 6.8701652906699895`}, {
      6.8701652906699895`, 6.8701652906699895`}}], 
     LineBox[{{6.8701652906699895`, 6.8701652906699895`}, {
      6.8701652906699895`, 10.098967607340379`}}], 
     LineBox[{{6.8701652906699895`, 10.098967607340379`}, {
      10.098967607340379`, 10.098967607340379`}}], 
     LineBox[{{10.098967607340379`, 10.098967607340379`}, {
      10.098967607340379`, 13.540679912488002`}}], 
     LineBox[{{10.098967607340379`, 13.540679912488002`}, {
      13.540679912488002`, 13.540679912488002`}}], 
     LineBox[{{13.540679912488002`, 13.540679912488002`}, {
      13.540679912488002`, 14.729122335272141`}}], 
     LineBox[{{13.540679912488002`, 14.729122335272141`}, {
      14.729122335272141`, 14.729122335272141`}}], 
     LineBox[{{14.729122335272141`, 14.729122335272141`}, {
      14.729122335272141`, 12.8619948054759}}], 
     LineBox[{{14.729122335272141`, 12.8619948054759}, {12.8619948054759, 
      12.8619948054759}}], 
     LineBox[{{12.8619948054759, 12.8619948054759}, {12.8619948054759, 
      15.038124963897992`}}], 
     LineBox[{{12.8619948054759, 15.038124963897992`}, {15.038124963897992`, 
      15.038124963897992`}}], 
     LineBox[{{15.038124963897992`, 15.038124963897992`}, {
      15.038124963897992`, 6.870165310171957}}], 
     LineBox[{{15.038124963897992`, 6.870165310171957}, {6.870165310171957, 
      6.870165310171957}}], 
     LineBox[{{6.870165310171957, 6.870165310171957}, {6.870165310171957, 
      10.09896761455146}}], 
     LineBox[{{6.870165310171957, 10.09896761455146}, {10.09896761455146, 
      10.09896761455146}}], 
     LineBox[{{10.09896761455146, 10.09896761455146}, {10.09896761455146, 
      13.540679919202471`}}], 
     LineBox[{{10.09896761455146, 13.540679919202471`}, {13.540679919202471`, 
      13.540679919202471`}}], 
     LineBox[{{13.540679919202471`, 13.540679919202471`}, {
      13.540679919202471`, 14.729122330337225`}}], 
     LineBox[{{13.540679919202471`, 14.729122330337225`}, {
      14.729122330337225`, 14.729122330337225`}}], 
     LineBox[{{14.729122330337225`, 14.729122330337225`}, {
      14.729122330337225`, 12.861994826828635`}}], 
     LineBox[{{14.729122330337225`, 12.861994826828635`}, {
      12.861994826828635`, 12.861994826828635`}}], 
     LineBox[{{12.861994826828635`, 12.861994826828635`}, {
      12.861994826828635`, 15.038124960100747`}}], 
     LineBox[{{12.861994826828635`, 15.038124960100747`}, {
      15.038124960100747`, 15.038124960100747`}}], 
     LineBox[{{15.038124960100747`, 15.038124960100747`}, {
      15.038124960100747`, 6.870165302426663}}], 
     LineBox[{{15.038124960100747`, 6.870165302426663}, {6.870165302426663, 
      6.870165302426663}}], 
     LineBox[{{6.870165302426663, 6.870165302426663}, {6.870165302426663, 
      10.098967611687549`}}], 
     LineBox[{{6.870165302426663, 10.098967611687549`}, {10.098967611687549`, 
      10.098967611687549`}}], 
     LineBox[{{10.098967611687549`, 10.098967611687549`}, {
      10.098967611687549`, 13.540679916535792`}}], 
     LineBox[{{10.098967611687549`, 13.540679916535792`}, {
      13.540679916535792`, 13.540679916535792`}}], 
     LineBox[{{13.540679916535792`, 13.540679916535792`}, {
      13.540679916535792`, 14.729122332297147`}}], 
     LineBox[{{13.540679916535792`, 14.729122332297147`}, {
      14.729122332297147`, 14.729122332297147`}}], 
     LineBox[{{14.729122332297147`, 14.729122332297147`}, {
      14.729122332297147`, 12.86199481834831}}], 
     LineBox[{{14.729122332297147`, 12.86199481834831}, {12.86199481834831, 
      12.86199481834831}}], 
     LineBox[{{12.86199481834831, 12.86199481834831}, {12.86199481834831, 
      15.038124961608839`}}], 
     LineBox[{{12.86199481834831, 15.038124961608839`}, {15.038124961608839`, 
      15.038124961608839`}}], 
     LineBox[{{15.038124961608839`, 15.038124961608839`}, {
      15.038124961608839`, 6.870165305502738}}], 
     LineBox[{{15.038124961608839`, 6.870165305502738}, {6.870165305502738, 
      6.870165305502738}}], 
     LineBox[{{6.870165305502738, 6.870165305502738}, {6.870165305502738, 
      10.098967612824962`}}], 
     LineBox[{{6.870165305502738, 10.098967612824962`}, {10.098967612824962`, 
      10.098967612824962`}}], 
     LineBox[{{10.098967612824962`, 10.098967612824962`}, {
      10.098967612824962`, 13.540679917594874`}}], 
     LineBox[{{10.098967612824962`, 13.540679917594874`}, {
      13.540679917594874`, 13.540679917594874`}}], 
     LineBox[{{13.540679917594874`, 13.540679917594874`}, {
      13.540679917594874`, 14.729122331518756`}}], 
     LineBox[{{13.540679917594874`, 14.729122331518756`}, {
      14.729122331518756`, 14.729122331518756`}}], 
     LineBox[{{14.729122331518756`, 14.729122331518756`}, {
      14.729122331518756`, 12.861994821716305`}}], 
     LineBox[{{14.729122331518756`, 12.861994821716305`}, {
      12.861994821716305`, 12.861994821716305`}}], 
     LineBox[{{12.861994821716305`, 12.861994821716305`}, {
      12.861994821716305`, 15.038124961009894`}}], 
     LineBox[{{12.861994821716305`, 15.038124961009894`}, {
      15.038124961009894`, 15.038124961009894`}}], 
     LineBox[{{15.038124961009894`, 15.038124961009894`}, {
      15.038124961009894`, 6.870165304281062}}], 
     LineBox[{{15.038124961009894`, 6.870165304281062}, {6.870165304281062, 
      6.870165304281062}}], 
     LineBox[{{6.870165304281062, 6.870165304281062}, {6.870165304281062, 
      10.098967612373233`}}], 
     LineBox[{{6.870165304281062, 10.098967612373233`}, {10.098967612373233`, 
      10.098967612373233`}}], 
     LineBox[{{10.098967612373233`, 10.098967612373233`}, {
      10.098967612373233`, 13.540679917174254`}}], 
     LineBox[{{10.098967612373233`, 13.540679917174254`}, {
      13.540679917174254`, 13.540679917174254`}}], 
     LineBox[{{13.540679917174254`, 13.540679917174254`}, {
      13.540679917174254`, 14.729122331827899`}}], 
     LineBox[{{13.540679917174254`, 14.729122331827899`}, {
      14.729122331827899`, 14.729122331827899`}}], 
     LineBox[{{14.729122331827899`, 14.729122331827899`}, {
      14.729122331827899`, 12.861994820378683`}}], 
     LineBox[{{14.729122331827899`, 12.861994820378683`}, {
      12.861994820378683`, 12.861994820378683`}}], 
     LineBox[{{12.861994820378683`, 12.861994820378683`}, {
      12.861994820378683`, 15.03812496124777}}], 
     LineBox[{{12.861994820378683`, 15.03812496124777}, {15.03812496124777, 
      15.03812496124777}}], 
     LineBox[{{15.03812496124777, 15.03812496124777}, {15.03812496124777, 
      6.87016530476626}}], 
     LineBox[{{15.03812496124777, 6.87016530476626}, {6.87016530476626, 
      6.87016530476626}}], 
     LineBox[{{6.87016530476626, 6.87016530476626}, {6.87016530476626, 
      10.098967612552642`}}], 
     LineBox[{{6.87016530476626, 10.098967612552642`}, {10.098967612552642`, 
      10.098967612552642`}}], 
     LineBox[{{10.098967612552642`, 10.098967612552642`}, {
      10.098967612552642`, 13.540679917341308`}}], 
     LineBox[{{10.098967612552642`, 13.540679917341308`}, {
      13.540679917341308`, 13.540679917341308`}}], 
     LineBox[{{13.540679917341308`, 13.540679917341308`}, {
      13.540679917341308`, 14.729122331705119`}}], 
     LineBox[{{13.540679917341308`, 14.729122331705119`}, {
      14.729122331705119`, 14.729122331705119`}}], 
     LineBox[{{14.729122331705119`, 14.729122331705119`}, {
      14.729122331705119`, 12.861994820909937`}}], 
     LineBox[{{14.729122331705119`, 12.861994820909937`}, {
      12.861994820909937`, 12.861994820909937`}}], 
     LineBox[{{12.861994820909937`, 12.861994820909937`}, {
      12.861994820909937`, 15.038124961153294`}}], 
     LineBox[{{12.861994820909937`, 15.038124961153294`}, {
      15.038124961153294`, 15.038124961153294`}}], 
     LineBox[{{15.038124961153294`, 15.038124961153294`}, {
      15.038124961153294`, 6.870165304573557}}], 
     LineBox[{{15.038124961153294`, 6.870165304573557}, {6.870165304573557, 
      6.870165304573557}}], 
     LineBox[{{6.870165304573557, 6.870165304573557}, {6.870165304573557, 
      10.098967612481387`}}], 
     LineBox[{{6.870165304573557, 10.098967612481387`}, {10.098967612481387`, 
      10.098967612481387`}}], 
     LineBox[{{10.098967612481387`, 10.098967612481387`}, {
      10.098967612481387`, 13.540679917274959`}}], 
     LineBox[{{10.098967612481387`, 13.540679917274959`}, {
      13.540679917274959`, 13.540679917274959`}}], 
     LineBox[{{13.540679917274959`, 13.540679917274959`}, {
      13.540679917274959`, 14.729122331753883`}}], 
     LineBox[{{13.540679917274959`, 14.729122331753883`}, {
      14.729122331753883`, 14.729122331753883`}}], 
     LineBox[{{14.729122331753883`, 14.729122331753883`}, {
      14.729122331753883`, 12.86199482069894}}], 
     LineBox[{{14.729122331753883`, 12.86199482069894}, {12.86199482069894, 
      12.86199482069894}}], 
     LineBox[{{12.86199482069894, 12.86199482069894}, {12.86199482069894, 
      15.038124961190817`}}], 
     LineBox[{{12.86199482069894, 15.038124961190817`}, {15.038124961190817`, 
      15.038124961190817`}}], 
     LineBox[{{15.038124961190817`, 15.038124961190817`}, {
      15.038124961190817`, 6.870165304650095}}], 
     LineBox[{{15.038124961190817`, 6.870165304650095}, {6.870165304650095, 
      6.870165304650095}}], 
     LineBox[{{6.870165304650095, 6.870165304650095}, {6.870165304650095, 
      10.098967612509687`}}], 
     LineBox[{{6.870165304650095, 10.098967612509687`}, {10.098967612509687`, 
      10.098967612509687`}}], 
     LineBox[{{10.098967612509687`, 10.098967612509687`}, {
      10.098967612509687`, 13.540679917301311`}}], 
     LineBox[{{10.098967612509687`, 13.540679917301311`}, {
      13.540679917301311`, 13.540679917301311`}}], 
     LineBox[{{13.540679917301311`, 13.540679917301311`}, {
      13.540679917301311`, 14.729122331734516`}}], 
     LineBox[{{13.540679917301311`, 14.729122331734516`}, {
      14.729122331734516`, 14.729122331734516`}}], 
     LineBox[{{14.729122331734516`, 14.729122331734516`}, {
      14.729122331734516`, 12.861994820782739`}}], 
     LineBox[{{14.729122331734516`, 12.861994820782739`}, {
      12.861994820782739`, 12.861994820782739`}}], 
     LineBox[{{12.861994820782739`, 12.861994820782739`}, {
      12.861994820782739`, 15.038124961175914`}}], 
     LineBox[{{12.861994820782739`, 15.038124961175914`}, {
      15.038124961175914`, 15.038124961175914`}}], 
     LineBox[{{15.038124961175914`, 15.038124961175914`}, {
      15.038124961175914`, 6.870165304619695}}], 
     LineBox[{{15.038124961175914`, 6.870165304619695}, {6.870165304619695, 
      6.870165304619695}}], 
     LineBox[{{6.870165304619695, 6.870165304619695}, {6.870165304619695, 
      10.098967612498447`}}], 
     LineBox[{{6.870165304619695, 10.098967612498447`}, {10.098967612498447`, 
      10.098967612498447`}}], 
     LineBox[{{10.098967612498447`, 10.098967612498447`}, {
      10.098967612498447`, 13.540679917290845`}}], 
     LineBox[{{10.098967612498447`, 13.540679917290845`}, {
      13.540679917290845`, 13.540679917290845`}}], 
     LineBox[{{13.540679917290845`, 13.540679917290845`}, {
      13.540679917290845`, 14.729122331742207`}}], 
     LineBox[{{13.540679917290845`, 14.729122331742207`}, {
      14.729122331742207`, 14.729122331742207`}}], 
     LineBox[{{14.729122331742207`, 14.729122331742207`}, {
      14.729122331742207`, 12.861994820749459`}}], 
     LineBox[{{14.729122331742207`, 12.861994820749459`}, {
      12.861994820749459`, 12.861994820749459`}}], 
     LineBox[{{12.861994820749459`, 12.861994820749459`}, {
      12.861994820749459`, 15.038124961181833`}}], 
     LineBox[{{12.861994820749459`, 15.038124961181833`}, {
      15.038124961181833`, 15.038124961181833`}}], 
     LineBox[{{15.038124961181833`, 15.038124961181833`}, {
      15.038124961181833`, 6.870165304631768}}], 
     LineBox[{{15.038124961181833`, 6.870165304631768}, {6.870165304631768, 
      6.870165304631768}}], 
     LineBox[{{6.870165304631768, 6.870165304631768}, {6.870165304631768, 
      10.09896761250291}}], 
     LineBox[{{6.870165304631768, 10.09896761250291}, {10.09896761250291, 
      10.09896761250291}}], 
     LineBox[{{10.09896761250291, 10.09896761250291}, {10.09896761250291, 
      13.540679917295002`}}], 
     LineBox[{{10.09896761250291, 13.540679917295002`}, {13.540679917295002`, 
      13.540679917295002`}}], 
     LineBox[{{13.540679917295002`, 13.540679917295002`}, {
      13.540679917295002`, 14.729122331739152`}}], 
     LineBox[{{13.540679917295002`, 14.729122331739152`}, {
      14.729122331739152`, 14.729122331739152`}}], 
     LineBox[{{14.729122331739152`, 14.729122331739152`}, {
      14.729122331739152`, 12.861994820762678`}}], 
     LineBox[{{14.729122331739152`, 12.861994820762678`}, {
      12.861994820762678`, 12.861994820762678`}}], 
     LineBox[{{12.861994820762678`, 12.861994820762678`}, {
      12.861994820762678`, 15.038124961179482`}}], 
     LineBox[{{12.861994820762678`, 15.038124961179482`}, {
      15.038124961179482`, 15.038124961179482`}}], 
     LineBox[{{15.038124961179482`, 15.038124961179482`}, {
      15.038124961179482`, 6.870165304626974}}], 
     LineBox[{{15.038124961179482`, 6.870165304626974}, {6.870165304626974, 
      6.870165304626974}}], 
     LineBox[{{6.870165304626974, 6.870165304626974}, {6.870165304626974, 
      10.098967612501138`}}], 
     LineBox[{{6.870165304626974, 10.098967612501138`}, {10.098967612501138`, 
      10.098967612501138`}}], 
     LineBox[{{10.098967612501138`, 10.098967612501138`}, {
      10.098967612501138`, 13.540679917293351`}}], 
     LineBox[{{10.098967612501138`, 13.540679917293351`}, {
      13.540679917293351`, 13.540679917293351`}}], 
     LineBox[{{13.540679917293351`, 13.540679917293351`}, {
      13.540679917293351`, 14.729122331740365`}}], 
     LineBox[{{13.540679917293351`, 14.729122331740365`}, {
      14.729122331740365`, 14.729122331740365`}}], 
     LineBox[{{14.729122331740365`, 14.729122331740365`}, {
      14.729122331740365`, 12.86199482075743}}], 
     LineBox[{{14.729122331740365`, 12.86199482075743}, {12.86199482075743, 
      12.86199482075743}}], 
     LineBox[{{12.86199482075743, 12.86199482075743}, {12.86199482075743, 
      15.038124961180415`}}], 
     LineBox[{{12.86199482075743, 15.038124961180415`}, {15.038124961180415`, 
      15.038124961180415`}}], 
     LineBox[{{15.038124961180415`, 15.038124961180415`}, {
      15.038124961180415`, 6.870165304628877}}], 
     LineBox[{{15.038124961180415`, 6.870165304628877}, {6.870165304628877, 
      6.870165304628877}}], 
     LineBox[{{6.870165304628877, 6.870165304628877}, {6.870165304628877, 
      10.098967612501841`}}], 
     LineBox[{{6.870165304628877, 10.098967612501841`}, {10.098967612501841`, 
      10.098967612501841`}}], 
     LineBox[{{10.098967612501841`, 10.098967612501841`}, {
      10.098967612501841`, 13.540679917294005`}}], 
     LineBox[{{10.098967612501841`, 13.540679917294005`}, {
      13.540679917294005`, 13.540679917294005`}}], 
     LineBox[{{13.540679917294005`, 13.540679917294005`}, {
      13.540679917294005`, 14.729122331739886`}}], 
     LineBox[{{13.540679917294005`, 14.729122331739886`}, {
      14.729122331739886`, 14.729122331739886`}}], 
     LineBox[{{14.729122331739886`, 14.729122331739886`}, {
      14.729122331739886`, 12.861994820759504`}}], 
     LineBox[{{14.729122331739886`, 12.861994820759504`}, {
      12.861994820759504`, 12.861994820759504`}}], 
     LineBox[{{12.861994820759504`, 12.861994820759504`}, {
      12.861994820759504`, 15.038124961180046`}}], 
     LineBox[{{12.861994820759504`, 15.038124961180046`}, {
      15.038124961180046`, 15.038124961180046`}}], 
     LineBox[{{15.038124961180046`, 15.038124961180046`}, {
      15.038124961180046`, 6.870165304628123}}], 
     LineBox[{{15.038124961180046`, 6.870165304628123}, {6.870165304628123, 
      6.870165304628123}}], 
     LineBox[{{6.870165304628123, 6.870165304628123}, {6.870165304628123, 
      10.098967612501562`}}], 
     LineBox[{{6.870165304628123, 10.098967612501562`}, {10.098967612501562`, 
      10.098967612501562`}}], 
     LineBox[{{10.098967612501562`, 10.098967612501562`}, {
      10.098967612501562`, 13.540679917293746`}}], 
     LineBox[{{10.098967612501562`, 13.540679917293746`}, {
      13.540679917293746`, 13.540679917293746`}}], 
     LineBox[{{13.540679917293746`, 13.540679917293746`}, {
      13.540679917293746`, 14.729122331740076`}}], 
     LineBox[{{13.540679917293746`, 14.729122331740076`}, {
      14.729122331740076`, 14.729122331740076`}}], 
     LineBox[{{14.729122331740076`, 14.729122331740076`}, {
      14.729122331740076`, 12.861994820758682`}}], 
     LineBox[{{14.729122331740076`, 12.861994820758682`}, {
      12.861994820758682`, 12.861994820758682`}}], 
     LineBox[{{12.861994820758682`, 12.861994820758682`}, {
      12.861994820758682`, 15.038124961180193`}}], 
     LineBox[{{12.861994820758682`, 15.038124961180193`}, {
      15.038124961180193`, 15.038124961180193`}}]}}, {{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.5], LineBox[CompressedData["
1:eJwl13k8lF8XAHARSVmSrDPWsQwzYwzGzNhOSknyK0VlqZQ9bfZ9S4qyJNmi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      "]]}}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->Automatic,
  PlotRangeClipping->True,
  Prolog->{
    AbsoluteThickness[1], 
    LineBox[{{0, 0}, {15, 15}}]}]], "Output",
 CellChangeTimes->{3.4651779034294033`*^9, 3.465177972130124*^9, 
  3.465178147993499*^9, 3.465181031621789*^9, 3.465181339500792*^9, 
  3.465207951121868*^9, 3.4652088931114902`*^9, 3.4652090252113132`*^9, 
  3.4652098660694523`*^9, 3.465222156296322*^9, 3.465226019850765*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading background figures", "Subsubsection",
 CellChangeTimes->{{3.4651769117798853`*^9, 3.465176919146043*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", 
        RowBox[{
         RowBox[{"countList1", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "200"}]}], "}"}], "]"}], ",", "  ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"GrayLevel", "[", "0.8", "]"}]}], "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\!\(\*SubscriptBox[\(N\), \(spike\)]\)/\!\(\*SubscriptBox[\(N\), \
\(pulse\)]\)\>\""}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", "rateMapDatab"}], "}"}], "]"}], ",", "  ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", " ", "Black"}], 
       "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\!\(\*SubscriptBox[\(N\), \(spike\)]\)/\!\(\*SubscriptBox[\(N\), \
\(pulse\)]\)\>\""}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "4.994145750178575`"}], "}"}], ",", " ", 
      "Automatic"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.8], Thickness[0.007], LineBox[CompressedData["
1:eJxd2HlcjF0bB/A01GRpUTLJFvEQSmOJkjtG2VqsqZi2J4WUhLQoMk+rUEoL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     "]]}, 
   {GrayLevel[0], Thickness[0.005], LineBox[CompressedData["
1:eJxd13lcTPv/B/BqpCnaSCZZirgJpSFRcmKUpQ0pFdN2Keq2CCkJmduKFGmh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     "]]}},
  AspectRatio->0.3,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"T\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*SubscriptBox[\\(t\\), \\(r\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(spike\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(pulse\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{0.5, 4.994145750178575}, Automatic},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.465176936781933*^9, 3.4652079513110323`*^9, 
  3.465208893147744*^9, 3.465209025294159*^9, 3.46520986613601*^9, 
  3.4652221565020723`*^9, 3.465226019876699*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", 
        RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", " ", "2"}], "\[RightDoubleBracket]"}]}], "}"}], 
      "]"}], ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", " ", 
        RowBox[{"GrayLevel", "[", "0.6", "]"}]}], "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\[Lambda]\>\""}], "}"}]}], ",", " ", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"4.994145750178575`", ",", " ", "0"}], "}"}]}], "}"}], 
       "]"}]}]}], "]"}], ",", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", "lceMapDatab"}], "}"}], "]"}], ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", " ", "Black"}], 
       "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\[Lambda]\>\""}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "4.994145750178575`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.7"}], ",", "0.11535638937726764`"}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465155729888483*^9, 3.465155841879208*^9}, {
  3.4651559246611023`*^9, 3.4651559320156717`*^9}, {3.465155969509884*^9, 
  3.46515600631553*^9}, {3.465156048084021*^9, 3.4651560928964987`*^9}, {
  3.465156991371931*^9, 3.4651570351777287`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.6], Thickness[0.005], LineBox[CompressedData["
1:eJwtV3c41e0bx7HnMTIaRslbkaJXKul5UFKRdnapUERCRUplZ1fejIyorGwy
Mm4je89zDo6t7L1HfvTr+edcz/W9rvvc92dd9yN268ElIzoaGpppWhqazd/g
oM2TjQozSna1qmaj10o3B+p35iDH5WVHNlYPeDokIcMcn4tUljNEx3ojwfTN
2DMkl4/qk9bMglgjQPtoevnjfEDWCtOuNwdT4LOlIivpUwGqjXYa53CNhZAf
oslWdwsR/8UBGb31t+AvSH+Nc38RevX2+z36qmDwuv9rJXaqCN3mGu14qRMO
TgWVEacyipEfkyfLkk8QPONLPN3z9Acyei/k5SyfANZ3NxsoQWb1J5s5LmSC
Wa7NO0H6UmS6dNFc7lwR3CZqbXRUiqaTeYdv+xeCzh2FLk3vMnRvl+6L945l
cDlL2GXkYjnKKXhwxl2zDM6y00m68Vcg9W9V1v/oVoHy5vjtFeh4gVaBen01
HNscL7wSDQWGxvb21YIsc/x2nTtViCIZObxDpAH26fkWze2pRjI5IujEqQYQ
25j2zVg1Ek7yupfj0ARCm+Om1qBljr0Xt0o1Afdme49r0eTg1tvv0puBZbOc
Qh2yu3yIX0SmBWj+nHoU5M8R/ay5BdZipxo1btWjbfA7UegoCRYv93358KMe
/ZTONmwUI8HsWrPtkEQD0vkmlxv+gwyT0aXn5F83IJHGMpFBDzKMXtwcuAFp
KWSFF7ymwCbajRqNaJ+Su+ppwTbo36gmmtyICHy1mlirDbo1vQMseJoQnxG3
nPaHduhYcjDNtWlCSxnf3qxcagfyp02Cm9Cns3MJFTod0KRxawPxZjTuxcPq
rtsBdQubDTaj4sYj1zxqO6Bqg82ZtWaERnfaeCtToWyjO6WbLciz8vDjyJNU
2ABvA8EWRA55FGop3gkQvvUAVbwVObiy+l7f1wk5ZzYJakUmdtHyate7IHNm
c+BWlHG/Ytvrc12QFjqxMTEJNbQEEQ7s6IZNtfAlklCCoFidsFg3xG3CRySj
gjzN2e2m3RC1Oa4VGb2sITVku3bDpz/tkVGwD1lXL6obwjfLyVOQcbRm6evW
bvi/Pyjo1vpVh0+kbniv4rmhWAq64X1OU5u3B95u2sGgDUkZlPeZM/WAzwZ6
TgVtKPO0f5XKhR74v5/a0fmzPXWfNXpgQ3wbhLSjwwRJO/OIHnj132bBdnRb
rMmSOaYHHDaqfT/TgQi/ZMoGJnv++q8D6Zoq8iT+7oFH7zYNREVTh1ax7Z5e
eLhpN0sqWqaTyok52wvmfwimom66otArp3vh3h+/dqKYgcd01s974Y8dAjpR
/MdfjHV3esFws7ulTiRb9UTpjWsv6G/KWa8LiTMdS4lO7v3r7y403epu8ORb
7188u9FdyWvNajO9ELMpN6VutO/E7gdK4n1/8e1GHUrLUr929P3Ng270naFz
NprYB5F/8O5GZkV6E5M8ffBxk27GHhSZvmW581QfhP3BvwdJlXtd0nPr+5sf
PSiFxYvlYFLfXz560Mkdba58BX0QuAl3ZQ/qMq9tLmjo+8tPD/pC4Q9kGun7
mze9yMDf75hRdd9fvnrRxK+dvxKc+sDvjwB7kdXnXlpXgX7w/sNfL+KsI32/
adb/N596Ue1Qom+CU/9fPvvQyYdrVrdfd4MbP6V2Q/KIrDBjQN3Qt+sffvuQ
eDwneAa2/c2zPrS47cZ8sS0ZHP/w3YcKRyXeDye1wgvTzQDrR6sm/i5jYi3w
/A///WgyutbhfmET2P/Jv37kkR6n4ezcCHZ/9NCPdoWYBXvfaYAn+ZuG6UcH
Bk8JZujV/9XHADpOo1mc3lj7Ny8HUIbh4/WzXDV/9TKAuHVVr8SZVsGDTfgi
BpDj4Qd9u3sq/upnACne1DdKe1D+N19/Ipf8Fb8S3jL4U07uJzqRxxkuW1UC
Jsab5yd6e+GIl4j/D2DxK2PKyvmJxgUEO3lDiyAue08sC/cvVJNTm8FcVwDq
fa/P6hr/Qlm7Zcuq1fJhjH1kJD7nF1q2lK5RlckB38Pq3r+Jg0jRIy+d80IW
HLyZIH3BeBApl4UFrIV9g8bXnPUROYNom8Wr7QuCaWCT9uDhDHEIpc6s/MrN
ToYt1HqeU8ZDKMva/l3USjxkMsqmv88ZQs59NJenfsSA1sF3VweJw6jAUObk
k6rPsKw9O3/UeBg9OzQ0EMARASFOVwM9c4aRJ59SwJVtH0AxIeMolTiCMoTY
XCri/aGrVaBd2ngEvZB27eQS8oGXNHbPXuaMoFF83z0/1QV27mvb0UgcRT8/
Mr1sV3eC4ssKsMt4FClEJ4Z4dPuA8fOQm49yRpE0a93H+qYIYI5eoy0jjiEd
68gs8ZI0iK03+CRoPIY8ffeaEoZK4NwynDTNGUMOV94nsZyjwOgusZ85xPGN
vLxZcU/vO/hoOLpxGI8jhyDrkrjRBDjwpG/PjZxxJBWWIrxmmoAaPp6sTCZO
INWPzQJ7Y78h68ovZnTGE6jCN5gVHUhCfLOMHFdyJtDlqskXS56pqJ3zX9Il
5kn0YVbChGHAD75+6o9ekZ1ElSEGEZaeb+D5kf9sP+tPoolIh/HXnsnofM2p
Mxruk8hrKiv3u1EKEr41LzSfOons6a+YaZGj0cR81HAYdRK12C1x0W9PQQWe
13NOM08htpLyRSuDdPRGlNlrUnYKBWdd8I0OzUaG37L0gvSnkIKqo3NuRwaS
PXtvv7L7FLpiOCYhEWWECF1Cv4dTp1DzCBv5ny2fULN1Ze076hTysjLxWzkX
j74w24cfZ55Gnw/SByyEBKHHoZKWA7LT6H5IzODVfTagKtuBffSnEVkyJsl3
C4BAmRe3vPs0sqGc8A0vL4FBXcXertRpVHLkcah8QCVkT46lulOn0d7arEd+
NHXg4RLmJMM8g4ZbnTNCphtAZ6vmlTbZGSRbGSde/aoFJJPWxZ30ZxBZd3fd
zooeWFVJnpN0n0Ej9wWZdum0Qg35Zmlz6gwyujc1989II4SZcwc8p86gpZkr
nuU0DWBBV2QiwTyLzDMYGjK06wAFWB2pk51FusVb61jO1wBRaheLrf4sepjb
/LUovAp6Cpooou6zSCxz4JiodCWkXHWOq0idRTQnbzuRBsrBcfhfeyvqLCo3
7pN/+X1j/3kxcG4b8xyKKTTu8/tUCuJ877f/kJ1D1y3mdJuDS2AuRnXsvv4c
sroRruTz4QeUKC7kbXGfQ+F2/mmLEcXwvjHaJz91Dr1/tdo3GVcEJiZaN0yo
c+il6CJnQVohHFllPkhknkfKtwT3z2YXAMubbJps2Xm0rWXcz/UxAGW3aYOh
/jzaHZBkMWKaB3Hft0ayus8jLRGjt/HqOWCvWWWVljqP1hqTuS4KZIN6v72K
HnUexXfWll4szYAddlJ8DMwLiBIsHKJyNR3GOKj9CbILSBbHNJkUpEB+pPe3
a/oLqI7S6TfDngi+8idc190W0LdOX5erhjFws3r8WkzqAvKPdhMSMn4PBw3D
/7lIXUBUnaWgMT9voJ3XXFxiWkSHC5l0npV8Ro0eNBWRsovouNtFK68dceiz
SErQOf1F1CXHtZSgG4oepRuazrotoii9aOaBSE906gyPQmjqIqrPx4kPcjwR
f2cRmyp1EV1sv1i93SUa/bKy7hhnWkLU0Ja9BexJKItJPCFAdgnVXzhTVHLR
Hb0OaX6O9ZdQUB7tCe0xU6Qt43J+yG0J2Yv6WCyUBaJ9pXIib1OX0OW9Rdld
48FoRefnxDHqEtIxfReeSB8F1RPvC/qYlhHbMafTtjppEOp8+o2X7DLS0hNh
sYnNAnOhRUM5/WW0vouDnbM6F04kxsh2ui2jr/wmV5Z2FgCXijbBLXUZMS+7
pizFFEI3iaX5AHUZOXGtS0gxF0Py/e+fyUwrSKVyaMD37A94RWv26JXsCmpI
tKxof1wCl95vU92nv4I+JHm/Jb8phV2S1fxNbivoYvb5nwLhZTALz37Zp66g
Em9mA72IcvhxZX+WOHUF7dulIt0WXAH/DVHda5hWkUjcd+6b3pVg7OCj/Vh2
Fa3mKm21floF8rxon4j+KiJqWDUY3q4G5piJ5TK3VeS3zK1z6UwNkI9/rLJM
XUWq7cZ0GvtrIbbhQogQdRXpfZZ3PUmsg6fGtOZFTGuojpT/ZvtMHZxbSVE0
k11DJZJaK9fN6mG73y1OPv01lHyBL3uYWg+j4rxduW5riLp9t1/qxQbIyy5O
MkpdQ0aSulHCZQ3gc97mJSd1DV0YuXzw84lGuNEnfjGT6TfSK6d+LsxqhAO2
LWI3ZX8jS7FLz+gONwENh+s0s/5vlHlbNJA+swkaIg4Xp7j9RrH/lPzrcLwZ
Ig//eqeT+hsZhw1Gq5Y1g3VVwB0C9Tc6E6ibfUurBVRuqsnFM60jmHX4smWq
BfjmFhmuyq4jDmJ6z/LbVhh4Hdu6preOqq87We7HJMgQ1omOcltHzXoHO91W
SOCWxmqrmbqOImIWlrkqyHBdLUdtsWMd6dDu5spJpID/+DevegINPrJjOn3y
WxusHeGcExeiwe9oy9Z7x9vByMlY306aBsvNS82r2lGhpia/pEaFBo8fvee5
HNEFhwUFpHdq0+C2t3LZh8p7IOzWg/ePLWjw50+XZH1L+oApoex3pRMNVu5c
uima2A0PFkRMRIJoMLnnvvqKcBeQlGzrrBNp8PZA0/dq1VTAXvXy5cU0uPDq
u2Tlnx0Q07rn43YKDXZ+uIURUAdwi71ifjhOgx27tFMuFLeDnRnFsoRAi5tm
j1WLGLVDzzcZipAQLbbX5JWf29EOZ2k8lCykabHGwQPmIkNtkHq2N7ZIhRYz
/Nemc7+4Dbb9d4xHQJsWK9n67AmL29jfut4+NbOgxQtqR+m2h7bB6N6RXnCi
xbsYWHKKgtrgio3KOb4gWnw7MnGiLLwNcvM/pN1NpMXcHZ7mMYltIM4yuy2v
mBYr16j9K1zaBt6X1Z25KbTYyOqFwPafbTAX+nnUaJwW64i5+NZytoPB4OqV
7wQ63GD31iwCt0Op7NU8TiE6XJNN2a/+rB0OPE/YfVuaDnMyMJr+KmqHwDIG
n0wVOrxnuNiZyN8BNDwG82zadPiMd/UeCdsOuKeXYXDTgg6zvjcdSRntgPoo
zrJ0JzqsrnPMef8Gf0enjA+wBNFhhrFz5LcSnRChAAH6iRv1jSwZp+i7gNVV
gCa1mA5nmKXERG7tBqv6B3cZKXRYONeli3/jvdO+tbxeZ5wOWwS/ibEW7AMV
I9GjSQQCvtMkOpFX3wvxSbYRBCEC/qnMt/ytuRv4lutZtKQJOIxre97Hwi54
dnKvVbwKAY+mn5Q88awT+n1etdFoE/DtvEX1+25U0KBQlK9aEPAspcaXpbgD
vu2S/RrrRMCnhFYOcot0gLCFB+/vQAKmplfzXXvbDq5ZvfaXEgm4sfhRPa9A
O0zQKfRHFRPwk+WFNNPYNriu8U59hUzApq7OUmGqbVAQMJKuOU7AEk1nOL+O
UmBPr8qOzwR6rLXv2UHWYAr4SYW4LArSY8+JNEcPDQosPp4dU5emxzVMHXpH
GClgWKh+LUKFHtPvQgkaxWSoYPuSP6dFj8OOJChJOJNB9tqaxFkLety1kLH1
iBoZgj9e9Q1zoseB2yw8ObjIQBhJWJgOpMf+/Qz0SmQSmMkx3jydSI816aIa
7D6RoPmFQfmHYnpsb18Vd8+SBAqVGQcnyfTYmmk2tvIECT7zcQWdHKfHKZrU
QX1OErDfMKENIjDgsJJ3isOdrfAoFu6NCTLgl+oWv48ltwJ1RqBRSZoBp86w
/Sfi2AqqJyyPvVdhwMZL1tdNr7RCont55LAWA9a5RFKblGgFgSZRNmTBgK+w
Woi4L7XAix121u+cGHD+S5aTrNUtMGjS0P4rkAEf0fGf1AxrAc3UvSePJzJg
zpO8C7KWLZC1+irer5gBe9oZK3grtYDo6Ta+ATIDfnLWXekITwu8fiP7/Og4
Ax52X89k722GqXaPAW8CI+6keznek9wMOhJ9Gr2CjHimKkXb26EZiiwVMg5L
M+Jz3Hfmes42g2TOO2FPFUY8/6VaP2lLM/gzjLp2aTHiwjuEQ4WdTbCieXLi
kAUjTi5iZur80gS3g0OuuzsxYt+wSpZS0yao7p+FjkBGzL9L/IfM/iaQO6Cx
RyaREbuoi8/XjTZCqN0XP5diRmw3TzVViW0Exh9rixQyIy7ewvxT5FYjWHBe
M5QeZ8Snhx4tDfA3AkkrscKRwIT7bhVVrpU2APrEKEsSZMLS+YTspIcNED1m
ECwpzYRjTeTXhPgbgOtIJt1LFSb8IUZBZGdaPdg6cpk1azHhaKF40Run66G7
2qRpjwUTZurkb52MqIMzAgUKz52Y8NV6vNoTXAsphoKfGwKZsE64YW6oVQ1s
jbdkl0hkwuWRNj4rwtXgOF9u87SYCS8oSh3CfpUwgsWotWQmrHq30nxLfDlc
9rQ7tWucCa802KTaKpVCTktDwhMCMzaLMzASHimCXaL7+KsFmfFNz0j3n64l
4GXq6CAqvXHv/CWpuK8EZtPbftqoMOMlixjLZL5S0F+X1azQYsYmYno6Zsyl
UHLGM3OHBTMmmRhc0vtQAtL+fSJWTsz4kp8EQ0PPD3jfqeBeGsiMB84SE2wa
i2F9j//k1kRm7JLzIkpTrQiMrUe1HhQz4/qpk7ypmQB1eScLi8nMmBXjO74d
30CeOXSv4DgzxuoxrvrCAB8vzb25T2DBYKn6lVchD5hDNZYLBFnwA7W5r8nD
mfDw15dbW6RZ8D/fY/m6pjKBIvO78p4KCx6SuaZBy5cGys+uHcrXYsF72+/f
Vk1JgbjSxA88Fiw4/cfZUA2dCODlZqI3cWLBt6sv3clkjIWnujfu5wSy4H+v
aWotSrpA35fMZq5EFpy8s/tUMlcMnJvkUrxTzIIH9J4ntL9KhvRjd79kkVmw
J2NMFhc5Dba7FHBwjLPg/rRHTIUBGeBSJ/jYkMCK9xgcjFZazIIxoYed3wRZ
8TbXULPfW3Lg2p0KVVZpVkznv+ULmTYPIFEsyUCFFfPxpCrUlOaDxJKdQJoW
K3b6J+74icMF4KPS+ILJghX3540/OrpaAAve+wZ1nVjxyV9EX8vMQrhJdryQ
HLhRvyH/vPO9Iijf2Z5Fn8iKKRxHwwt4i0HG/JCYdjErHn1icvpQZjEEZXq+
TiCz4tXXzjdyrvwAOrr+KdpxVlx3+l8OvrEfYKp+XOcagQ2PFce+63hZAk3v
/YviBNkwYbWzI5RYCsd6Rvet72fDX/dUSdaFlMInyVPvLquw4Z7yvr2U3WXA
9jh0JVqLDe9fm0oUjC8Dm4K526vmbFipQiin+0A5dLCer77gxIaPi/9atU8p
h1NXo/79EsiGcy9ba0vLVEBC+O+QpQQ23OsoynM4qQL4h68xnC9mw78cH52u
lqwEh3+TzCPJG/UH43dJRFfCTwem1vkxNvwbjCUfiVXB+YobJ84R2DFTnfLh
weAqyOTNigoXZMfZupmeX3mrQcSAyDW7nx2P8gspD3lWg3vM3SdqKuz4eY/b
UAWhBianC7pCtNhx8NfvrTb2NaCtKKQ2Zc6O2dAxaeJMDRS6PUw+5cSO9UL6
fAtNa2FfY4VgcCA7PnX5Hl1iby283b7z1XgCO86t0jRa1qmDZeOnQ8rF7Njm
LYxWNdXBrZTGiwFkdky89Grmk0Q9VK3s+z4yxr6RR7nHK2/XwyFVp52YwIG7
abW07kfUQ4hfu4e/IAdeDD9iHtZVD/Tth2YG93NgSquX7SPhBjDf7aWrqMKB
n1MqHzMZNEDLg/7iN1oceILWNsAsrAFOfD8u9dOcA9sGBj793tUAX+j/8z/m
xIHTbn1x5tzZCJyaY6s+gRz4QsXkDmejRngcdMqoL4EDdwR5chyLa4SuvtAa
+WIOPOIUynlpshFOS8/LeZE58Mz4UaEp+SZItj0f1j3GgW90OV7Gr5pAsDiK
UY7AiadSg83Nq5vgFce6xWtBTszIw7z8VagZhq5fJ1H3c+KlyudnD99rhkuR
SUhWhRNPqNEQNHOaIXuUKcZVixOfKRLvVSa2wE75m8R2c05soeG31+xuC3i8
yrI94MSJ2YhiXgd/tMBMFbHHKZAT79ex1+ESb4XjBzvpDqdwYqkwgbmZwFZw
8f8qPljBia9cWLJFW0hQs2irGtzLiYvyFjQNg0nAr696V32FE1P3NHAr7CPD
jUJej9+8XFjorLLctTIyRO/u+ZosxYXPq63kHX9EganXiTW3TnHh5+0mKVuO
tsHRcfsJPgMuvORzPL12azs4XjrDXfaYC9NI4ede/3RAVQb/ITtfLny49byf
zxMq8G7rvyIZw4VFbQz6ylEX6L1IeUwt4MLPrkqxOnP1wJc+h0BfChe+/LO/
dql7AMZOq39XmubCilB0oCi5B7a1so/bMRDxyusk8Zec3YDcZ343chOxT+a8
1vTlTrhzrI1LSpiIHbR5lm13UMF9tEDUZR8Re4kz3A6X64D4sGiZzsNEfO/J
zCP6F+3QcMFHWV6FiHs8cMCJ4Y19lu7RZT9NIva3y7pwyKINhL7p3hnSJWL+
0/6HORna4ISJ8iPlu0RMXYmyp8RR4JbQXtcPNkR87HB1yg89CrhWcQXMvtz4
fjTySZ4gBb4+n4/W8CbiNxWXJ2WoZKg7QM2KCiJiG1PxXcMxZJjtKa5Y/0LE
Lx1p70w8JYOgf1ybVioRn71ZNfj0EhmOq74ZScknYotMjzPD0mQwXHyyylpF
xPr32BUzN/YvlzgDjjskIr7PzokezpIgVu+UcF4fEZfvu6Of3UGCWk6pA/yT
RPy4lfDhRDkJpgt48INVIpazNlTPydjg33rpQjkzN16dIlydid7Yz3Z3G4pt
4cbP5HadTf1AghukUqunYtxYp+ixeuUbEji9TnBq2s+N79NdnOPxIEGMgr+/
1DFuzGzF9/6uMwmqx55+cVHlxojH6O3XlySYCjfM6LzEjYW/PYwHBxJsuaRW
Jn+DG98LTEnx3LgfpT9A9jPjxuM2iTxLL0hgkLFlaOgJN8YLXwNnHEngeHd1
SdmZG//eYUZzz40EUVv7WEP8uPGWrKcTat4kqKyu2DYXwo31gm7bOPuTYMIh
Wep8LDeOq1Y24gwlAa9MgGL0N27M4LYjsC2KBPJ9z8/TFHHjfLT8b2cKCfT/
u3NDu5YbS6bPuHDlk+DV6XOWqW3cuPrFgwyjKhJ8WZJ5xfaLG5fnKS2SKRv/
91Xw7Z0Zbhxz84HarSESjOuvR+atc2PFxVCzlSUS8BB/pvGz82CDvobxMDYy
yBdV/3ggyIMVyht3qQmTQdcmraVcnAeL6tJPTcuQ4YVE8E8xGR6MPELmP6iS
4RP55cJTxY17J9UC65Gh3MOEufkMDzZMSlPstCLD6PHzQvuv8WDptEaKtQcZ
iBP/7nO9xYPd/wvRp/lEBrmIbQpdFjzYWTPDwSmXDNqX6dSP2PNg/z2p/mut
ZHjOMKT3xo0H75XzePtgmgyRmXXmw+94cOFE7s52TgqU3stwUPnIg9svNPsp
S1FgeFuob0g8D769ktEdc5YCXLVOH+eyePCp/crt3KYUOPTSNOV8CQ9e/8Eh
4OhBgeuyF4uiG3iwxH1v4vpXCjzrl2+i6eTBJqIqYr61FPj4Xrhfe5gHGwv4
Rx2dpsAPNYa51HkezP227ASTQBsMLY8wsBN4sQlXljutYhtwJDTyG3HxYq5b
+jmH7rSBzI3sf/K38eL0KNO7cV5tcJX74xGBPbzY7MORSeuMNrAvdj1j+S8v
ZmCdDfjY0wbhj8x1KjAvdn9nMKa88T4t/ueK2U4NXqybNDjz4Hg7DFKOPbPX
5sVzfFXJ6H47sHuJeTcb8eLLH4c9akLb4eAJ5rD9VrxYZ/TC8JGGdrg6OZ7o
6sCL7a9VL3xh7AC7yBbo8uDFRx9qPTpxogNCr+TWHwngxXEfLVdkN96vRYyf
et584sWSpwaVctM74GfW6+nhJF7MFCkgvGO2A1jNLAknc3mxXFsl+fNhKhzY
cZ0vtJwXN73Tdkh9RoXLdYq755t58ZI5B3d2KRWevBI/rNnDi9McT1w5taUT
Qg6xnY4Z48U9KhMKjPc6oWBg6jrtMi/uGI14Qy7qhP8Bz93mcg==
     "]]}, 
   {GrayLevel[0], Thickness[0.005], LineBox[CompressedData["
1:eJwtV3lYzF8Xr6Zl2pspCaEUP0IbKYV7FdlKhDZKklBaSBSyFO2LSEIiraJV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     "]]}},
  AspectRatio->0.3,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"T\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*SubscriptBox[\\(t\\), \\(r\\)]\\)\"", TraditionalForm], 
    FormBox["\"\[Lambda]\"", TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{0.5, 4.994145750178575}, {-0.7, 0.11535638937726764`}},
  PlotRangeClipping->True,
  Prolog->LineBox[{{0, 0}, {4.994145750178575, 0}}]]], "Output",
 CellChangeTimes->{
  3.465155981560594*^9, 3.465156093667206*^9, {3.465156992051538*^9, 
   3.465157035815701*^9}, 3.465177248562879*^9, 3.4652079513411703`*^9, 
   3.465208893180688*^9, 3.4652090253306828`*^9, 3.465209866269717*^9, 
   3.465222156535857*^9, 3.465226019910089*^9}]
}, Open  ]]
}, Open  ]],

Cell["Creating cobweb plots", "Subsubsection",
 CellChangeTimes->{{3.465177305426066*^9, 3.465177323601501*^9}, {
  3.465177560759997*^9, 3.465177567878709*^9}}],

Cell[CellGroupData[{

Cell["Define cobWebT", "Subsubsection",
 CellChangeTimes->{{3.4644025259245453`*^9, 3.464402529698769*^9}, {
   3.465178827910511*^9, 3.4651788318381157`*^9}, 3.4652047103278627`*^9}],

Cell[BoxData[
 RowBox[{"Clear", "[", "cobWebT", "]"}]], "Input",
 CellChangeTimes->{{3.465180830242443*^9, 3.465180833697386*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobWebT", "[", 
   RowBox[{"T_", ",", 
    RowBox[{"{", 
     RowBox[{"\[ScriptCapitalN]_", ",", " ", "\[ScriptCapitalN]pre_"}], 
     "}"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[Tau]00", "=", "18"}], ",", " ", "\[Tau]0", ",", " ", 
      "\[Tau]List", ",", " ", 
      RowBox[{"plotMax", "=", "28"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{"\[Tau]0", "=", 
      RowBox[{"Nest", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"FNMap", "[", "#", "]"}], "+", "T"}], ")"}], "&"}], ",", 
        " ", "\[Tau]00", ",", " ", "\[ScriptCapitalN]pre"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"\[Tau]List", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"FNMap", "[", "#", "]"}], "+", "T"}], ")"}], "&"}], ",", 
        " ", "\[Tau]0", ",", " ", "\[ScriptCapitalN]"}], "]"}]}], ";", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"cobweb", "[", "\[Tau]List", "]"}], ",", " ", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"FNMap", "[", "t", "]"}], "+", "T"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"t", ",", " ", "dom1", ",", " ", "dom2"}], "}"}], ",", " ", 
         
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"Directive", "[", 
           RowBox[{
            RowBox[{"AbsoluteThickness", "[", "1.5", "]"}], ",", " ", 
            RowBox[{"GrayLevel", "[", "0", "]"}]}], "]"}]}]}], "]"}], ",", 
       " ", 
       RowBox[{"Prolog", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", " ", 
          RowBox[{"Line", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"plotMax", ",", " ", "plotMax"}], "}"}]}], "}"}], 
           "]"}]}], "}"}]}], ",", " ", 
       RowBox[{"AspectRatio", "\[Rule]", "Automatic"}], ",", " ", 
       RowBox[{"PlotRange", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"5", ",", " ", "plotMax"}], "}"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"5", ",", " ", "plotMax"}], "}"}]}], "}"}]}], ",", " ", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(n\)]\)\>\"", ",", " ", 
          "\"\<\!\(\*SubscriptBox[\(\[Tau]\), \(n + 1\)]\)\>\""}], "}"}]}], 
       ",", 
       RowBox[{"ImageSize", "\[Rule]", 
        RowBox[{"72", "*", "4.5"}]}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.464395800761174*^9, 3.4643958380417767`*^9}, {
   3.464395873202549*^9, 3.464395968824357*^9}, {3.464396100741774*^9, 
   3.464396164857424*^9}, {3.464396206169854*^9, 3.464396333523837*^9}, {
   3.4643963671733627`*^9, 3.46439640923951*^9}, {3.464396815424827*^9, 
   3.464396818561715*^9}, {3.464396919185316*^9, 3.4643969217955923`*^9}, {
   3.464402909727249*^9, 3.4644029268088427`*^9}, {3.465177721139872*^9, 
   3.465177743724482*^9}, {3.465178382905787*^9, 3.465178393374813*^9}, {
   3.4651785975619087`*^9, 3.465178606767415*^9}, {3.465178666916129*^9, 
   3.465178705163559*^9}, {3.465178807549581*^9, 3.465178810517824*^9}, {
   3.4651791019313927`*^9, 3.465179115230521*^9}, {3.4651793493865213`*^9, 
   3.46517941461515*^9}, {3.4651796265354843`*^9, 3.465179626747326*^9}, {
   3.465180824577874*^9, 3.465180904118882*^9}, 3.465180974415842*^9, 
   3.465181109197349*^9, {3.465181378682886*^9, 3.465181381523086*^9}, {
   3.4651814480737123`*^9, 3.4651814494467793`*^9}, {3.465204015793108*^9, 
   3.465204063447888*^9}, {3.465209963667142*^9, 3.465209963957556*^9}, {
   3.465233770331519*^9, 3.4652337752532177`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Testing cobWebT", "Subsubsection",
 CellChangeTimes->{{3.465178922885374*^9, 3.465178927821353*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"2.2", "tr"}]], "Input",
 CellChangeTimes->{{3.4651792310088167`*^9, 3.465179233845325*^9}}],

Cell[BoxData["8.053402868427435`"], "Output",
 CellChangeTimes->{3.465179234473619*^9, 3.465207951454076*^9, 
  3.465208893248721*^9, 3.465209025384901*^9, 3.4652098665798283`*^9, 
  3.4652221565984573`*^9, 3.465226019975862*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"2.2", "/", "tr"}]], "Input",
 CellChangeTimes->{{3.465179240366786*^9, 3.4651792433840733`*^9}}],

Cell[BoxData["0.6009881883563455`"], "Output",
 CellChangeTimes->{3.465179243848229*^9, 3.465207951489193*^9, 
  3.465208893301425*^9, 3.465209025426824*^9, 3.465209866633564*^9, 
  3.465222156630769*^9, 3.465226020033175*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cobWebT", "[", 
  RowBox[{
   RowBox[{"0.6", "tr"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", " ", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4651790707082767`*^9, 3.465179089053629*^9}, {
  3.4651792992475357`*^9, 3.465179302412409*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.67, 0.6, 0.6], PointSize[0.01], PointBox[CompressedData["
1:eJztxU9I03Ech/Ex9LRZQSD5QyMlIbb5h0wsHCNFRWIuU8Ghjra5xVI2QcbI
dYhQqkOUoowpU1SIgtAElTmdlRBMRLGyOeZ0UKE4XRazhaVihufP+3vt4AMP
r2RtQ5mez+Pxpg//51EXr3ZwrsRT186Qnn1/+uX803Ok5fau3mDwPOlzQ+Fj
cegCaax3yG6rEJOaJbYTa/dEpAqvcaE/Tkz6RS6ZLXWKSG2p5jb3d1q3yOHL
maVVLVu2JF9p3wbqOts+0RYV1YejK7QfhAXxv3y0BYMbyvkAreCB4EDppzUW
DuyFl2iH7vRWb/hpez4fCFqXaANjzyKpwOF3D9dvA7MyHVoZMM36M78K2JTX
bCgGOoQeXzkwRrffIgeapO7sG8BoysglBdAskyWXAvu4mVUF0PJi4dV1YN+i
MR3Z4ym5jxQ7r8iRH/WXTci7/Y1KpLVBdwtZw1lUyOL69Fqkob3lJrIkd0WD
rHxUo0ZKN8s0yJ2kUTWSn8FpkLlmvxopDfE1yD/V62qkVvUbmta0Bf3WGIXm
7P6Aunzb0A5+BCrM2IY6TBFoIIQNd2Gtc9iEAeziFPbJCPbkJLbbieUmsMEx
rHwcq3VhdxjaGXoZDjL0MHQynGI4wfANQzfD1wwnjz32P/QvxJga1w==
      "]]}, 
    {GrayLevel[0.3], AbsoluteThickness[1], 
     LineBox[{{18, 6.072327088163224}, {6.072327088163224, 
       6.072327088163224}}], 
     LineBox[{{6.072327088163224, 6.072327088163224}, {6.072327088163224, 
      8.280881258171629}}], 
     LineBox[{{6.072327088163224, 8.280881258171629}, {8.280881258171629, 
      8.280881258171629}}], 
     LineBox[{{8.280881258171629, 8.280881258171629}, {8.280881258171629, 
      10.435292261954748`}}], 
     LineBox[{{8.280881258171629, 10.435292261954748`}, {10.435292261954748`, 
      10.435292261954748`}}], 
     LineBox[{{10.435292261954748`, 10.435292261954748`}, {
      10.435292261954748`, 12.455410369370226`}}], 
     LineBox[{{10.435292261954748`, 12.455410369370226`}, {
      12.455410369370226`, 12.455410369370226`}}], 
     LineBox[{{12.455410369370226`, 12.455410369370226`}, {
      12.455410369370226`, 13.665211459718657`}}], 
     LineBox[{{12.455410369370226`, 13.665211459718657`}, {
      13.665211459718657`, 13.665211459718657`}}], 
     LineBox[{{13.665211459718657`, 13.665211459718657`}, {
      13.665211459718657`, 13.249802070457214`}}], 
     LineBox[{{13.665211459718657`, 13.249802070457214`}, {
      13.249802070457214`, 13.249802070457214`}}], 
     LineBox[{{13.249802070457214`, 13.249802070457214`}, {
      13.249802070457214`, 13.526632887990356`}}], 
     LineBox[{{13.249802070457214`, 13.526632887990356`}, {
      13.526632887990356`, 13.526632887990356`}}], 
     LineBox[{{13.526632887990356`, 13.526632887990356`}, {
      13.526632887990356`, 13.358038311393504`}}], 
     LineBox[{{13.526632887990356`, 13.358038311393504`}, {
      13.358038311393504`, 13.358038311393504`}}], 
     LineBox[{{13.358038311393504`, 13.358038311393504`}, {
      13.358038311393504`, 13.46823553602989}}], 
     LineBox[{{13.358038311393504`, 13.46823553602989}, {13.46823553602989, 
      13.46823553602989}}], 
     LineBox[{{13.46823553602989, 13.46823553602989}, {13.46823553602989, 
      13.398863542378756`}}], 
     LineBox[{{13.46823553602989, 13.398863542378756`}, {13.398863542378756`, 
      13.398863542378756`}}], 
     LineBox[{{13.398863542378756`, 13.398863542378756`}, {
      13.398863542378756`, 13.44370217514932}}], 
     LineBox[{{13.398863542378756`, 13.44370217514932}, {13.44370217514932, 
      13.44370217514932}}], 
     LineBox[{{13.44370217514932, 13.44370217514932}, {13.44370217514932, 
      13.415173334402311`}}], 
     LineBox[{{13.44370217514932, 13.415173334402311`}, {13.415173334402311`, 
      13.415173334402311`}}], 
     LineBox[{{13.415173334402311`, 13.415173334402311`}, {
      13.415173334402311`, 13.433516872496636`}}], 
     LineBox[{{13.415173334402311`, 13.433516872496636`}, {
      13.433516872496636`, 13.433516872496636`}}], 
     LineBox[{{13.433516872496636`, 13.433516872496636`}, {
      13.433516872496636`, 13.42179936962785}}], 
     LineBox[{{13.433516872496636`, 13.42179936962785}, {13.42179936962785, 
      13.42179936962785}}], 
     LineBox[{{13.42179936962785, 13.42179936962785}, {13.42179936962785, 
      13.429316309592771`}}], 
     LineBox[{{13.42179936962785, 13.429316309592771`}, {13.429316309592771`, 
      13.429316309592771`}}], 
     LineBox[{{13.429316309592771`, 13.429316309592771`}, {
      13.429316309592771`, 13.424507112652483`}}], 
     LineBox[{{13.429316309592771`, 13.424507112652483`}, {
      13.424507112652483`, 13.424507112652483`}}], 
     LineBox[{{13.424507112652483`, 13.424507112652483`}, {
      13.424507112652483`, 13.427589317466039`}}], 
     LineBox[{{13.424507112652483`, 13.427589317466039`}, {
      13.427589317466039`, 13.427589317466039`}}], 
     LineBox[{{13.427589317466039`, 13.427589317466039`}, {
      13.427589317466039`, 13.425616134012984`}}], 
     LineBox[{{13.427589317466039`, 13.425616134012984`}, {
      13.425616134012984`, 13.425616134012984`}}], 
     LineBox[{{13.425616134012984`, 13.425616134012984`}, {
      13.425616134012984`, 13.426880240426552`}}], 
     LineBox[{{13.425616134012984`, 13.426880240426552`}, {
      13.426880240426552`, 13.426880240426552`}}], 
     LineBox[{{13.426880240426552`, 13.426880240426552`}, {
      13.426880240426552`, 13.426070769052265`}}], 
     LineBox[{{13.426880240426552`, 13.426070769052265`}, {
      13.426070769052265`, 13.426070769052265`}}], 
     LineBox[{{13.426070769052265`, 13.426070769052265`}, {
      13.426070769052265`, 13.426589266370092`}}], 
     LineBox[{{13.426070769052265`, 13.426589266370092`}, {
      13.426589266370092`, 13.426589266370092`}}], 
     LineBox[{{13.426589266370092`, 13.426589266370092`}, {
      13.426589266370092`, 13.42625721127124}}], 
     LineBox[{{13.426589266370092`, 13.42625721127124}, {13.42625721127124, 
      13.42625721127124}}], 
     LineBox[{{13.42625721127124, 13.42625721127124}, {13.42625721127124, 
      13.426469890921988`}}], 
     LineBox[{{13.42625721127124, 13.426469890921988`}, {13.426469890921988`, 
      13.426469890921988`}}], 
     LineBox[{{13.426469890921988`, 13.426469890921988`}, {
      13.426469890921988`, 13.426333681127959`}}], 
     LineBox[{{13.426469890921988`, 13.426333681127959`}, {
      13.426333681127959`, 13.426333681127959`}}], 
     LineBox[{{13.426333681127959`, 13.426333681127959`}, {
      13.426333681127959`, 13.42642092041779}}], 
     LineBox[{{13.426333681127959`, 13.42642092041779}, {13.42642092041779, 
      13.42642092041779}}], 
     LineBox[{{13.42642092041779, 13.42642092041779}, {13.42642092041779, 
      13.426365047389488`}}], 
     LineBox[{{13.42642092041779, 13.426365047389488`}, {13.426365047389488`, 
      13.426365047389488`}}], 
     LineBox[{{13.426365047389488`, 13.426365047389488`}, {
      13.426365047389488`, 13.426400832393679`}}], 
     LineBox[{{13.426365047389488`, 13.426400832393679`}, {
      13.426400832393679`, 13.426400832393679`}}], 
     LineBox[{{13.426400832393679`, 13.426400832393679`}, {
      13.426400832393679`, 13.426377913464856`}}], 
     LineBox[{{13.426400832393679`, 13.426377913464856`}, {
      13.426377913464856`, 13.426377913464856`}}], 
     LineBox[{{13.426377913464856`, 13.426377913464856`}, {
      13.426377913464856`, 13.42639259228529}}], 
     LineBox[{{13.426377913464856`, 13.42639259228529}, {13.42639259228529, 
      13.42639259228529}}], 
     LineBox[{{13.42639259228529, 13.42639259228529}, {13.42639259228529, 
      13.426383191033269`}}], 
     LineBox[{{13.42639259228529, 13.426383191033269`}, {13.426383191033269`, 
      13.426383191033269`}}], 
     LineBox[{{13.426383191033269`, 13.426383191033269`}, {
      13.426383191033269`, 13.426389212214627`}}], 
     LineBox[{{13.426383191033269`, 13.426389212214627`}, {
      13.426389212214627`, 13.426389212214627`}}], 
     LineBox[{{13.426389212214627`, 13.426389212214627`}, {
      13.426389212214627`, 13.42638535586167}}], 
     LineBox[{{13.426389212214627`, 13.42638535586167}, {13.42638535586167, 
      13.42638535586167}}], 
     LineBox[{{13.42638535586167, 13.42638535586167}, {13.42638535586167, 
      13.426387825722312`}}], 
     LineBox[{{13.42638535586167, 13.426387825722312`}, {13.426387825722312`, 
      13.426387825722312`}}], 
     LineBox[{{13.426387825722312`, 13.426387825722312`}, {
      13.426387825722312`, 13.426386243863439`}}], 
     LineBox[{{13.426387825722312`, 13.426386243863439`}, {
      13.426386243863439`, 13.426386243863439`}}], 
     LineBox[{{13.426386243863439`, 13.426386243863439`}, {
      13.426386243863439`, 13.426387256988992`}}], 
     LineBox[{{13.426386243863439`, 13.426387256988992`}, {
      13.426387256988992`, 13.426387256988992`}}], 
     LineBox[{{13.426387256988992`, 13.426387256988992`}, {
      13.426387256988992`, 13.426386608117573`}}], 
     LineBox[{{13.426387256988992`, 13.426386608117573`}, {
      13.426386608117573`, 13.426386608117573`}}], 
     LineBox[{{13.426386608117573`, 13.426386608117573`}, {
      13.426386608117573`, 13.426387023697078`}}], 
     LineBox[{{13.426386608117573`, 13.426387023697078`}, {
      13.426387023697078`, 13.426387023697078`}}], 
     LineBox[{{13.426387023697078`, 13.426387023697078`}, {
      13.426387023697078`, 13.426386757532946`}}], 
     LineBox[{{13.426387023697078`, 13.426386757532946`}, {
      13.426386757532946`, 13.426386757532946`}}], 
     LineBox[{{13.426386757532946`, 13.426386757532946`}, {
      13.426386757532946`, 13.426386928001776`}}], 
     LineBox[{{13.426386757532946`, 13.426386928001776`}, {
      13.426386928001776`, 13.426386928001776`}}], 
     LineBox[{{13.426386928001776`, 13.426386928001776`}, {
      13.426386928001776`, 13.42638681882245}}], 
     LineBox[{{13.426386928001776`, 13.42638681882245}, {13.42638681882245, 
      13.42638681882245}}], 
     LineBox[{{13.42638681882245, 13.42638681882245}, {13.42638681882245, 
      13.426386888747993`}}], 
     LineBox[{{13.42638681882245, 13.426386888747993`}, {13.426386888747993`, 
      13.426386888747993`}}], 
     LineBox[{{13.426386888747993`, 13.426386888747993`}, {
      13.426386888747993`, 13.426386843963128`}}], 
     LineBox[{{13.426386888747993`, 13.426386843963128`}, {
      13.426386843963128`, 13.426386843963128`}}], 
     LineBox[{{13.426386843963128`, 13.426386843963128`}, {
      13.426386843963128`, 13.426386872646269`}}], 
     LineBox[{{13.426386843963128`, 13.426386872646269`}, {
      13.426386872646269`, 13.426386872646269`}}], 
     LineBox[{{13.426386872646269`, 13.426386872646269`}, {
      13.426386872646269`, 13.42638685427572}}], 
     LineBox[{{13.426386872646269`, 13.42638685427572}, {13.42638685427572, 
      13.42638685427572}}], 
     LineBox[{{13.42638685427572, 13.42638685427572}, {13.42638685427572, 
      13.426386866041415`}}], 
     LineBox[{{13.42638685427572, 13.426386866041415`}, {13.426386866041415`, 
      13.426386866041415`}}], 
     LineBox[{{13.426386866041415`, 13.426386866041415`}, {
      13.426386866041415`, 13.426386858505898`}}], 
     LineBox[{{13.426386866041415`, 13.426386858505898`}, {
      13.426386858505898`, 13.426386858505898`}}], 
     LineBox[{{13.426386858505898`, 13.426386858505898`}, {
      13.426386858505898`, 13.426386863332134`}}], 
     LineBox[{{13.426386858505898`, 13.426386863332134`}, {
      13.426386863332134`, 13.426386863332134`}}], 
     LineBox[{{13.426386863332134`, 13.426386863332134`}, {
      13.426386863332134`, 13.426386860241099`}}], 
     LineBox[{{13.426386863332134`, 13.426386860241099`}, {
      13.426386860241099`, 13.426386860241099`}}], 
     LineBox[{{13.426386860241099`, 13.426386860241099`}, {
      13.426386860241099`, 13.426386862220799`}}], 
     LineBox[{{13.426386860241099`, 13.426386862220799`}, {
      13.426386862220799`, 13.426386862220799`}}], 
     LineBox[{{13.426386862220799`, 13.426386862220799`}, {
      13.426386862220799`, 13.426386860952869`}}], 
     LineBox[{{13.426386862220799`, 13.426386860952869`}, {
      13.426386860952869`, 13.426386860952869`}}], 
     LineBox[{{13.426386860952869`, 13.426386860952869`}, {
      13.426386860952869`, 13.426386861764934`}}], 
     LineBox[{{13.426386860952869`, 13.426386861764934`}, {
      13.426386861764934`, 13.426386861764934`}}], 
     LineBox[{{13.426386861764934`, 13.426386861764934`}, {
      13.426386861764934`, 13.426386861244834`}}], 
     LineBox[{{13.426386861764934`, 13.426386861244834`}, {
      13.426386861244834`, 13.426386861244834`}}], 
     LineBox[{{13.426386861244834`, 13.426386861244834`}, {
      13.426386861244834`, 13.42638686157794}}], 
     LineBox[{{13.426386861244834`, 13.42638686157794}, {13.42638686157794, 
      13.42638686157794}}], 
     LineBox[{{13.42638686157794, 13.42638686157794}, {13.42638686157794, 
      13.426386861364598`}}], 
     LineBox[{{13.42638686157794, 13.426386861364598`}, {13.426386861364598`, 
      13.426386861364598`}}], 
     LineBox[{{13.426386861364598`, 13.426386861364598`}, {
      13.426386861364598`, 13.426386861501236`}}], 
     LineBox[{{13.426386861364598`, 13.426386861501236`}, {
      13.426386861501236`, 13.426386861501236`}}], 
     LineBox[{{13.426386861501236`, 13.426386861501236`}, {
      13.426386861501236`, 13.426386861413725`}}], 
     LineBox[{{13.426386861501236`, 13.426386861413725`}, {
      13.426386861413725`, 13.426386861413725`}}], 
     LineBox[{{13.426386861413725`, 13.426386861413725`}, {
      13.426386861413725`, 13.426386861469771`}}], 
     LineBox[{{13.426386861413725`, 13.426386861469771`}, {
      13.426386861469771`, 13.426386861469771`}}], 
     LineBox[{{13.426386861469771`, 13.426386861469771`}, {
      13.426386861469771`, 13.426386861433876`}}], 
     LineBox[{{13.426386861469771`, 13.426386861433876`}, {
      13.426386861433876`, 13.426386861433876`}}], 
     LineBox[{{13.426386861433876`, 13.426386861433876`}, {
      13.426386861433876`, 13.426386861456866`}}], 
     LineBox[{{13.426386861433876`, 13.426386861456866`}, {
      13.426386861456866`, 13.426386861456866`}}], 
     LineBox[{{13.426386861456866`, 13.426386861456866`}, {
      13.426386861456866`, 13.426386861442142`}}], 
     LineBox[{{13.426386861456866`, 13.426386861442142`}, {
      13.426386861442142`, 13.426386861442142`}}], 
     LineBox[{{13.426386861442142`, 13.426386861442142`}, {
      13.426386861442142`, 13.426386861451572`}}], 
     LineBox[{{13.426386861442142`, 13.426386861451572`}, {
      13.426386861451572`, 13.426386861451572`}}], 
     LineBox[{{13.426386861451572`, 13.426386861451572`}, {
      13.426386861451572`, 13.426386861445533`}}], 
     LineBox[{{13.426386861451572`, 13.426386861445533`}, {
      13.426386861445533`, 13.426386861445533`}}], 
     LineBox[{{13.426386861445533`, 13.426386861445533`}, {
      13.426386861445533`, 13.4263868614494}}], 
     LineBox[{{13.426386861445533`, 13.4263868614494}, {13.4263868614494, 
      13.4263868614494}}], 
     LineBox[{{13.4263868614494, 13.4263868614494}, {13.4263868614494, 
      13.426386861446924`}}], 
     LineBox[{{13.4263868614494, 13.426386861446924`}, {13.426386861446924`, 
      13.426386861446924`}}], 
     LineBox[{{13.426386861446924`, 13.426386861446924`}, {
      13.426386861446924`, 13.42638686144851}}], 
     LineBox[{{13.426386861446924`, 13.42638686144851}, {13.42638686144851, 
      13.42638686144851}}], 
     LineBox[{{13.42638686144851, 13.42638686144851}, {13.42638686144851, 
      13.426386861447494`}}], 
     LineBox[{{13.42638686144851, 13.426386861447494`}, {13.426386861447494`, 
      13.426386861447494`}}], 
     LineBox[{{13.426386861447494`, 13.426386861447494`}, {
      13.426386861447494`, 13.426386861448144`}}], 
     LineBox[{{13.426386861447494`, 13.426386861448144`}, {
      13.426386861448144`, 13.426386861448144`}}], 
     LineBox[{{13.426386861448144`, 13.426386861448144`}, {
      13.426386861448144`, 13.426386861447728`}}], 
     LineBox[{{13.426386861448144`, 13.426386861447728`}, {
      13.426386861447728`, 13.426386861447728`}}], 
     LineBox[{{13.426386861447728`, 13.426386861447728`}, {
      13.426386861447728`, 13.426386861447995`}}], 
     LineBox[{{13.426386861447728`, 13.426386861447995`}, {
      13.426386861447995`, 13.426386861447995`}}], 
     LineBox[{{13.426386861447995`, 13.426386861447995`}, {
      13.426386861447995`, 13.426386861447824`}}], 
     LineBox[{{13.426386861447995`, 13.426386861447824`}, {
      13.426386861447824`, 13.426386861447824`}}], 
     LineBox[{{13.426386861447824`, 13.426386861447824`}, {
      13.426386861447824`, 13.426386861447932`}}], 
     LineBox[{{13.426386861447824`, 13.426386861447932`}, {
      13.426386861447932`, 13.426386861447932`}}], 
     LineBox[{{13.426386861447932`, 13.426386861447932`}, {
      13.426386861447932`, 13.426386861447863`}}], 
     LineBox[{{13.426386861447932`, 13.426386861447863`}, {
      13.426386861447863`, 13.426386861447863`}}], 
     LineBox[{{13.426386861447863`, 13.426386861447863`}, {
      13.426386861447863`, 13.426386861447908`}}], 
     LineBox[{{13.426386861447863`, 13.426386861447908`}, {
      13.426386861447908`, 13.426386861447908`}}], 
     LineBox[{{13.426386861447908`, 13.426386861447908`}, {
      13.426386861447908`, 13.42638686144788}}], 
     LineBox[{{13.426386861447908`, 13.42638686144788}, {13.42638686144788, 
      13.42638686144788}}], 
     LineBox[{{13.42638686144788, 13.42638686144788}, {13.42638686144788, 
      13.426386861447897`}}], 
     LineBox[{{13.42638686144788, 13.426386861447897`}, {13.426386861447897`, 
      13.426386861447897`}}], 
     LineBox[{{13.426386861447897`, 13.426386861447897`}, {
      13.426386861447897`, 13.426386861447886`}}], 
     LineBox[{{13.426386861447897`, 13.426386861447886`}, {
      13.426386861447886`, 13.426386861447886`}}], 
     LineBox[{{13.426386861447886`, 13.426386861447886`}, {
      13.426386861447886`, 13.426386861447893`}}], 
     LineBox[{{13.426386861447886`, 13.426386861447893`}, {
      13.426386861447893`, 13.426386861447893`}}], 
     LineBox[{{13.426386861447893`, 13.426386861447893`}, {
      13.426386861447893`, 13.426386861447888`}}], 
     LineBox[{{13.426386861447893`, 13.426386861447888`}, {
      13.426386861447888`, 13.426386861447888`}}], 
     LineBox[{{13.426386861447888`, 13.426386861447888`}, {
      13.426386861447888`, 13.426386861447892`}}], 
     LineBox[{{13.426386861447888`, 13.426386861447892`}, {
      13.426386861447892`, 13.426386861447892`}}], 
     LineBox[{{13.426386861447892`, 13.426386861447892`}, {
      13.426386861447892`, 13.42638686144789}}], 
     LineBox[{{13.426386861447892`, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}], 
     LineBox[{{13.42638686144789, 13.42638686144789}, {13.42638686144789, 
      13.42638686144789}}]}}, {{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.5], LineBox[CompressedData["
1:eJwl13k4lF8bB3ChkoRsM2Qb6yyWmcFgLH1thUqShCzRjlRCpX4qWlRUilKk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      "]]}}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  ImageSize->324.,
  PlotRange->{{5, 28}, {5, 28}},
  PlotRangeClipping->True,
  Prolog->{
    AbsoluteThickness[1], 
    LineBox[{{0, 0}, {28, 28}}]}]], "Output",
 CellChangeTimes->{{3.465179090899445*^9, 3.465179120692564*^9}, 
   3.465179303107987*^9, 3.465179362023176*^9, 3.465179421609413*^9, 
   3.465180922056445*^9, 3.465180981450177*^9, 3.465181139093732*^9, 
   3.465181388355146*^9, 3.465181453125148*^9, 3.465207951606312*^9, 
   3.465208893409202*^9, 3.46520902554533*^9, 3.465209866753149*^9, 
   3.465209967696628*^9, 3.465222156748543*^9, 3.465226020143283*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cobWebT", "[", 
  RowBox[{
   RowBox[{"2.2", "tr"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", " ", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4651790707082767`*^9, 3.465179089053629*^9}, {
  3.4651792992475357`*^9, 3.4651793091724663`*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.67, 0.6, 0.6], PointSize[0.01], PointBox[CompressedData["
1:eJxTTMoPSmViYGA4AcQgGgKMHJbarMq6fFsdJ53qfOrR91hjnPSDzpjgdKA6
XLTJXbEf94HqcNG6L2aXg9ThonMYZBkeANXholn394PV4aLd/KXA6nDRkoch
6nDRegEQdbhoCag6XPSo/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+o0dAL9sngw=

      "]]}, 
    {GrayLevel[0.3], AbsoluteThickness[1], 
     LineBox[{{18, 11.92934735611045}, {11.92934735611045, 
       11.92934735611045}}], 
     LineBox[{{11.92934735611045, 11.92934735611045}, {11.92934735611045, 
      19.36706368864124}}], 
     LineBox[{{11.92934735611045, 19.36706368864124}, {19.36706368864124, 
      19.36706368864124}}], 
     LineBox[{{19.36706368864124, 19.36706368864124}, {19.36706368864124, 
      11.928522687002385`}}], 
     LineBox[{{19.36706368864124, 11.928522687002385`}, {11.928522687002385`, 
      11.928522687002385`}}], 
     LineBox[{{11.928522687002385`, 11.928522687002385`}, {
      11.928522687002385`, 19.3666987472363}}], 
     LineBox[{{11.928522687002385`, 19.3666987472363}, {19.3666987472363, 
      19.3666987472363}}], 
     LineBox[{{19.3666987472363, 19.3666987472363}, {19.3666987472363, 
      11.928523767263039`}}], 
     LineBox[{{19.3666987472363, 11.928523767263039`}, {11.928523767263039`, 
      11.928523767263039`}}], 
     LineBox[{{11.928523767263039`, 11.928523767263039`}, {
      11.928523767263039`, 19.366699225502472`}}], 
     LineBox[{{11.928523767263039`, 19.366699225502472`}, {
      19.366699225502472`, 19.366699225502472`}}], 
     LineBox[{{19.366699225502472`, 19.366699225502472`}, {
      19.366699225502472`, 11.92852376584734}}], 
     LineBox[{{19.366699225502472`, 11.92852376584734}, {11.92852376584734, 
      11.92852376584734}}], 
     LineBox[{{11.92852376584734, 11.92852376584734}, {11.92852376584734, 
      19.366699224875696`}}], 
     LineBox[{{11.92852376584734, 19.366699224875696`}, {19.366699224875696`, 
      19.366699224875696`}}], 
     LineBox[{{19.366699224875696`, 19.366699224875696`}, {
      19.366699224875696`, 11.928523765849194`}}], 
     LineBox[{{19.366699224875696`, 11.928523765849194`}, {
      11.928523765849194`, 11.928523765849194`}}], 
     LineBox[{{11.928523765849194`, 11.928523765849194`}, {
      11.928523765849194`, 19.36669922487652}}], 
     LineBox[{{11.928523765849194`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}]}}, {{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.5], LineBox[CompressedData["
1:eJwl13c8ld8fAHA7JGSTPe417r5cXOtjldmQMjJKVCLZDRVJQpSGkhlFyA5J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      "]]}}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  ImageSize->324.,
  PlotRange->{{5, 28}, {5, 28}},
  PlotRangeClipping->True,
  Prolog->{
    AbsoluteThickness[1], 
    LineBox[{{0, 0}, {28, 28}}]}]], "Output",
 CellChangeTimes->{3.465179310073107*^9, 3.465179365007565*^9, 
  3.465179418565819*^9, 3.4651817102923937`*^9, 3.4652079517671003`*^9, 
  3.465208893515353*^9, 3.465209025662718*^9, 3.465209866870997*^9, 
  3.4652221568645563`*^9, 3.465226020247913*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Static cobweb plots", "Subsubsection",
 CellChangeTimes->{{3.465177569662396*^9, 3.4651775756460123`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cobWebT", "[", 
  RowBox[{
   RowBox[{"0.85", "tr"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", " ", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4651790707082767`*^9, 3.465179089053629*^9}, {
  3.4651792992475357`*^9, 3.465179302412409*^9}, {3.465179576926261*^9, 
  3.4651795795869913`*^9}, {3.465179819010168*^9, 3.46517983576239*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.67, 0.6, 0.6], PointSize[0.01], PointBox[CompressedData["
1:eJy1y11Ik3EYxuG1PqwQ58pqy6abU+s13mkz0ZY0Q0WjQCnnoHJizdS1ED9K
GbqJgUWBsKyjIkOQVkQTmoEHYkkHkR5JFLFNKUIpJIhSRmr2/zq9D3vg5jr5
PYYLzafrlQqF4i0ZlZ+5qK7O/yT7VzJ0R3JzqeusEVozGkkYr5Wg9nVV2oBJ
hrYOD1VqRyXo8PSE9V6GDC3bZJ5JmpKg5bb5jS0GGXrpub2m770EbZrIXLyS
KkN12++e3/BJgsrKV7/dKTK01fDXWhCWoNeVjUvfdTI0uDMQsUUk6NrIgZcB
0iFjj2sNC6RD5q6HZ/pIhzTdiDoORSVo59Ll9qukQ2bV2RrspEOWBjJuu0mH
zN3s++YiHdKyqos1kA4Zeja92E465MHCjw/rSYfM759N9JAOmVKmdjlJh1wp
Hwl1kQ5Z+Kd76iLpkKMvJlVe0iFno/Ee2iHnfMpJ2iFTvxZU0g6peNCv85EO
OXFi3EI75M/qgVO0Q9qDoWzaIR81jTlphzQub8uiHVJ9S99CO6Qvqt9PO2TF
SV8H7ZAO01AG7ZBbwm88tEPuHoqm0w45FtfWRTtkW7CTdUhzrKKbdsg7H0pY
h5xrec06pD8vi3XIhbEV1iGrbu5jHfJLQOulHTKpdxfrkINbJdYhvfNq1iHj
fuSwDpkWn8g6ZOHqYdYhezQq1iGvqfNZh3TcT2Ad0mYsYB1y7zneIdeCvENq
LLxDHo3xDpku8Q5ZrTvCOmSznndIZw7vkMvJvEOaLLxDPtXyDpln5R2yS8M7
5LvjvEN+3sM7pK6Yd0i/6JDTokM2ig6ZWcI75BnRIatEhywXHdItOmSx6JAd
okMWiQ7pFR3SKjpkj+iQx0SH7BUd8n/9/wO5tXz8
      "]]}, 
    {GrayLevel[0.3], AbsoluteThickness[1], 
     LineBox[{{18, 6.987486505029978}, {6.987486505029978, 
       6.987486505029978}}], 
     LineBox[{{6.987486505029978, 6.987486505029978}, {6.987486505029978, 
      9.676592035114968}}], 
     LineBox[{{6.987486505029978, 9.676592035114968}, {9.676592035114968, 
      9.676592035114968}}], 
     LineBox[{{9.676592035114968, 9.676592035114968}, {9.676592035114968, 
      12.686989273492765`}}], 
     LineBox[{{9.676592035114968, 12.686989273492765`}, {12.686989273492765`, 
      12.686989273492765`}}], 
     LineBox[{{12.686989273492765`, 12.686989273492765`}, {
      12.686989273492765`, 14.5909662861374}}], 
     LineBox[{{12.686989273492765`, 14.5909662861374}, {14.5909662861374, 
      14.5909662861374}}], 
     LineBox[{{14.5909662861374, 14.5909662861374}, {14.5909662861374, 
      12.85370876298359}}], 
     LineBox[{{14.5909662861374, 12.85370876298359}, {12.85370876298359, 
      12.85370876298359}}], 
     LineBox[{{12.85370876298359, 12.85370876298359}, {12.85370876298359, 
      14.573404304659855`}}], 
     LineBox[{{12.85370876298359, 14.573404304659855`}, {14.573404304659855`, 
      14.573404304659855`}}], 
     LineBox[{{14.573404304659855`, 14.573404304659855`}, {
      14.573404304659855`, 12.896643227201038`}}], 
     LineBox[{{14.573404304659855`, 12.896643227201038`}, {
      12.896643227201038`, 12.896643227201038`}}], 
     LineBox[{{12.896643227201038`, 12.896643227201038`}, {
      12.896643227201038`, 14.565315362803304`}}], 
     LineBox[{{12.896643227201038`, 14.565315362803304`}, {
      14.565315362803304`, 14.565315362803304`}}], 
     LineBox[{{14.565315362803304`, 14.565315362803304`}, {
      14.565315362803304`, 12.91508762069061}}], 
     LineBox[{{14.565315362803304`, 12.91508762069061}, {12.91508762069061, 
      12.91508762069061}}], 
     LineBox[{{12.91508762069061, 12.91508762069061}, {12.91508762069061, 
      14.561385516862815`}}], 
     LineBox[{{12.91508762069061, 14.561385516862815`}, {14.561385516862815`, 
      14.561385516862815`}}], 
     LineBox[{{14.561385516862815`, 14.561385516862815`}, {
      14.561385516862815`, 12.923838513442258`}}], 
     LineBox[{{14.561385516862815`, 12.923838513442258`}, {
      12.923838513442258`, 12.923838513442258`}}], 
     LineBox[{{12.923838513442258`, 12.923838513442258`}, {
      12.923838513442258`, 14.559425018728769`}}], 
     LineBox[{{12.923838513442258`, 14.559425018728769`}, {
      14.559425018728769`, 14.559425018728769`}}], 
     LineBox[{{14.559425018728769`, 14.559425018728769`}, {
      14.559425018728769`, 12.928163528224761`}}], 
     LineBox[{{14.559425018728769`, 12.928163528224761`}, {
      12.928163528224761`, 12.928163528224761`}}], 
     LineBox[{{12.928163528224761`, 12.928163528224761`}, {
      12.928163528224761`, 14.558433216997633`}}], 
     LineBox[{{12.928163528224761`, 14.558433216997633`}, {
      14.558433216997633`, 14.558433216997633`}}], 
     LineBox[{{14.558433216997633`, 14.558433216997633`}, {
      14.558433216997633`, 12.930342574612807`}}], 
     LineBox[{{14.558433216997633`, 12.930342574612807`}, {
      12.930342574612807`, 12.930342574612807`}}], 
     LineBox[{{12.930342574612807`, 12.930342574612807`}, {
      12.930342574612807`, 14.557927792041022`}}], 
     LineBox[{{12.930342574612807`, 14.557927792041022`}, {
      14.557927792041022`, 14.557927792041022`}}], 
     LineBox[{{14.557927792041022`, 14.557927792041022`}, {
      14.557927792041022`, 12.931450884749196`}}], 
     LineBox[{{14.557927792041022`, 12.931450884749196`}, {
      12.931450884749196`, 12.931450884749196`}}], 
     LineBox[{{12.931450884749196`, 12.931450884749196`}, {
      12.931450884749196`, 14.557669247965896`}}], 
     LineBox[{{12.931450884749196`, 14.557669247965896`}, {
      14.557669247965896`, 14.557669247965896`}}], 
     LineBox[{{14.557669247965896`, 14.557669247965896`}, {
      14.557669247965896`, 12.932017292539594`}}], 
     LineBox[{{14.557669247965896`, 12.932017292539594`}, {
      12.932017292539594`, 12.932017292539594`}}], 
     LineBox[{{12.932017292539594`, 12.932017292539594`}, {
      12.932017292539594`, 14.557536733797619`}}], 
     LineBox[{{12.932017292539594`, 14.557536733797619`}, {
      14.557536733797619`, 14.557536733797619`}}], 
     LineBox[{{14.557536733797619`, 14.557536733797619`}, {
      14.557536733797619`, 12.932307461902912`}}], 
     LineBox[{{14.557536733797619`, 12.932307461902912`}, {
      12.932307461902912`, 12.932307461902912`}}], 
     LineBox[{{12.932307461902912`, 12.932307461902912`}, {
      12.932307461902912`, 14.557468746516074`}}], 
     LineBox[{{12.932307461902912`, 14.557468746516074`}, {
      14.557468746516074`, 14.557468746516074`}}], 
     LineBox[{{14.557468746516074`, 14.557468746516074`}, {
      14.557468746516074`, 12.932456299548539`}}], 
     LineBox[{{14.557468746516074`, 12.932456299548539`}, {
      12.932456299548539`, 12.932456299548539`}}], 
     LineBox[{{12.932456299548539`, 12.932456299548539`}, {
      12.932456299548539`, 14.557433847103415`}}], 
     LineBox[{{12.932456299548539`, 14.557433847103415`}, {
      14.557433847103415`, 14.557433847103415`}}], 
     LineBox[{{14.557433847103415`, 14.557433847103415`}, {
      14.557433847103415`, 12.93253269194097}}], 
     LineBox[{{14.557433847103415`, 12.93253269194097}, {12.93253269194097, 
      12.93253269194097}}], 
     LineBox[{{12.93253269194097, 12.93253269194097}, {12.93253269194097, 
      14.557415927671249`}}], 
     LineBox[{{12.93253269194097, 14.557415927671249`}, {14.557415927671249`, 
      14.557415927671249`}}], 
     LineBox[{{14.557415927671249`, 14.557415927671249`}, {
      14.557415927671249`, 12.932571913878844`}}], 
     LineBox[{{14.557415927671249`, 12.932571913878844`}, {
      12.932571913878844`, 12.932571913878844`}}], 
     LineBox[{{12.932571913878844`, 12.932571913878844`}, {
      12.932571913878844`, 14.557406725510699`}}], 
     LineBox[{{12.932571913878844`, 14.557406725510699`}, {
      14.557406725510699`, 14.557406725510699`}}], 
     LineBox[{{14.557406725510699`, 14.557406725510699`}, {
      14.557406725510699`, 12.932592054862189`}}], 
     LineBox[{{14.557406725510699`, 12.932592054862189`}, {
      12.932592054862189`, 12.932592054862189`}}], 
     LineBox[{{12.932592054862189`, 12.932592054862189`}, {
      12.932592054862189`, 14.557401999595747`}}], 
     LineBox[{{12.932592054862189`, 14.557401999595747`}, {
      14.557401999595747`, 14.557401999595747`}}], 
     LineBox[{{14.557401999595747`, 14.557401999595747`}, {
      14.557401999595747`, 12.932602398412067`}}], 
     LineBox[{{14.557401999595747`, 12.932602398412067`}, {
      12.932602398412067`, 12.932602398412067`}}], 
     LineBox[{{12.932602398412067`, 12.932602398412067`}, {
      12.932602398412067`, 14.557399572439802`}}], 
     LineBox[{{12.932602398412067`, 14.557399572439802`}, {
      14.557399572439802`, 14.557399572439802`}}], 
     LineBox[{{14.557399572439802`, 14.557399572439802`}, {
      14.557399572439802`, 12.93260771065246}}], 
     LineBox[{{14.557399572439802`, 12.93260771065246}, {12.93260771065246, 
      12.93260771065246}}], 
     LineBox[{{12.93260771065246, 12.93260771065246}, {12.93260771065246, 
      14.55739832586738}}], 
     LineBox[{{12.93260771065246, 14.55739832586738}, {14.55739832586738, 
      14.55739832586738}}], 
     LineBox[{{14.55739832586738, 14.55739832586738}, {14.55739832586738, 
      12.932610438974734`}}], 
     LineBox[{{14.55739832586738, 12.932610438974734`}, {12.932610438974734`, 
      12.932610438974734`}}], 
     LineBox[{{12.932610438974734`, 12.932610438974734`}, {
      12.932610438974734`, 14.557397685629324`}}], 
     LineBox[{{12.932610438974734`, 14.557397685629324`}, {
      14.557397685629324`, 14.557397685629324`}}], 
     LineBox[{{14.557397685629324`, 14.557397685629324`}, {
      14.557397685629324`, 12.932611840234559`}}], 
     LineBox[{{14.557397685629324`, 12.932611840234559`}, {
      12.932611840234559`, 12.932611840234559`}}], 
     LineBox[{{12.932611840234559`, 12.932611840234559`}, {
      12.932611840234559`, 14.55739735680224}}], 
     LineBox[{{12.932611840234559`, 14.55739735680224}, {14.55739735680224, 
      14.55739735680224}}], 
     LineBox[{{14.55739735680224, 14.55739735680224}, {14.55739735680224, 
      12.932612559922575`}}], 
     LineBox[{{14.55739735680224, 12.932612559922575`}, {12.932612559922575`, 
      12.932612559922575`}}], 
     LineBox[{{12.932612559922575`, 12.932612559922575`}, {
      12.932612559922575`, 14.557397187915802`}}], 
     LineBox[{{12.932612559922575`, 14.557397187915802`}, {
      14.557397187915802`, 14.557397187915802`}}], 
     LineBox[{{14.557397187915802`, 14.557397187915802`}, {
      14.557397187915802`, 12.932612929555974`}}], 
     LineBox[{{14.557397187915802`, 12.932612929555974`}, {
      12.932612929555974`, 12.932612929555974`}}], 
     LineBox[{{12.932612929555974`, 12.932612929555974`}, {
      12.932612929555974`, 14.557397101175182`}}], 
     LineBox[{{12.932612929555974`, 14.557397101175182`}, {
      14.557397101175182`, 14.557397101175182`}}], 
     LineBox[{{14.557397101175182`, 14.557397101175182`}, {
      14.557397101175182`, 12.932613119400825`}}], 
     LineBox[{{14.557397101175182`, 12.932613119400825`}, {
      12.932613119400825`, 12.932613119400825`}}], 
     LineBox[{{12.932613119400825`, 12.932613119400825`}, {
      12.932613119400825`, 14.55739705662489}}], 
     LineBox[{{12.932613119400825`, 14.55739705662489}, {14.55739705662489, 
      14.55739705662489}}], 
     LineBox[{{14.55739705662489, 14.55739705662489}, {14.55739705662489, 
      12.932613216905803`}}], 
     LineBox[{{14.55739705662489, 12.932613216905803`}, {12.932613216905803`, 
      12.932613216905803`}}], 
     LineBox[{{12.932613216905803`, 12.932613216905803`}, {
      12.932613216905803`, 14.557397033743694`}}], 
     LineBox[{{12.932613216905803`, 14.557397033743694`}, {
      14.557397033743694`, 14.557397033743694`}}], 
     LineBox[{{14.557397033743694`, 14.557397033743694`}, {
      14.557397033743694`, 12.932613266984719`}}], 
     LineBox[{{14.557397033743694`, 12.932613266984719`}, {
      12.932613266984719`, 12.932613266984719`}}], 
     LineBox[{{12.932613266984719`, 12.932613266984719`}, {
      12.932613266984719`, 14.557397021991823`}}], 
     LineBox[{{12.932613266984719`, 14.557397021991823`}, {
      14.557397021991823`, 14.557397021991823`}}], 
     LineBox[{{14.557397021991823`, 14.557397021991823`}, {
      14.557397021991823`, 12.932613292705444`}}], 
     LineBox[{{14.557397021991823`, 12.932613292705444`}, {
      12.932613292705444`, 12.932613292705444`}}], 
     LineBox[{{12.932613292705444`, 12.932613292705444`}, {
      12.932613292705444`, 14.557397015956017`}}], 
     LineBox[{{12.932613292705444`, 14.557397015956017`}, {
      14.557397015956017`, 14.557397015956017`}}], 
     LineBox[{{14.557397015956017`, 14.557397015956017`}, {
      14.557397015956017`, 12.932613305915707`}}], 
     LineBox[{{14.557397015956017`, 12.932613305915707`}, {
      12.932613305915707`, 12.932613305915707`}}], 
     LineBox[{{12.932613305915707`, 12.932613305915707`}, {
      12.932613305915707`, 14.557397012856002`}}], 
     LineBox[{{12.932613305915707`, 14.557397012856002`}, {
      14.557397012856002`, 14.557397012856002`}}], 
     LineBox[{{14.557397012856002`, 14.557397012856002`}, {
      14.557397012856002`, 12.932613312700552`}}], 
     LineBox[{{14.557397012856002`, 12.932613312700552`}, {
      12.932613312700552`, 12.932613312700552`}}], 
     LineBox[{{12.932613312700552`, 12.932613312700552`}, {
      12.932613312700552`, 14.557397011263824`}}], 
     LineBox[{{12.932613312700552`, 14.557397011263824`}, {
      14.557397011263824`, 14.557397011263824`}}], 
     LineBox[{{14.557397011263824`, 14.557397011263824`}, {
      14.557397011263824`, 12.932613316185272`}}], 
     LineBox[{{14.557397011263824`, 12.932613316185272`}, {
      12.932613316185272`, 12.932613316185272`}}], 
     LineBox[{{12.932613316185272`, 12.932613316185272`}, {
      12.932613316185272`, 14.557397010446074`}}], 
     LineBox[{{12.932613316185272`, 14.557397010446074`}, {
      14.557397010446074`, 14.557397010446074`}}], 
     LineBox[{{14.557397010446074`, 14.557397010446074`}, {
      14.557397010446074`, 12.932613317975038`}}], 
     LineBox[{{14.557397010446074`, 12.932613317975038`}, {
      12.932613317975038`, 12.932613317975038`}}], 
     LineBox[{{12.932613317975038`, 12.932613317975038`}, {
      12.932613317975038`, 14.557397010026076`}}], 
     LineBox[{{12.932613317975038`, 14.557397010026076`}, {
      14.557397010026076`, 14.557397010026076`}}], 
     LineBox[{{14.557397010026076`, 14.557397010026076`}, {
      14.557397010026076`, 12.932613318894267`}}], 
     LineBox[{{14.557397010026076`, 12.932613318894267`}, {
      12.932613318894267`, 12.932613318894267`}}], 
     LineBox[{{12.932613318894267`, 12.932613318894267`}, {
      12.932613318894267`, 14.557397009810362`}}], 
     LineBox[{{12.932613318894267`, 14.557397009810362`}, {
      14.557397009810362`, 14.557397009810362`}}], 
     LineBox[{{14.557397009810362`, 14.557397009810362`}, {
      14.557397009810362`, 12.93261331936639}}], 
     LineBox[{{14.557397009810362`, 12.93261331936639}, {12.93261331936639, 
      12.93261331936639}}], 
     LineBox[{{12.93261331936639, 12.93261331936639}, {12.93261331936639, 
      14.55739700969957}}], 
     LineBox[{{12.93261331936639, 14.55739700969957}, {14.55739700969957, 
      14.55739700969957}}], 
     LineBox[{{14.55739700969957, 14.55739700969957}, {14.55739700969957, 
      12.932613319608873`}}], 
     LineBox[{{14.55739700969957, 12.932613319608873`}, {12.932613319608873`, 
      12.932613319608873`}}], 
     LineBox[{{12.932613319608873`, 12.932613319608873`}, {
      12.932613319608873`, 14.557397009642667`}}], 
     LineBox[{{12.932613319608873`, 14.557397009642667`}, {
      14.557397009642667`, 14.557397009642667`}}], 
     LineBox[{{14.557397009642667`, 14.557397009642667`}, {
      14.557397009642667`, 12.932613319733415`}}], 
     LineBox[{{14.557397009642667`, 12.932613319733415`}, {
      12.932613319733415`, 12.932613319733415`}}], 
     LineBox[{{12.932613319733415`, 12.932613319733415`}, {
      12.932613319733415`, 14.557397009613442`}}], 
     LineBox[{{12.932613319733415`, 14.557397009613442`}, {
      14.557397009613442`, 14.557397009613442`}}], 
     LineBox[{{14.557397009613442`, 14.557397009613442`}, {
      14.557397009613442`, 12.932613319797378`}}], 
     LineBox[{{14.557397009613442`, 12.932613319797378`}, {
      12.932613319797378`, 12.932613319797378`}}], 
     LineBox[{{12.932613319797378`, 12.932613319797378`}, {
      12.932613319797378`, 14.557397009598432`}}], 
     LineBox[{{12.932613319797378`, 14.557397009598432`}, {
      14.557397009598432`, 14.557397009598432`}}], 
     LineBox[{{14.557397009598432`, 14.557397009598432`}, {
      14.557397009598432`, 12.93261331983023}}], 
     LineBox[{{14.557397009598432`, 12.93261331983023}, {12.93261331983023, 
      12.93261331983023}}], 
     LineBox[{{12.93261331983023, 12.93261331983023}, {12.93261331983023, 
      14.557397009590723`}}], 
     LineBox[{{12.93261331983023, 14.557397009590723`}, {14.557397009590723`, 
      14.557397009590723`}}], 
     LineBox[{{14.557397009590723`, 14.557397009590723`}, {
      14.557397009590723`, 12.932613319847103`}}], 
     LineBox[{{14.557397009590723`, 12.932613319847103`}, {
      12.932613319847103`, 12.932613319847103`}}], 
     LineBox[{{12.932613319847103`, 12.932613319847103`}, {
      12.932613319847103`, 14.557397009586763`}}], 
     LineBox[{{12.932613319847103`, 14.557397009586763`}, {
      14.557397009586763`, 14.557397009586763`}}], 
     LineBox[{{14.557397009586763`, 14.557397009586763`}, {
      14.557397009586763`, 12.932613319855768`}}], 
     LineBox[{{14.557397009586763`, 12.932613319855768`}, {
      12.932613319855768`, 12.932613319855768`}}], 
     LineBox[{{12.932613319855768`, 12.932613319855768`}, {
      12.932613319855768`, 14.55739700958473}}], 
     LineBox[{{12.932613319855768`, 14.55739700958473}, {14.55739700958473, 
      14.55739700958473}}], 
     LineBox[{{14.55739700958473, 14.55739700958473}, {14.55739700958473, 
      12.93261331986022}}], 
     LineBox[{{14.55739700958473, 12.93261331986022}, {12.93261331986022, 
      12.93261331986022}}], 
     LineBox[{{12.93261331986022, 12.93261331986022}, {12.93261331986022, 
      14.557397009583685`}}], 
     LineBox[{{12.93261331986022, 14.557397009583685`}, {14.557397009583685`, 
      14.557397009583685`}}], 
     LineBox[{{14.557397009583685`, 14.557397009583685`}, {
      14.557397009583685`, 12.932613319862506`}}], 
     LineBox[{{14.557397009583685`, 12.932613319862506`}, {
      12.932613319862506`, 12.932613319862506`}}], 
     LineBox[{{12.932613319862506`, 12.932613319862506`}, {
      12.932613319862506`, 14.557397009583148`}}], 
     LineBox[{{12.932613319862506`, 14.557397009583148`}, {
      14.557397009583148`, 14.557397009583148`}}], 
     LineBox[{{14.557397009583148`, 14.557397009583148`}, {
      14.557397009583148`, 12.93261331986368}}], 
     LineBox[{{14.557397009583148`, 12.93261331986368}, {12.93261331986368, 
      12.93261331986368}}], 
     LineBox[{{12.93261331986368, 12.93261331986368}, {12.93261331986368, 
      14.557397009582873`}}], 
     LineBox[{{12.93261331986368, 14.557397009582873`}, {14.557397009582873`, 
      14.557397009582873`}}], 
     LineBox[{{14.557397009582873`, 14.557397009582873`}, {
      14.557397009582873`, 12.932613319864283`}}], 
     LineBox[{{14.557397009582873`, 12.932613319864283`}, {
      12.932613319864283`, 12.932613319864283`}}], 
     LineBox[{{12.932613319864283`, 12.932613319864283`}, {
      12.932613319864283`, 14.557397009582731`}}], 
     LineBox[{{12.932613319864283`, 14.557397009582731`}, {
      14.557397009582731`, 14.557397009582731`}}], 
     LineBox[{{14.557397009582731`, 14.557397009582731`}, {
      14.557397009582731`, 12.932613319864593`}}], 
     LineBox[{{14.557397009582731`, 12.932613319864593`}, {
      12.932613319864593`, 12.932613319864593`}}], 
     LineBox[{{12.932613319864593`, 12.932613319864593`}, {
      12.932613319864593`, 14.557397009582658`}}], 
     LineBox[{{12.932613319864593`, 14.557397009582658`}, {
      14.557397009582658`, 14.557397009582658`}}], 
     LineBox[{{14.557397009582658`, 14.557397009582658`}, {
      14.557397009582658`, 12.932613319864753`}}], 
     LineBox[{{14.557397009582658`, 12.932613319864753`}, {
      12.932613319864753`, 12.932613319864753`}}], 
     LineBox[{{12.932613319864753`, 12.932613319864753`}, {
      12.932613319864753`, 14.55739700958262}}], 
     LineBox[{{12.932613319864753`, 14.55739700958262}, {14.55739700958262, 
      14.55739700958262}}], 
     LineBox[{{14.55739700958262, 14.55739700958262}, {14.55739700958262, 
      12.932613319864835`}}], 
     LineBox[{{14.55739700958262, 12.932613319864835`}, {12.932613319864835`, 
      12.932613319864835`}}], 
     LineBox[{{12.932613319864835`, 12.932613319864835`}, {
      12.932613319864835`, 14.557397009582601`}}], 
     LineBox[{{12.932613319864835`, 14.557397009582601`}, {
      14.557397009582601`, 14.557397009582601`}}], 
     LineBox[{{14.557397009582601`, 14.557397009582601`}, {
      14.557397009582601`, 12.932613319864878`}}], 
     LineBox[{{14.557397009582601`, 12.932613319864878`}, {
      12.932613319864878`, 12.932613319864878`}}], 
     LineBox[{{12.932613319864878`, 12.932613319864878`}, {
      12.932613319864878`, 14.557397009582592`}}], 
     LineBox[{{12.932613319864878`, 14.557397009582592`}, {
      14.557397009582592`, 14.557397009582592`}}], 
     LineBox[{{14.557397009582592`, 14.557397009582592`}, {
      14.557397009582592`, 12.932613319864897`}}], 
     LineBox[{{14.557397009582592`, 12.932613319864897`}, {
      12.932613319864897`, 12.932613319864897`}}], 
     LineBox[{{12.932613319864897`, 12.932613319864897`}, {
      12.932613319864897`, 14.557397009582587`}}], 
     LineBox[{{12.932613319864897`, 14.557397009582587`}, {
      14.557397009582587`, 14.557397009582587`}}], 
     LineBox[{{14.557397009582587`, 14.557397009582587`}, {
      14.557397009582587`, 12.93261331986491}}], 
     LineBox[{{14.557397009582587`, 12.93261331986491}, {12.93261331986491, 
      12.93261331986491}}], 
     LineBox[{{12.93261331986491, 12.93261331986491}, {12.93261331986491, 
      14.557397009582585`}}], 
     LineBox[{{12.93261331986491, 14.557397009582585`}, {14.557397009582585`, 
      14.557397009582585`}}], 
     LineBox[{{14.557397009582585`, 14.557397009582585`}, {
      14.557397009582585`, 12.932613319864913`}}], 
     LineBox[{{14.557397009582585`, 12.932613319864913`}, {
      12.932613319864913`, 12.932613319864913`}}], 
     LineBox[{{12.932613319864913`, 12.932613319864913`}, {
      12.932613319864913`, 14.557397009582584`}}], 
     LineBox[{{12.932613319864913`, 14.557397009582584`}, {
      14.557397009582584`, 14.557397009582584`}}], 
     LineBox[{{14.557397009582584`, 14.557397009582584`}, {
      14.557397009582584`, 12.932613319864917`}}], 
     LineBox[{{14.557397009582584`, 12.932613319864917`}, {
      12.932613319864917`, 12.932613319864917`}}], 
     LineBox[{{12.932613319864917`, 12.932613319864917`}, {
      12.932613319864917`, 14.557397009582584`}}], 
     LineBox[{{12.932613319864917`, 14.557397009582584`}, {
      14.557397009582584`, 14.557397009582584`}}], 
     LineBox[{{14.557397009582584`, 14.557397009582584`}, {
      14.557397009582584`, 12.932613319864917`}}], 
     LineBox[{{14.557397009582584`, 12.932613319864917`}, {
      12.932613319864917`, 12.932613319864917`}}], 
     LineBox[{{12.932613319864917`, 12.932613319864917`}, {
      12.932613319864917`, 14.557397009582584`}}], 
     LineBox[{{12.932613319864917`, 14.557397009582584`}, {
      14.557397009582584`, 14.557397009582584`}}]}}, {{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.5], LineBox[CompressedData["
1:eJwl13k4lF8bB3BbqCRlN9axDjPMDAZj+9pKtGiXqEiLSJaopCgtKqSiVBIt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      "]]}}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  ImageSize->324.,
  PlotRange->{{5, 28}, {5, 28}},
  PlotRangeClipping->True,
  Prolog->{
    AbsoluteThickness[1], 
    LineBox[{{0, 0}, {28, 28}}]}]], "Output",
 CellChangeTimes->{{3.465179090899445*^9, 3.465179120692564*^9}, 
   3.465179303107987*^9, 3.465179362023176*^9, 3.465179421609413*^9, 
   3.465179588726493*^9, 3.4651796329957438`*^9, {3.465179820098777*^9, 
   3.465179836374489*^9}, 3.465181714487357*^9, 3.465207951883045*^9, 
   3.465208893621436*^9, 3.465209025780795*^9, 3.465209866987506*^9, 
   3.465222156982004*^9, 3.4652260203539124`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cobWebT", "[", 
  RowBox[{
   RowBox[{"2.2", "tr"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", " ", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4651790707082767`*^9, 3.465179089053629*^9}, {
  3.4651792992475357`*^9, 3.465179302412409*^9}, {3.465179576926261*^9, 
  3.4651795970507936`*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.67, 0.6, 0.6], PointSize[0.01], PointBox[CompressedData["
1:eJxTTMoPSmViYGA4AcQgGgKMHJbarMq6fFsdJ53qfOrR91hjnPSDzpjgdKA6
XLTJXbEf94HqcNG6L2aXg9ThonMYZBkeANXholn394PV4aLd/KXA6nDRkoch
6nDRegEQdbhoCag6XPSo/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+o0dAL9sngw=

      "]]}, 
    {GrayLevel[0.3], AbsoluteThickness[1], 
     LineBox[{{18, 11.92934735611045}, {11.92934735611045, 
       11.92934735611045}}], 
     LineBox[{{11.92934735611045, 11.92934735611045}, {11.92934735611045, 
      19.36706368864124}}], 
     LineBox[{{11.92934735611045, 19.36706368864124}, {19.36706368864124, 
      19.36706368864124}}], 
     LineBox[{{19.36706368864124, 19.36706368864124}, {19.36706368864124, 
      11.928522687002385`}}], 
     LineBox[{{19.36706368864124, 11.928522687002385`}, {11.928522687002385`, 
      11.928522687002385`}}], 
     LineBox[{{11.928522687002385`, 11.928522687002385`}, {
      11.928522687002385`, 19.3666987472363}}], 
     LineBox[{{11.928522687002385`, 19.3666987472363}, {19.3666987472363, 
      19.3666987472363}}], 
     LineBox[{{19.3666987472363, 19.3666987472363}, {19.3666987472363, 
      11.928523767263039`}}], 
     LineBox[{{19.3666987472363, 11.928523767263039`}, {11.928523767263039`, 
      11.928523767263039`}}], 
     LineBox[{{11.928523767263039`, 11.928523767263039`}, {
      11.928523767263039`, 19.366699225502472`}}], 
     LineBox[{{11.928523767263039`, 19.366699225502472`}, {
      19.366699225502472`, 19.366699225502472`}}], 
     LineBox[{{19.366699225502472`, 19.366699225502472`}, {
      19.366699225502472`, 11.92852376584734}}], 
     LineBox[{{19.366699225502472`, 11.92852376584734}, {11.92852376584734, 
      11.92852376584734}}], 
     LineBox[{{11.92852376584734, 11.92852376584734}, {11.92852376584734, 
      19.366699224875696`}}], 
     LineBox[{{11.92852376584734, 19.366699224875696`}, {19.366699224875696`, 
      19.366699224875696`}}], 
     LineBox[{{19.366699224875696`, 19.366699224875696`}, {
      19.366699224875696`, 11.928523765849194`}}], 
     LineBox[{{19.366699224875696`, 11.928523765849194`}, {
      11.928523765849194`, 11.928523765849194`}}], 
     LineBox[{{11.928523765849194`, 11.928523765849194`}, {
      11.928523765849194`, 19.36669922487652}}], 
     LineBox[{{11.928523765849194`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}], 
     LineBox[{{19.36669922487652, 19.36669922487652}, {19.36669922487652, 
      11.928523765849192`}}], 
     LineBox[{{19.36669922487652, 11.928523765849192`}, {11.928523765849192`, 
      11.928523765849192`}}], 
     LineBox[{{11.928523765849192`, 11.928523765849192`}, {
      11.928523765849192`, 19.36669922487652}}], 
     LineBox[{{11.928523765849192`, 19.36669922487652}, {19.36669922487652, 
      19.36669922487652}}]}}, {{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.5], LineBox[CompressedData["
1:eJwl13c8ld8fAHA7JGSTPe417r5cXOtjldmQMjJKVCLZDRVJQpSGkhlFyA5J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      "]]}}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  ImageSize->324.,
  PlotRange->{{5, 28}, {5, 28}},
  PlotRangeClipping->True,
  Prolog->{
    AbsoluteThickness[1], 
    LineBox[{{0, 0}, {28, 28}}]}]], "Output",
 CellChangeTimes->{3.465179597767544*^9, 3.465179633480236*^9, 
  3.4651817168979*^9, 3.465207951998549*^9, 3.465208893768859*^9, 
  3.465209025899453*^9, 3.465209867103826*^9, 3.465222157097624*^9, 
  3.465226020517789*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cobWebT", "[", 
  RowBox[{
   RowBox[{"4.2", "tr"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"100", ",", " ", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4651790707082767`*^9, 3.465179089053629*^9}, {
  3.4651792992475357`*^9, 3.465179302412409*^9}, {3.465179576926261*^9, 
  3.465179608691184*^9}}],

Cell[BoxData[
 GraphicsBox[{{
    {Hue[0.67, 0.6, 0.6], PointSize[0.01], PointBox[CompressedData["
1:eJxTTMoPSmViYGA4AcQgGgKMHN6sZj2v4WCMk04q6jDnxEM79kj646PffWfH
S3OzcuClGUfpUXqUHqVH6VF6lB6lR+lRepQe8jQAmNrReg==
      "]]}, 
    {GrayLevel[0.3], AbsoluteThickness[1], 
     LineBox[{{18, 19.250622691044484`}, {19.250622691044484`, 
       19.250622691044484`}}], 
     LineBox[{{19.250622691044484`, 19.250622691044484`}, {
      19.250622691044484`, 19.250140639126023`}}], 
     LineBox[{{19.250622691044484`, 19.250140639126023`}, {
      19.250140639126023`, 19.250140639126023`}}], 
     LineBox[{{19.250140639126023`, 19.250140639126023`}, {
      19.250140639126023`, 19.250142043816826`}}], 
     LineBox[{{19.250140639126023`, 19.250142043816826`}, {
      19.250142043816826`, 19.250142043816826`}}], 
     LineBox[{{19.250142043816826`, 19.250142043816826`}, {
      19.250142043816826`, 19.250142039723805`}}], 
     LineBox[{{19.250142043816826`, 19.250142039723805`}, {
      19.250142039723805`, 19.250142039723805`}}], 
     LineBox[{{19.250142039723805`, 19.250142039723805`}, {
      19.250142039723805`, 19.25014203973573}}], 
     LineBox[{{19.250142039723805`, 19.25014203973573}, {19.25014203973573, 
      19.25014203973573}}], 
     LineBox[{{19.25014203973573, 19.25014203973573}, {19.25014203973573, 
      19.250142039735696`}}], 
     LineBox[{{19.25014203973573, 19.250142039735696`}, {19.250142039735696`, 
      19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}], 
     LineBox[{{19.250142039735696`, 19.250142039735696`}, {
      19.250142039735696`, 19.250142039735696`}}]}}, {{}, {}, 
    {GrayLevel[0], AbsoluteThickness[1.5], LineBox[CompressedData["
1:eJwl2Xk4VN8bAHBbWZIksi/JNpZhZsw1c22vra+tSFJkiVSKrFGhkpJdFBIh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      "]]}}},
  AspectRatio->Automatic,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  ImageSize->324.,
  PlotRange->{{5, 28}, {5, 28}},
  PlotRangeClipping->True,
  Prolog->{
    AbsoluteThickness[1], 
    LineBox[{{0, 0}, {28, 28}}]}]], "Output",
 CellChangeTimes->{{3.465179609340275*^9, 3.465179633614915*^9}, 
   3.465181721559291*^9, 3.465207952114505*^9, 3.465208893875064*^9, 
   3.465209026015663*^9, 3.46520986721983*^9, 3.465222157263624*^9, 
   3.465226020637044*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["System evolves quickly to the home trajectory (red)", "Section",
 CellChangeTimes->{{3.4642127835108747`*^9, 3.4642127838929043`*^9}, {
  3.46520840091064*^9, 3.465208407996934*^9}, {3.4652160567716703`*^9, 
  3.4652160718053617`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Show", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Block", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"res", "=", 
           RowBox[{"G3", "[", 
            RowBox[{"i", ",", "0", ",", "t"}], "]"}]}], "}"}], ",", 
         RowBox[{"ParametricPlot", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"res", "[", 
             RowBox[{"[", "2", "]"}], "]"}], "//", "Evaluate"}], ",", " ", 
           RowBox[{"{", 
            RowBox[{"t", ",", " ", "0", ",", " ", 
             RowBox[{"res", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}], ",", 
           RowBox[{"Frame", "\[Rule]", "True"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2.2"}], ",", "3"}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"-", "2"}], ",", "1.25"}], "}"}]}], "}"}]}]}], 
          "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "m"}], "}"}]}], "]"}], ",", " ", "homePic", ",", 
     " ", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"72", "*", "6"}]}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
       "\"\<x (voltage)\>\"", ",", " ", "\"\<y (refractoriness)\>\""}], 
       "}"}]}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", 
       RowBox[{"{", "startPt", "}"}]}], "}"}], ",", "Locator", ",", 
     RowBox[{"LocatorAutoCreate", "\[Rule]", "True"}]}], "}"}]}], 
  RowBox[{"(*", 
   RowBox[{",", " ", 
    RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "*)"}], "]"}]], "Input",\

 CellChangeTimes->{{3.4642137534192333`*^9, 3.464213765565276*^9}, {
   3.464213820282483*^9, 3.4642138351699247`*^9}, 3.464214924099896*^9, {
   3.464216193778637*^9, 3.464216208571125*^9}, 3.464350826624704*^9, {
   3.464350993374744*^9, 3.464350994242797*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`m$$ = {{-0.16400000000000015`, \
-0.20500000000000007`}}, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`m$$], {{-1.199408035244027, -0.6242600440550339}}}, 
      Automatic}}, Typeset`size$$ = {540., {168., 175.}}, Typeset`update$$ = 
    0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`m$$ = {{-1.199408035244027, \
-0.6242600440550339}}}, "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Table[
         Block[{$CellContext`res = $CellContext`G3[$CellContext`i, 
             0, $CellContext`t]}, 
          ParametricPlot[
           Evaluate[
            Part[$CellContext`res, 2]], {$CellContext`t, 0, 
            Part[$CellContext`res, 3]}, Frame -> True, 
           PlotRange -> {{-2.2, 3}, {-2, 
              1.25}}]], {$CellContext`i, $CellContext`m$$}], \
$CellContext`homePic, ImageSize -> 72 6, 
        FrameLabel -> {"x (voltage)", "y (refractoriness)"}], 
      "Specifications" :> {{{$CellContext`m$$, {{-1.199408035244027, \
-0.6242600440550339}}}, Automatic, ControlType -> Locator, LocatorAutoCreate -> 
         True}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{601., {206.21875, 212.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.4642162103578653`*^9, 3.464348379896915*^9, 3.464350780144*^9, 
   3.464350827886857*^9, {3.4643509760284*^9, 3.464350996009083*^9}, 
   3.464431557902264*^9, 3.464432267326606*^9, 3.465209872395204*^9, {
   3.465226020863626*^9, 3.465226024416197*^9}}]
}, {2}]],

Cell["\<\
NB: Location on the home-trajectory labelled zero is different than in \
previous slides.\
\>", "Text",
 CellChangeTimes->{{3.4652205344615097`*^9, 3.46522063918154*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["A pulse \"resets\" the time along the home trajectory", "Section",
 CellChangeTimes->{{3.465208418877406*^9, 3.46520842393272*^9}, {
  3.4652160845244427`*^9, 3.465216108236445*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "cachedRes", ",", "ttupperbound", ",", "t", ",", "xExt", ",", "res", ",", 
     "yExt"}], "}"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"cachedRes", "[", "tau_", "]"}], ":=", 
     RowBox[{
      RowBox[{"cachedRes", "[", "tau", "]"}], "=", 
      RowBox[{"G3", "[", 
       RowBox[{
        RowBox[{"home", "[", "tau", "]"}], ",", "Aref", ",", "t"}], "]"}]}]}],
     ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ttupperbound", "[", "tau_", "]"}], ":=", 
     RowBox[{"Part", "[", 
      RowBox[{
       RowBox[{"cachedRes", "[", "tau", "]"}], ",", "3"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Manipulate", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"res", "=", 
        RowBox[{"cachedRes", "[", "tau", "]"}]}], ";", 
       RowBox[{"xExt", "=", 
        RowBox[{"Head", "[", 
         RowBox[{"res", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "1"}], "]"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"yExt", "=", 
        RowBox[{"Head", "[", 
         RowBox[{"res", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "2"}], "]"}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Show", "[", 
        RowBox[{"homePic", ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
              RowBox[{"Point", "[", 
               RowBox[{"home", "[", "tau", "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"Line", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"home", "[", "tau", "]"}], ",", 
                RowBox[{
                 RowBox[{"home", "[", "tau", "]"}], "+", 
                 RowBox[{"{", 
                  RowBox[{"Aref", ",", "0"}], "}"}]}]}], "}"}], "]"}], 
             "}"}]}], "}"}], "]"}], ",", 
         RowBox[{"ParametricPlot", "[", 
          RowBox[{
           RowBox[{"res", "[", 
            RowBox[{"[", "2", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", 
             RowBox[{"res", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Blue", ",", 
             RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"xExt", "[", 
                 RowBox[{"res", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], "]"}], ",", 
                RowBox[{"yExt", "[", 
                 RowBox[{"res", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], "]"}]}], "}"}], "]"}]}], 
            "}"}], "}"}], "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"{", 
            RowBox[{"Green", ",", 
             RowBox[{"PointSize", "[", "0.04", "]"}], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"home", "[", 
               RowBox[{"res", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "]"}], "]"}]}], "}"}], "}"}], 
          "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"xExt", "[", "tt", "]"}], ",", 
               RowBox[{"yExt", "[", "tt", "]"}]}], "}"}], "]"}]}], "}"}], 
          "]"}], ",", 
         RowBox[{"Graphics", "[", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", 
            RowBox[{"PointSize", "[", "0.03", "]"}], ",", 
            RowBox[{"Point", "[", 
             RowBox[{"home", "[", 
              RowBox[{
               RowBox[{"res", "[", 
                RowBox[{"[", "1", "]"}], "]"}], "+", "tt"}], "]"}], "]"}]}], 
           "}"}], "]"}], ",", " ", 
         RowBox[{"ImageSize", "\[Rule]", 
          RowBox[{"72", "*", "6"}]}], ",", " ", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
           "\"\<x (voltage)\>\"", ",", " ", "\"\<y (refractoriness)\>\""}], 
           "}"}]}]}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tau", ",", " ", "4.5", ",", " ", "\"\<\[Tau]\>\""}], "}"}], 
        ",", "4.5", ",", "25"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"tt", ",", " ", "0", ",", " ", "\"\<t\>\""}], "}"}], ",", 
        "0", ",", 
        RowBox[{"ttupperbound", "[", "tau", "]"}]}], "}"}], ",", 
      RowBox[{"SaveDefinitions", "\[Rule]", "True"}]}], "]"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.464344080787057*^9, 3.464344081594183*^9}, {
   3.4643442512255087`*^9, 3.464344296810206*^9}, {3.464344410292551*^9, 
   3.464344411431004*^9}, {3.46434445140036*^9, 3.46434445584347*^9}, {
   3.4643451877990303`*^9, 3.4643452135118923`*^9}, {3.464347086451758*^9, 
   3.4643470915506983`*^9}, 3.464347128010665*^9, 3.464347271129931*^9, {
   3.464347388248118*^9, 3.4643474189819736`*^9}, {3.46434745311194*^9, 
   3.4643475072506247`*^9}, {3.4643480170593147`*^9, 3.464348017354583*^9}, {
   3.464352267822423*^9, 3.464352268985776*^9}}],

Cell[BoxData[
 DynamicModuleBox[{$CellContext`cachedRes$$, $CellContext`ttupperbound$$, \
$CellContext`t$$, $CellContext`xExt$$ = 
  InterpolatingFunction[{{0., 2.6565921395846743`}}, {
   3, 11, 1, {87}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAss1HEAB/A75xVtR96b1zUrKwqHRPr+phTlUtcMqXl1U6lDD7SW7Lgr
adymWo9lHgmtlaKm2NTiTA9Ml7c8/keP8zzuhDuXla3v9t1n3y8rLonL06HR
aPSVhtP+p3RLaH3aYS/8M3DVMMw1pd5ja6JXNw9tQU2NhpUCKP/++chjmfs8
q7gNx6HxkkbuA8SY5aYJHatQO3lEEjleC0PeLSOr/reo4Wrc6QFNiCG8SHl5
C9wFrJanme3wOC4eTXCVwnOPls7q7YKXM9++V9QHb6MB3wL2IGxVZZs3JA/D
NmHgtWAPhZsH3I9y91Iw9hYus4IoCOx6imZWXNR13fUumELKeOaoeB+FmDrn
TW4hFA5cb+e3cSj4R6ZX80Mp5PP148qjKQxn3TQZSqLAvru+wTqTgvBp1ZlD
YgpvsvxxzUOGqYgPJg1SGZy2hI8oU0cRyZBVu9iMIa87WRhfNwZ5sPwSp+M7
gup4Z7f9/IEyl6ETLNov6BQeiTa2kiOa+TVM6TqO+szQkMHdE/AUBjZdfDGJ
zkY7ByOTaaxrvhPVJZlGaIvZnYeXZ5D7MU+a4qlA8+c1ppArwGjP5qwtmQXp
0Ob0RMwhT6p5UjY1h/7OpbYUkRKbehYU/nYqpPfNWxjVqCAZUPp07puHxdBs
VMnwPOJHZjL46b/xXDZV7MtcgHZsolH/0QI4P+XfO3Yswi8oRHF+dhHO5U/U
lo+XcEnVbGLmp0ZrIOXE/KSG461lH+NjGpyT2XAMJjWQsL1iGVeWYZN18IKW
qUViR2LOUpEWg+L3rUvWNHLa+curtlQaWWwYKSyV0sjVcIUozYNOzKfoSfvF
dFIiMg13mKSTrfYszO7XIfUv3TY2V+qQYA5h3jdgEEPLsG6zJAaRfDtZfKOT
QbLLM07p7dQlAckF7IwyXULfXqFWrdUjMQ88YquJHvkDJopQIQ==
   "], {
   Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 
    26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 60, 
    62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 86, 88, 90, 92, 94, 96, 
    98, 100, 102, 104, 106, 108, 110, 112, 114, 116, 118, 120, 122, 124, 126, 
    128, 130, 132, 134, 136, 138, 140, 142, 144, 146, 148, 150, 152, 154, 156,
     158, 160, 162, 164, 166, 168, 170, 172, 174}, CompressedData["
1:eJwNznk4lAkABnAhV1IbhVlRjh5Hy4RK6fFtjRStK0JKNiltq5oubdkipEa1
lZIzkdBIjjUhyiuNWTqQM5TyfeNojGMc30PCzh/vH7/n/eN9VwYc33lwnoyM
TJ40wQVxhQb3KPBvVb+y9xIQGY9ssnPjKKxYuMGlx0NA8OWjuGulLjZpjbrs
LiCKUo79t+0uhYDeBQHVvwmIh6pKWr53KEz2R/bJbRcQ4dx9ycGxFNRSbmls
ZgkINVdOPpNDwZh5381XXUDc8jdvVgqnkP/vip0isprghJZvmQihENXk8nCo
sJoYM+hZSx+lsP5cZWVgeDXhZtxLNhMU8iLzFO1O8Ak/9tRVhgaFOD3donq3
18Tn0tqRIRGJuLv+s6HLq4h8Tn7UBT6JXKef7GNaKglnW07iRBqJsBMXPXcM
VRCWEe5ej4JJiHwODewSPyda41tCl2whYaJlVh7uwiMMPbObT+iTUAkcnp43
94RwSTXM1FlE4i0z68VAejIxUKx8NEGZRN7G4nt1IjbQvrUwXp0Ep0e4OGQm
A2xhy6Hv5iQkvrJZa2R4uHjmTIaKBYm9y66ofpLnQcuui2JIfafmntIVZR70
jy42NpM6yfysnaUaDxFrVNm2UkcamuZ9XsLDyrIP5TukvhJd6M3R5EFYMOIb
LLXPgbPLu1fw4GNuo3xD6qodiW82mPLQzuUKnkqtX2Tsf8eKB/HT3exJJolu
8wyJ/W0eCrkCVUdLEgd1mk3dh3nIFOSkP7Aisfh2N6vU+Rk0JbXWP6xJ1CSM
nzmf+wzRn0xv97Okf+VUhI2nnkOtLj5o6y4SxozJS0/8X8LAR1Xb9A8S9FQI
K7C0Eg6ZTqF5YSS4SSyuuKkKvS6db0UJJBw/Lt1eJluNuDVvzSRvSChExOr9
KqmBPWvEtWY+BfpxwDxDxnt0iiwjhx0pXB1k7y+saMAH/uDPPfEU9rbvPq+4
sAkF9/1tDUco6BYle6qdbYHgWtlKfQ8hthpujtCYbgPfwlL8uUeItlSGQ8CR
TiyQOZ2eeL0HIZYa7NmpLtgoK4YNb+vFrGyM237XbgQlFaxjavUh7fmnFzJG
FF4FpEicZ/qw/8/YkkfjQvCZDrkCuh/8r5CxLuqFU1pa5k05ETadjLwj9OiH
e8zNtfL6A1ghmDLIrvmGZ18aDOczxJjeV6fHaxDBwah5mmQMwvnR9ET94wF4
HWHLFOsPQac9MybSUYy2jX4jnhbD6LtrHs/OFUPzQWQtU28EPb/sqXr3TgyT
WNu23KwRrCrSPlCXLYbE+0BFy2oJWhUut/3YJEZdzJDFoQIJqr2YS33+kf4o
VtcwZo6ikRkX5pomwuFuhWtzOaOI/avDL/rcN1zgXL/WsH4Mq0XyPrzmPnTs
l01OLRsDS2Wzd9D3HsR0JCdyGeOwS4tvUTosRIk1hzp9ahzeLCXlkhoSZlcX
+rfzx5HU0DgzbdgNn6bAN81qE2j39p83qfQFdQdL5S67T+BuvMPHC52duDLw
WqB/YwJvA5zGTN59BDf/mcaPVxOoMgmGEdUC+RT78mMjE5DTDm/csqoJqS8r
TUsMaKQ108ad/Hpcm+ye6XWmUWljyXIU1kLC1j0+dpxGvWxQlkIOHwllO7Xf
xdAQqWnEchZVoktxdM7jAQ0FXYWltEYp5kxmrPzyaGw3Oq6eplOIsa9tMVml
NFJHzXgL1mWh1Naoq6OChtULajyvKR6k0dGrT17R2PRedVIx6CT0WouPDFbS
YGyU89UcjCai3Mrn1r+k0Wrau0evKYFY/rDcVbWERsolC/9lo+nE78oFRW3S
vdmdq/62jsgi/L6IL2rmSPuMrkHOucfE/zaDD+k=
    "]}, {
   Automatic}], $CellContext`res$$ = {10.111784355330117`, {
    InterpolatingFunction[{{0., 2.6565921395846743`}}, {
     3, 11, 1, {87}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAss1HEAB/A75xVtR96b1zUrKwqHRPr+phTlUtcMqXl1U6lDD7SW7Lgr
adymWo9lHgmtlaKm2NTiTA9Ml7c8/keP8zzuhDuXla3v9t1n3y8rLonL06HR
aPSVhtP+p3RLaH3aYS/8M3DVMMw1pd5ja6JXNw9tQU2NhpUCKP/++chjmfs8
q7gNx6HxkkbuA8SY5aYJHatQO3lEEjleC0PeLSOr/reo4Wrc6QFNiCG8SHl5
C9wFrJanme3wOC4eTXCVwnOPls7q7YKXM9++V9QHb6MB3wL2IGxVZZs3JA/D
NmHgtWAPhZsH3I9y91Iw9hYus4IoCOx6imZWXNR13fUumELKeOaoeB+FmDrn
TW4hFA5cb+e3cSj4R6ZX80Mp5PP148qjKQxn3TQZSqLAvru+wTqTgvBp1ZlD
YgpvsvxxzUOGqYgPJg1SGZy2hI8oU0cRyZBVu9iMIa87WRhfNwZ5sPwSp+M7
gup4Z7f9/IEyl6ETLNov6BQeiTa2kiOa+TVM6TqO+szQkMHdE/AUBjZdfDGJ
zkY7ByOTaaxrvhPVJZlGaIvZnYeXZ5D7MU+a4qlA8+c1ppArwGjP5qwtmQXp
0Ob0RMwhT6p5UjY1h/7OpbYUkRKbehYU/nYqpPfNWxjVqCAZUPp07puHxdBs
VMnwPOJHZjL46b/xXDZV7MtcgHZsolH/0QI4P+XfO3Yswi8oRHF+dhHO5U/U
lo+XcEnVbGLmp0ZrIOXE/KSG461lH+NjGpyT2XAMJjWQsL1iGVeWYZN18IKW
qUViR2LOUpEWg+L3rUvWNHLa+curtlQaWWwYKSyV0sjVcIUozYNOzKfoSfvF
dFIiMg13mKSTrfYszO7XIfUv3TY2V+qQYA5h3jdgEEPLsG6zJAaRfDtZfKOT
QbLLM07p7dQlAckF7IwyXULfXqFWrdUjMQ88YquJHvkDJopQIQ==
     "], {
     Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 
      24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 
      60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 86, 88, 90, 92, 94, 
      96, 98, 100, 102, 104, 106, 108, 110, 112, 114, 116, 118, 120, 122, 124,
       126, 128, 130, 132, 134, 136, 138, 140, 142, 144, 146, 148, 150, 152, 
      154, 156, 158, 160, 162, 164, 166, 168, 170, 172, 174}, CompressedData["

1:eJwNznk4lAkABnAhV1IbhVlRjh5Hy4RK6fFtjRStK0JKNiltq5oubdkipEa1
lZIzkdBIjjUhyiuNWTqQM5TyfeNojGMc30PCzh/vH7/n/eN9VwYc33lwnoyM
TJ40wQVxhQb3KPBvVb+y9xIQGY9ssnPjKKxYuMGlx0NA8OWjuGulLjZpjbrs
LiCKUo79t+0uhYDeBQHVvwmIh6pKWr53KEz2R/bJbRcQ4dx9ycGxFNRSbmls
ZgkINVdOPpNDwZh5381XXUDc8jdvVgqnkP/vip0isprghJZvmQihENXk8nCo
sJoYM+hZSx+lsP5cZWVgeDXhZtxLNhMU8iLzFO1O8Ak/9tRVhgaFOD3donq3
18Tn0tqRIRGJuLv+s6HLq4h8Tn7UBT6JXKef7GNaKglnW07iRBqJsBMXPXcM
VRCWEe5ej4JJiHwODewSPyda41tCl2whYaJlVh7uwiMMPbObT+iTUAkcnp43
94RwSTXM1FlE4i0z68VAejIxUKx8NEGZRN7G4nt1IjbQvrUwXp0Ep0e4OGQm
A2xhy6Hv5iQkvrJZa2R4uHjmTIaKBYm9y66ofpLnQcuui2JIfafmntIVZR70
jy42NpM6yfysnaUaDxFrVNm2UkcamuZ9XsLDyrIP5TukvhJd6M3R5EFYMOIb
LLXPgbPLu1fw4GNuo3xD6qodiW82mPLQzuUKnkqtX2Tsf8eKB/HT3exJJolu
8wyJ/W0eCrkCVUdLEgd1mk3dh3nIFOSkP7Aisfh2N6vU+Rk0JbXWP6xJ1CSM
nzmf+wzRn0xv97Okf+VUhI2nnkOtLj5o6y4SxozJS0/8X8LAR1Xb9A8S9FQI
K7C0Eg6ZTqF5YSS4SSyuuKkKvS6db0UJJBw/Lt1eJluNuDVvzSRvSChExOr9
KqmBPWvEtWY+BfpxwDxDxnt0iiwjhx0pXB1k7y+saMAH/uDPPfEU9rbvPq+4
sAkF9/1tDUco6BYle6qdbYHgWtlKfQ8hthpujtCYbgPfwlL8uUeItlSGQ8CR
TiyQOZ2eeL0HIZYa7NmpLtgoK4YNb+vFrGyM237XbgQlFaxjavUh7fmnFzJG
FF4FpEicZ/qw/8/YkkfjQvCZDrkCuh/8r5CxLuqFU1pa5k05ETadjLwj9OiH
e8zNtfL6A1ghmDLIrvmGZ18aDOczxJjeV6fHaxDBwah5mmQMwvnR9ET94wF4
HWHLFOsPQac9MybSUYy2jX4jnhbD6LtrHs/OFUPzQWQtU28EPb/sqXr3TgyT
WNu23KwRrCrSPlCXLYbE+0BFy2oJWhUut/3YJEZdzJDFoQIJqr2YS33+kf4o
VtcwZo6ikRkX5pomwuFuhWtzOaOI/avDL/rcN1zgXL/WsH4Mq0XyPrzmPnTs
l01OLRsDS2Wzd9D3HsR0JCdyGeOwS4tvUTosRIk1hzp9ahzeLCXlkhoSZlcX
+rfzx5HU0DgzbdgNn6bAN81qE2j39p83qfQFdQdL5S67T+BuvMPHC52duDLw
WqB/YwJvA5zGTN59BDf/mcaPVxOoMgmGEdUC+RT78mMjE5DTDm/csqoJqS8r
TUsMaKQ108ad/Hpcm+ye6XWmUWljyXIU1kLC1j0+dpxGvWxQlkIOHwllO7Xf
xdAQqWnEchZVoktxdM7jAQ0FXYWltEYp5kxmrPzyaGw3Oq6eplOIsa9tMVml
NFJHzXgL1mWh1Naoq6OChtULajyvKR6k0dGrT17R2PRedVIx6CT0WouPDFbS
YGyU89UcjCai3Mrn1r+k0Wrau0evKYFY/rDcVbWERsolC/9lo+nE78oFRW3S
vdmdq/62jsgi/L6IL2rmSPuMrkHOucfE/zaDD+k=
      "]}, {
     Automatic}][$CellContext`t$$], 
    InterpolatingFunction[{{0., 2.6565921395846743`}}, {
     3, 11, 1, {87}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAss1HEAB/A75xVtR96b1zUrKwqHRPr+phTlUtcMqXl1U6lDD7SW7Lgr
adymWo9lHgmtlaKm2NTiTA9Ml7c8/keP8zzuhDuXla3v9t1n3y8rLonL06HR
aPSVhtP+p3RLaH3aYS/8M3DVMMw1pd5ja6JXNw9tQU2NhpUCKP/++chjmfs8
q7gNx6HxkkbuA8SY5aYJHatQO3lEEjleC0PeLSOr/reo4Wrc6QFNiCG8SHl5
C9wFrJanme3wOC4eTXCVwnOPls7q7YKXM9++V9QHb6MB3wL2IGxVZZs3JA/D
NmHgtWAPhZsH3I9y91Iw9hYus4IoCOx6imZWXNR13fUumELKeOaoeB+FmDrn
TW4hFA5cb+e3cSj4R6ZX80Mp5PP148qjKQxn3TQZSqLAvru+wTqTgvBp1ZlD
YgpvsvxxzUOGqYgPJg1SGZy2hI8oU0cRyZBVu9iMIa87WRhfNwZ5sPwSp+M7
gup4Z7f9/IEyl6ETLNov6BQeiTa2kiOa+TVM6TqO+szQkMHdE/AUBjZdfDGJ
zkY7ByOTaaxrvhPVJZlGaIvZnYeXZ5D7MU+a4qlA8+c1ppArwGjP5qwtmQXp
0Ob0RMwhT6p5UjY1h/7OpbYUkRKbehYU/nYqpPfNWxjVqCAZUPp07puHxdBs
VMnwPOJHZjL46b/xXDZV7MtcgHZsolH/0QI4P+XfO3Yswi8oRHF+dhHO5U/U
lo+XcEnVbGLmp0ZrIOXE/KSG461lH+NjGpyT2XAMJjWQsL1iGVeWYZN18IKW
qUViR2LOUpEWg+L3rUvWNHLa+curtlQaWWwYKSyV0sjVcIUozYNOzKfoSfvF
dFIiMg13mKSTrfYszO7XIfUv3TY2V+qQYA5h3jdgEEPLsG6zJAaRfDtZfKOT
QbLLM07p7dQlAckF7IwyXULfXqFWrdUjMQ88YquJHvkDJopQIQ==
     "], {
     Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 
      24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 
      60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 86, 88, 90, 92, 94, 
      96, 98, 100, 102, 104, 106, 108, 110, 112, 114, 116, 118, 120, 122, 124,
       126, 128, 130, 132, 134, 136, 138, 140, 142, 144, 146, 148, 150, 152, 
      154, 156, 158, 160, 162, 164, 166, 168, 170, 172, 174}, CompressedData["

1:eJwN0ntUjHkYB/BuCmUlusnSiEjDtGkQ6ldjTU1FsS2n0YXa0iaSLuMoRs1q
s+k2JLHpZhptuqtpunh0mVcXRbrwTtNbTYYoVOiiDvv+8fzxOed5nnOe53wp
viGH/ZWVlJSKycI0f3sseimHmresEJoAQ3+KulUR6XKPNulh0hHD6UysTw6M
1dt2RJK2IIRtPb1y+Pao9mkd6S5ei/NIjxwWXveuV83H0NeYhdbJbrL/U9Au
FunL4WcNY9vk4FX11nT2PoYORBm5rWiQQyGnKCuxEEPsixnns0RyyDzjG7Ck
GEN2uwszqcVyEDKsbE6VYqhK+y/jPdFysL4UijNrMaTIpiymO8lB3T3kE6UJ
Q7yyb2soBnJQmi8ye/EEQ8pPafHqb4ZBAHwjs1YMUaxUifGKYcA6r05+xjDU
NDr8zuX4MLzgWdCgBkN598f7PmoNg9+G5+0juRhyuxXR8UM8BE/fmH3XvYQh
qjJ3UfnJIfA95e044ISh0lHNSBu9IbhrwE5L1cAQqjNZ1pAwCFrTX3s9yiWo
C2avNHwgYOWrEm0qS4LQ4hlONOkMx6SxWUcJuuh3J2gnaceERbUS0qmDCq+p
cQJWe2+J45OO+afvUBFp+6QFFx/S7udOMwNJfxyNWk4l/ezlWwtijIB+dk+C
xEGCdHPmf3YnPaM7NO1NOti2YFnbewJeuWa6zTIlSO+kbM5fQYDdXIfBFEOC
bvdpjqsMEZDnztFX2EqQ28hHRbaUAFTuz+zaLUH3D9q9Q70EUPjsrKod5Pxa
S35pFgHHtiRXb9OSoJsMRVxKEAFFfZvJNc3oTDRt8g2dgB9D5/aWFTej6Nca
e2qVyftEp6rio5rRuyZjbd3OAfgwYeftsr8Zld+gzqRFDoD9Dh+VxKEmJI97
6TNiPACVdaYnBkObkOcEt9qsQwa7Ihc4dbONKCnioCg9Sgbbw34PzwpvROta
Wpy9qTKgzwkjFisaELrHjC0d7IcXovhqLqsB+edzmSe4/TC/Ko/VF/QYnb+d
lua4oR8ezN19cmj8EVJ7tqhd0SmFfKZl2fveOmTB87eq4Uoh1507vYlfg5o0
zkiYO6Wwz7nlRjalGslGI22WTONg7muKq8ZVorVzE43n63AYe0y97NhYjnqK
f1VRScAhOOCafn5lCZIbHmOlBOJwwXxqIrH+P9Rpvom+zAUHuaPwnppAgIyv
OsVk0HEYSec4p0RkoymDuwusjTiwBPTWhrCbSOeZ1wFTIxz6BQVH903/jY7I
BFqb9XGQhnm46Nz2QLScdtfdhjjEJ7CXztJiQEDJKram4KDu780LjuGDq5pJ
55dtOHx9bpTcqPkvWOZcCt7KwCEgtMBnXWou2OsEnv3jOA6nlURjD0VCKLeW
sIRXcJAcNyzoDXkAGvXKFd1CHNr1jLbypCWQYeJvWtGBw8UKRuhwVBkcyHZ3
+0D+Iznc3NlzpBxOnPQrMzORQsoshzlj8hAcNnevWXFYCpxkRtR120rw86r8
dpAnheSVHDbfqgp0Pkc58aukMO8smBZriOC7MDUwaUwKrdExwYY1Ilja7Nm0
17If9Lmf82bDqqF1SfrRJxf6gYFn57b9qCZzvz+/uLkf6G4PXEp8xUDdGK4W
u1wGP9Wv52bmiCF4u9Ungi0DB59OuX2DGFhZrivO5suAzfK48F4iBjvj2DXj
kzKwHrdNia4Qw9YvIamrbAZg1LPF7FyiGFKt2hKPJJP5pJ/OCHYTw0IW7bpo
iLRZQCGuIgbaSjeaxi8E3OowNmkRVgOzKl977WUCdByOqXfZV8Oda7wcWQcB
hknmrqbdIlBk69VbfiFAl6PH25Ahgv8BpFP8CA==
      "]}, {
     Automatic}][$CellContext`t$$]}, 2.6565921395846743`, 
   12.768376494914792`}, $CellContext`yExt$$ = 
  InterpolatingFunction[{{0., 2.6565921395846743`}}, {
   3, 11, 1, {87}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAss1HEAB/A75xVtR96b1zUrKwqHRPr+phTlUtcMqXl1U6lDD7SW7Lgr
adymWo9lHgmtlaKm2NTiTA9Ml7c8/keP8zzuhDuXla3v9t1n3y8rLonL06HR
aPSVhtP+p3RLaH3aYS/8M3DVMMw1pd5ja6JXNw9tQU2NhpUCKP/++chjmfs8
q7gNx6HxkkbuA8SY5aYJHatQO3lEEjleC0PeLSOr/reo4Wrc6QFNiCG8SHl5
C9wFrJanme3wOC4eTXCVwnOPls7q7YKXM9++V9QHb6MB3wL2IGxVZZs3JA/D
NmHgtWAPhZsH3I9y91Iw9hYus4IoCOx6imZWXNR13fUumELKeOaoeB+FmDrn
TW4hFA5cb+e3cSj4R6ZX80Mp5PP148qjKQxn3TQZSqLAvru+wTqTgvBp1ZlD
YgpvsvxxzUOGqYgPJg1SGZy2hI8oU0cRyZBVu9iMIa87WRhfNwZ5sPwSp+M7
gup4Z7f9/IEyl6ETLNov6BQeiTa2kiOa+TVM6TqO+szQkMHdE/AUBjZdfDGJ
zkY7ByOTaaxrvhPVJZlGaIvZnYeXZ5D7MU+a4qlA8+c1ppArwGjP5qwtmQXp
0Ob0RMwhT6p5UjY1h/7OpbYUkRKbehYU/nYqpPfNWxjVqCAZUPp07puHxdBs
VMnwPOJHZjL46b/xXDZV7MtcgHZsolH/0QI4P+XfO3Yswi8oRHF+dhHO5U/U
lo+XcEnVbGLmp0ZrIOXE/KSG461lH+NjGpyT2XAMJjWQsL1iGVeWYZN18IKW
qUViR2LOUpEWg+L3rUvWNHLa+curtlQaWWwYKSyV0sjVcIUozYNOzKfoSfvF
dFIiMg13mKSTrfYszO7XIfUv3TY2V+qQYA5h3jdgEEPLsG6zJAaRfDtZfKOT
QbLLM07p7dQlAckF7IwyXULfXqFWrdUjMQ88YquJHvkDJopQIQ==
   "], {
   Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 22, 24, 
    26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 54, 56, 58, 60, 
    62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 86, 88, 90, 92, 94, 96, 
    98, 100, 102, 104, 106, 108, 110, 112, 114, 116, 118, 120, 122, 124, 126, 
    128, 130, 132, 134, 136, 138, 140, 142, 144, 146, 148, 150, 152, 154, 156,
     158, 160, 162, 164, 166, 168, 170, 172, 174}, CompressedData["
1:eJwN0ntUjHkYB/BuCmUlusnSiEjDtGkQ6ldjTU1FsS2n0YXa0iaSLuMoRs1q
s+k2JLHpZhptuqtpunh0mVcXRbrwTtNbTYYoVOiiDvv+8fzxOed5nnOe53wp
viGH/ZWVlJSKycI0f3sseimHmresEJoAQ3+KulUR6XKPNulh0hHD6UysTw6M
1dt2RJK2IIRtPb1y+Pao9mkd6S5ei/NIjxwWXveuV83H0NeYhdbJbrL/U9Au
FunL4WcNY9vk4FX11nT2PoYORBm5rWiQQyGnKCuxEEPsixnns0RyyDzjG7Ck
GEN2uwszqcVyEDKsbE6VYqhK+y/jPdFysL4UijNrMaTIpiymO8lB3T3kE6UJ
Q7yyb2soBnJQmi8ye/EEQ8pPafHqb4ZBAHwjs1YMUaxUifGKYcA6r05+xjDU
NDr8zuX4MLzgWdCgBkN598f7PmoNg9+G5+0juRhyuxXR8UM8BE/fmH3XvYQh
qjJ3UfnJIfA95e044ISh0lHNSBu9IbhrwE5L1cAQqjNZ1pAwCFrTX3s9yiWo
C2avNHwgYOWrEm0qS4LQ4hlONOkMx6SxWUcJuuh3J2gnaceERbUS0qmDCq+p
cQJWe2+J45OO+afvUBFp+6QFFx/S7udOMwNJfxyNWk4l/ezlWwtijIB+dk+C
xEGCdHPmf3YnPaM7NO1NOti2YFnbewJeuWa6zTIlSO+kbM5fQYDdXIfBFEOC
bvdpjqsMEZDnztFX2EqQ28hHRbaUAFTuz+zaLUH3D9q9Q70EUPjsrKod5Pxa
S35pFgHHtiRXb9OSoJsMRVxKEAFFfZvJNc3oTDRt8g2dgB9D5/aWFTej6Nca
e2qVyftEp6rio5rRuyZjbd3OAfgwYeftsr8Zld+gzqRFDoD9Dh+VxKEmJI97
6TNiPACVdaYnBkObkOcEt9qsQwa7Ihc4dbONKCnioCg9Sgbbw34PzwpvROta
Wpy9qTKgzwkjFisaELrHjC0d7IcXovhqLqsB+edzmSe4/TC/Ko/VF/QYnb+d
lua4oR8ezN19cmj8EVJ7tqhd0SmFfKZl2fveOmTB87eq4Uoh1507vYlfg5o0
zkiYO6Wwz7nlRjalGslGI22WTONg7muKq8ZVorVzE43n63AYe0y97NhYjnqK
f1VRScAhOOCafn5lCZIbHmOlBOJwwXxqIrH+P9Rpvom+zAUHuaPwnppAgIyv
OsVk0HEYSec4p0RkoymDuwusjTiwBPTWhrCbSOeZ1wFTIxz6BQVH903/jY7I
BFqb9XGQhnm46Nz2QLScdtfdhjjEJ7CXztJiQEDJKram4KDu780LjuGDq5pJ
55dtOHx9bpTcqPkvWOZcCt7KwCEgtMBnXWou2OsEnv3jOA6nlURjD0VCKLeW
sIRXcJAcNyzoDXkAGvXKFd1CHNr1jLbypCWQYeJvWtGBw8UKRuhwVBkcyHZ3
+0D+Iznc3NlzpBxOnPQrMzORQsoshzlj8hAcNnevWXFYCpxkRtR120rw86r8
dpAnheSVHDbfqgp0Pkc58aukMO8smBZriOC7MDUwaUwKrdExwYY1Ilja7Nm0
17If9Lmf82bDqqF1SfrRJxf6gYFn57b9qCZzvz+/uLkf6G4PXEp8xUDdGK4W
u1wGP9Wv52bmiCF4u9Ungi0DB59OuX2DGFhZrivO5suAzfK48F4iBjvj2DXj
kzKwHrdNia4Qw9YvIamrbAZg1LPF7FyiGFKt2hKPJJP5pJ/OCHYTw0IW7bpo
iLRZQCGuIgbaSjeaxi8E3OowNmkRVgOzKl977WUCdByOqXfZV8Oda7wcWQcB
hknmrqbdIlBk69VbfiFAl6PH25Ahgv8BpFP8CA==
    "]}, {Automatic}]}, 
  TagBox[
   StyleBox[
    DynamicModuleBox[{$CellContext`tau$$ = 14.44, $CellContext`tt$$ = 0., 
     Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
     Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
     1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
        Hold[$CellContext`tau$$], 4.5, "\[Tau]"}, 4.5, 25}, {{
        Hold[$CellContext`tt$$], 0, "t"}, 0, 
       Dynamic[
        $CellContext`ttupperbound$$[$CellContext`tau$$]]}}, Typeset`size$$ = {
     540., {168., 175.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
     Typeset`skipInitDone$$ = False, $CellContext`tau$60355$$ = 
     0, $CellContext`tt$60356$$ = 0}, 
     DynamicBox[Manipulate`ManipulateBoxes[
      1, StandardForm, 
       "Variables" :> {$CellContext`tau$$ = 4.5, $CellContext`tt$$ = 0}, 
       "ControllerVariables" :> {
         Hold[$CellContext`tau$$, $CellContext`tau$60355$$, 0], 
         Hold[$CellContext`tt$$, $CellContext`tt$60356$$, 0]}, 
       "OtherVariables" :> {
        Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
         Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
         Typeset`specs$$, Typeset`size$$, Typeset`update$$, 
         Typeset`initDone$$, Typeset`skipInitDone$$}, 
       "Body" :> ($CellContext`res$$ = \
$CellContext`cachedRes$$[$CellContext`tau$$]; $CellContext`xExt$$ = Head[
           Part[$CellContext`res$$, 2, 1]]; $CellContext`yExt$$ = Head[
           Part[$CellContext`res$$, 2, 2]]; Show[$CellContext`homePic, 
          Graphics[{{
             PointSize[0.02], 
             Point[
              $CellContext`home[$CellContext`tau$$]]}, {
             Line[{
               $CellContext`home[$CellContext`tau$$], \
$CellContext`home[$CellContext`tau$$] + {$CellContext`Aref, 0}}]}}], 
          ParametricPlot[
           Part[$CellContext`res$$, 2], {$CellContext`t$$, 0, 
            Part[$CellContext`res$$, 3]}], 
          Graphics[{{Blue, 
             PointSize[0.02], 
             Point[{
               $CellContext`xExt$$[
                Part[$CellContext`res$$, 3]], 
               $CellContext`yExt$$[
                Part[$CellContext`res$$, 3]]}]}}], 
          Graphics[{{Green, 
             PointSize[0.04], 
             Point[
              $CellContext`home[
               Part[$CellContext`res$$, 1]]]}}], 
          Graphics[{
            PointSize[0.03], 
            Point[{
              $CellContext`xExt$$[$CellContext`tt$$], 
              $CellContext`yExt$$[$CellContext`tt$$]}]}], 
          Graphics[{Blue, 
            PointSize[0.03], 
            Point[
             $CellContext`home[
             Part[$CellContext`res$$, 1] + $CellContext`tt$$]]}], ImageSize -> 
          72 6, FrameLabel -> {"x (voltage)", "y (refractoriness)"}]), 
       "Specifications" :> {{{$CellContext`tau$$, 4.5, "\[Tau]"}, 4.5, 
          25}, {{$CellContext`tt$$, 0, "t"}, 0, 
          Dynamic[
           $CellContext`ttupperbound$$[$CellContext`tau$$]]}}, 
       "Options" :> {}, "DefaultOptions" :> {}],
      ImageSizeCache->{593., {240.21875, 246.78125}},
      SingleEvaluation->True],
     Deinitialization:>None,
     DynamicModuleValues:>{},
     Initialization:>({$CellContext`homePic = Graphics[{{{{}, {}, {
              Hue[0.67, 0.6, 0.6], 
              Directive[
               RGBColor[1, 0, 0], 
               Thickness[0.01]], 
              Line[CompressedData["
1:eJwl13c81d8bAPAbEUpIRijZpaiMSHSulUhIWZFRhCJEkb1XZDX4Kg0qpZAi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               "]]}}}, {
            Hue[0.67, 0.6, 0.6], 
            Directive[
             PointSize[0.02], 
             RGBColor[1, 0, 0]], 
            Point[CompressedData["
1:eJwlzXtUUwUcB/DBVGzQY0hDQNjG8IGHhR7IHAe4y+gYZjE48wHi42zykKED
G1EQ8cjHJNGNYGHRiYyAhWh0sIKw30UbAwYi8ppzPNqFxbEE8o7BNhjde/yd
8zvf8/nj+/uxRdKEFFcKhRJFLJnPxwt9nkEow0IrCzlB49fW2rxDfNnosKj1
yBWfF/irdftfLY/ehNZ1qm7P6t3465X5sjmqN5oeetg/9pt1/IKdGWHPpJ5o
rAc9Q5iylt825abtmfRATXrOryWha/jJYvs7bz9Ziy65S/wmbK782NzPBz+F
VWBU2t4c6nDhC2SMm56CBTDeTZnVfEbhtzd9zxC1zECWJClcJXMi5yNrHzAn
HkKxoCrao9WBvF/b8S7z7O9Iwq3leHbLEtJGL2oUvmZE4n4OVmX6LyAeDT4v
KtVmhAcu5y+w5pGTthh0yu8pEjqVE7dqGEHEug4/W8Y8sseq3sjLdkDivSPn
qtfMImJV37zWl4I+zMunnw6cRrp/E8ibJ5xgLtUZZMUGhGV9pTRMsQIwJrrZ
nN6DMAoc2w3xyyDM20Krv1SDnIkYRiM2O6B6l/XZul/a4cHHx7krNDu47eMc
lFzuA6ep4UsL1QaIM1zg/t8Q9NWwZP70JfiwPUj0w+QjMLOUloqwRfBd7aIO
3h2DJ0P+9ouZVtBrmzHFiUmYjnBd9LqzANciNQ510V+wVR5SxtyyABuC+9mG
BBP8YaVWMxosUHxVGvOd2QT7SkqTW/ZYYLRJHmOMxYAhz1zfZcFByek9dFuO
Ab2bWhLQjkMSEqIsbcKA5XPyfnUlDon6oLOjKAbUrwIUigIcqG2HZDu6MRhb
bKgPysKBW8e7mqzDwKg4MDJyCgdftY53pQcD97Gjwt40HN4LXkpp6cLA8LUb
1UJ4+BR2a7ATg/vXUm/Y03GYfCzGDmswGHg03s/JwGE0e3NV0p8YaEeieb4S
HECQ+0/nPQwc5kabhrCUuzGqkLBUYqjiZuLArm8SpRLuLUeviwj/tJvFJV1x
IzU5l3A4Ms7MIszxnovLI8yo3O35CeHH+hphDmHNJteoC4RfDunZfoZw/p0d
uWWETRtaG9MI9146N6MkvG1gYJy8vy1JFVlBmLlrpf844adb43dWkv+5eQHH
CO+1dolJz7zOPnaU8KxL2huk1YFeoaRbC/3+JfvO69NvkT7ACVST/vag/TRp
WqHPR6T/zun7grTXXFwi6cv28mbSPwoL9pLOjuFpSeteco8mvf+D5UHSjUXG
CNL/A/06GXE=
             "]]}, {
            Directive[FontSize -> 12], 
            Text["\[Tau]=4", {2.219643130711698, -1.332049064664961}], {
             Text["\[Tau]=5", {1.903463558678336, -0.2948684251322862}], 
             Text["\[Tau]=6", {1.543977089178004, 0.440327804070218}], 
             Text["\[Tau]=10", {-1.7699834517478101`, 0.03230020522027091}], 
             Text[
             "\[Tau]=20", {-1.2134130592290726`, -0.6177189799887469}]}}}, {
          AxesOrigin -> {0, 0}, BaseStyle -> {FontFamily -> "Arial"}, 
           Frame -> {True, True, False, False}, FrameStyle -> 
           AbsoluteThickness[0.5], PlotRange -> {{-2.2, 3}, {-2, 1.25}}, 
           PlotRangeClipping -> True, 
           PlotRangePadding -> {
            Automatic, Automatic}}], $CellContext`home = {
          $CellContext`xHT1[#], 
          $CellContext`yHT1[#]}& , $CellContext`xHT1 = 
        InterpolatingFunction[{{0., 30.}}, {
          3, 11, 1, {509}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwtV3c8FQz/vUZW9p534NI173Xt9f0mREiUkoxKQjR4ykNDkiJkRlRGkXg0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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwt04FGIAgUBdB2NkmSJEmSNkmSJEmSJEmSJEmSJEmSNkmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEkyxtgz7OO8H7j3/tPwb0XbXwEBAb//PPeDQIIIJoRQ
wggngkiiiCaGWOKIJ4FEkkgmhVTSSCeDTLLIJodc8singEKKKKaEUsoop4JK
qqimhlrqqKeBRppopoVW2ming0666KaHXvroZ4BBhhhmhFHGGGeCSaaYZoZZ
5phngUWWWGaFVdZYZ4NNtthmh1322OeAQ4445oRTzjjngkuuuOaGW+6454FH
nnjmhVfeeOeDT7745ie/+E2ADvwgkCCCCSGUMMKJIJIoookhljjiSSCRJJJJ
IZU00skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVPyVv
p4NOuuimh1766GeAQYYYZoRRxhhngkmmmGaGWeaYZ4FFllhmhVXWWGeDTbbY
Zodd9tjngEOOOOaEU84454JLrrjmhlvuuOeBR5545oVX3njng0+++OYnv/76
f//G/4NAgggmhFDCCCeCSKKIJoZY4ogngUSSSCaFVNJIJ4NMssgmh1zyyKeA
QooopoRSyiingkqqqKaGWuqop4FGmmimhVbaaKeDTrropode+uhngEGGGGaE
UcYYZ4JJpphmhlnmmGeBRZZYZoVV1lhng0222GaHXfbY54BDjjjmhFPOOOeC
S6645oZb7rjngUeeeOaFV95454NPvvjmJ7/4TcDf8ieQIIIJIZQwwokgkiii
iSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqpoJIqqqmhljrq
aaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZYZY55llgkSWW
WWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkiuuueGWO+554JEnnnnhlTfe
+eCTL775yX93dQHC
           "], CompressedData["
1:eJwt13c81d//APBrcz8ps7JHVlLRMCr3HMqIJLNIiJBSioyiQkRGSINo2Rml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           "]}, {Automatic}], $CellContext`yHT1 = 
        InterpolatingFunction[{{0., 30.}}, {
          3, 11, 1, {509}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwtV3c8FQz/vUZW9p534NI173Xt9f0mREiUkoxKQjR4ykNDkiJkRlRGkXg0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          "], {Developer`PackedArrayForm, CompressedData["
1:eJwt04FGIAgUBdB2NkmSJEmSNkmSJEmSJEmSJEmSJEmSNkmSJEmSJEmSJEmS
JEmSJEmSJEmSJEmSJEkyxtgz7OO8H7j3/tPwb0XbXwEBAb//PPeDQIIIJoRQ
wggngkiiiCaGWOKIJ4FEkkgmhVTSSCeDTLLIJodc8singEKKKKaEUsoop4JK
qqimhlrqqKeBRppopoVW2ming0666KaHXvroZ4BBhhhmhFHGGGeCSaaYZoZZ
5phngUWWWGaFVdZYZ4NNtthmh1322OeAQ4445oRTzjjngkuuuOaGW+6454FH
nnjmhVfeeOeDT7745ie/+E2ADvwgkCCCCSGUMMKJIJIoookhljjiSSCRJJJJ
IZU00skgkyyyySGXPPIpoJAiiimhlDLKqaCSKqqpoZY66mmgkSaaaaGVPyVv
p4NOuuimh1766GeAQYYYZoRRxhhngkmmmGaGWeaYZ4FFllhmhVXWWGeDTbbY
Zodd9tjngEOOOOaEU84454JLrrjmhlvuuOeBR5545oVX3njng0+++OYnv/76
f//G/4NAgggmhFDCCCeCSKKIJoZY4ogngUSSSCaFVNJIJ4NMssgmh1zyyKeA
QooopoRSyiingkqqqKaGWuqop4FGmmimhVbaaKeDTrropode+uhngEGGGGaE
UcYYZ4JJpphmhlnmmGeBRZZYZoVV1lhng0222GaHXfbY54BDjjjmhFPOOOeC
S6645oZb7rjngUeeeOaFV95454NPvvjmJ7/4TcDf8ieQIIIJIZQwwokgkiii
iSGWOOJJIJEkkkkhlTTSySCTLLLJIZc88imgkCKKKaGUMsqpoJIqqqmhljrq
aaCRJpppoZU22umgky666aGXPvoZYJAhhhlhlDHGmWCSKaaZYZY55llgkSWW
WWGVNdbZYJMtttlhlz32OeCQI4454ZQzzrngkiuuueGWO+554JEnnnnhlTfe
+eCTL775yX93dQHC
           "], CompressedData["
1:eJwt1nc81d//APBrcynZIuteSQiVUMp5KxKhaBiVQlY2DTIKZYQGUfpklhQV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           "]}, {Automatic}], $CellContext`Aref = 
        0.6823310565208429}; Typeset`initDone$$ = True),
     SynchronousInitialization->True,
     UnsavedVariables:>{Typeset`initDone$$},
     UntrackedVariables:>{Typeset`size$$}], "Manipulate",
    Deployed->True,
    StripOnInput->False],
   Manipulate`InterpretManipulate[1]],
  DynamicModuleValues:>{{DownValues[$CellContext`cachedRes$$] = {HoldPattern[
         $CellContext`cachedRes$$[4.5]] :> {4.512330886480282, {
          
          InterpolatingFunction[{{0., 0.3899393736861847}}, {
           3, 11, 1, {62}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGI7BgR4u1Fy+0LOD3YQmsEeQgvYP+laNqmITwLKV7CP
+57DcFvAxv4xWNzDnse3+5I1V6D9spDD0Xa8YfY5ae/3vnidae808Z/azIwS
e/981ve2t6vt16m1RX9c1mi/ZWrnfueEVvsWtVlbnv/psl8VffXKUZ8J9kJL
Ys+LS0+2r3rz9GTmy6n2j03yjuzePsPeu/bbPt622fbtu7wedRbNt39YfZ6p
ef1C+/pZlSIHly62l92prPZ/9lL73dfPmttOWm4f+a3cs7pjpf13EaXonXWr
7c+4HXx/MGWdfYCNgVPq0g321lfrezIlNtmr5p2/ltu92V6AXV6x6N8W+1/z
87LLCrfZP7HYt7XqyXZ7qT1SnNv27LQPsC+P+Thlt33bocvrdXL32u92NWDO
cN1vX5nitvpi3wF74WVfQt5XHbRf93zRP570Q/bTGbN0T886bN8gbRjTee6I
fabpjy53pmP2Qf77d7KaHbe3zmx7cTjzhL1Ks69409yT9rxzRdwcLp6yn1Dc
HJKUfMZeyOtTUsvXs/ZTFRILl7Wft+/5/dz+Sc8F+7Np8u5fQy/a810K82OT
v2QfYNsXKv7ikv2GPRo8m95fthe0OXzI5/sV+6LdsZXP/121v2T1Q7+J7bq9
8a5Jz2T4btiveBnpduTLDXsARKvusQ==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124}, CompressedData["
1:eJwB7QMS/CFib1JlAQAAAHwAAACoLYzqL/kFQPugwJjJOybAAko5zdb4BUAW
C3h68zkmwI9nQrd9+AVAUssJlR04JsB7lwqay/cFQCcSQ01yNCbAayI7mhn3
BUDdwJvoxzAmwFjszLdn9gVAtrzFZh4tJsAdEnQpe+8FQBTiOtCvCCbAeQWy
9pnoBUCazf+UmOQlwCsecwTE4QVAG7I/mdfAJcA0N983+doFQHr6PsVrnSXA
7hykzXmzBUADlmH7gdEkwFAjE+ZrjQVAjPNYBV8QJMB04mEsvGgFQIo1BYBA
WSPAU37on1hFBUBxz8cddasiwPIk5HwwIwVAnpBH+FoGIsDw4a/I6PEEQPnQ
VXy0HCHABdkw8RjDBEDy4xktt0MgwAZAOm2UlgRAXWpY6qTzHsBZZJfdMmwE
QLGq1IpJex3Ass/khs9DBEBg8TjP6RscwKn0a+pIHQRAPxLj5VjTGsC5WhED
T+oDQH2BNp59KhnAWp0aaXK6A0CtNyKK1KUXwOh+Sx9wjQNAHllkGWBBFsBo
X3JsDGMDQDjVQh+u+RTATp0p5BE7A0CzIJg7wcsTwKtSl5RQFQNAf4n8o/60
EsAc2uVTnfECQP2+FQgfsxHAjCqBpU/AAkCND+Z8K1gQwHiES526kgJAOBE8
/OlBDsDFpySLfWgCQKNDWfO1EQzAqe/bDkRBAkCuf7Q68RcKwJOAzSzEHAJA
m5l+lwNOCMAnnNq8vPoBQIOTIvpOrgbA6JPSIPTaAUCOt7GzAzQFwFbE8Slv
tQFATnu+lyiCA8AHykVw3pIBQK4lIuz8/gHAIsDxmfFyAUBgVUC0bKQAwBW+
d5piVQFAqlOMwrDa/r8HUa0a9DkBQOFPUmHPqvy/HQxjK3AgAUCEnyXvy7H6
v1PBxjKnCAFAlpCamkvp+L+fKp3u+usAQDOTJrws1va/zK9iZqbRAED/WeM9
8QH1vwPP1FBjuQBAoK3i0QJk878Vg6rc9KIAQKMvdx0r9fG//80lMiaOAEC1
hu0mUq/wv6rjNDvJegBAkJFbCpUa779uJB6jtWgAQG6G+MNQFe2/6ch7z8xS
AEC8RrNKkMPqv1rxEgiWPgBA+6jLq+PB6L87tvsy1ysAQAronQ1zBOe/tR3T
tl4aAEA+5qbHXoHlv/GmQRUCCgBAaPMrXWAw5L8ly4aQOfX/PxRP4lF/CuO/
ePNDqB7Y/z8NhLjZ1QnivyyLTj0qtP8//725EXLp4L/6G+HlVpL/P58FEIol
7t+/7lEZCU5y/z+5IoBGE1bevzJoF2bHU/8/e3BkrhT+3L9YXq6Ehjb/P/2M
grTK29u/SM5s3tAd/z8ArRoFEQPbvyHM2J8=
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.3899393736861847}}, {
           3, 11, 1, {62}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGI7BgR4u1Fy+0LOD3YQmsEeQgvYP+laNqmITwLKV7CP
+57DcFvAxv4xWNzDnse3+5I1V6D9spDD0Xa8YfY5ae/3vnidae808Z/azIwS
e/981ve2t6vt16m1RX9c1mi/ZWrnfueEVvsWtVlbnv/psl8VffXKUZ8J9kJL
Ys+LS0+2r3rz9GTmy6n2j03yjuzePsPeu/bbPt622fbtu7wedRbNt39YfZ6p
ef1C+/pZlSIHly62l92prPZ/9lL73dfPmttOWm4f+a3cs7pjpf13EaXonXWr
7c+4HXx/MGWdfYCNgVPq0g321lfrezIlNtmr5p2/ltu92V6AXV6x6N8W+1/z
87LLCrfZP7HYt7XqyXZ7qT1SnNv27LQPsC+P+Thlt33bocvrdXL32u92NWDO
cN1vX5nitvpi3wF74WVfQt5XHbRf93zRP570Q/bTGbN0T886bN8gbRjTee6I
fabpjy53pmP2Qf77d7KaHbe3zmx7cTjzhL1Ks69409yT9rxzRdwcLp6yn1Dc
HJKUfMZeyOtTUsvXs/ZTFRILl7Wft+/5/dz+Sc8F+7Np8u5fQy/a810K82OT
v2QfYNsXKv7ikv2GPRo8m95fthe0OXzI5/sV+6LdsZXP/121v2T1Q7+J7bq9
8a5Jz2T4btiveBnpduTLDXsARKvusQ==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124}, CompressedData["
1:eJwNzmlQ1AUcxvHNXGBhHWO5EhaQCKKCBORoA/lFOCSHASuCpUACEkEMgsWQ
A3Jl6BDHcJlQgUEyC8vhciS2zA9xgyaQkLhWlD3Z/Svs+Y9wxbR98bz4zDwv
vi6puewzL1EolCLj+L0dtqlDBJ6+Gfj3eTEJX/T4h7xntIfbQQMYTbQcymAY
nW1/05Vq9JEo1q8TgwSa+i+U1YpIsD9PNz9ndEenlX6f0QNrI8muRnt1533Z
uUaCXUMyw3SAQDOBeY7lfRICJ0VFG1wCDbKNjIuLJOgYr/84xzH+WflxlHsk
HK2wzR+5TqBg24VZPkOC5+hlk/hGAr//am9uIo+EPQFvfEcrJ9Bbsp//ylVj
71im31IugeF2Ja4/l5KgbY8IGk0ikKwqaaJ8TkJx47jiRhSB7699LHBhkyCp
HDfv8yawOum3AqoPCXHj3OplGwLTRInluZYkeNUFpnjuKLGtMOybw6QeLGSP
G7rFShzuPdSVvaSHTk7R6dhJJcpddsfP3tID3eORA5OrRN/iU+rEdj1ceWpm
PlSpROtv5xddivUwZxnjUpumxG46M0t4Ug/m/IsTHFDiRmNk9vFgPVywutdC
YSrx6odhlnlOeigJ/am17okChyi78yx26cHGuY5MWFSgNDTuuYlSB020j8zi
eAr0nsl2jLirAy9ynrZ5QYGGX46x0jk60PvGcjeiFGhFNZT/VamD7NiJhoh9
Ctyy5sTGZOpgYWqaSlGu49f/9VX1R+pgdbZ8kTa8jgeKeyom3tGBnedxdmrF
OgoWZ7ZTrI0WFrCo7HW8xAiJTt/RQsDd+nebrdZxYbMqJ+ehFhL6eJH1i3Ks
LGHwY25rwXN+a0d/RY6rLepS4XUtxHJWK3ifyNGb0ZoiqtbCtYye/mlHOdqE
v3UqqEALhW1ucyyJDDX86D0zKVoYvU1wnnTKMKIumjwXqYXPGv61kyXI8Pna
Uo29txZ4ZWNNR2gy3ATmeLCdFs6GZeS8xpdiIc96OemFBg4mx3GzcqVIWCy3
N89rIGvKl8Z0lWKpaCVY2qWBCWefWZ9lCZ6orM00LdFAqoA92VUlwXS6w8sL
iRq4Zib2L35Tgny2b9ScuwZsDcOvPpoSo/2zt7debKvhZFO+QZ4hxhv8x4P2
02qg7p31yzYRo0iY/Lu0TQ0hJ8pGVNEi7Gm/FORaoIaOcKcDpjVr6D1QU993
VA2y3ju+DnMPkR709HKSuxrcoTSmeuUBjn3g+MOxf1TgHN//aZN0FZ/pAq0F
d1RABLQ6eajvI5EGksJGFVAm6cKgHSH6n93/4HCGCtqh2u8PmhDdmj39d7FU
cIbLDuUFruCtwYA/rRkq+B9EWRhX
            "]}, {Automatic}][$CellContext`t$$]},
          0.3899393736861847, 4.902270260166466}, HoldPattern[
         $CellContext`cachedRes$$[4.52]] :> {4.5333976183640114`, {
          
          InterpolatingFunction[{{0., 0.39177709146139383`}}, {
           3, 11, 1, {62}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGI7BgSYxHBq+lnZD3YQmsEeQgvY32ZYn7xFRwLKV7D/
37DwpLqJjf0tsLiH/ewFboWr5APtTxzYuuGXRpj9tN1ZZrO5s+xTvG27YhpL
7P9YuFa+/lNt7zVZzcR2T6O9eNeq1SxVrfYJ9/LXJ8h224fMnBUZlzDBvtK5
NprHaLL9vLfxsbuYp9kfmu4Un3F1hv0zR9VEseWz7fVuy15ymjHf3tqqe+H2
Iwvt77ex3/Ldu9i++XKz0JOtS+3VFRi8q9Yttz+dU9MssHylff7OH7uXzV9t
H7fcv1Ctc539Mq9g4eCdG+znHvz3Vkhvk/1Ui1UnLi3abN+zPnTxJPGt9s1q
jHVBPdvsq+auiRBi3GE/9w8fT9vtnfb7owv3/9y62/7RrstFuRP22rNImak9
zNpvP9nmTM6qRQfsVXNq3Z70H7TfNltPQa72kH3vu/oG/02H7VMdLz5oeH7E
3maKkuMmmWP2Is+LFz4OPG7/2vIoo2j7CfvDPWJJbntO2s+6n36o/OMp+51a
Sy/Xt56xv1766Em75Dn7bwfkv/WvPW/P1baO+cyCC/aztH15LmRdtNe8+Frk
iskl+x1lXbI3/l2yT3wtHreZ/Yo9V8LSeX0CV+03XzG6nyl5zT7a84C8q9J1
e5Z9vgkK2jfsJVpOWjwQumkPAABZ6LY=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124}, CompressedData["
1:eJwB7QMS/CFib1JlAQAAAHwAAACQbGmcRewFQPxxcwZJGSbAm+P3mezrBUCO
OjT+dRcmwMMv356T6wVAxhx0LqMVJsBVZV234eoFQI+HPhH+ESbAD0g37S/q
BUDCzbvVWQ4mwHC+ZUB+6QVAkkuee7YKJsD77XTHk+IFQFjfbiSF5iXA6NAy
pbTbBUCl3DacqsIlwPFrlb7g1AVA94vNyCWfJcCMOs74F84FQOXFHZT1eyXA
cXWKkKamBUC2+cxrb7EkwDvpqN2lgAVAmK5QaZ3xI8DP4+yVAlwFQF4tfHO+
OyPAToaOwqo4BUCtwTFqIo8iwCSCCKmNFgVAvq3heijrIcDYTgJaVeUEQHbm
d9EZAyHAh9wwiJO2BECasZE6lysgwNaHUMMbigRA5C/fnSXGHsDU6uXCxV8E
QIuz1rxaUB3AVXpZ4Gw3BEAbT2ebX/MbwP+3BrDvEARAJZkWKAutGsBu52p5
Ad4DQDizhFAUBxnAot/r1S6uA0C/0lqQD4UXwPgVk+80gQNAtg07TAYjFsBu
XWUw2FYDQCrIIV2M3RTAf5WnS+MuA0DUw82fqbETwB/ODmwmCQNAimTE3Mec
EsCvEpmBduUCQB+rY8ajnBHAlz+k5yu0AkCtmERrAkQQwKOCywOYhgJAIh79
PrwdDsBa4WNgWlwCQDv0swo98QvADIdy0B41AkAmWLZvy/oJwK3YW4WbEAJA
skLz99ozCMA5cr1+j+4BQCJkL6LXlgbAvw+SQcHOAUAkaCpj+h4FwMFb5oUz
qQFAARd0IN5vA8Dha+XNmIYBQHYVMCse7wHABQ+x7qBmAUA593BqsZYAwExB
mwQGSQFA+hc/DgPD/r8i8v7bii0BQAJ9ji98lvy/MP2kpPkTAUAr2RlTcqD6
v0R1xN8i/ABAe84ZN5ba+L8sqOHtY98AQIVTzqN3yva/xM3xLvzEAECdj9xp
z/j0v39L136lrABAvEwM8BZd87/Gp20rI5YAQDEeShUl8PG/+mMFd0CBAEDt
3g8R7avwv2xJSGHPbQBAVmAx/ZUW77+/VIinp1sAQBKvpE+2E+2/KQSsjKRF
AEAhpXNikcTqv9uvsa5TMQBAW1V0WgPF6L9SwlQHex4AQOqrN91JCee/lvim
C+kMAED1BJoPl4flv7ESFY/m+P8/DjDCPbM35L+ZeId36tn/P+fyfTuyEuO/
NEox4Z68/z9hOuGCuBLivzXTj6FrmP8/G0cPOP7y4L+/FLnlWnb/P1erj2wU
AeC/7JjLCRZW/z8jgo1PsmrevxScj7xUN/8/zy71txMT3b+bRcpx2hn/P7rO
tHv98Nu/Yl/shPMA/z8oYYtsVhjbv4Mo3N0=
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.39177709146139383`}}, {
           3, 11, 1, {62}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGI7BgSYxHBq+lnZD3YQmsEeQgvY32ZYn7xFRwLKV7D/
37DwpLqJjf0tsLiH/ewFboWr5APtTxzYuuGXRpj9tN1ZZrO5s+xTvG27YhpL
7P9YuFa+/lNt7zVZzcR2T6O9eNeq1SxVrfYJ9/LXJ8h224fMnBUZlzDBvtK5
NprHaLL9vLfxsbuYp9kfmu4Un3F1hv0zR9VEseWz7fVuy15ymjHf3tqqe+H2
Iwvt77ex3/Ldu9i++XKz0JOtS+3VFRi8q9Yttz+dU9MssHylff7OH7uXzV9t
H7fcv1Ctc539Mq9g4eCdG+znHvz3Vkhvk/1Ui1UnLi3abN+zPnTxJPGt9s1q
jHVBPdvsq+auiRBi3GE/9w8fT9vtnfb7owv3/9y62/7RrstFuRP22rNImak9
zNpvP9nmTM6qRQfsVXNq3Z70H7TfNltPQa72kH3vu/oG/02H7VMdLz5oeH7E
3maKkuMmmWP2Is+LFz4OPG7/2vIoo2j7CfvDPWJJbntO2s+6n36o/OMp+51a
Sy/Xt56xv1766Em75Dn7bwfkv/WvPW/P1baO+cyCC/aztH15LmRdtNe8+Frk
iskl+x1lXbI3/l2yT3wtHreZ/Yo9V8LSeX0CV+03XzG6nyl5zT7a84C8q9J1
e5Z9vgkK2jfsJVpOWjwQumkPAABZ6LY=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124}, CompressedData["
1:eJwNx3sw2wccAPCgTgQ1OtKxqlftIcq6a9OebV9sjcXa1HTVHocSlPN+nKJU
aSNlaG01N6vVWLmZMY/a5vVFq+pwneamQjyC5JciyS/54aTV3vLH54+PU1RK
UIwBjUbL0+N4ldCyzBRoXF5umTBCQdhgIYun/8RaAsdL/+ou8oKb/iz1VOHW
IwqszvZ2TDMUmBbdYnBN/4MnIvYK9f+rqf57hv6iA5IEtv71r9rYVQ8p8Bxz
yLY3UaDgsaDACCn4OnbDm7ZHgZGGPSPZPRRcaPToltEUeL25Tbf5gAJ184Rs
/DWBVd0kI7udgoIuJ0xcJ3B8bJcTXE1BSrvHz4fEBFocDjfcf5UC8e5y59Zj
AoXMWn57DAVt/D5vSReBshjjSCaPguTaY1dm6gmMc+R3AJuCgf7zrrNCAgV1
K5c8bCngunudM00iMPxd3a9121p4c9N2lx9E4N33B22uzmjh26lAloJN4NGc
Vm1LrxYm/WPt7hwg8NaOWbttnRbWROx3Yo0I5JY4DDYKtJAlarQzWZSjzvLF
0+woLRw7k1K83iPH8snAYravFu42bfZYVssxN9u69x8nLaCLCz81Q44fsrm9
s0ZauGIWkswIlGPNPeO2HEIDaSNnTedYcjSt/NQ+Z0ID/UNk9aKpHO3r+zIG
OjTg7aBMLJ2W4Z1D1z6Zr9DAcRf3oJoGGbJKva2+StJAQ7krQU+T4cu40ISJ
0xoo/C4k6d/PZEi3Wg/y8NKAmx+za91chlY/3T7i87YGCl5xTILnVlFccVoq
0ZFA919wNGteRQPXiJnFJRJyrI4EdCas4l7+jJ98mASxwaj1qMcqso+ecx9p
JKEi/5SBD7mCW2rddkAZCcmZ8OX+zhX8Mawy8lQGCbrJL/4MyFpBi0zejYZQ
EkRbTwXPTqzgc8lJuudJEo5v5Zf8/noZkwVP8qc8SUj44Lzw77Zl5P8Q2pBq
Q8JvuXt4vlHLyPAJ87HVqSHIrcIRbJaxjEefXxtTg4MzGrc8kaL4wSjuq1VD
ROFHrUV5UpwoDY49k64Gluxi+ICXFA8+i2iK5qrhfou5JES2hGybqSwnZzW4
L1Zw+NeXMC90jmuqUYHA39rOyHkJRe0qjeuwCm5Qf7RdKlrEnft9bFaVCnaa
NpsWhxbwv/HlOGm8Clrj9x2ONlzAl57m9ZY+KvhlaPfmxufz6EfbjSlhqoDZ
V8ZIK5agMPf25fdIJajSpazLt+bQQtxiTh9QQjyXs2BTM4s1nbqPo8uVUFTW
j76NYrwY9pbIOFwJIyxrc03nDK4xhd3oqYRHLyTf2D98jsH5PFqioRIWtofT
KzXTeO9NVGbq3Ab8D4bMFyk=
            "]}, {Automatic}][$CellContext`t$$]}, 
         0.39177709146139383`, 4.925174709825405}, HoldPattern[
         $CellContext`cachedRes$$[5.14]] :> {5.160710697652468, {
          
          InterpolatingFunction[{{0., 0.5458458825547297}}, {
           3, 11, 1, {66}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGInBgQImhro6s3+2Q5CM9tDaGH73/G/nn/okoHyle1X
JC2/k7jMwf4XWNzHfvm6ZT/3m4fYB+gG1LNrRdlv/LrgudiMPPvYV2fYp/JW
2H9c88S3P73BfvOTR+IhJ1rsS2UePpTQ7LRXUI2/qnWo3/7ZtLyUebqT7a1n
68apV02znzj/TfiGYzPtny1eHWgpPNdeLmSr6kP9BfaFW6L2GNUtsj8iwhDc
cmaJvXjp0pdXpZbbZ131alDPXGm/1/SDWOX21fYC06auPcW6zt6wWlaJT2uD
vZDPriyjexvtP8uEbw6btNn+8tvPv6vcttpv2TfBZf6vbfZT+nV7D6/bYV+a
cOrq86Rd9mGG6XI84nvsSy1L80477bM/tcAx3tX8gP3NJR7sqr4H7V+u8F/P
knzI/seasPAnFYftOTbG/j/cd8RefGvK8sVLjtoXnms9+onvuP3p58seO1ae
sFdhPME48fFJ+zqpl/IPfE/b3zDmstPfccbeyFc7pk7pnH1Pmk/V2Z7z9r8W
/z9tsPmC/TqRm7d+zb9on9S66eWRnkv24t+6f/RVXrY/nZbKHpl2xb7+up2Y
cvBVe2MPCdW39tfsFdzFZ0wru27P5ybG7bD2hv1vF9G6l49v2r90Fvk4Seq2
/TUn4RSbwDv2hx2Frj9tv2u/0UHQq3/fPXu2G6XLpmg/sN/C/3j5w+8P7BuC
jp+YWP7QHgC6evrV
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132}, CompressedData["
1:eJwBLQTS+yFib1JlAQAAAIQAAACcx+FCVFAEQBOgtWi7/yHAq9xJqv5PBEDu
posgRf4hwPiYpRipTwRAuDo3Bs/8IcB2ZUID/k4EQJijDDzj+SHAuXKmCVNO
BEDVpvoo+PYhwOvzyiuoTQRAi4DBzA30IcD23+NxAUcEQEjZbEcN1yHAgNoX
cmVABECEBkkqU7ohwIXtghLUOQRAUPIrjd6dIcDDTHs5TTMEQJ4RVouugSHA
cZdyY6wNBEC0hBO56uAgwBPCWwRi6QNAM0yK2KtIIMDYpNYlXMYDQBkxddyu
cB/AFMgwD4qkA0DoFCxFwV4ewCPUmy/cgwNA6skE0Y1aHcAvhOWIpFQDQOJK
8jdX6hvA+VhEN7YnA0AhRKviapQawGf6iu3n/AJAydEyiU1WGcDWOhhAFNQC
QE+IysfOLRjA2jtEJxmtAkBrtk5z/hgXwHKb457XhwJAHIPavyMWFsAieTsz
cVYCQHwoLXt9xxTA+kdE/ewnAkCi6W4PTJUTwIrenBoN/AFAz2vE4mh8EsAm
9YdmmtIBQEpq+NgbehHAqrSjk2OrAUBFAipfCYwQwKHiL2g8hgFA2FEo4Edg
D8DZ+fcX/WIBQO58jipAyQ3As/N4gRkyAUAKMVT4L6ULwA1yRMuqBAFAvnv5
RyW5CcC0UqzlV9oAQEpnohjZ/QfABXJ3IdOyAECYEav7LG0GwOhf0mfYjQBA
6w1vi/MBBcAl5mPGK2sAQNVOJa/EtwPAyyDVPZhKAEDB5ZD02ooCwA/pJCDW
IwBAsypWMsAwAcAQjgBotf//PwvbtKZ79v+/ngcytbe8/z8okgQaH8v9vwVX
+Osxfv8/0voN1GPX+797pN3cskP/P4lTNwJ9FPq/Y8Hv+tYM/z8kEVhfn3z4
v02qMV9G2f4/7OZ/W9QK979pSEJnfZr+P1kOdVrcWvW/tOd+YTNg/j+Ja/L4
YNzzv5vyE/zlKf4/DpP7XrCI8r9zvdREJPf9P8Z3+XAsWvG/M1NL6IvH/T+2
vUIPF0zwv3/y1vPGmv0/xNpJlNK07r+MeqH+iXD9P0tJy0JmA+2/SH/E9bc8
/T+yNPeadg7rvw7h3q1HDP0/79gRZLpZ6b94Rs8ry978PwQ7mfr52+e/ycKB
C+Sz/D89tXm+hI3mvzYDhvNAi/w/4jmixeZn5b9scH2Dm2T8P/lPwlauZeS/
Q3PsorY//D+D/YPKPYLjv9rPQ0ifEfw/U3gazgWA4r+QoBAlyuX7P8fwOwym
pOG/cyAgk+C7+z/oQLSwB+rgvy+tuFuZk/s/9aN+myVL4L+RGz1itmz7P/1b
B/6th9+/GSNswgJH+z8O6kq6SqHev1qAZElRIvs/xilaJFfd3b/43DD+VvP6
P7QNZPj4B92/FKSmiY7F+j8iBA90wlzcv7DB8OFwqfo//Ov8bNsD3L9mZhdS

            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.5458458825547297}}, {
           3, 11, 1, {66}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGInBgQImhro6s3+2Q5CM9tDaGH73/G/nn/okoHyle1X
JC2/k7jMwf4XWNzHfvm6ZT/3m4fYB+gG1LNrRdlv/LrgudiMPPvYV2fYp/JW
2H9c88S3P73BfvOTR+IhJ1rsS2UePpTQ7LRXUI2/qnWo3/7ZtLyUebqT7a1n
68apV02znzj/TfiGYzPtny1eHWgpPNdeLmSr6kP9BfaFW6L2GNUtsj8iwhDc
cmaJvXjp0pdXpZbbZ131alDPXGm/1/SDWOX21fYC06auPcW6zt6wWlaJT2uD
vZDPriyjexvtP8uEbw6btNn+8tvPv6vcttpv2TfBZf6vbfZT+nV7D6/bYV+a
cOrq86Rd9mGG6XI84nvsSy1L80477bM/tcAx3tX8gP3NJR7sqr4H7V+u8F/P
knzI/seasPAnFYftOTbG/j/cd8RefGvK8sVLjtoXnms9+onvuP3p58seO1ae
sFdhPME48fFJ+zqpl/IPfE/b3zDmstPfccbeyFc7pk7pnH1Pmk/V2Z7z9r8W
/z9tsPmC/TqRm7d+zb9on9S66eWRnkv24t+6f/RVXrY/nZbKHpl2xb7+up2Y
cvBVe2MPCdW39tfsFdzFZ0wru27P5ybG7bD2hv1vF9G6l49v2r90Fvk4Seq2
/TUn4RSbwDv2hx2Frj9tv2u/0UHQq3/fPXu2G6XLpmg/sN/C/3j5w+8P7BuC
jp+YWP7QHgC6evrV
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132}, CompressedData[
"
1:eJwBLQTS+yFib1JlAQAAAIQAAAD6I0gT8GbGv+pj6r/wsfA/VkYRPlFmxr8q
X/wOuLHwP2if9WqyZca/XDZaYn+x8D8+bfTIdGTGv6/ArBEOsfA/Es9eLzdj
xr8A/CvSnLDwP0F+M575Yca/7l7Toyuw8D+x2kfAk1XGv2X2f4DDq/A/dqtq
JjFJxr+LFvz+YafwP/4XucvRPMa/NkFaDwej8D/r2lardTDGvzwN06GynvA/
mAGwn+nnxb9Sz0bosoXwP3al0jHJn8W/7Vo7Aodt8D9ERWTbEFjFv2pqROMj
VvA/owz/Q70Qxb+SrJRBfz/wPx3V5D7LycS/jb+XiI8p8D+eDYGgkV/Ev5Z2
HHvCCfA/kOOmGSX2w782ruApwNbvPzY+EaZ8jcO/jBfZzJ2c7z9Pt1/ijyXD
vysStsPvZO8/tA38+1a+wr/xn3shjC/vP7CvZqTKV8K/j5psqkz87j/5Zp/o
gsnBv5N/iQ/9t+4/ygtg1G08wb93tOTqQnfuPw3tRJR7sMC/J8eS4tE57j8u
uAuhnSXAvxtltOll/+0/fp+6OI03v7+tWyUgwsftP38f2WPUJb6/W3vf5q+S
7T8dyer4+RW9vztXlxL+X+0/snzJQIWHu7/TvrT4ERntP58ckza5/Lm/e9zs
VXfW7D/afID/XXW4v3vyBP+/l+w/TjMPPEHxtr9lWRXOi1zsP5PdRlg1cLW/
NOacc4Yk7D/sZvf2EPKzv009Lqxl7+s/Ljknc652sr/CRW7I57zrP4uYtkEK
l7C/2Y+7gQeA6z+Dv1G80Hatv6RGfN+mRus/bKIibh7Hqb9zy03haRDrP+Ik
EiCWHqa/tx/jRQDd6j++h6CL2nyiv8aXgrojrOo/Xj3gvC7Dnb+mnaFcln3q
PyUAcVYAmZa/IR5PgCFR6j83IUFJQqaKv3VYobsAGuo/4xpd+fmAcL/4o8Ya
wOXpP4B463N1AnQ/V7Eabg606T91ucXTmiCMP7rSSkylhOk/mx8qYpUPlz/J
JOdgR1fpP+fFWrIk/58/3qnyB78r6T9J1lh+zG+kPzyNbirdAek/QKduWAsy
qj8jZB4wV83oP3VbVGZo6K8/FSECLQyb6D/27ZrDr8myPzQzBlS3aug/a9Z+
7K6ZtT/8O9aMHTzoP+THjuNhZLg/bj+s4QsP6D8qxV9i8ym7P0rp2DRW4+c/
8krGYInqvT9Kqqsz1rjnP2wDlrvMv8A/vmGtL7KC5z94cCKISYbCP8UU6XQp
Tuc/Q70QKNhIxD+0SjWLBRvnP9WH29+RB8Y/RZFLYBjp5j91AhO7jMLHP2sg
ndY6uOY/lXOgB9x5yT/psxyXS4jmP8edP7yQLcs/xvNYHS5Z5j+ED5QfPmXN
P2ttC8tMHOY/eGSVy+aWzz9GXbZrfeDlP7cPmp12edA/3eV+aZW75T86oTGG

            "]}, {Automatic}][$CellContext`t$$]}, 0.5458458825547297, 
         5.706556580207198}, HoldPattern[
         $CellContext`cachedRes$$[6.140000000000001]] :> {
        6.140397363168287, {
          
          InterpolatingFunction[{{0., 2.1299026449407847`}}, {
           3, 11, 1, {129}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFiA801AcAx384Zf7koWKPmr/vSrfecolwfa+SKxTTDSNl5s+h2Km9QrVq
iWH+7KE/tt17/o1bdi7rrrnaoo6jGE6SQsuh7jh/w7njtrf23j7vfd/nfT92
UclBMboEQej8s4vE/yQZPq9i5qh3vbMR3tka3QzHc19VO/73t8C2Rmsmf38/
pP92JtaL9k+/5x0BylWBS9tkFHpU/JtPOr6EAZNkO2x+EeSfefHhuzLhoxte
L43/FrcoX69UthXC21PI0mOXoPeAojvSshRxoR/Qfr/Hwdn6GqmJSxnEDQ+y
vDIqsKZpgJbYV4UCN4qniRUXFrVp7ryQWvgVym5U+9XB+HHO9VQFH+2rqNd8
c+qRt7u/xHrLbQSevVg83ibAzRCe3sNtv8GAOsAuvSZC9Bqjlynae3h5yobs
RL2PvCjqYEFsI7wCfYs115sgp33mz2p/gO6MifOUYDEa2lP5U4PNKFu3SvZr
nATZEd+tT51qRUrlxgO01EcIm+Cm6+i2Y4+r2y/i7A5IScML/H2d0E/mWun4
dMH9GXtnoE83EvbuDOP4SPF9LZGu9OlBh6WklMZ4AuJS/t1cRi96WNVCbslT
/BTQeEsy0of0Hf21o9v7cWjDbDXp8nPYk4wr7KUvMC935NDtB9HaRbtxlD2E
EuqdPGbRSzDOf9ypSv4LixK5GcfvFbgWlw97k4cRfnRD8RtdGYxrBL15gzLc
mw2w2t4wgl6mRyO9bxSTtx0TDs6PwcDS1CJs7RvYnVGJYl3k8Hg2HH0yUIHD
Hh0mF5LGcbz0jiA3dwLXaQxi/NQkfoyrCz6XPAXZlT8t3HWnsblK2TlTNI1k
sUleLXkGt2UUP1bDDNR6/gYOB2dBd0gUDwzN4sqe7EvXUuYQWpdlEzc+hy0b
MwWusW8h2pSuf+zRW/hTk5lZH81jgPZ5Ob94Hkn7Q2b6l+ahDfLbTYpcQH4E
Cj4UL8CWRR0Kdl4EP4W89UL+IoxGZUrp80VEf1rGI29SYeRIjQOTpUJMZN3V
C9UqjNH6bJxeqBBvTZS1mi5BsUgmJ+1dwonegJvmp5cwVX96m5C7hJRCjiB8
cAlzSS2ehLkaB8imXWmhanhbK86czFWDbtpie/y+Gl565ZLoOTXcFs5/EbFJ
A6oizCr4iAZbh3bcP1SggbPUnMV4qIFTi9KUvqiBnahN6E5ZxgZe1bFtkcuw
Kr+02rloGWuvHuXZS5ZhmuMRYq1ZRmz/mFm8xwrubi5+LDizAvPUPZkk4Qri
JZO7g96u4A/LHzQcqhbr4nyFE2wtEgULbM86LZr0KynfKLUYsehJyNhI0OUV
n6B5H0FXuj61WH2CoM82h75mFBH0hZD+u1kigq55HV7Y+oqgE2kDMYaGOvS/
AVKw84o=
           "], {Developer`PackedArrayForm, CompressedData["
1:eJwt0gFHnQEAheFvSTJJMkmSymQySZJJkiTJZK6ZSZIrSXJLMkkykyRJkiSZ
JMnMZJJJMpMkSZIkSZIkSZIkSQ/t8PyB480It4QiL4Ig+BY8L4poYojlJXHE
k0Air0gimRRSSSOdTF6TxRuyeUsOueSRTwHvKKSIYkoopYxyKqjkPVV8IMRH
PvGZamqopY4w9TTQSBPNRGiljXa+0EEnXXTz9f8PPfTSRz8DDDLEMCOMMsY4
E3xnkimmmWGWH/zkF3P8Zp4F/rDIEsv85R8rrLLGOhtsssU2O+yyxz4HHHLE
MSeccsY5F1xyxTU33HLHPQ88Egghiic62kG6
            "], CompressedData["
1:eJwNyXk8038cwPHvhhSFtE2XRKKfQhKl7PcZP6nWHNEjKRVljfpFUnJFKMUy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            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.1299026449407847`}}, {
           3, 11, 1, {129}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFiA801AcAx384Zf7koWKPmr/vSrfecolwfa+SKxTTDSNl5s+h2Km9QrVq
iWH+7KE/tt17/o1bdi7rrrnaoo6jGE6SQsuh7jh/w7njtrf23j7vfd/nfT92
UclBMboEQej8s4vE/yQZPq9i5qh3vbMR3tka3QzHc19VO/73t8C2Rmsmf38/
pP92JtaL9k+/5x0BylWBS9tkFHpU/JtPOr6EAZNkO2x+EeSfefHhuzLhoxte
L43/FrcoX69UthXC21PI0mOXoPeAojvSshRxoR/Qfr/Hwdn6GqmJSxnEDQ+y
vDIqsKZpgJbYV4UCN4qniRUXFrVp7ryQWvgVym5U+9XB+HHO9VQFH+2rqNd8
c+qRt7u/xHrLbQSevVg83ibAzRCe3sNtv8GAOsAuvSZC9Bqjlynae3h5yobs
RL2PvCjqYEFsI7wCfYs115sgp33mz2p/gO6MifOUYDEa2lP5U4PNKFu3SvZr
nATZEd+tT51qRUrlxgO01EcIm+Cm6+i2Y4+r2y/i7A5IScML/H2d0E/mWun4
dMH9GXtnoE83EvbuDOP4SPF9LZGu9OlBh6WklMZ4AuJS/t1cRi96WNVCbslT
/BTQeEsy0of0Hf21o9v7cWjDbDXp8nPYk4wr7KUvMC935NDtB9HaRbtxlD2E
EuqdPGbRSzDOf9ypSv4LixK5GcfvFbgWlw97k4cRfnRD8RtdGYxrBL15gzLc
mw2w2t4wgl6mRyO9bxSTtx0TDs6PwcDS1CJs7RvYnVGJYl3k8Hg2HH0yUIHD
Hh0mF5LGcbz0jiA3dwLXaQxi/NQkfoyrCz6XPAXZlT8t3HWnsblK2TlTNI1k
sUleLXkGt2UUP1bDDNR6/gYOB2dBd0gUDwzN4sqe7EvXUuYQWpdlEzc+hy0b
MwWusW8h2pSuf+zRW/hTk5lZH81jgPZ5Ob94Hkn7Q2b6l+ahDfLbTYpcQH4E
Cj4UL8CWRR0Kdl4EP4W89UL+IoxGZUrp80VEf1rGI29SYeRIjQOTpUJMZN3V
C9UqjNH6bJxeqBBvTZS1mi5BsUgmJ+1dwonegJvmp5cwVX96m5C7hJRCjiB8
cAlzSS2ehLkaB8imXWmhanhbK86czFWDbtpie/y+Gl565ZLoOTXcFs5/EbFJ
A6oizCr4iAZbh3bcP1SggbPUnMV4qIFTi9KUvqiBnahN6E5ZxgZe1bFtkcuw
Kr+02rloGWuvHuXZS5ZhmuMRYq1ZRmz/mFm8xwrubi5+LDizAvPUPZkk4Qri
JZO7g96u4A/LHzQcqhbr4nyFE2wtEgULbM86LZr0KynfKLUYsehJyNhI0OUV
n6B5H0FXuj61WH2CoM82h75mFBH0hZD+u1kigq55HV7Y+oqgE2kDMYaGOvS/
AVKw84o=
           "], {Developer`PackedArrayForm, CompressedData["
1:eJwt0gFHnQEAheFvSTJJMkmSymQySZJJkiTJZK6ZSZIrSXJLMkkykyRJkiSZ
JMnMZJJJMpMkSZIkSZIkSZIkSQ/t8PyB480It4QiL4Ig+BY8L4poYojlJXHE
k0Air0gimRRSSSOdTF6TxRuyeUsOueSRTwHvKKSIYkoopYxyKqjkPVV8IMRH
PvGZamqopY4w9TTQSBPNRGiljXa+0EEnXXTz9f8PPfTSRz8DDDLEMCOMMsY4
E3xnkimmmWGWH/zkF3P8Zp4F/rDIEsv85R8rrLLGOhtsssU2O+yyxz4HHHLE
MSeccsY5F1xyxTU33HLHPQ88Egghiic62kG6
            "], CompressedData["
1:eJwN0nk01HsfB/BISHVb7vXgaqSaq6R9kaLeSrmVpZKi5YlIjbbJpYQUudY2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            "]}, {Automatic}][$CellContext`t$$]}, 2.1299026449407847`, 
         8.270300008109071}, HoldPattern[
         $CellContext`cachedRes$$[6.68]] :> {6.451609909024424, {
          
          InterpolatingFunction[{{0., 1.878689011461627}}, {
           3, 11, 1, {120}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFiAtQEwQAhidcvCQwGIe3sXg0NHCwkxLuQPjFoIDDc4AXHA9BHomPUIFo
mE4hiMRDRFMQSRHRJTLiDTYSh8grIuU53owR0XCw92BsVFfe9d39993/2cef
Ck3SIxAIW/4Zk/A/e4zKJBRfffxnyzd+DwxT0VK1gPbmfwDXvG/dNHwGDv7b
o9Ha8+A3+heJCLg86nwp8zhsySQqcfk8DjATx+uC82Ai5JaP3y/EwkPjxou6
6/gouqmY6FSCw8u/1LBS78DbWxqviKlAX865lEfZDxDRb3j2MPsHLFpez7Xs
f4y0qHeLeiQ1KMu2n46pqgNrrOFM+FQD4mgfG4SYNWN/Fr80aF8rqKPH6X6p
P8Fgl+65d2Ubli4URniMPsXij+5+IhMe+Hcdp1qrOtBXSEzPC+pE2wV9009F
L1BzSnafmt+N8liBl9ypF9cOvhzi9fbhzq3G+vCZfjwWlhSJZQOYuunTyvv6
Jea5tWzTK6+wNOdQHF4yiJW3bnxTUTEEpbNhhrh6GDuubOXkGI0iQmq+QE4c
Q/4hIrmhnY+2lu2hQeQJrJAolwQZk7Bj2T9jDk4hVOCoNnedQS1tclhPOgvD
vQHjmvE5tAgcAtK5AnyWp2sWl83DyoXveJQlROdg/XdzsQtIYxboR/r+juBk
N4uQY4ugRozZBRT9Ae0n5+h4soQRD3sfd8Gf4OzsCnYxXkau9Yko6u7XiFP3
HLGhiuE1tiOZaL2CnzODDN6fXQFsUiq92KuImw24x/aQoKI28nTdbQmEWSfB
/UsCahjL7EWCFEnUq9MD3VI8VN6r5u+Sofma0/d7v5Shi15XUN4hQ+6W7KdB
enL4D4WuKnzlsPNyKK1Ml0NTIfU7xJZjxIS3qj8hR23q1dIGUwXyJ2L9E6BA
0n66xCJVgX1Vm6UdlQpkCOGdJlLg+XRnPpuixDv8QP4kQ4nYwQHHbTlKcPrD
0vxalNjo4j9jipQI5MWYcSgq3OTORwkYKiw0HX1klaOCW+1rVWCLCherzvix
RCoMVKqK6ilqkO9+NbvIUOPYLYILOUcN23wOicxTY+RspBF5U43LJwxVJK81
+EY3CknMNaiDj7wiNa2B423WTpKtIcGVW02ir2O7bXIp6eQ6rBm/0ihP1mGV
5dZua6CBZX1xiEOYBhZCrZBarsE2YnzGTrEGZv7dRs6eG3g7g3ablreBrewi
F/rwBoz5qvbd9loYGUeHfpiihYEnb8Gdq8Xnap+xMBsdhhrbek+f18Ez1bOt
YEYHMSNzj435Jv4GUvna7A==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174, 176, 178, 180, 182, 184, 186, 188, 190, 
            192, 194, 196, 198, 200, 202, 204, 206, 208, 210, 212, 214, 216, 
            218, 220, 222, 224, 226, 228, 230, 232, 234, 236, 238, 
            240}, CompressedData["
1:eJwNj2s41GkfgP/S1BBmMs00b3TQSWI6h6Seol6W1L6kkqGUQqHocqzdWkRI
NVEqqVVCTmUqSvF7si+SUwbREjLKKZs5GzPzt324P9zXdX+5TY6ccj2mRRDE
+E/mrc+St0STqMLzs1/XKhpukH0c3PzTV+krLc9Z0DD9R9jAoygSlapbDsxf
ScM3U2KkUZEk0t69xvfwMhoOd1m+bncEiV52EeXZi2i4+q+9mYvDSVQsq/EY
MaLhaHwzOfIEicYczZjD3w1wyQyNQZ83if7ob+cfrzTAducOTBxwI1Hh6ZQA
n2sGOC5RzBY6kCg6/GpExxEDLDVKtb6kQ6LxiM7zdcH6OD531phRowYlHLUG
u0t6+PaOMMPY6xqU0zy016F4FuY8dQjJ9tAgXnYzR9yri3ubVRn+izVo1DaV
H2qsi9+/PjpbT6BGplcoLWlUHXzrSP5jUZwaRRryso7oUPHdnLYbXTZq5KC3
IbbbeCZuftGj5ElUCOX7p2zbPgPr7C4y7S9WoZeGXne0wijYunM99V6gCl3O
8RqA0ul4X3mFVRNDhTbRGBZLq7Tx5xY2SVZOIjqscLwqnIZD6+bYtQdNoscF
EREX2dNwksZPm1g0iQwX6mkPeGvht3JSadmuRO8Kw1IEzwks/8Y4uSlFie7k
xVqVsQmsdfSoRaODEh1yWII9DKeg5+DJEI+vEyh2ZMAo/roGvOZU0n5LmEBs
F4+iZ1vUsNoqvfQFZwKpHWJq/muggkQy6C2vQ4F6ap27rkwpIbuxJKEoToFs
WkcabusrwZZ7glOyQYHenTYU0jdOQGm13qfdg3L09NbYsvlnFECQdo1XE+SI
f+smpyNdDtvrkjqWmMsRN4hJOfRJBrVD8W/utMjQJ5R/1XSDDHqmtlTyomXo
jM9bge0jKfQ22XNLlsnQseUrPUxXSuHpHuffCwRSlBvzW307loAPJ0C06Q8p
MokU7Ez2k4Bj6YP6frYUCdTjW0upEqgLTgj6H1+CenYVr5mFxZARHBHJcJGg
NTuKqvyTxSDe4t2Hh8SoY/wsf2GAGMJaRC+UcWJE3k3M690vBvby1l2+JmLk
M4t+L2+fGH7RFuQUVIjQqawlNeArhgDVgV7eZhGqJeRsWooYQnXyRikvx5FT
hty0tlEMhfUf5nHXjaMMqTl/aLkEohaY1DW6/UDPq10GFbckYNxfXfJt8z/o
HavbUrlUCoMNXPNkozFk0eLSHdoghTCF/46VolHU0ZD5MJQng8ah3Ibg/SPI
MrmXcK2Wg959nec2j4bQ1oJCUyvrCaAfS1if3/4N3XdqCmmUKKFgcB9JFw6g
vUR08LLpaghoiTCpr+lHIeqq41qRJETce66mRvWhX5mFwRefErhy3H2tXNCN
FMrJnc7Madgp+WAC06MT7Xudm1BSrI3zZOW6M7ltKNONIRkwp+Dty4UKJ/oH
NH992vjNthm480nmWc7fNejGyOjahwVUvCPzS0Nh9it07r294BVfF+umaM6E
+l5F2v4HG38f1sPna4K7jG49g22Trexfd9HwZOBMfCyuBqT+lIt7h+nYtefr
VvECAaQ2Hb6ZbmmI81oXutGzOiAk7YsFWsvAz+qa/lGf/Ay7Pc24z5bMwc9s
rnea2X8Bn5f1e34XzsFxzGySPSgE+6DA+eXXmLg1vvtuGe0bBFxenfqEysIr
ORNj2+yHILByw8CDQBbWGiv0Tjw/Ahkpt1OqXrJw+dysj5Sq7/DG1ZbiNczC
4lxb1DLzB5StnSszVLHwmNPe4q6ccXi0NECuP8rCBl5fkhe/E4Ez0XfaqoyF
PY1P0Fr2SCA+pvDP5PUs3HwoR5TtL4XpdW1mETlMPA8cx2KiZLDCFrUnyOZg
p55SSskFOYi2UV1v/Pyhtslf/XlOAbRLt+9f2cDA+4WKTtXJCbjraSrcyTHE
SSt6VxW7KOGvYNUaC8ZsTJ/Q5Y0umoSMRj8dnU4aNmKGE+u+TsKUIDPf/Kw+
DrRK0XG8owLbmP6Y2nmzcDCZ/tlqmxrOMtlug5iKZ4oX9jh0qGE080amffgM
XGaTECI6pIG530d30eym4/13WMqPf2vg0mWz7wNm03DgxjgTdy4Jjjk1Cy7n
T4H30emxdQ0kRAdaMe/6quA/6Vx+KWcKgl73H/S9qABh+WHX7AtTINrlSXXV
k4JPAaV5du0UhPIPJ7bKxuH2uwqupRaBU6tvcM9HfgebpLVmlHkEHk7ibbcp
GYTchwu+8lYROG/dU+f4eCFkdaZa/2JPYF2+njGD1QNNU83ODDcCt11KynZ/
8BHcky0v1noTuIKZtt8+8gOIX3i4GfsR+IlvL1NTWwO8KfuW/EACOyO/kOre
N8Cb3cYTnyJw8rDvsM3xYqhYIHH0CiHwYF/aRDH9Ghw3Njez++mvlorVzeFp
qPP/Jf1DP/sq5yC2vsljZNSRuPVyEIHfDN5bsvMBH21czfDgniDwyPCBdMfU
MvS6733U8WMEXpzYJeqPfYMaOEsvZB4icLdn7KuPKzAiFQP0dR4E3rS6aNDh
/ltU5N6bWO9O4JPp0V+SrKvQvxeNABs=
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 1.878689011461627}}, {
           3, 11, 1, {120}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFiAtQEwQAhidcvCQwGIe3sXg0NHCwkxLuQPjFoIDDc4AXHA9BHomPUIFo
mE4hiMRDRFMQSRHRJTLiDTYSh8grIuU53owR0XCw92BsVFfe9d39993/2cef
Ck3SIxAIW/4Zk/A/e4zKJBRfffxnyzd+DwxT0VK1gPbmfwDXvG/dNHwGDv7b
o9Ha8+A3+heJCLg86nwp8zhsySQqcfk8DjATx+uC82Ai5JaP3y/EwkPjxou6
6/gouqmY6FSCw8u/1LBS78DbWxqviKlAX865lEfZDxDRb3j2MPsHLFpez7Xs
f4y0qHeLeiQ1KMu2n46pqgNrrOFM+FQD4mgfG4SYNWN/Fr80aF8rqKPH6X6p
P8Fgl+65d2Ubli4URniMPsXij+5+IhMe+Hcdp1qrOtBXSEzPC+pE2wV9009F
L1BzSnafmt+N8liBl9ypF9cOvhzi9fbhzq3G+vCZfjwWlhSJZQOYuunTyvv6
Jea5tWzTK6+wNOdQHF4yiJW3bnxTUTEEpbNhhrh6GDuubOXkGI0iQmq+QE4c
Q/4hIrmhnY+2lu2hQeQJrJAolwQZk7Bj2T9jDk4hVOCoNnedQS1tclhPOgvD
vQHjmvE5tAgcAtK5AnyWp2sWl83DyoXveJQlROdg/XdzsQtIYxboR/r+juBk
N4uQY4ugRozZBRT9Ae0n5+h4soQRD3sfd8Gf4OzsCnYxXkau9Yko6u7XiFP3
HLGhiuE1tiOZaL2CnzODDN6fXQFsUiq92KuImw24x/aQoKI28nTdbQmEWSfB
/UsCahjL7EWCFEnUq9MD3VI8VN6r5u+Sofma0/d7v5Shi15XUN4hQ+6W7KdB
enL4D4WuKnzlsPNyKK1Ml0NTIfU7xJZjxIS3qj8hR23q1dIGUwXyJ2L9E6BA
0n66xCJVgX1Vm6UdlQpkCOGdJlLg+XRnPpuixDv8QP4kQ4nYwQHHbTlKcPrD
0vxalNjo4j9jipQI5MWYcSgq3OTORwkYKiw0HX1klaOCW+1rVWCLCherzvix
RCoMVKqK6ilqkO9+NbvIUOPYLYILOUcN23wOicxTY+RspBF5U43LJwxVJK81
+EY3CknMNaiDj7wiNa2B423WTpKtIcGVW02ir2O7bXIp6eQ6rBm/0ihP1mGV
5dZua6CBZX1xiEOYBhZCrZBarsE2YnzGTrEGZv7dRs6eG3g7g3ablreBrewi
F/rwBoz5qvbd9loYGUeHfpiihYEnb8Gdq8Xnap+xMBsdhhrbek+f18Ez1bOt
YEYHMSNzj435Jv4GUvna7A==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174, 176, 178, 180, 182, 184, 186, 188, 190, 
            192, 194, 196, 198, 200, 202, 204, 206, 208, 210, 212, 214, 216, 
            218, 220, 222, 224, 226, 228, 230, 232, 234, 236, 238, 
            240}, CompressedData["
1:eJwN1Gs41PsWB3BSnC4yiSbqSUqR40h0SC7fKJcSRWWni4TkuEQSFVsu6aaz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            "]}, {
           Automatic}][$CellContext`t$$]}, 1.878689011461627, 
         8.330298920486051}, HoldPattern[
         $CellContext`cachedRes$$[7.140000000000001]] :> {
        6.634462292067602, {
          
          InterpolatingFunction[{{0., 1.7172246505438489`}}, {
           3, 11, 1, {130}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAkwnAcABeANg7iyVWubcca2aIM4knYdSV40rSMymlA5auK2QpCkcQzR
UEMI1jGqVB0RMhV11B0NIUTVEZPF2qxJ3bf89nZtRrvTZqZv5s037xn6X3cP
kiORSPtkTSL9nyS3iZ5wqgb+0/CdVuiNcqisLLd9tx0QoLxFObV8BT3//iEI
bZIvGzf5FsJfl9Yn7sRg4HRV9VvHexgurOM5BuehmaycTjYtgluv1fthMffR
s+ftc45bgVW6dleEqArkm2x9pnoddDydu9h5DagTGPEWDjXDIUveQFzbCvbh
WTd5+3ZkMCjsmMEOGLIqzDfNuvE2ovPGb+Jn4KhxmkI7etFUzd/8KLkPWc4q
dtOu/QhZ+vC7nzQHUHrFYOCXliGMjmtrtV4cgbxxhuVc/EuUzKZdWH3Bgk3J
3Xi+/hhGLyU/2Lo+jjBK0p973WxojSi5bYVz8DSVOcbT5oLhoHl5pX8SZGnh
1Ezkazxu1g/kGk7BL6JylTUyDQVKPn2xcwajbftqmb2zKPOKoH02MIfwvycL
pkbmYVfhpJ46vgAlp+Yki8lFDNkRvsX1S8g+YgzllGV40Hz0or9ZwQfUQumc
xSriLH+YvTe5ir/O5PRbpqzhVFBmLcdiHZUJaXl3JtehVJQca5TyBqHNiT7D
FgRY6UPWupYEbP2oimEy79P9uE9kKh2oqVG1IhCxsJngJfN4bqaxVKbKSdqL
ImsCr9babtkdJbBYnSOJtiUgCg2JaQIBkunnO7wvCaiva982O0sgmjUVXh5H
YLrtgS/1EQHnUoZHBodAY/JhR5LiBnSubdhEHdvAK2v3RsHdDeTvtphGcDfQ
7Or6h64eD2PFM75DvjwIiShpbCUPGlD98eMVHg46nytc1+Kjil+02EPnozZG
J644gI+mvZ8PRGfz0Z6iW/HVEz661Eronyzz0ZenNyynKcCgdqnv65MCvCzX
l7SECmDplTtPLRGgocF8VPpcAKv9g90zb2Tbm1HfRxHCqkWutPq4EI2qZZnZ
gUJY+9vfjswUYuKoI3e3TYg4hfP07+eF0Od45SuRReipYoiYdiIw4m6epzBE
UDkbX1+UK0KdXqq6YacI+x/SmAs8EfzNnqpV0cToaLqcec1TDKq9RNUiTYwb
PTkZwt/FGHQxU20lxDBi9afHHpIg4VKAygkPCRY4AQOflkvgcjEw7QhPgvqJ
QCeTE5ugXAhSPJSxiVh2UN9B7iamv2Yka5hs4YtxxmmVqC088giWk+/dAnks
+Jn0vW1Eul9NFHtvg8u6CqJmGyPCM7REtR081zRX0AzbQfsx8srDoR3UeQoG
bUx3URE9VjuUvovCgpYc77VdMB8X3BK4SFGZZpDVHSvFPyO7DPI=
           "], {
           Developer`PackedArrayForm, CompressedData["
1:eJwl0gFHnQEAQNFveZJJkkmSVCaTSZIkSZIkk3lmJkmeJEklSZKkTZIkSZJJ
ksxMJpkkM0mSJEmSJEkykyRJkg67nH9w0yOt4ZYXQRB8Dv4XRYhoYnhJLHHE
k8ArEkkimRRSSSOD12Tyhizekk0OueSRTwGFFFFMCaWUUU4FlbyjiveE+cBH
PlFNDbXUEaGeBhppopkW2ming0666KaHXvro5wsDDDLEMCOMMsY4E0wyxVem
mWGWOeb5xnd+sMBPFlniF8ussMpv/rDGOhtsssU2O+yyxz4HHHLEMSeccsY5
F1zyl39ccc0Nt9xxzwOPPBEYIYoQz0P0QcA=
            "], CompressedData["
1:eJwN0Xk01HsfB/DfZJKlLDPGZKsJRaRU1/Yo33sVKSREhUiWSKmLrGmyZbtU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            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 1.7172246505438489`}}, {
           3, 11, 1, {130}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAkwnAcABeANg7iyVWubcca2aIM4knYdSV40rSMymlA5auK2QpCkcQzR
UEMI1jGqVB0RMhV11B0NIUTVEZPF2qxJ3bf89nZtRrvTZqZv5s037xn6X3cP
kiORSPtkTSL9nyS3iZ5wqgb+0/CdVuiNcqisLLd9tx0QoLxFObV8BT3//iEI
bZIvGzf5FsJfl9Yn7sRg4HRV9VvHexgurOM5BuehmaycTjYtgluv1fthMffR
s+ftc45bgVW6dleEqArkm2x9pnoddDydu9h5DagTGPEWDjXDIUveQFzbCvbh
WTd5+3ZkMCjsmMEOGLIqzDfNuvE2ovPGb+Jn4KhxmkI7etFUzd/8KLkPWc4q
dtOu/QhZ+vC7nzQHUHrFYOCXliGMjmtrtV4cgbxxhuVc/EuUzKZdWH3Bgk3J
3Xi+/hhGLyU/2Lo+jjBK0p973WxojSi5bYVz8DSVOcbT5oLhoHl5pX8SZGnh
1Ezkazxu1g/kGk7BL6JylTUyDQVKPn2xcwajbftqmb2zKPOKoH02MIfwvycL
pkbmYVfhpJ46vgAlp+Yki8lFDNkRvsX1S8g+YgzllGV40Hz0or9ZwQfUQumc
xSriLH+YvTe5ir/O5PRbpqzhVFBmLcdiHZUJaXl3JtehVJQca5TyBqHNiT7D
FgRY6UPWupYEbP2oimEy79P9uE9kKh2oqVG1IhCxsJngJfN4bqaxVKbKSdqL
ImsCr9babtkdJbBYnSOJtiUgCg2JaQIBkunnO7wvCaiva982O0sgmjUVXh5H
YLrtgS/1EQHnUoZHBodAY/JhR5LiBnSubdhEHdvAK2v3RsHdDeTvtphGcDfQ
7Or6h64eD2PFM75DvjwIiShpbCUPGlD98eMVHg46nytc1+Kjil+02EPnozZG
J644gI+mvZ8PRGfz0Z6iW/HVEz661Eronyzz0ZenNyynKcCgdqnv65MCvCzX
l7SECmDplTtPLRGgocF8VPpcAKv9g90zb2Tbm1HfRxHCqkWutPq4EI2qZZnZ
gUJY+9vfjswUYuKoI3e3TYg4hfP07+eF0Od45SuRReipYoiYdiIw4m6epzBE
UDkbX1+UK0KdXqq6YacI+x/SmAs8EfzNnqpV0cToaLqcec1TDKq9RNUiTYwb
PTkZwt/FGHQxU20lxDBi9afHHpIg4VKAygkPCRY4AQOflkvgcjEw7QhPgvqJ
QCeTE5ugXAhSPJSxiVh2UN9B7iamv2Yka5hs4YtxxmmVqC088giWk+/dAnks
+Jn0vW1Eul9NFHtvg8u6CqJmGyPCM7REtR081zRX0AzbQfsx8srDoR3UeQoG
bUx3URE9VjuUvovCgpYc77VdMB8X3BK4SFGZZpDVHSvFPyO7DPI=
           "], {
           Developer`PackedArrayForm, CompressedData["
1:eJwl0gFHnQEAQNFveZJJkkmSVCaTSZIkSZIkk3lmJkmeJEklSZKkTZIkSZJJ
ksxMJpkkM0mSJEmSJEkykyRJkg67nH9w0yOt4ZYXQRB8Dv4XRYhoYnhJLHHE
k8ArEkkimRRSSSOD12Tyhizekk0OueSRTwGFFFFMCaWUUU4FlbyjiveE+cBH
PlFNDbXUEaGeBhppopkW2ming0666KaHXvro5wsDDDLEMCOMMsY4E0wyxVem
mWGWOeb5xnd+sMBPFlniF8ussMpv/rDGOhtsssU2O+yyxz4HHHLEMSeccsY5
F1zyl39ccc0Nt9xxzwOPPBEYIYoQz0P0QcA=
            "], CompressedData["
1:eJwN0nk4lGsbAHB0qi+pLCWiRIhoDl+0nHLuEoVTyF5OU9m3pEkIk2QpYz0a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            "]}, {Automatic}][$CellContext`t$$]}, 1.7172246505438489`, 
         8.351686942611451}, HoldPattern[
         $CellContext`cachedRes$$[7.9399999999999995`]] :> {
        7.8812232753885665`, {
          
          InterpolatingFunction[{{0., 0.49900322646562756`}}, {
           3, 11, 1, {52}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBsQFO/iFib1JlAgAAAAEAAAA0AAAAAAAAAAAAAAC6SzdrEoQCP7pLN2sS
hBI/z3qvQhWhTT8UBvwb1HhcP2AnUMuOEGU/cbLi0WcZdD8yUR0+iKp9P/r3
K1XUnYM/WkdJi2RmiD8O88F7wvuQP25C37FSxJU/zpH85+KMmj8v4Rkec1Wf
P0iYG6oBD6I/xZvNysQrpj9Cn3/rh0iqP7+iMQxLZa4/HtNxFgdBsT/c1Mqm
aE+zP5vWIzfKXbU/pqlIysw4uD+xfG1dzxO7P7xPkvDR7r0/ZJHbQepkwD/p
+m2La9LBP29kANXsP8M/9M2SHm6txD96NyVo7xrGPwCht7FwiMc/rVYHR14h
yT9bDFfcS7rKP9x474S7Csw/XuWHLStbzT/fUSDWmqvOP2G+uH4K/M8/cZWo
Ez2m0D+yy/TndE7RP/MBQbys9tE/e4f3AVHt0j8DDa5H9ePTP4qSZI2Z2tQ/
Ehgb0z3R1T+andEY4sfWPyIjiF6Gvtc/qqg+pCq12D8ak9I4/vbZP4p9Zs3R
ONs/+mf6YaV63D9qUo72eLzdP9o8IotM/t4/riyROqvv3z+Ams2v
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104}, CompressedData["
1:eJwBTQOy/CFib1JlAQAAAGgAAAA+rq/7y63pv1FO2M2n9BTAV2C5AlCv6b9S
rVxQ2fQUwGDsVg3UsOm/LX/gxgr1FMAi5xzyntTpvw43xpmM+RTAwlgocnH4
6b/ye5AP9P0UwNQLRGBLHOq/Exce7EACFcCqwCvZ5YDqv3k9xdq9DRXAisj3
NLXl6r/RPoMHYxgVwPJxgG61Suu/QS7fcSsiFcAb4PtZ4q/rvzPZqS4SKxXA
zqLxJbF67L869gl3JzoVwN3Wj3L+Re2/9n8xu31FFcA63U+6pRHuv4e2Pu/x
TBXABWKbO4Hd7r8dAYV0Y1AVwIMODgdqqe+/TJQRa7RPFcC4byaW14Pwv+Ai
216VRBXAhq8rtGky8b+WE1nGhCwVwJp5V5L/3/G/XT3w4jMHFcDRqNpsK4zy
vwdi6St51BTARyPvzn4287/EcRMlU5QUwIx2UOOL3vO/PQosQepGFMA7cN3u
XcP0vzKTYy8OxhPAenZQJeih9b9qNqqyqi0TwG+PZIMoefa/HSjKUbh/EsDY
Gf6ANkj3vy7H5CKxvhHA69R+UUgO+L9BXyH+d+0QwL4Bx+i2yvi/5y7RfDoP
EMCS18uWAH35v7nLpjKgTg7A9eciJ8ok+r83vc/aMXIMwF32443ewfq/t0vZ
1LyPCsCSOU832GT7v+MgSXtrdAjAscTWmnH6+7+NhoOkGGEGwElmhKSwa/y/
8z97y7y2BMA2Z02kT9T8v7bMeOh+GQPABymYgpo0/b9gtCwW74sBwBeJJDHp
jP2/UkIsIA4QAMCUPV27nN39v6NfABapTv2/KRf8mRwn/r9QyBxVe6X6v+T9
l0LUaf6/qFD4m6kl+L8lGZfQR8D+v9l07zDcxvS/UU1y9GgK/79A5p0vLsDx
v4rBFwCFSf+/LtEPDRsc7r8XD2Vg2H7/vzRHdSTGVum/wXM864mr/781QbEw
UCTlv7tkOjSo0P+/TqcsoLt34b+0PhF2KO//v0MBzRmih9y/5kpwcTUHAMAO
tRNCI2zVv8P9DBLEEgDAkJ7voz4Tz7/AOeMr9RoAwBm3jdJ6XsW/Txya7mAg
AMAr/1k/zse6vwEFflOGIwDA2OYUtwhkq79yRI5BpCQAwJK8a/Jz3JW/w5a5
GQ==
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.49900322646562756`}}, {
           3, 11, 1, {52}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBsQFO/iFib1JlAgAAAAEAAAA0AAAAAAAAAAAAAAC6SzdrEoQCP7pLN2sS
hBI/z3qvQhWhTT8UBvwb1HhcP2AnUMuOEGU/cbLi0WcZdD8yUR0+iKp9P/r3
K1XUnYM/WkdJi2RmiD8O88F7wvuQP25C37FSxJU/zpH85+KMmj8v4Rkec1Wf
P0iYG6oBD6I/xZvNysQrpj9Cn3/rh0iqP7+iMQxLZa4/HtNxFgdBsT/c1Mqm
aE+zP5vWIzfKXbU/pqlIysw4uD+xfG1dzxO7P7xPkvDR7r0/ZJHbQepkwD/p
+m2La9LBP29kANXsP8M/9M2SHm6txD96NyVo7xrGPwCht7FwiMc/rVYHR14h
yT9bDFfcS7rKP9x474S7Csw/XuWHLStbzT/fUSDWmqvOP2G+uH4K/M8/cZWo
Ez2m0D+yy/TndE7RP/MBQbys9tE/e4f3AVHt0j8DDa5H9ePTP4qSZI2Z2tQ/
Ehgb0z3R1T+andEY4sfWPyIjiF6Gvtc/qqg+pCq12D8ak9I4/vbZP4p9Zs3R
ONs/+mf6YaV63D9qUo72eLzdP9o8IotM/t4/riyROqvv3z+Ams2v
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104}, CompressedData["
1:eJwBTQOy/CFib1JlAQAAAGgAAAAUN2UVwe7uP3DByG32A86/PV5Atq/u7j8t
5J+8vwXOv6bnElae7u4/sTHjDokHzr8f5IQWA+3uP9ycEAG3Mc6/ivW1lmXr
7j+VSb8t7FvOv6PdRNbF6e4/61F3XSiGzr/sPvrmLOXuPy+Kim6j/M6/ic3p
PYLg7j+66cXeTnPPv6gEVtTF2+4/m3GqwSXqz7+JZSGk99buP0TJwX2RMNC/
dSAy2yXN7j9GqLW/vafQv+YR4MEMw+4/ztWjuBYf0b+4VzpErLjuP+8w8xuG
ltG/S8udWwSu7j9y70/i9A3Svxw8dw8Vo+4/CAnWUkuF0r9n6IJNoY/uP1u1
J0b8UdO/IfIdm1t77j/PQNW1nR3Uvx8woFJFZu4//gM30qzn1L/0qNRVYFDu
Pz/mc6Kkr9W/8Ui+D6857j86uKiT/3TWv1olU3Q0Iu4/vSsBFDk3179JVeXo
UQDuP9MX+6rPPti/60fqz/zc7T9DOOmSFT7ZvySBaehBuO0/lo12AtYz2r80
Am2UL5LtP0QgpQD8Htu/glvjptVq7T8mzwO0mP7bv+W7kylFQu0/8bdKL+jR
3L924m0dkBjtPzhfSoJUmN2/hT7FN8nt7D/xPSj6dlHevwwGCZ8Dwuw/m7Nx
nRf93r+nRmG19I/sPwSBgigNrd+/U3SUKtpc7D8IL8ITHSbgv5KaV94YMuw/
4yIm1W9h4L+INojEwgbsP4Rbmbdel+C/2GKvyOXa6z82fJ4xG8jgv6+wpUqP
rus/qKqP5N3z4L8zfNsNzIHrP9miXeLkGuG/2ApPLahU6z+VWfL9cT3hv/vJ
tRMvJ+s/rTi2Uclb4b/RdbH+/uPqPwwt8nA5geG/kpM3mU2g6j9gw3o1CZ/h
v7wRnrA2XOo/GgZwIQq24b9sX9n+0hfqPwRl+bkCx+G/AD2/WjjT6T8JKJax
q9Lhv+YntPB5juk/f5DiVa7Z4b9IN2p/qEnpP3XXifOj3OG/RDqM6Nfv6D/7
/8TGStvhv7JSb/Ealug/oPic6v7U4b8+TgoziDzoP0VmmUqiyuG/IsnDMzLj
5z+ckPWS8rzhvwLYWxEoiuc/kKRODI6s4b87OQS7mUfnP1nd487LnuG/8CDQ
jQ==
            "]}, {Automatic}][$CellContext`t$$]}, 0.49900322646562756`, 
         8.380226501854194}, HoldPattern[
         $CellContext`cachedRes$$[8.48]] :> {8.433429994785934, {
          
          InterpolatingFunction[{{0., 0.4945745542001868}}, {
           3, 11, 1, {47}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBiQF2/iFib1JlAgAAAAEAAAAvAAAAAAAAAAAAAACpCZuv2YcPP6kJm6/Z
hx8/LTL++0wNUj/gWYEuDhFhP6iaA991G2k/6pSCi0pLeD9ArsETbQSCPwoS
wuE044c/1XXCr/zBjT+2nuElxr+UP4AC4vONnpo/JjPx4Ko+oD8LZfHHDi6j
P/CW8a5yHaY/a7salsfPqj/m30N9HIKvPzCCNrI4GrI/bhTLJWNztD+rpl+Z
jcy2P+g49Ay4Jbk/JsuIgOJ+uz9jXR30DNi9P6WGpC0JRcA/mV464QuewT+N
NtCUDvfCP4EOZkgRUMQ/deb7+xOpxT9pvpGvFgLHPwUXC/4IxMg/oW+ETPuF
yj89yP2a7UfMP9kgd+nfCc4/dXnwN9LLzz8J6TRD4sbQP1eVcWrbp9E/zxhy
4C/w0j9HnHJWhDjUP8Afc8zYgNU/OKNzQi3J1j+wJnS4gRHYPyiqdC7WWdk/
oS11pCqi2j8ZsXUaf+rbP+/Ur6XrVt0/xPjpMFjD3j8qT+4HHKffP07rtyw=

           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94}, CompressedData["
1:eJwB/QIC/SFib1JlAQAAAF4AAADVVwxE0lb1v2fMuex73Q/AbYHXZ81X9b+q
cAHoGNwPwOt5soDIWPW/+A8UrLXaD8Df0yfaxGj1v3RRVkLxww/AR5BOtLV4
9b+ylNL086wPwDifsvKaiPW/pRkdTr6VD8DS7kjgwrb1v8o7NY+5UA/AfO5o
JYTk9b9D6hUb5wkPwOVdIDHcEfa/XdaofVXBDsB8CDZ+yD72v8yidtATdw7A
4Y1pN1SX9r9pz1QJv90NwF6zO/QU7va/p+WWeWo+DcAhp3Xj+UL3vy3rm6qd
mQzA2LuWwfOV97++W9nl5O8LwB9Rwu705ve/nNXO6s9BC8Da4Yw8XGT4v6sd
HGecIwrA5cbfLHHc+L8f/kLFDv4IwASh+rQWT/m/VMskSXvTB8AjXDWXOrz5
v2VYGGMlpgbAZSTk+9Qj+r9Q6iSkNXgFwAmIf97nhfq/ijY1PbFLBMB7Sd1W
fuL6v8eVEzdzIgPAfr6+xqs5+7+Qm3ByJ/4BwN2St5Izl/u/5M48Qqa2AMCM
yeED8e37vwbpUP798v6/fYPxLyA+/L81gtEyfJD8v4WdGakEiPy/Yh1x0TBI
+r9fFBSd58v8v+iUnxThG/i/hBKNMBYK/b+AIfqIuwz2v1+KCyYgU/2/xZ+9
QhiK879Z323AsJP9v3c1C4JsOvG/PAZFE3rM/b/30RNh3TnuvxX+oNsp/v2/
RaO/zvtf6r8wKDb3Zin+v5wh2rK14ua/Bmi8kM9O/r9N223Ssbzjv4/dder3
bv6/O9thLhDo4L9AvJEzlJX+v0f+/rW7l9q/8syE7Kaz/r93XmjqmnnUv+5P
8DuCyv6/SVhPEtehzr/XchyuStv+v0BQc2AI98W/I85fEfvm/r/LCKUUA2q9
v+5eutFo7v6/CyYnoghKsb8dK0KCSPL+vyp/PXNRupy/WswBMzLz/r/Pcqyg
jKxzP/lQ7SlY8f6/iQ6eK3jToT9y8vOkBe3+v7yTvUcEU64/AGYEbUbp/r9S
Vb2NPXWyP87qrHQ=
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.4945745542001868}}, {
           3, 11, 1, {47}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBiQF2/iFib1JlAgAAAAEAAAAvAAAAAAAAAAAAAACpCZuv2YcPP6kJm6/Z
hx8/LTL++0wNUj/gWYEuDhFhP6iaA991G2k/6pSCi0pLeD9ArsETbQSCPwoS
wuE044c/1XXCr/zBjT+2nuElxr+UP4AC4vONnpo/JjPx4Ko+oD8LZfHHDi6j
P/CW8a5yHaY/a7salsfPqj/m30N9HIKvPzCCNrI4GrI/bhTLJWNztD+rpl+Z
jcy2P+g49Ay4Jbk/JsuIgOJ+uz9jXR30DNi9P6WGpC0JRcA/mV464QuewT+N
NtCUDvfCP4EOZkgRUMQ/deb7+xOpxT9pvpGvFgLHPwUXC/4IxMg/oW+ETPuF
yj89yP2a7UfMP9kgd+nfCc4/dXnwN9LLzz8J6TRD4sbQP1eVcWrbp9E/zxhy
4C/w0j9HnHJWhDjUP8Afc8zYgNU/OKNzQi3J1j+wJnS4gRHYPyiqdC7WWdk/
oS11pCqi2j8ZsXUaf+rbP+/Ur6XrVt0/xPjpMFjD3j8qT+4HHKffP07rtyw=

           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94}, CompressedData["
1:eJwB/QIC/SFib1JlAQAAAF4AAADferD2LXrlP4XxKkoYE9W/alyLbAR65T87
Y72cNxTVv60iMODaeeU/zgr54FYV1b+HUsuhM3flPwAR6MKfJ9W/V3BDGIp0
5T+ToH+V2TnVv6X5fkXeceU/9ezuNgRM1b8AFJhLBGrlP4aK90K5gNW/EhRg
FBdi5T+ord5n6LTVvyFX2tAWWuU/gqGNmY7o1b9iK9KzA1LlPyZLX92oG9a/
fE2gvaVB5T9cFmo3LoDWvzMR59z+MOU/4qMv02Li1r8QmDHMECDlPyypNvoy
Qte/kwFvU90O5T/IlTPfjJ/Xvxd9Akdm/eQ/UsQDumD617/EbCsR7ODkP02A
Fo1Vhti/3iUDfdHD5D9ndF95hAvZv5LEXJIepuQ/4Vrju82J2b84lYp224fk
P4YtScseAdq/ohodXRBp5D82xb7RcXHav8D7YXnFSeQ/vUff88za2r+6ENbw
AirkP00KrWtBPdu/zRC5ztAJ5D8gKViC6pjbv5KAmhdd5OM/n91sG+/5278j
zEZjbL7jP6D8BnxzUty/ygBT8gmY4z+CR5H6xaLcv+bhZJZAceM/KZRT4j3r
3L8BjHqmGkrjPyUHFCU5LN2/sOWn96Ei4z85cnlGGmbdvwM2euy67uI/4UyP
JZKn3b8XxKEvarriP5XQXQyF3t2/x1s0eMGF4j+uAoUj1Avev6GozvXQUOI/
y9hmoFow3r9A42JepxviPxQsAaDqTN6/9zRCAFLm4T+3/MgFS2LevxEUIdfc
sOE/JvkbBzZx3r+ZttJktWLhP/Bb8XXGfN6/PgTYDH4U4T947av35n3ev+q6
tWhPxuA/UIyQDj923r8S2oQePnjgP1H9KbY8Z96/E+0ablsq4D+4mGGVGVLe
v0QAyV9rud8/Am49bOA33r84dpqMsR7fP8/xgsZyGd6/Mh4DAJ2E3j+VCBuC
jvfdv23sejht2t0/L/iBoKLO3b/auJ24LjHdP9Ur4mrqot2/hCD1o+jH3D+V
RvRDbobdv5kxkL0=
            "]}, {Automatic}][$CellContext`t$$]}, 
         0.4945745542001868, 8.92800454898612}, HoldPattern[
         $CellContext`cachedRes$$[8.940000000000001]] :> {
        8.878422674276694, {
          
          InterpolatingFunction[{{0., 0.5622542000293659}}, {
           3, 11, 1, {46}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBgQF+/iFib1JlAgAAAAEAAAAuAAAAAAAAAAAAAAB5mFkClN0RP3mYWQKU
3SE/U7NrhV7JUz/MGUZFhatiP+5Z1kdbcms/o0ZfASv6ej8osGkvlB2EP/68
I94Svoo/6uRuxkivkD/A8Sh1x0+XP5b+4iNG8J0/toVOaWJIoj8hjKvAoZil
P4ySCBjh6Kg//vlisOcFrj+4sF4kd5GxP3Lki3D6H7Q/Kxi5vH2utj/kS+YI
AT25P55/E1WEy7s/WaM3EFxcvz+L463lmXbBP2n1P8MFP8M/RgfSoHEHxT8k
GWR+3c/GPwIr9ltJmMg/4DyIObVgyj+dct9ZUY7MP1moNnrtu84/C+9GzcR0
0D/piXLdkovRP8cknu1gotI/pr/J/S650z+EWvUN/c/UP7MExBqsSNY/466S
J1vB1z8SWWE0CjrZP0IDMEG5sto/ca3+TWgr3D+gV81aF6TdP9ABnGfGHN8/
AFY1urpK4D+qmQBljhfhP1Tdyw9i5OE/yUUlhfz94T+TrLLc
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92}, CompressedData["
1:eJwB7QIS/SFib1JlAQAAAFwAAACw2uAhNR70v4OWrHkQMwvAukk1ECgf9L+9
qw8RCzILwE7HaPUaIPS/uM+3cwUxC8CYOATzAC/0v4dpbYvZIAvAjbDWA949
9L8RwM0WexALwO+FPgyyTPS/aczUb+r/CsBfjdEdQ3n0v2GdJoS1zArAyP6L
3X2l9L/HBSFVxJcKwLc8tH5f0fS/Fcw7riFhCsAA9X085fz0vzPwre/YKArA
zQj2WtJS9b/bAatBhbMJwNMY8aEwp/W/EZY8Oi44CcCO0ubZ7Pn1vz723rk/
twjAhVLMNPVK9r8tlW2rKzEIwFExsmg5mva/3S/f8WimB8DReO6t8xD3vxYA
DSYzyAbARvc29SeD97+ZoIcRy+EFwPhLtQmx8Pe/ykvLTQb1BMAOuNQOc1n4
v0Tqldi3AwTAk9khZFu9+L+xzEF/pw8DwGDQzFZgHPm/US2mM4oaAsAUkm+T
u5j5v6R2XkvxxQDA2rv4jakL+r9yEIfTvez+v91Dg6Zadfq/61XBy4Je/L/w
VLa2Fdb6v6lb//no5vm/hNLY5TMu+7+R6u9MfYr3v92yroscfvu/7WvPTqtM
9b/ax/RJQcb7v6ymha7QL/O/F/b3bYoU/L/mChmQysnwv2EkclvSWPy/NhUz
bPYv7b/YpbzW+5P8vyN25BOyM+m/LNlzs+TG/L/Uivkwb5vlvwBlaZZh8vy/
tkChWTFi4r9sFc0AOxf9v46088jJA9+/j9zgcis2/b+fmrmHpufZvy9EQXbD
V/2/W+ceQ6rs078SETDJQ3H9v6Guk1gwxM2/cjqB2/WD/b+8I1tEm07Fv1YG
4fn0kP2/rJO6yDd5vL+wpt+VMpn9v/RC0BzfsLC/u7Su9Xqd/b+IDkNhxZab
v7BJs/p5nv2/1kmVqzyicz8Gboycv5z9v8vyepjQ0p8/jtu5xVKY/b8r34D/
eeurPxDeSqW6kf2/Y3rdxXbWsj87KeUCxpD9v/7lvFkGYbM/ArqnPw==
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.5622542000293659}}, {
           3, 11, 1, {46}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBgQF+/iFib1JlAgAAAAEAAAAuAAAAAAAAAAAAAAB5mFkClN0RP3mYWQKU
3SE/U7NrhV7JUz/MGUZFhatiP+5Z1kdbcms/o0ZfASv6ej8osGkvlB2EP/68
I94Svoo/6uRuxkivkD/A8Sh1x0+XP5b+4iNG8J0/toVOaWJIoj8hjKvAoZil
P4ySCBjh6Kg//vlisOcFrj+4sF4kd5GxP3Lki3D6H7Q/Kxi5vH2utj/kS+YI
AT25P55/E1WEy7s/WaM3EFxcvz+L463lmXbBP2n1P8MFP8M/RgfSoHEHxT8k
GWR+3c/GPwIr9ltJmMg/4DyIObVgyj+dct9ZUY7MP1moNnrtu84/C+9GzcR0
0D/piXLdkovRP8cknu1gotI/pr/J/S650z+EWvUN/c/UP7MExBqsSNY/466S
J1vB1z8SWWE0CjrZP0IDMEG5sto/ca3+TWgr3D+gV81aF6TdP9ABnGfGHN8/
AFY1urpK4D+qmQBljhfhP1Tdyw9i5OE/yUUlhfz94T+TrLLc
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92}, CompressedData["
1:eJwB7QIS/SFib1JlAQAAAFwAAAB9JTOz4kLcP2R+8w1mP9C/kjPYHJpC3D+Z
yY/AfUDQv307nIFRQtw/EWPvZpVB0L+HWK2/2T3cP6tcV6+7UtC/HEVAS105
3D80UeIE1mPQvzd7oCfcNNw/VfOhRuR00L+lhQUWJSfcP4vK9OAcqNC/qCH1
xkMZ3D8MlOuk4trQv+dZsZk4C9w/UL4KPTIN0b966HrxA/3bP+E+jWAIP9G/
GWRNyh/g2z8gsBObO6HRv159r5+awts/+xX8+GMB0r/2Q3znd6TbP/DmlNZq
X9K/KPeyOruF2z9waJZPO7vSv4AZtVNoZts/1VpfYMIU07/dGGqa8zTbP5Mf
s59HmtO/2J535jAC2z+YE/oi/RnUv1JWxkovzto/j31/+riT1L+7Zts3/pja
PyfsDLFcB9W/gXJfXa1i2j+BNb4f1XTVv5Gl2I1MK9o/SJgHDBrc1b9HG2cX
aNzZPyOXvCfMYda/3Q3WK7yL2T+zrkt7mNvWv3hnhMZyOdk/dt3mjMNJ178t
Zo+8tOXYP4igJv6srNe/WVE5ZamQ2D/D5952ygTYvwGOpVR2Otg/rw40gKJS
2L/Y3lwoP+PXP5QN9bvHlti/hM5auYF31z9mwTZlwN3YvxwTBqSqCtc/YbS/
XUYY2b9dk2Gt7ZzWP13+vuF5R9m/nOcWwHku1j/3VCcRdGzZvwlAShd5v9U/
uUV2xkGI2b9jAVZ8EVDVP9wwfQ3gm9m/04DdkGTg1D9qF2TtOajZv3Ugv0VJ
SdQ/cm0bDtuu2b86hurfJLLTPzUZP0Gcq9m/vFOPnSwb0z9GXZtUG6DZv/DH
YeiMhNI/+yh+rbuN2b/oQJScau7RPz2a0RWsddm/ADtLLORY0T8gLhWM7FjZ
v/emU6ISxNA/YhAcTFQ42b91YCGACjDQP9z6kImXFNm/4ltRBQsgzz+Elnm8
1+rYv7yYH3cn4s0/5yCnb7G+2L9014Enk7rNP8dYJDcIudi/NQOGpw==
            "]}, {
           Automatic}][$CellContext`t$$]}, 0.5622542000293659, 
         9.44067687430606}, HoldPattern[
         $CellContext`cachedRes$$[9.219999999999999]] :> {
        9.149037942635022, {
          
          InterpolatingFunction[{{0., 0.6064005992793257}}, {
           3, 11, 1, {46}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBgQF+/iFib1JlAgAAAAEAAAAuAAAAAAAAAAAAAAD93jZ11lcTP/3eNnXW
VyM/GcP4cVcBVT8pVaUK2stjP8ZITlwIF20/FGOyQzr5fD/j0J4seLOFPzxw
ZDdT6ow/ygcVIZcQkj8jp9orckeZPz4jUJsmP6A/6vKyIJTaoz+XwhWmAXan
P0OSeCtvEas/kUzy63NRsD8BUChCMBqzP3BTXpjs4rU/4FaU7qiruD9QWspE
ZXS7P79dAJshPb4/JfiSZ1YYwT9qwaUBHBLDP6+KuJvhC8U/9FPLNacFxz85
Hd7PbP/IP37m8Gky+co/w68DBPjyzD8A0ClR70HPPx74J09zyNA/PQi79e7v
0T9bGE6cahfTP3ko4ULmPtQ/mDh06WFm1T+2SAeQ3Y3WPyxpfc1aEtg/oYnz
CtiW2T8WqmlIVRvbP4zK34XSn9w/AetVw08k3j92C8wAzajfP/YVIR+lluA/
MSbcveNY4T8qt9I1rTbiPyNIya12FOM/gb7FOqJn4z8Suqwb
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92}, CompressedData["
1:eJwB7QIS/SFib1JlAQAAAFwAAAAWxNfrMF/zv8vXGHZJmgjAXNIz1h5g87+E
WxipeJkIwLeFqrgMYfO/gZUbqaeYCMAL3zR9Um/zv2wyFi4BjAjAzaIP25B9
879l+fPfK38IwLXpGrfHi/O/fdur/ydyCMAIPzWQubfzv1xreG2YSAjALTfb
3F7j878UfOejUh0IwMoyV5m0DvS/rEmUY1/wB8ADGnHHtzn0vwYRjQjIwQfA
azW31rqO9L+IJZU11V8HwA7f6oRR4vS/JXzaws/3BsDZuBOUZjT1v6xRGAMV
igbAH3ELHuaE9b9iOps1CRcGwDKfN7O90/W/oufZjxafBcCLAF+EC0r2vy1d
tv5Q3QTAwI/fkQi89r/KHuZhkRIEwIB1haiHKfe/bgjK6I5AA8AN+OIpZZL3
v7AJMLwEaQLAaKNaE4f297/GV58oqY0BwK7JeMrcVfi/ay3QgiWwAMD/Wcva
4NT4v81DSj9H6v6/vdYFwzRK+b9HGio/PHr8vzO8Rdj+tfm/2uijeHUX+r/U
gXgQgBj6v3e+fOUYyPe/i4jdUQ9y+r/Vk36SGpH1v1TM5rwUw/q/5uLHUUF2
87/upRgmBQz7vylEjwI4evG/pppes6lX+78j9t1goaPuvykjsJvAmfu/KW/G
bLut6r9OFefEG9P7v06hQ8BgEue/xIBDuYkE/L9RlxpjH8/jv8PGrIDRLvy/
vqzE1P3f4L9Hvvmqr1L8v34ZeS/tf9y/Py/eYNRw/L/7k0P5v9LXvySPpbPP
kPy/ZJ8i5CB40r+YPxS0Sqn8v617KYK91su/wyCakGm7/L9mZZsqMyTEv0xQ
r8cpyPy/ADSWPydPu7+wXc5TZdD8v/7D5R3HaLC/cNCvS9bU/L/airpp4Bid
v6nV6aoa1vy/+wG3INluVz//rp3zt9T8vxOnHtHl+5o/sNyOuXPQ/L+2dcTK
Qn2pP+eGXx7Xyfy/Z+TiCLKcsT+0zI992cb8v7wwod19MLM/NwugIA==
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.6064005992793257}}, {
           3, 11, 1, {46}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBgQF+/iFib1JlAgAAAAEAAAAuAAAAAAAAAAAAAAD93jZ11lcTP/3eNnXW
VyM/GcP4cVcBVT8pVaUK2stjP8ZITlwIF20/FGOyQzr5fD/j0J4seLOFPzxw
ZDdT6ow/ygcVIZcQkj8jp9orckeZPz4jUJsmP6A/6vKyIJTaoz+XwhWmAXan
P0OSeCtvEas/kUzy63NRsD8BUChCMBqzP3BTXpjs4rU/4FaU7qiruD9QWspE
ZXS7P79dAJshPb4/JfiSZ1YYwT9qwaUBHBLDP6+KuJvhC8U/9FPLNacFxz85
Hd7PbP/IP37m8Gky+co/w68DBPjyzD8A0ClR70HPPx74J09zyNA/PQi79e7v
0T9bGE6cahfTP3ko4ULmPtQ/mDh06WFm1T+2SAeQ3Y3WPyxpfc1aEtg/oYnz
CtiW2T8WqmlIVRvbP4zK34XSn9w/AetVw08k3j92C8wAzajfP/YVIR+lluA/
MSbcveNY4T8qt9I1rTbiPyNIya12FOM/gb7FOqJn4z8Suqwb
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92}, CompressedData["
1:eJwB7QIS/SFib1JlAQAAAFwAAAAAa134L17UPxjMl4PeFsu/6E1rc+5d1D8n
OQzkBBnLvwOlRumsXdQ/kY3jLisby791vSzaulnUP4r88cwtPMu/v4llAcRV
1D9yPPsxHF3LvzWE5WHIUdQ/xsw2HfZ9y79NPe8aTEXUP8RFRhly48u/9Ed1
QaI41D/b43u4HkjMv3iSZjPLK9Q/LfdWyfSrzL9QgBxTxx7UPyacxi3tDs2/
Bn64tDoE1D+TJj1NKdLNv3YWF7f/6NM/bCz7qp2Rzr/W2YnaGc3TP5EYuhMY
Tc+/RCESyoyw0z/F3PfVNALQvyJAsVlck9M/Y+/inbNb0L8ZAkfYFWXTPzKm
1Zxt4dC/EeDOwGI10z+M2BXRkWHRv+VUkOlSBNM/h21juOzb0b9Ie/So9tHS
P22u5JxWUNK/8gVKs16e0j9PdgeSs77SvxSlcPqbadI/oZZ3M/Mm079WSn8s
2xzSP9AJv89fsNO/mOTvpxPO0T/bDqm0hi3Uv8p4X4R1fdE/q177jaGe1L9o
xSm0LyvRP353WTAKBNW/hAl2kG/X0D/jodHiNF7Vv46feHxggtA/Rhoadaqt
1b8DAoifKyzQP256MbEC89W/NQWtx2GMzz+XgTl3ETjWv7GNs2smvs4/PFVZ
Vzhx1r+UlbhEDu7NP1AyKSqDn9a//OBp1ngczT8Z4Aqd+MPWv0TW1Fa8Scw/
sR1jJJXf1r9rIUkeJnbLPwSo9m9H89a/YNDlMfuhyj9QWQoe7v/Wv7qMDvOL
isk/ZRTMei4H17/WYCjU/XLIPyTl+QZGBde/b034Gbdbxz+N1iGlpPvWv4c3
I8YNRcY/ZgNkGYnr1r8K/ZTRSS/FP2AcXVwF1ta/AhOJL6caxD96RN0iA7zW
v77esJpXB8M/7nFnrkie1r9biOElhPXBP9/zinJ9fda/DC5T5di+wD/y3b+j
/1TWv1DlrFTjFL8/PUD/t+cp1r8tztuNzi6+P2Vk6OYwGda/9s+GKw==
            "]}, {
           Automatic}][$CellContext`t$$]}, 0.6064005992793257, 
         9.755438541914348}, HoldPattern[
         $CellContext`cachedRes$$[9.3]] :> {9.226774217104854, {
          
          InterpolatingFunction[{{0., 0.6193253295543037}}, {
           3, 11, 1, {46}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBgQF+/iFib1JlAgAAAAEAAAAuAAAAAAAAAAAAAAA7gbYYrs0TPzuBthiu
zSM/WV3s4XhiVT9G9WAAniVkP967y4//mW0/MUBDGnWdfT85UVA29TaGP1oC
f98vn40/vdlWRLWDkj/eioXt7+uZP/8dWksVqqA/kHbxnzJepD8gz4j0TxKo
P7AnIEltxqs/2zEezny+sD/eT6z3wpmzP+BtOiEJdbY/44vISk9QuT/lqVZ0
lSu8P+jH5J3bBr8/puSEl6iNwT9XZRdg45fDPwjmqSgeosU/umY88Visxz9s
5865k7bJPx1oYYLOwMs/zujzSgnLzT986VT1SxLQP5HeL0UTP9E/ptMKldpr
0j+8yOXkoZjTP9G9wDRpxdQ/5rKbhDDy1T/7p3bU9x7XP+od8XjDqNg/2pNr
HY8y2j/KCebBWrzbP7p/YGYmRt0/qfXaCvLP3j/NtarX3izgP8Tw56nE8eA/
vCslfKq24T/ZXu2IjJniP/WRtZVufOM/IKWAWoPR4z/LVsGP
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92}, CompressedData["
1:eJwB7QIS/SFib1JlAQAAAFwAAABm9n5vjinzv+aK5cBw4wfAJglX8Xoq87+n
/HQfruIHwMn6pWtnK/O/VEuPS+vhB8AAcdzAgDnzv6lle0Ay1gfATlYxG5NH
878AJfduS8oHwMpgqV+eVfO/P2SKETe+B8CZThgicoHzvxe8tOE3lwfAqSDH
DPys879KlP5tg24HwLC+ewg52PO/0zvB6yFEB8B1JcQCJgP0vxWJPy4cGAfA
pxfv/QNY9L8vQiQhSrsGwLXOUs1+q/S/W2j6215YBsCKMuaBgP30v1mbq++z
7wXAUiCQgPRN9b9LMr0gqoEFwONwVaLHnPW/Cu6vd6gOBcClLK7eBRP2v7et
qDZ+VATAWy9+fAGF9r/xWPK9JJEDwE6PctSK8va/mK34QkvGAsDpoR7re1v3
v1zsPsym9QHA+yH+gri/97+sEF1F6SABwKW0CPEtH/i/R6qgP7lJAMA1RstT
K5/4v1pqQcB6Kv6/gMLd1FoV+b8cRvH5Z8b7v2bv+Pffgfm/f0wKIK9u+b9k
2C5l+uT5v2v4rzidKfe/OtwFAgE/+r9RkB+rSPz0vwRNAf5ckPq/ELbiupTq
8r8GG8ANhdn6v7bJcGpC9/C/OSVCBUYk+7+0az8o5L/tv7vTTMyZZfu/dgRu
tcHo6b+Ld9InTp77v+HilsjgaOa/uzgw0S3P+7+CYJD1/j3jv53T1Fj8+Pu/
KkzSzFtk4L/EsAA0cxz8v6Qn7xZgrtu//KfHzD86/L/AAoj3IyLXv6ZuELS8
Wfy/aC04movx0b9cOSR12XH8v3yTTjLWDcu/Mzv1F7OD/L8DVnChVJLDv6c0
1klBkPy/QcoORJSDur9GgUpaWZj8vzz9mi3Uxq+/R0VSrbGc/L87Esiy4uGb
v4Z2pFjlnfy/0j3x5mTpXz88aJCfd5z8vz6Q1+4K+po/16fDiR6Y/L91alJj
/FipP/J4JHRmkfy/KHWZBMJ7sT/0mJweXY78v8RVO1ikCrM/Ki2YsQ==
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.6193253295543037}}, {
           3, 11, 1, {46}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBgQF+/iFib1JlAgAAAAEAAAAuAAAAAAAAAAAAAAA7gbYYrs0TPzuBthiu
zSM/WV3s4XhiVT9G9WAAniVkP967y4//mW0/MUBDGnWdfT85UVA29TaGP1oC
f98vn40/vdlWRLWDkj/eioXt7+uZP/8dWksVqqA/kHbxnzJepD8gz4j0TxKo
P7AnIEltxqs/2zEezny+sD/eT6z3wpmzP+BtOiEJdbY/44vISk9QuT/lqVZ0
lSu8P+jH5J3bBr8/puSEl6iNwT9XZRdg45fDPwjmqSgeosU/umY88Visxz9s
5865k7bJPx1oYYLOwMs/zujzSgnLzT986VT1SxLQP5HeL0UTP9E/ptMKldpr
0j+8yOXkoZjTP9G9wDRpxdQ/5rKbhDDy1T/7p3bU9x7XP+od8XjDqNg/2pNr
HY8y2j/KCebBWrzbP7p/YGYmRt0/qfXaCvLP3j/NtarX3izgP8Tw56nE8eA/
vCslfKq24T/ZXu2IjJniP/WRtZVufOM/IKWAWoPR4z/LVsGP
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92}, CompressedData["
1:eJwB7QIS/SFib1JlAQAAAFwAAABcIBfcwj/SPxyurx+fncm/nm/cbYM/0j9L
gP8Dw5/Jv8WtVfpDP9I/lXWH0+ahyb8tKuAveDvSP+/yn3qOwsm/Mb/gk6c3
0j/ZZwHsIuPJv3esMinSM9I/Ze0w56MDyr8DPq2bryfSP6K6OUn/aMq/otJh
UV4b0j/vUQBgkc3Kv4inCqjeDtI/VfFdylIxy79AZ/QBMQLSP20/4zg8lMu/
CIMWWU3o0T9sQEqzalfMvxDNrqq2zdE/BWZfw+UWzb9mdPp8cLLRP/sgqYh5
0s2/kp2Ug36W0T99WlFy9YnOv7XMyp3kedE/0ZODjiw9z78FnZUFhkzRP7Nj
ufZxJNC/0xtV5bAd0T/haALYxqTQv3DnLVZ17dA/7dc/el4f0b8LAe/847vQ
Pxh04VcOlNG/E6yL5g2J0D/K0UzgtwLSv1VcYmYEVdA/hpLlQEhr0r/wgpUy
vwjQPyW1tuwA9tK/3qlJ3rp0zz+YqcCsSnTTv88uA+Yi1M4/MXRLQFzm07+V
6eXcGDDOP27TZWaOTNS/Ejqn2PuIzT8YaWLlVafUvwEJ8dgm38w/B91PUj33
1L9hO+Et8DLMP1vL7jTfPNW/dR9BiQZqyz/5zXsVMYHVv0KsG8bSnso/2ksl
J8K51b9H2m+IvtHJP7BPu0mZ59W/kopX3ykDyT+eHlaTuAvWv8cRy4prM8g/
uFb8TRgn1r9yfmxp0WLHPwlB7W+jOta/04FvAaGRxj9SVG1NNUfWvyBZKjtC
f8U/RBerzG5O1r+5fNCCw2zEP2Cn75WmTNa/AbI62Ypawz+moKnLQ0PWvx5u
hyTuSMI/e8FqGH4z1r94pnRfNTjBP7T6qMNhHta/h9mTk5wowD+ieC8C1ATW
v08WhD6rNL4/RdBJkZfn1b8iHemBExu8P/WxcSxRx9W/1MmxSqGzuT+TuoqZ
D5/Vv0cN3oDLULc/pLfi/yx01b/4c8av+Wy2P/gYAsuIY9W/aiSJ2Q==
            "]}, {
           Automatic}][$CellContext`t$$]}, 0.6193253295543037, 
         9.846099546659158}, HoldPattern[
         $CellContext`cachedRes$$[10.84]] :> {10.605172949271417`, {
          
          InterpolatingFunction[{{0., 0.9850149319464714}}, {
           3, 11, 1, {48}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBkQFu/iFib1JlAgAAAAEAAAAwAAAAAAAAAAAAAADucNfM7ichP+5w18zu
JzE/LFj5vR+UYD86wleiQQNvPyQWW8MxuXY/0DfHwuPUhj9IcvBRlyaRP6dI
fcK84pY/Bh8KM+KenD/i5RGKlgukP0K8nvq7x6k/oZIra+GDrz+ANNxtA6Cy
P7CfIiYWfrU/Dto0hJc+uj9uFEfiGP++P2anLCDN38E/lsQ1zw1AxD/F4T5+
TqDGP/X+Ry2PAMk/SiUiA8TXyz+fS/zY+K7OP/o4a9cWw9A/JUxYQrEu0j9P
X0WtS5rTP3pyMhjmBdU/pIUfg4Bx1j/zeyI/7k/YP0FyJftbLto/kGgot8kM
3D/eXitzN+vdPy1VLi+lyd8/vqWYdQnU4D/lIJpTQMPhPwycmzF3suI/6Gmi
H2nQ4z/FN6kNW+7kP6EFsPtMDOY/ftO26T4q5z9aob3XMEjoPzZvxMUiZuk/
Ez3LsxSE6j/vCtKhBqLrP8zY2I/4v+w/qKbfferd7T+EdOZr3PvuPy4E2Qg+
he8/g369Yw==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96}, CompressedData["
1:eJwBDQPy/CFib1JlAQAAAGAAAADKrY243PDuv3n+qSKhrfi/OmQfHITy7r8+
pSnoxK34v0+xEYIr9O6/jgp2Yeit+L9MLI7ibwrvvy28bBOpr/i/wyNmv7Ug
77/Iyy+fM7H4vx73qef8Nu+/ibzE04ey+L99/Mg1033vv/0Dmz9Wtfi/kWz1
Xq7E77+GM6hZ+LX4vyLz0BrEBfC/7SorW2m0+L+sx3I1LSnwvwW55TalsPi/
FTGYQudv8L+nM4oHcaL4v1u868RrtvC/KZFlqUqL+L9pLKsKofzwvxEKacUt
a/i/OX9zam1C8b9fPOcrI0L4v86ipWa3h/G/6CShDEEQ+L83hqFaKPnxv6d6
dxWEqve/ZtuB3X5o8r+3Zlp01y33v+v0bPtQ1fK/jiuSpIub9r+ggh++Oz/z
vwn8r+JH9fW/zUWYxuSl87+MOPOt/jz1v7HFn477CPS/WdREw9909L/5LwWn
Ynr0v91U64kldPO/3qjOiOrl9L8ZEJTYZ2TyvzhdHx1KS/W/fh06GPRJ8b94
m3uXUKr1v6Mh2aYBKfC/H6k1juQC9r9pbaY1Hwvuv7QnOWgCVfa/xvdY8ZHG
6781PglCuqD2v8WuW0vgium/qqXiCtb69r+i/788cLHmv3rv0U+KSve/3n5/
lyP7478Q0z0LaZD3v0wk+V5Xb+G/G8S0uBrN97/z4LNmjyXev/dMaSBVAfi/
4+tnxM7P2b+Z//iJ0y34v96kp7aL3tW/LLzJcVBT+L9eX3C98E/Sv07YRcCA
cvi/G90aHfQ/zr+eTZljdJD4v0pSO5YKise/RjmzK22n+L/ez4UbmrzBv5qF
f4xhuPi/XxTsZ7Z/ub/QJPtBLcT4vzvTak/n97C/VaAE25HL+L+taQGsCWij
vwsoLjQ4z/i/htNAjklMjL/EjEp9ss/4vzGe5WR/4no/4JI0fn7N+L/ZgxFG
BlaYPyysPeoHyfi/mBz6/KyVoz/1hwCgqsL4v1Opmdwh0ak/V1R4wrS6+L93
YkBrBguvP640BUZktvi/aVI+3vqesD8oUsI4
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 0.9850149319464714}}, {
           3, 11, 1, {48}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwBkQFu/iFib1JlAgAAAAEAAAAwAAAAAAAAAAAAAADucNfM7ichP+5w18zu
JzE/LFj5vR+UYD86wleiQQNvPyQWW8MxuXY/0DfHwuPUhj9IcvBRlyaRP6dI
fcK84pY/Bh8KM+KenD/i5RGKlgukP0K8nvq7x6k/oZIra+GDrz+ANNxtA6Cy
P7CfIiYWfrU/Dto0hJc+uj9uFEfiGP++P2anLCDN38E/lsQ1zw1AxD/F4T5+
TqDGP/X+Ry2PAMk/SiUiA8TXyz+fS/zY+K7OP/o4a9cWw9A/JUxYQrEu0j9P
X0WtS5rTP3pyMhjmBdU/pIUfg4Bx1j/zeyI/7k/YP0FyJftbLto/kGgot8kM
3D/eXitzN+vdPy1VLi+lyd8/vqWYdQnU4D/lIJpTQMPhPwycmzF3suI/6Gmi
H2nQ4z/FN6kNW+7kP6EFsPtMDOY/ftO26T4q5z9aob3XMEjoPzZvxMUiZuk/
Ez3LsxSE6j/vCtKhBqLrP8zY2I/4v+w/qKbfferd7T+EdOZr3PvuPy4E2Qg+
he8/g369Yw==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96}, CompressedData["
1:eJwNj31Qy3EAhysseW113VzUCReRw9qhRLsm0VmIUh0XC11SO715bcISplfK
LcqIsjCvmSZ9evv9+P5+rda2zBnpOtRxirTcOdfZH88fz3/P4yORRu13dHBw
2GPHzzeQWzyRoMoW/mmSZxmGitWtNXbPaFJHjPuVwbclMO+V3UN7eJqxwDKc
2Oj9xzaJ4Mb5r1HDruXQ1Gvzg5wJXohL0voGyqE1K1YqJhMwW6sXvGm6Cmqb
1egynWAXnWlVJFdgw6jnKyc3Ao9ZuhqVeyVGaMaQxSPQh+XImcYb+Lwtrlfi
RRCxRjnvAP8m/qRWjqgXE/xwZZXL31UjqmRQ1RNI8G/PqszVx2uQ0N9v7Y8g
sDF8Sx5PDcPulEH9bgIpt+i9z8N7+NUyGFeaTjBfntbPE2pgKK+a6agkYONz
O0yrHoM99Dwmvp2gNPnIey/RU4TPVPjKRgn25R36+TukHlyVfCzcj4GM/50r
99dixWmRV5GEwZehSyMLnRswQScQLlQxsPBjOSmdOvTuuKPhDzP4bsm2FJoa
4eNUKOgSseh79G7O+YYmPFoSmXarkkVSXJeuIKQZv6bV+Wz5xyJAGFnRym3B
7R8pBdkJHYgRW4VBphY0R8XfbqA74N64NtdR3orYZcRft0KPg9lZLtEL2tBW
MuPp9TY90jmU+FtvG14qix0L4zuRvjpM8VfWjtDS8Ty9rROZZrc0Dw6Fn4lW
/9orXZAHLGPGsyikVEvDg2YbsNI5uO6qgUL7upLmyFQDHAoiN7E8Gq+DBe6b
mw2YlajXnhLTGB91EY+6d+PMtbtrL2bQWBRWUZ1/tBtMoqa2r5CG23bCpn7s
RtmFLNE0JY37GuOThFAj8t34O89dobGXZ3s+t9aIt4KAoDNnaQx4B6fnTDXB
KUe9fjiJxq6h2MsRUhM2H9YOnBTRuFyvYxONJkj3mTxV9p5Q5TNLncCMyhec
aOUXCsfuSm5yys3wrgq5dlxj/5PFySRjZrjca4hZmkHh8BTZuQfRPfhKH2g6
IqAgzO344Hq2B6LsvZO3e1D4D98UrEc=
            "]}, {
           Automatic}][$CellContext`t$$]}, 0.9850149319464714, 
         11.590187881217888`}, HoldPattern[
         $CellContext`cachedRes$$[11.92]] :> {11.324800788346888`, {
          
          InterpolatingFunction[{{0., 1.399248250479089}}, {
           3, 11, 1, {50}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGIjBgTIP6//WlJY1R5Cm0JpV3u17ccfLJvjD+WH2jde
Pbl2W0GRvTpYvN4+7cyjTu+UNnvLvYmLnX/12Ise8Pv96uoS+7yOR22LzDba
7zlw1mbxxG32PD93fFr8Zrf9WomgkEuLD9hf3eK+PijwsP2fAFuuy/+O2i9g
lo6M+37C3nnbj+Uv35+2f55x7VvJi3P2R3lvKTV8uGAv/tzj1NGcS/aZB7YX
cr+8bF92+pVnffc1+9zDx1b6dd6wT929iFOu/ZZ9zOa6zLctd+yDV0ed3NN0
z35p4GwRN4cH9gt9O4/o2j+0//dlgw5D9CP76Dk3plwqe2y/w5nh75JJT+zF
Xqunlq97al88yf+s56ln9hcsy01lnj231304b+47xpf2HPdVWc44vrJ/cmdN
1srG1/b7bxlfbDv4xn7WjV3mKYzv7EuvOc5zdHxvr5GV0tTv8MFe9OVy07oH
H+zn9yp4LLrw0V7DaGbUsQOf7DdeE8x9teGzvXV1Vz3fwi/2R+SZJxlN/Gq/
Z72OUlDyN3sA3kbNgQ==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100}, CompressedData["
1:eJwBLQPS/CFib1JlAQAAAGQAAAAIl2HDepfqv16J53QJ4um/y8dajouY6r/O
/Oj8ZuPpv/QotWecmeq/QEMLVsTk6b+WZCY3vpvqv8jl3nh+5+m/7NUIQOCd
6r/RoLTfN+rpvw3/TIICoOq/cQMqivDs6b+vJtJfZbXqv5BXG2b+B+q/BofE
Y97K6r9I6aAGwSLqv7di209t4Oq/8Q3x7DY96r/PG0/kEfbqv/A0F5peV+q/
A2iYddOr67/VGHG61yLrvy7+/46qZuy/lWyT8trV6787/HUIC/3svypb9Mal
T+y/sqmVrsaV7b95Pa2x37bsv8wFCHt2MO6/w4ObMzgK7b8SF+3ErMzuvxP4
MD+FSO2/HdhPH/Zp77+O/s8Xy3Dtvx/L/7CTDPC/FjiSQMSC7b/eA28WN2Tw
vyuK1un1d+2/EsruLo+78L8YauoVDFDtvyzXKIRFEvG/nc2yUhwL7b97uX6C
BGjxv4RRuHuoqey/VMK+uHi88b+3uhYBnizsv34zXLcfTvK/8nVQFVQP67+d
sRwn5bfyv4/VQIcZB+q/eybo8EQd879XJC5dFNvovwX74LW8ffO/4hGSeXeR
57+yrPCi49jzv3E/J+fZMOa/ochucmsu9L++Ogdh7b/kv2SQU0ogfvS/kAr4
4jlF47/HB58J5s/0v1N1q1WJm+G/uU6rPlAa9b8X6W1L4+nfv/S73oR7XfW/
y2npZPev3L/VGSrdnpn1v4wJV4D6k9m/2/eVOwbP9b+SG63vKJ7WvxJ98joN
/vW/UT+MFm3U07+foKwyGif2vx+kJVqWOtG/ihjx1btO9r/EnYTkBhDNv6kW
u6rvb/a/5j/EuJ0qyL84BSP5U4v2v9CWuedHwsO/vZa644Gh9r+oMhTIOKO/
v+B5rIwKs/a/PlFCQ7CiuL82JMI/dcD2v0LMjGY2crK/5K+Sbz7K9r+na6jN
9/+pv5sau3QT0/a/YTUQSvlBmL+vWyMnBtb2v8CdhAGnt1q/TRrsUjLU9r+9
HWhW15mQP88J0HqEzva/ZuTHpaVKnz+y66cLwMX2v60r/6uOhKU/o/i5dwq8
9r+cZAgpgaipPxye1fw=
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 1.399248250479089}}, {
           3, 11, 1, {50}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGIjBgTIP6//WlJY1R5Cm0JpV3u17ccfLJvjD+WH2jde
Pbl2W0GRvTpYvN4+7cyjTu+UNnvLvYmLnX/12Ise8Pv96uoS+7yOR22LzDba
7zlw1mbxxG32PD93fFr8Zrf9WomgkEuLD9hf3eK+PijwsP2fAFuuy/+O2i9g
lo6M+37C3nnbj+Uv35+2f55x7VvJi3P2R3lvKTV8uGAv/tzj1NGcS/aZB7YX
cr+8bF92+pVnffc1+9zDx1b6dd6wT929iFOu/ZZ9zOa6zLctd+yDV0ed3NN0
z35p4GwRN4cH9gt9O4/o2j+0//dlgw5D9CP76Dk3plwqe2y/w5nh75JJT+zF
Xqunlq97al88yf+s56ln9hcsy01lnj231304b+47xpf2HPdVWc44vrJ/cmdN
1srG1/b7bxlfbDv4xn7WjV3mKYzv7EuvOc5zdHxvr5GV0tTv8MFe9OVy07oH
H+zn9yp4LLrw0V7DaGbUsQOf7DdeE8x9teGzvXV1Vz3fwi/2R+SZJxlN/Gq/
Z72OUlDyN3sA3kbNgQ==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100}, CompressedData["
1:eJwBLQPS/CFib1JlAQAAAGQAAADTbSJGtinZv8A3MWY51LA/kJkf+Ikp2b9T
8arxd9GwP412X7FdKdm/1E2tYLbOsD/aKGUyBSnZvyE90gUzybA/QPd30Kwo
2b+SiEs5r8OwPzo4motUKNm/IxZB+yq+sD+HwjUb6CTZv3fbV03ohrA/ViPX
Doch2b8fQ0D2eU+wPwfWYG8xHtm/xbrnleAXsD9wg51F5xrZv/qVq585wK8/
DfJyYHkB2b+lLjpMmRusP1qeaA4s69i/vOiekdxjqD9aq1yB1tvYv04nI/Kd
aqU/2FhSS4HO2L/bT+HahGmiP5urJAUxw9i/y/uGNCDFnj8eNlLn6LnYv329
26u4r5g/1/Wnt6qy2L8lNohlP5eSP5zzkZUErdi/vgOfcNWrhz8iIaBR36nY
v6CM9z12c3Q/VXp8ozap2L9tOwJGi9ZYvwIVmdkDq9i/w0SUfdNEgL9EB8zc
Pa/Yv1P2SV2CN42/ZtbQPtm12L8dzYbPPPOUv+o8JlVAx9i/oxLLu1DNn78V
oyQGC9nYv8RPLQH/zaO/v6hlbKDu2L+mcaULjoOnv7Cr0pXMB9m/b/MhOrwC
q78EwpJ9VyTZv3EE8fvwR66/nokDDQZE2b8CxFodTqiwvwFyKCObZtm/V5X5
qJkNsr8kfAZCOpDZv1IfqgiTdrO/+Lmo68682b+gLBI5+ri0v4aAkm8E7Nm/
3DSwn6fVtb88cQ6OiB3av3cIrBfyzba/Zg8WcwxR2r9wDcnUk6O3v584LnRF
htq/JECHbo9YuL8MYkqV7bzav3UKBpYX77i/ZBS0ou372r9pwRjTHne5vzAE
7GsYPNu/WUb6Ibzeub8AtJMRIX3bv/ubHEc5Kbq/E1LJxsK+278dQI+iv1m6
v2EyA27AANy/kStOiUpzur/zP2sa5ELcv++KvdCeeLq/WFJ3gf6E3L9Xif5d
Rmy6v6pcGnTV59y/tpDtWYc9ur+6dV+5xkndv4kid9Pm8rm//u03znSq3b/1
dGBJIpK5vxqVYdmVCd6/W+8wfP0fub/vr99C8GbevyqgSwtmoLi/A6a7Ywe3
3r8Pr1wLRCi4v0wQrkE=
            "]}, {Automatic}][$CellContext`t$$]}, 
         1.399248250479089, 12.724049038825978`}, HoldPattern[
         $CellContext`cachedRes$$[13.46]] :> {11.234644267922326`, {
          
          InterpolatingFunction[{{0., 2.173590270387871}}, {
           3, 11, 1, {67}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJnBgR4yV/yySRS0x5CW0JpT/v33Ne3PmcKhvIj7d/0
qobw6ZXZvwOLN9s/D5jteOJdl/2HU+vTQnIn2nv4d6ts5l1h3xNznytu02b7
EsHK5kexu+39vb+aOzYfsH/Cq6c3MfywfdWFNJWH2sfsY6T0AnzrTtjbpXyt
3nnhlL38uj3LVZXP2jP+aL48sfS8vberTup6o4v2U/umPZi66pL9g+sMMTVK
V+y1FLOvJ826al+SdTXIU+i6Pc+VLSxf5960X2w7ZdsCzTv25+4cNvO0vmf/
d2/l7Qq1B/aTeidK++o/tNeIXRmtaPHIfp/OwdlfHR7bB/+5cfuk5xP7f+5S
in+rntqvmBydZrDmmX3w/Tmrk+8+t/+rde/DNL6X9ivK5M1O2b+yDzqUUP23
4LX9X95FBwwWvbHX8mKKi/n81j6iLel3u8t7e+fExDM3vT7YR9YLzs7//MG+
YO7BTNY5H+3bdxdazHb5ZD/vpiK74dtP9mub2VrW3P9sr7DCl0li5hf7yWem
NDQHfbVn+3j73zvub/YVosq1UUe/2b+2zPp9tO67fVzcxkpDix/2F5t+fJ/z
8Yf9H/ePC6OO/bTX4H3lLTH7l33wpUdfr+b/tq+ffnv+ZJc/9qtirngGSv61
v6p49jPfu7/2jM+Pzj1z6J/9/ntnlPds+W9v9/rlldBgBgfZ9LfTfc8wOPx5
9CHK1ZXR4cvBjd7NyYwOAA/LDiI=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 
            134}, CompressedData["
1:eJwNkms01AkAxacInbxWW1vrUVIqUqPOiIkMpdUWKxyv3Yhoq3GS1fOQlJJE
y8qW8jrNZklTh5UMNXdOMs3OJGqkEdOMybwJM/OnLbTz4X74nfvl3nOvc1Ja
eMocEomUZ1SF+nKvgC3HvObzu6hFLCyd1/+LwchtPSsUV8pYcNVE6Rwgx9LW
QLv3lSxMWTRtPmJkat/OvNz7LKgOdzfCyIM2S2juYOH4tpZ933DkmOP92P9N
Nwt2LTalIR1yfC9tpU2eaAO7Y11uFVeOBvLV6s9O7YhM+jbElC+Hz9crB2TP
28GLG7E82yXHTdGLG8z0xziWxZzdrjXmOTNTm9XPQWG8ycr11gq0iU+g/FoH
olZtG0j1UmD+691WTw5xwbSa614brQDtt4yL/xXzkCat7zRkKrDmUWjS5U4+
fPbwVtEZCpjys65LzLpwwLqyk8JVYMmlByehfgmSMOECRavAphK//LWHe2BO
nrHIsFNC5uF5YsH+V6DHCqMmtyhxKcHmLjXhNUbjXos7MpQI9CQVJt8WosXr
bPbuB0q869HVFqp7sWite9PNj0pw3UZN+zb1oVTQuaPFUwWhm2nNDzlv4Rjt
OOevUyqEk1NzBF0inCF3V92dVmGsK/Se1noAMzJug32hGgO+yaq8YDGOJnhT
9BYa2FdLgg9YSpBL27DyS6EG733rhTf3SWEIEzE032kxdevdlJY8BMusAs/9
9VpoV6dPnzQMYabrK2eMNgJpwU8u2XUyVC8LTDV9P4KwGdcS3x8/oKnRnG1X
Por8qEcbT2s+wGzFgOvF2I84+Oudnvn0YewNNbN3dBrDM7/pzcW8YWyvWjKY
LR+DluXQHUky/qDBI8ghehxLk67z0m2Nux1ziUhpH8cn/r+Rk1PDEFf4vRE5
TaBn4Y25sy3DEK4SCvoLJlBHDSFXBAwb+8cXfNJPoLFsa0pi9Qe8rSLbRcbq
sBbWf77olYEStGeLa5sOAd67v5xTDuFxZbqMt0iP+dSFQ4RYCtrvhT4suh7P
bxXn2mdLsO7nBcvL2/VwFjLazruIUcsnRKkuBvBNmFYm9f2Ic/aaUh0ygMNo
ujBIeguR4PgWbp0B6xtrn+442At7c1JvgNQAyrN7BePqV7iDXbbNtgS82X1/
s+27cdQzjZdPJUDMHtro8Q8frPCH57zjCdgEMz5zarjwThzJDMwi4BCimwhV
PsXWUZMo+g3C+EPNyVBHNoS1O4Ou3icQbOVmpg55BFngbUkiCOTQnZ3CIhph
GUSNKRYQaFZzHYKpdcYeR84/FBJgbg5qYKRUYbEi2SReRKD11GiNmlmEimXx
e83fEZCXUPQlljEoylxDExr9CGmlhF+e5x+9umPDYC+By170xMUfy/zrTJWv
br0kIFY1efg2V/kbuPc5p7kEYipzqMn62/4qXc018jMCZ3h/lCqfMPz/B1jA
bMc=
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.173590270387871}}, {
           3, 11, 1, {67}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJnBgR4yV/yySRS0x5CW0JpT/v33Ne3PmcKhvIj7d/0
qobw6ZXZvwOLN9s/D5jteOJdl/2HU+vTQnIn2nv4d6ts5l1h3xNznytu02b7
EsHK5kexu+39vb+aOzYfsH/Cq6c3MfywfdWFNJWH2sfsY6T0AnzrTtjbpXyt
3nnhlL38uj3LVZXP2jP+aL48sfS8vberTup6o4v2U/umPZi66pL9g+sMMTVK
V+y1FLOvJ826al+SdTXIU+i6Pc+VLSxf5960X2w7ZdsCzTv25+4cNvO0vmf/
d2/l7Qq1B/aTeidK++o/tNeIXRmtaPHIfp/OwdlfHR7bB/+5cfuk5xP7f+5S
in+rntqvmBydZrDmmX3w/Tmrk+8+t/+rde/DNL6X9ivK5M1O2b+yDzqUUP23
4LX9X95FBwwWvbHX8mKKi/n81j6iLel3u8t7e+fExDM3vT7YR9YLzs7//MG+
YO7BTNY5H+3bdxdazHb5ZD/vpiK74dtP9mub2VrW3P9sr7DCl0li5hf7yWem
NDQHfbVn+3j73zvub/YVosq1UUe/2b+2zPp9tO67fVzcxkpDix/2F5t+fJ/z
8Yf9H/ePC6OO/bTX4H3lLTH7l33wpUdfr+b/tq+ffnv+ZJc/9qtirngGSv61
v6p49jPfu7/2jM+Pzj1z6J/9/ntnlPds+W9v9/rlldBgBgfZ9LfTfc8wOPx5
9CHK1ZXR4cvBjd7NyYwOAA/LDiI=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 
            134}, CompressedData["
1:eJwN0nkwnHccx3HEII51FAl1jqilJHGmGcn8TIRgdFBdlWQ1yEbiaCgJCSmm
rhjHLHGsNlJaiyh2l3TdvruPMGgqEXF7nn2e2kQnRQRbgtD94/PH65/PX2/L
yPivrikqKCjkyifT9rNuj6PgSqVtVFoXhhxvHnuZIncZeqerL7fxVe/MM3Ir
7oy2NndiaGTGSDIYS8GgqGUU78DQOSstzwC5h6LeNNHk7u61bJ6JocAuMy4A
CTGUqRvy96koCvSltMWjrRjSX39vXhVBQRSNVJ7nYmgsXhSzx6TA5dqHypxq
DC3vVw1HhFLwu3toxtFyDE2YHnqm4EpBVmK6PTcQQ+i19QO6HgVB8S2cGBUM
WVAjkdJ3JIDRmZ9chWJ0Um3RTWmahKJvX0kMU8ToCFLH0vpJqGUP2uS7iFEp
P3yZUU9C+IFzROqqCM0efGS+KCXBjFHTFtQmQrlJxtqlGSRcnHMVdyaJ0JEp
44XqOBKK85oqG5xESN3+i/r/LpLAUjOwOE4Aunlpbmv8HAmtTiuZGvaAlJV5
NGd7EtLLTmoPfN+P2Avv/zU3JOEy/Uszb14fshw44DxSIMGXZ8stlPYi7UlH
r5hpCVh7s5QqdHtRdZFDz3yJBDJPZKsmsLuRr2/AI49ACTBNCrbUtzrRPcLq
tKKZBGJn/ItlnA7knHCYx10lwDyru2v7cyHK9/NR98cIwMxSoin+E3R5Su2u
ThUB2RYFj3n0diSjOVCaSQQEV+jGc8oESDhslxgaSEDrYvKCxjIPOafVBRXb
E5Ch6BPTb9yMcgw+VDG1CJCVJKVmnmpEP+vYaEyu43Bi1286y6cOJQeYtSvi
OLif3+Wnfl2DWMM9N6R/4jBscue7f55ykKp29e1kwGGjueaAtcFGKdHKtxs7
cJifyF9ayfkROeTV5Pg/wWHn7YpWcFoA6tplm/gLcZDRpJWm+2ngmjizEN+H
Q9imUXj92SJQahlhJI/goIcv0vCJchj9g1VuMIcDJRHOqj14COMMr5W9VRzE
4Rm6WHQtbIrp41OqBHhyPaaaL9SB5bMr9OeOBNDCWmI/XWsAWuSYnk8IAdt0
b+OgsCZw41pcVU8noPItx+p0ajNoOoeu/NZIwOKGx2fbvq3Q0/3DWMMkAXU3
nBQEL3gw62LdylOWwJ1jWssP8/lg8FdTIdNVAsNztqxYDQHkuQ25fXNdAnaq
a/0ZCQJgc/IuSGslICqqZP/yVAAqYeJOBi6BnudMDfaOAHTSDo3Va5IQgSV9
tDBsg1v7BaZ9diQoVXj0zhm3AcNzpXDUhwT+5vZ5mUYbSKvvrvOjSHBfexnM
WBbAraVPeCHZ8h5NqZKifvnfa1OjOi4JNvfHHOj3BFC2FDx6fYiE0KDHLC8H
ATCYI4WFb0hwOS5UCXvFB7eI7hRFFQpiBoZluUl8+NUihSPWouDw2b09v0t8
+B9X+ELs
            "]}, {Automatic}][$CellContext`t$$]}, 2.173590270387871, 
         13.408234538310197`}, HoldPattern[
         $CellContext`cachedRes$$[13.64]] :> {11.094462947856798`, {
          
          InterpolatingFunction[{{0., 2.275687119370713}}, {
           3, 11, 1, {61}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJbBgSYl/Vw4elvWvYQ2gpKe9l/48/cKWEZAuVH2XvZ
LtX9NL3c/jtYvMXeo/F/tMWyHnvfn17/V3dOsueTqFX8+GCl/e7IVYptdlvt
89WnbZrcs9d+0q8DCwPeHrLPeWiWFS5y3D730rqltldP229PnPxB0PuCvUWU
P1/r6kv2O4K4dX5wX7W39D7umZ1z3X6Xc3P6vTM37VcVONVNsbhrf+5cg5dq
0AP7JVvmFJ3Y+dC+etaOWdmKj+2DGq4c4ut8Yq+Z9uHVxg9P7Rl8eIRDI57b
XzPUsP6x/4X9WnGX5Nnqr+xb/sZ32/W/to96XL354bc39oYnp99uiXtnz7F+
M7PGsff2+aeeT3067YN99N6vmtu9Ptq7bWDe1/Hvo73RYsGgqE2f7GWnyT/T
Tvtsz9GpW/VX8ov9l2prvvNnv9jfz/NctKDxq/2pxHCzItNv9ttCUk85v/xm
v9C9OE507nf7DyH2LI97ftjbJ3Gv2lDz095ixakiO/Nf9obvOq3PfPxlr23i
yRK15re9ShXH2edpf+xlDxyfWqr4116crT2O+c5fewEfN/WJ0/7Zc05i/SAX
+N8+q860+ZAKg8MF44y+rwsYHExfzpqpIcvoMHve2SXRMxkdGEIYNvSJMjlE
MZ4tmm3C5AAAXAzslg==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122}, CompressedData["
1:eJwNzHsw1AkAB/A18szl0TljLmvV4aQcddRF7UYP17q1rcy4zJVHupvpWA3a
pJvsORpxXnUokseSXY/zWOx5fVmuOOUVdeSW4reey8b+sHO6bv/4/vGZ73y/
NiFcTpgWhUK5oYlSf6BKfYZATHbpNyd4AthsFqgNmQQYkgnukyQBTH35nF0a
myhmRr/OFoCy9COVrnHc5e32fg0CxIpE1BCNeePRt4NHBHhm6uWXqLG5UfVG
9JoAx6myx0ofAq35YbtZjmX41qTrXiSLQOqp07w9YY9xRcJ212ETWLEfEq8X
lmP6uV1b9VkCAaf0M3tlQuzQl96vDybwNCh3pWWjFoHC9lEzHgGzWl5iG70J
xVZGZsZZBPqMzxz172lFV3JA7mIdAZelK71K706M7JNicYyAqO0kfzurG7ay
5s8id8hxJN3xte7CUzgv+wglTDnGaZN95tV9aDGMbbfJkuPwpdC0ppwBDFsM
VFLeypGaJGsSDQ3hbt9CR6H7LLRGnMY/kr/A9SUvZ8ajWfxbYMRe0HkJn9p5
8yTGHK79dfviBG0M/I2EKYuNOUj304SkxwQ8PQMo4/nz4Boc86BBhrscfnss
ewFt342YUX+bgp1xxLmzpotYjHTZeiB5g+WsoswI2SJY71Vb/0nfon8tuSKt
cQm6djoVelXTMCoNSrPKVWAbpSMjgzuDXf3Hrn7FX4Zu0qf1W9oEPtnJZLZw
V9BlWyIWXiKwlNO+v9hZCcO4RHHwrwTytDtdy4VKmNoulLXHEYi3/mG51OYd
3B7djL76BQF1xsEP/jnvEEPjsIJFMwjIJiYTDFahLg7n5CunoXRZ97fgrUL8
8+IeS/1pbIXus6JOrmLzcrE1e/MNDmfx1cOMNSwfvSiV9E7B42NfaVHeGiaP
+5VcM5zEia1cv89X1mC/dy6G9f0EzM69Kv/SXQXfcO6B681jqKycKeu4pQIt
aePBQ7NXYEPBWGpVwc9yRWB1cwTyqMyq9VUV5Hd03V5ShuHgH9+f7ExCS+St
6Bp8Du/08w36oSQUPTJVunMPGl0zlgMTSKTEi7XnjnQjpLEl1amAhJOIeein
kg6UpmjX6ItJuH0IorIHm+E+Hd4c/ieJKMPAW4UGDYjKh/X4MAnj+wdj/Ad/
h2+m4p/OCRL3/t5t4oky1Bc9q0ifJlGXoD6kk/oQTyx3NglmSXTnMbzjHdLB
tE/MjpwnEXrBi3ta7wA9VctR/YemT/Ez7XMdv0NnCeO2WWn2ne+lOTWMXLq2
fX44VfN/42TEeWlaIV1PvveC0wsSv4RLJK4OAroB57VBzSCJhDrZaM+qgP4/
q2UrHg==
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.275687119370713}}, {
           3, 11, 1, {61}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJbBgSYl/Vw4elvWvYQ2gpKe9l/48/cKWEZAuVH2XvZ
LtX9NL3c/jtYvMXeo/F/tMWyHnvfn17/V3dOsueTqFX8+GCl/e7IVYptdlvt
89WnbZrcs9d+0q8DCwPeHrLPeWiWFS5y3D730rqltldP229PnPxB0PuCvUWU
P1/r6kv2O4K4dX5wX7W39D7umZ1z3X6Xc3P6vTM37VcVONVNsbhrf+5cg5dq
0AP7JVvmFJ3Y+dC+etaOWdmKj+2DGq4c4ut8Yq+Z9uHVxg9P7Rl8eIRDI57b
XzPUsP6x/4X9WnGX5Nnqr+xb/sZ32/W/to96XL354bc39oYnp99uiXtnz7F+
M7PGsff2+aeeT3067YN99N6vmtu9Ptq7bWDe1/Hvo73RYsGgqE2f7GWnyT/T
Tvtsz9GpW/VX8ov9l2prvvNnv9jfz/NctKDxq/2pxHCzItNv9ttCUk85v/xm
v9C9OE507nf7DyH2LI97ftjbJ3Gv2lDz095ixakiO/Nf9obvOq3PfPxlr23i
yRK15re9ShXH2edpf+xlDxyfWqr4116crT2O+c5fewEfN/WJ0/7Zc05i/SAX
+N8+q860+ZAKg8MF44y+rwsYHExfzpqpIcvoMHve2SXRMxkdGEIYNvSJMjlE
MZ4tmm3C5AAAXAzslg==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122}, CompressedData["
1:eJwNzHlM03ccxnEIoIjAsoghRZBrZBa1FAaxbMAXFCjXFETGNa4OWo52gyLg
jAoOuaZ24EDLEVFwBQQm/XE6Cp/SekRdqgNlwfm7FJWCsrUQQDdk/eP545W8
8zjzvjucZWxkZHTcMO8TJ9N7VDRsWjOOn6xXI5HgUUauwa/4XdzTBrePemfu
MjjZOYHJNvh9k1PetQkaTm5Ta87/rEYWWGyxk8FDc1zOwgU1Gq1/WNGipOF6
9bOsMIOnEi5bFY/SsF5SEUKeVSPLW/KwmCEaxD9J61Mr1OhJpJ8/S06DCcOC
feeUGkmjy3SWPTRs/6dmefsxNbKPXzV/Wk7D5uU7sZsC1Wjg0uMHzl8b+vO/
pJHGamTjX75L503DdNBcS/KYCgWaPW+Js6bhT+7RYB+xCu2UYPtS5iho+vGm
8adOKoQd+UOrHKOgDvXm8W9OoD2MLemf1FOQGLllDxE2geqc8dDWPArSJAmW
n2mUSP/cjBERTEFMyvKhbeFK1Layahqwk4LrsuQdR8WADpr41jOXSCh7wWh/
6TeOCOjYr5WQEO75vqEmQYESkxYD8j1JWHWx5maH/oZeqxbdmPME2Hzl1Zlf
MIJq1zZuszsJKPDfcDlROoSE3aYO03kErO0tuscXDyB8bHw5w4cAxX2HiIko
DC2sp87YmBFwTXBBNPNxH3KwszR1+wuHEm6CtPBsN3pc9faIYhiHfTyL6oCn
MhTpKD2+0oRDNuf72Nt2bciIU5hDnsHhzGsTaaK8Cfkt9hwQFxn6Z3rFN4F1
KIPtrJEKcWhOSkyZe1uKOFFQsTsXB5n3G6L8cDR4RJin6EU4cA8KJdK4ciiy
SNohK8Fh49a3h+zoOuhvfBmur8ShPG4q5uHFRmBVFUpKmg1/TOTumHYFWirZ
UZoBHKy0m4n7snZgKNrSaiZx6OsPIgtbZWC59OvvnGUc6OhT0+vcLohlFn0h
ZBAwkT+Y8e5KN1wV5zAHgwhgZ/L+5ff0gpdueqxTSECXeS2/QHQDhrN8CwRd
BLjORg896u6Dvz2U5tFaAl7oyHajbDlc1ft0DNqTYHrxrr1uWg6VI1t5PjEk
9LZGbWx1x8AsJD30h0oSsgccklmZGEyxdA3xChI8PK1XbasxePD5QtIxPQkH
hGuqVCkGroLxgngbCjpHOnJzLmFw+u45O74HBdyiCrO8Kgy0ctFIbAQFfOmN
y7xcDJSzxcG4iIKPCpWTEi8M9hY37p6vpUDwoXm4dF4ObZ6ztqn9FPw3ww/j
NcjBMcOd5/KEgndvbPWvfORgde4ey22FAt+WLNcYTR+UcfYvhXygQCjL/ZLX
3wf/A56SD40=
            "]}, {Automatic}][$CellContext`t$$]}, 
         2.275687119370713, 13.37015006722751}, HoldPattern[
         $CellContext`cachedRes$$[13.72]] :> {11.038299396194738`, {
          
          InterpolatingFunction[{{0., 2.2943516855082935`}}, {
           3, 11, 1, {65}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJHBgTwc1wubX1e2x5CW0Npb/tfBXtDcm6HQPnR9iqR
RjuCQyvsf4PFW+xTtiae1evptX/2h2lxhdxke+On+6WOiK2x/6X6/6Oq/3b7
tTr+r0s8D9jHHpt3N+z1EXvehHfnLXpP2u/9aXtISv+c/YP11xcfYLho/yhp
wrPPLy/ZPxH11FS/fMX+2QnGnKg91+xfVO9a17v0hv0m1oOuSU9u2df0H79j
pnzX3k3yXDF30n37jsAs1oILD+zzpr0NuPX+oX3w7YI5LvyP7bOvuYXEP3li
L/axdcUSy2f2B7iP/nnZ99yea1mGi/iSF/bBDjw9Ljtf2s+9tf5y4blX9s9K
gqXnP35tb8D/PenMjzf2VStnrfrJ+87+/kaGn6pl7+2VYjcra+Z/sK+5u0te
788H+2uxh6SNOz/a6987KW4h9sm+M+6isO3iT/aP793gdzL4bG8T/4Dbfe9n
+2n3n7P7eH2x39Sly/2e46v9OdNivknHv9q/erBD0LTtmz1bzz+RGy7f7ZXM
XSSqmX/Y2z3qlJY79MM+qve83MGGn/ZlFqJKKfa/7Cc9jlJl//fLfl3fAo1V
e37br7l9R8FxxR/7lRqSkjcm/7VfVhoqmF//z37JoYmcbNn/7S+wP2/w02Zw
8Ndj/Su5kMHhXIhy5VMxRgefasevG3oYHU4vjC+sYWJyWGVXxnc1iskBACHr
+y0=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130}, CompressedData["
1:eJwN0ms0mwcAxvHoMe1hTlrtcYsWLVMzvbm0E8R6bDszl05LZz3udaY2ETG3
VKvY2qp7UCJoNhtVWqw1aY96FnfFQsnEVAhezKUh8XZaPbV8eD78vjyf/uZh
Mb4RGhQKJV29dsEZ1xwjAqEm1dpHfXJxsI8mL1S7NogtMcnKhbb7an6Z2pt+
ujJqTy4aLO9o31XbP+yXSxRGHhjRccJmtX2nrFbfa8mD7GRcWYfaPpnPHPIN
8uHkklAXYExAuqwl9GdzoTmy6K5JIxD039IgfbgIbxXXb3WobSRI+M7dvgR0
UaCgxISA2Qt+cjyfh+J3vUnaVgSoyeeKp8NqINhF8+g/qf6jWW1UeDQhmh7I
dvQhYMMbCs+3b8FnjtmR96IJ3FxxGetkPUWofQFxvZDAI2VglGJbBGaYTp+N
iMBZ/8zTT1hdkGh1Z6hWCKS2E32zEb0QujDbLx+YB5c96/oovh85nzO/euU3
DwuyKW2x8i+4hT+14BbOw9ugJGhOMYSo9AfRnLF5zCTHROryn4M2uTb209EF
FF2w3t9bPoqeM8qD9fkLMJ3kOHDv/o2cxTKl3tYCvlZ9a7/1RIpu8RBVzFyE
DXvn5rz4H8ywB+jy5UUMKhirN2ZeIOIZS9+O/S/etPIKgldl8BC5PRaFLEFX
XydperccwYIjPwhMlmHO2qNBtZpBYh2LxZ9dhpPOwxw7y1nk7aKyK7NXENg+
/vrK5Cxc2dJoDn0VbpPntb+8Ooek151dfopVFHluHwrVJPCxubeFc81LUGvt
Rp9/TyDX9DbPPEwBSt7vjmbNBNocrGLiqGvIaGRu+U8Q2HeRlXrj1hoa3Fhu
ulICmTYdqTLNdfQTuRccStXdSKQWnuHrSD5u3dnhTEBhn1ozjnVwhjnltW1z
MNkdfUVlpERyo6lhsNkcqm6X5ujFKjHSavuhXsQsPv3R0xCdSiSkGNRl5M9A
04ac4u5TgWu8105WLUfFTm2+U4gKKUE5lZn104hvwCsWVNDpvDeqlydDVGNT
2zH9DfCcjm8N3J+AhqXzOd+LG5DrXTIT90rBZEg4c7UbaBFqDSvXJEj2YnAO
LWygUkkEyu1GMGy543yMCYk/DN9fWuMPISs2W++0B4mYyYAD3JABHLOV1XwQ
S6I+3Psb9lIP2s/anmoqIGHdf+2O33gHjoS/qUyqJ0EzE23Sbf/ERPvb7MRu
EsXU0yk6fkIk0iTXSsZJpHXqNFMim4AtwVXxPAmvm12SLLIaJ3YsVLx7ScJV
nrqd1MdDlNRraklJYg9zb2lAeRoWVIerPlGR0BCSXQ9a4xke90MseGsk+A/t
0yk+BYzB39wy2MskNC8XcT86zGfI6V/oOs+REDueanlc9TOjqtq4v2mSxP6t
gnTRiV8Z/wOsdE7N
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.2943516855082935`}}, {
           3, 11, 1, {65}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJHBgTwc1wubX1e2x5CW0Npb/tfBXtDcm6HQPnR9iqR
RjuCQyvsf4PFW+xTtiae1evptX/2h2lxhdxke+On+6WOiK2x/6X6/6Oq/3b7
tTr+r0s8D9jHHpt3N+z1EXvehHfnLXpP2u/9aXtISv+c/YP11xcfYLho/yhp
wrPPLy/ZPxH11FS/fMX+2QnGnKg91+xfVO9a17v0hv0m1oOuSU9u2df0H79j
pnzX3k3yXDF30n37jsAs1oILD+zzpr0NuPX+oX3w7YI5LvyP7bOvuYXEP3li
L/axdcUSy2f2B7iP/nnZ99yea1mGi/iSF/bBDjw9Ljtf2s+9tf5y4blX9s9K
gqXnP35tb8D/PenMjzf2VStnrfrJ+87+/kaGn6pl7+2VYjcra+Z/sK+5u0te
788H+2uxh6SNOz/a6987KW4h9sm+M+6isO3iT/aP793gdzL4bG8T/4Dbfe9n
+2n3n7P7eH2x39Sly/2e46v9OdNivknHv9q/erBD0LTtmz1bzz+RGy7f7ZXM
XSSqmX/Y2z3qlJY79MM+qve83MGGn/ZlFqJKKfa/7Cc9jlJl//fLfl3fAo1V
e37br7l9R8FxxR/7lRqSkjcm/7VfVhoqmF//z37JoYmcbNn/7S+wP2/w02Zw
8Ndj/Su5kMHhXIhy5VMxRgefasevG3oYHU4vjC+sYWJyWGVXxnc1iskBACHr
+y0=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130}, CompressedData["
1:eJwNznkwnHccBnAhJkjEMZqGuuoo2W20tUFS4pfIIBJXd0ejM6s0xJGEdUTa
riCRhBCNYxkqQWywSLHeokvxtV6l0nQdNSmZvO++L7auOrMSjGj3j+ePzzwz
zzwfXuSxL+1RU1PLUKU+ZfHeMwUNZRGOp3ZXccRK2HK5q/KXh/nMX1Q2xXZn
kcqCvb374lXey9r0aZuhgWPiLaRXcDScMdLMUNnqW1yNo7LBmWzjx9M0RHsy
rPuXcVTWGGzgQtJgxknMsZrHEX9yRjA8QYMt70lAzDSObhmWiGL+osHXVd2v
lMARd2yerSmjwa4qhdv8N46+HvEO93us2hME+EVW4UhjyvP6B0k0bBolusyG
46hlrV9804sGi3UwHDXHkV7l3OE8ExqiyHNG0tE+pKz95OFXKxR4hHAknBt9
6B9vWx1lPwWsdmfzj8z7UMRS3cNqIQWTE4r0kiEp6vSxf7Vzk4JQral/y+Ok
KH9x3V07jAKHwLDdfbpStHD7bOELRIGsMM64rroXCbKN3iZYUjChLMoIcupF
df24U+CWHMotim2X2YC4EDnn1SoH62nNCl+7HvQg7eaqMkEOmclVVwSzXehk
dXJ6lqMcPEf8VySCX9FiU1Et8w0JkiAf/xlmJ+pk/k7rdpNgnReecU0sQW/d
g2zcokhoCM+tkZq2o8GUCp95BxIOyl27ki1aEWPJI159h4D4JPXc//ZjiGmC
D8leENB/vP6cvr8YVVgdGr/aRsCQ53Fuk04jwkL7qtdKCDh6wdVQGVWPbF03
ImPTCDjTUdXYLqlB8UMx9EI0AaO8Jb6NuhCNH0N6vAsEKBxFFumCR6ip+LyX
xIsAgb6C89tGIdqKtdHrcCPgWMFGXde7DIR7pzWknSCA5A7w+VoXUV5CgJL1
OQFu2zc2L9slwY9H3OQd7gQUJW6dt3HIggkXZ/Giak/0SMtn1LQQnAyCKyvZ
BNydmh3LY5eCxIxfKPqGAJ9LgnXGZxVQdrB1fjSJAN0msXX6ZBXcbp4d3M1X
9b7cd3aeNXBN3UBD7WcC3rfUD0sNqgOzW1nzvpMErM5k+m9oP4VyZU5+iAYJ
st6X0kMRjfBTWnRN46ck6HhoOphHNYOZdnRzTxgJCyzuzvP7YmCsfdFtLCCh
5IcBxp2TLSB09s8MHCRhdSVY1PNHCxwNrdTd3SEBO70mbDiBwfe2pcQASw7u
gade83MwIGqXO+99J4eF1QPbA88wyAjKGX/TLQee9MF7yjkMrh4pLJDtoeB1
cn605QIG8dd3pbk2FFwJNbBXjGHQo/tq6oA3BZFNf9awRRgUhCy//DiGgv0z
bhHKyxi48GqfjORQ0JYatz1picGd8mAe/ZSC4R2iWKj6tz4gU/g+p6C24n5q
dmwLMDXzTO1nKBiY7io+a9UC/wNXkkTq
            "]}, {
           Automatic}][$CellContext`t$$]}, 2.2943516855082935`, 
         13.332651081703032`}, HoldPattern[
         $CellContext`cachedRes$$[13.9]] :> {10.86346323701758, {
          
          InterpolatingFunction[{{0., 2.3778688285397322`}}, {
           3, 11, 1, {67}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJnBgTwaAhPPC+sZw+h7aC0n73ZAsbO231hUH6cvf0E
ndLQwCqoeJu9z4+ccJ6v/fZGGm8mzVs7xV7D4uAyldcb7F3Sjq94uGqPvcGp
tFB/0yP2dg8zr+mKnrKvkimZLLrpnP1tbfsVdcsv2ld6Hmn79PWyvXi6Z2qa
yzX7tYrRhyXUb9i73MlRPM15y/7WtLr62je37QsCJ9zVP3/Xno1nkfWjjfft
E+7OvrHl4wP7vVvSJldwPbKX6jH0s1F+bF+e/IeDweaJ/RWr44cPhzy1NxSa
VNee+8x+YdDEyNsWL+wt2GZ9PDbhpf2FnYs6N714Za+YvvTzkt+v7YtFVsRO
53trf+TgquOdiu/sxfLXGtaYvLc34bvhu135g/3dlJtNBms/2Pc8Nl0skf7R
3iZp0mEGxU/2v29ffnN/9Sf73aGiYvvNPttXnQ+zn3fws72V54yMWp8v9j8P
3ZwYc/2L/U4b6d3WSV/tK7fFPJF6+9X+zZlDrkuWf7OPf6yxXDfpu/2ln30c
22V+2LsKfM10uP7Dfqda9OmTE3/a69ge1An2+WU/P1i97w7bb3uhrN73qQd/
27c1fA54X/3H/ue0yE0VZn/tL63adTRV7p/96n3SN4PY/tu3Xqp5Y//uv73+
53f1YtkMDjK18zl57zM4cLAHTGYOZnT4OoFB9tcxRodHUhuXfbBicji3JNHg
+TomBweeZeIPWJkdADd+A5A=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 
            134}, CompressedData["
1:eJwNx3041AcAB/ArFC2UlErmydLzTLHkZUb2K01b7OHJFWk8W0wW8/K0MS9Z
p3u61oZIkpcsTpoOYfJy4Zvz/tZ2d2UO64bfnbvzesfvFOl2f3z++OwNifEL
W0ej0VhaGRY0K00Vic5jebUJAjbRmnk6fUZ7KnDMk9vBJnoCc/RGtNfY6sav
1LOJ7EMq4yfaW071miQUsImYnk0+mdrrpWZaLVxhE3VZckRq/zTYpjTkWzZh
ef7dOYNKErnJ7h7lviWEHR9BTzkk7q42t8KlmPjQymsu9REJ4dzfVLHlfcK7
0uGT4HIS6hpvZq5+EcGODclmlZDQqbvj7PQomfhNKK9glpKosSWK6Sa3IGh3
mzaoJtFca7l75FoZdtRHzA93ktDXtX/9mlWLxBEyq/oVCXm9gNdf2IiP0tu3
4R0J4vbvDPtNwNDbnbsi9kuwRz7zh5GMBxzY3GbmL4HFsLLe6aculG0NNP6S
KYGhKfdNJKMXC8XhRafrJXiuYHAlDwagUZaVh81LwCEiX0ZL/0IsL7Gh2k6K
qP3VYtv7fNTuDqgI/VGKHvsBRstZIexEt/JaB6XY/MohYi3sJdif/unscGgK
+oyyu6d+/gedVwZmFAVT4DQI3w8uEkEjXU/TbJGhm3mieztvFMNxo5FxN2Wg
3Yhtbyb/hYP5pj53Mzl8NKsPomn/IeSk7yzNQIHkPY7FRpxxPA7YWUsMKlDl
K7p4YmgCcRtsXDPuTWOo9YFLnGwSNcfKdZa9ZyAO0QnsqyDRm1SmyKTNwiLD
foV/VoLAJiY/mTuLc66i9zbKJVDTuTe5CXNg5o9nHzonhYUJfYez6zwENkoO
q1wKVvs+UdvaPH6Ncf9h6IUUlXuCrNjMBXglXZXnCKXYt61mf/ZGJRwDdEKv
p0khdkwRPfxOCVs/3e87baS4FbWB3dGtRPyCQXNVqQTKJ8vep/apcHuRsTbx
lkTLbUYBL0UFH6u6ZzxnEqMXZsPvCVXICz6g6+U/ifbpMkGC9SK2ejoZk19P
QGXt3qW5tAjBSzHczo6jsTrClBQuQhhpsT28SwzVrKXRBweXYJ7f98WxzjGk
cZTxuclLaNqS5ebWJkIa/c06Om8J/rLQ5rr+IYT6f3U0h0bhYo9TFFclRIff
N5w2ZwrpOq+DyKN8NHeRLWfCKOi1JNW9TRpEZSolEKdRuDps5t0l6sHlCfGR
5UoKMx8f/1xW3IFLhz37nXopmKXP5TgJn6HkcQqDP0nB+jDvno1XE06buySe
X6YwZnL+WpJpLVZ8c5dIXTVmLOjHzYce4nGptaGHoRrUCdnF3I58eN6/VvjZ
VjX23ohuEPlcRfCwYrBI+5OJ7V5PLsQTKbYeTxVGajy/E9YQQ2YRdN3LBRUG
arB+odUdMS0khDe3HDyzXo2GXXmOL46UEMypScvKVQrMYYMNjeOlxP9OA24c

            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.3778688285397322`}}, {
           3, 11, 1, {67}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGJnBgTwaAhPPC+sZw+h7aC0n73ZAsbO231hUH6cvf0E
ndLQwCqoeJu9z4+ccJ6v/fZGGm8mzVs7xV7D4uAyldcb7F3Sjq94uGqPvcGp
tFB/0yP2dg8zr+mKnrKvkimZLLrpnP1tbfsVdcsv2ld6Hmn79PWyvXi6Z2qa
yzX7tYrRhyXUb9i73MlRPM15y/7WtLr62je37QsCJ9zVP3/Xno1nkfWjjfft
E+7OvrHl4wP7vVvSJldwPbKX6jH0s1F+bF+e/IeDweaJ/RWr44cPhzy1NxSa
VNee+8x+YdDEyNsWL+wt2GZ9PDbhpf2FnYs6N714Za+YvvTzkt+v7YtFVsRO
53trf+TgquOdiu/sxfLXGtaYvLc34bvhu135g/3dlJtNBms/2Pc8Nl0skf7R
3iZp0mEGxU/2v29ffnN/9Sf73aGiYvvNPttXnQ+zn3fws72V54yMWp8v9j8P
3ZwYc/2L/U4b6d3WSV/tK7fFPJF6+9X+zZlDrkuWf7OPf6yxXDfpu/2ln30c
22V+2LsKfM10uP7Dfqda9OmTE3/a69ge1An2+WU/P1i97w7bb3uhrN73qQd/
27c1fA54X/3H/ue0yE0VZn/tL63adTRV7p/96n3SN4PY/tu3Xqp5Y//uv73+
53f1YtkMDjK18zl57zM4cLAHTGYOZnT4OoFB9tcxRodHUhuXfbBicji3JNHg
+TomBweeZeIPWJkdADd+A5A=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 
            134}, CompressedData["
1:eJwNyWs0m3ccwPFoO2bHVDGdzqVuUbd2G1lVo//OJeJYp6H04ChlkdAezNhY
XSqblZ2R4BiKVdyitGgedJT+QjJ1q2Ar2j1P8iStMmtxVFuXtZYX3xef87WK
SQpia1EolJ80fW8TVud3WA0t5b56w50ylFD/cGTTRQ1C/1cvyzVeoe5da9V4
Oy1/kqPxbNMTbwONR9iJHB2Nn23zK1Kd1WDvMDPQhMnQseeGq3NOapilY0pf
jT1id23K7NTQx3DZSWqXIdYJpZ3YUg1cny+YvFYZUo03Z9WaquG77UB+pkiG
0uQpOgIjNexzXRWdq5ehW+HFMa6zKpiwtxE/SpWhwuEw18QqFdDb9WnmdBnK
MBmtjopWgSK/P5S9IUWGiRN7HKgq8IyMky80S1H32deJVpsksAOOJIjPS1FR
5Zvke+MkiJh6WoGGUkRd14o9LCTBeFp0PLh3EFkEC0oSviVh8/SoXkjYIGo2
Wl+yOkMCY0JoYrB7EFFW0nV4n5JA3t408W8aQHn9IVHl+0i4yNkRj3kNIMcq
TgmhVsKbuF43zpwE7cLLnzo2KCGGdqBuJU6C/IbO+nIjlSBYOOfbhgHKLejg
Uk2VYJn+VlKSdxdNa7Uxi2cVQB2wbQr07kdeThc9HlQo4BQtrlb+7A56aObD
t4hUgGO/NseZ14u+pr22q7RVgOmelumu3T1Id7rX/Bs5AY1b+fQJbjciPjdi
UX4lYEa+/oNBaCeqXnrcczKGgB8picn7ncSIpEXLbT0JYKjeCTWO7kDPBywa
Vj4iwP5R0hEdo5soYjyp6/ZbHCy/NAl0D76O5ofK04rmceirXIxoy2tEse7L
QzmTOEzhno/l7UIkmHL5uRhwyJfENwy2VaHC8TapRzsOJHNjqyikGKkvu2mF
N+FQL93ibtVkIi+PSweyG3BI8wvPZvh+AiEx7uwqzbdzbNFlvMiC4czPqCU3
cBB3D5se/OcXKODnEfRuHCxq6KWe1mXQKSj9N1mKA2+Gf9Awqwr+ijVj7fyJ
w38hqynE3Vqwu3Q0t2sBh8ST0sVj/HqIWHvFGNEmQJHNSJXriKDuOI/d7EjA
Kou7EGbTAvkpLS2jQQRkXRFWs1U3IDI4Zaw5m4DeU4f0y7zbQZFx3wluEnA6
6HyPsKkD5hYq9guUBLx8lyXh596CvKEPuI1GCvidGrsSSxOD7tHlmmJ/BQRk
Zr7n/ocYbD6Oz1m9rIAz1EPW/m4YlHs7BXJ6FMAfcxyfzcOgMOrBsoiihOz4
gRd/D2FwVUmzLmUqQctXh7v4BIO2asESJlBCx4WvWD7zGHRMKZJEc0ow96+5
0zqOQXWmJOd9AxJ4BelrAdcwYJZd02a7kpCa4eYwHI3Bdc8K+xOhJEQFmu31
NsagkX2PwksnwS/BT/tCnxio9Hxni6sk3FdRWVcixDAo6ozAxSRsTD797UN9
MfwPOHtGbQ==
            "]}, {Automatic}][$CellContext`t$$]}, 
         2.3778688285397322`, 13.241332065557312`}, HoldPattern[
         $CellContext`cachedRes$$[14.]] :> {10.755913577581236`, {
          
          InterpolatingFunction[{{0., 2.432199327357915}}, {
           3, 11, 1, {71}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFiAlIkwEARndIh44McTEhTG2lVBq1ENHw+7PMLGlOzBnh1vV3SMsVSnSt
FJspFXPMZKBRmtFUFM0pU7xKVmtUXsNpmJraPHJz7ch5FiT04OPxPf+zaQkk
jUKhUP8uhvIflZJ3uaJoN/4Zq+YCnKUn99X81S9E+oXARabq9mrPQclJm2eE
XoaXPpeM6qYC+AWFkGvuVaHB39vC2qhBdeGHE3xxO7J81+4rSdYiqSzaa4bQ
Y0BRdq5Y1Al3flBkR3gPmmt8lcJUA8QMpn1e2Qf2RQ/uU10/+tqp5XtcX5Ev
M9QI9YOIE6o0j4uHQC9sGR5sGMZpyesx+/MRNJPyCY+87/BZd2er57NRZJST
Aq/aMXTFcZVM7TiCLWG9rIEfyM0P8NxsNmGcwzi6hTaJmwJHrEU7hYD1YYNt
jJ/Qv7kllifMgJA8CKw/ZYb6iOxb/3kLCnI/fVwOnUWnOeGVrGkW7onGzADC
imhNSkpdhxVREr9H0mu/gIOjjcm+NsRI9zK7ymw4rstMiw22I4nRpWuvs0PA
9WOH73eAlKdJat85IDK0GHcccyKdtYFT2u2EmyC70fTwNxSl8wd2YQ7bJsU6
sWMO6hBTvLrChej0FKPrzDwMmh5hJGsB5EqsKevzApyH2q6+z16ENC/U6RGx
hE2dlXfjrUtI5MmDer8sQ959o4dftYIJVUir6DCFyEl9oahWU4jtO71TrWwq
oZ2WgqOgEmSlyzuDTiPcRFem6q/TiNLgoda5ERoRZeYVhPPohK3v7TQ7g078
AZsVFrA=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142}, CompressedData["
1:eJwNy3081AcAx/FDKyWvjGurqDnMVcMUtTy8/F6K6USTUwvVZGzFZPNw1VbJ
0+smRnI6kvXAotTlYYVNvmrqPJwUh46c8Ls7D3fh3J3y1O6P7x/v1+v7oYVG
+4frUCiUTO3MwrGJyyJxamj4Q6FhBVG3jEiN1/oe/4qt6bIK4vruQgVT637u
gVtcSgWxsXntKyOtDXSCt2ZNlxOeYlNNWzyJWK9VY8nSciKhmueVrnV3cp0g
XlROeKWqOHMxJMKSuvf7HCgnQpr2fXX+ZxL8qrDy5cX3iW1/TAStPUGC/eLM
Rad8HiF1SbfhR5IwoyzaWmbcI8hEKz3GIRIRrdGz5uJiYuzVdtLHn8TllUtZ
tpu5xIJ5jf62vSTaFP/kPo2OIAJb91Yd9yPR0CrqnR7PBnXjNYPAQBIz5gfP
0/YUYwXXdjzoJxID1v1d9SYVoCo//jQqjYSX0ISzJLUGOTk0aXYJiTg9ivx8
RT0G+Gm1RQISOVTrusa8J9jAPEdffEfihN9njBrdZ5in+2fO20ig5zxxwfVy
M+as7FZ/f0SCGNYy+8n7AvzikTLAzpXgt6jRlA6yHXZZwS4FHRIEa1ZWIv8l
3gXMJLaslqLLoYRr6NuJWwnFDsR3UriqTW9bGHQhmBTwf6+XIitgpMud3gM9
R/0cXboMBq+2GYf7ijAzVK3/Ik+Gh21qs4HTfShbRT2oRx1BmDxK/E1pP34w
OUtcyRvBw7GDgj87B7D6zgH1r9ajMH/55t3C7Bs0MT1DnlqMobJht0t76RAy
G9t2ZkjHcEQe60M0DSNA4xTn+WAcsp1UzsbnJDz3h3Y2h8lhwlPTB9MlWM+e
ExmuU4CXfW603V6KDymdX2wXKtBoaU+5USvFBgnd2PfSWxgfS1riZylDy0Nz
jidzAnsLQjZ4R8owFeTc82HFJFgNHnWZWTLknePZelyYBDt+l9CCLcOMP6OE
pz+FxE0F85NuMijbT3P8IqZQlNA6ebNXCoeFTaVzzVPYsZJV/3ifFGzPMZ91
dCW425uXym5J0KvrlmyZqMQe8eHOyH4S3kWvOwp7lJhNZDM83g/jI3HOGdrm
aejcZJcJF4fQ92yLKvDUNMQKTsMT5SBq3Gz/Du2dBv31erMs1hs4bnUYbXNQ
IfRbcaXr637YbFlMjk1RwWL9YaUvvxd3na6KjgpUmKX1+LxHD1b0sceFBmoc
n4gquyoUwpGZVW+zSw2r8gmOlVEHZnZE84Zj1HBtutp4SPUc+9LcY1ILtH/H
eqNHdi24SIv7uuSRGt5JHvLbnU8xeXYLa1CkhkBReClw+DG65xIi7NVqVKUF
yS+6/4sHkX4nucs1eHGtmvHJQBWoVMtB/TUa9Pkfs4kzLANfbuIeQtNAcPsk
M9/5OhgFuc5HrTXYOr2miOGUgVinzP+q6Rq4KWxOp+TuJ56Nb456/7kGYar0
+MprGYQp8xhRou0N5u1+vGKeT5zQre350lQD9Uz4wh3DG4TockvulLEGlndH
u98+KSa4Ruli1SoNHjeyihrb/yL+B3t9hvg=
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.432199327357915}}, {
           3, 11, 1, {71}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFiAlIkwEARndIh44McTEhTG2lVBq1ENHw+7PMLGlOzBnh1vV3SMsVSnSt
FJspFXPMZKBRmtFUFM0pU7xKVmtUXsNpmJraPHJz7ch5FiT04OPxPf+zaQkk
jUKhUP8uhvIflZJ3uaJoN/4Zq+YCnKUn99X81S9E+oXARabq9mrPQclJm2eE
XoaXPpeM6qYC+AWFkGvuVaHB39vC2qhBdeGHE3xxO7J81+4rSdYiqSzaa4bQ
Y0BRdq5Y1Al3flBkR3gPmmt8lcJUA8QMpn1e2Qf2RQ/uU10/+tqp5XtcX5Ev
M9QI9YOIE6o0j4uHQC9sGR5sGMZpyesx+/MRNJPyCY+87/BZd2er57NRZJST
Aq/aMXTFcZVM7TiCLWG9rIEfyM0P8NxsNmGcwzi6hTaJmwJHrEU7hYD1YYNt
jJ/Qv7kllifMgJA8CKw/ZYb6iOxb/3kLCnI/fVwOnUWnOeGVrGkW7onGzADC
imhNSkpdhxVREr9H0mu/gIOjjcm+NsRI9zK7ymw4rstMiw22I4nRpWuvs0PA
9WOH73eAlKdJat85IDK0GHcccyKdtYFT2u2EmyC70fTwNxSl8wd2YQ7bJsU6
sWMO6hBTvLrChej0FKPrzDwMmh5hJGsB5EqsKevzApyH2q6+z16ENC/U6RGx
hE2dlXfjrUtI5MmDer8sQ959o4dftYIJVUir6DCFyEl9oahWU4jtO71TrWwq
oZ2WgqOgEmSlyzuDTiPcRFem6q/TiNLgoda5ERoRZeYVhPPohK3v7TQ7g078
AZsVFrA=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142}, CompressedData["
1:eJwNy39cy3kAx/FqTvdYQsWd36Su0nVUC83FR7pKxF0Ry1Uo8iMu+uUROWI5
R6zf64dV6FGptNp2lOTdtu8wD8lDwkPfbd+NTc6PDnf98KNuf7z+eP7xcoxN
DN9uaWFhcdacw7wux6fhBuzT+7app6nIhhV+7SfMDs7KH6w2+8KAdyTH7Jrb
Lc58s/m2PnnZYQasdxFuWWb2nv3RncZfzP/Dss1DU1UkjdXMJmZHRLU6Ssze
5lra1xZiwDt7N6HpGxWxXe9Uww0wwC7l2HjWJBUZNyBd0+JnQMd+Mc/aTkVS
7e88W7zIgPk2/YEfbFVkQq5EKLYy4Ez+FaHVe4oUXyxqSO7So4OT5FLZRZHY
Ry7JBef06Pc5PjaumiK7ZpUFOO3WIzTZoOlNpUjf21KBt68ejX27ZhcupUjH
aTr7+SiDV12t75Z+UJL710Kb0m4zsCnzidorUpJlznMmvRAx4G+MFoyGKUlY
TPHjMSkMFDnrhe0jClJbFH5Uv4pBfJ3PleCLCtLfenibYC6DL/KLXoQoyMFj
n6ZUWzKY/MTYOd0oJ71NMzI6FToMxfj75/HlRF0fvfbacR0ebNBsT5opJ/LF
PkPuQToMZMwaEYg7SKPh5FZftg69fpFy5ZIO4qz8kJSi0uJ2uzpRvBbkT+SZ
/I9rwVYoLFUONwjLod/vboAWQ0p1QAl1nQy/GetFrLUourqnxHVrG/Fv/H7d
zU4NriQPO4petpLVe0OLsoUafMmxpzbHtJCsnuUbxwVp8LEld8+My3+RxKDu
+2l2GnD+O137tkJKOH130hcZaPxBf+fel9FMZj9bUvEINC4YXVN/jROTw1Xj
eNzzNAQ/Z5okV+vJpn8rdyadoMF4zd/l9qmGMF9PpHMSaTSYKi9keVcR6uOt
nPIoGkqHuMDPsZXEtd3hccUaGsnuplOOziXkXuHyxaOERrDn0ZsPj5wlw4/G
y0d9aVRkni4vsUsjYZdVfhPMFlz6xyN7OAbcHz6xWD/SSMkuSFoRcwyz1wlj
r/vTmN7DXeC3IAdW7O5p34bS8Oxhu38xFsGe62L5dyQN/YmnNi2rRGBWb2q2
TqCRlZj71eT688glnAhyhIbkzcilkMwqCKyqb3wup8GKa+d1sWoxWLeDPqCk
Edq0s7FxXj0WFnDtPV7TSHVcOBj2/jJ+GuDtL5yiQeAki+jSBU34LTEngbNS
g2f7uO8pbjPiqn4fPXVQA++GierXUyVI5/N5bmINdBSl63ogQbZxwssKowaH
yvwj0ndI8WJot61gphYN4fGiab1S1Kk/h5zboEUan6185SlD/EidbbhIC8o3
M+hJqgyN1gdWXnuuhfaIqSGlWAaTEy8r3kMHX56NTiGS4cy9TcxQsg5NvVyP
4FMy3Dq/LXhumw61LYUnWbEy2J5zirpvwWBtzPy8g24yJExcoy53YiDutou8
ykhBVfSMMQUyiHNJf7LxjBT9GTXa/B0MEtKiCoo9pcgLvt5ecpKBarNXxJa7
ErC7Oa9m5DNwLT10Q1onwf/r62n7
            "]}, {Automatic}][$CellContext`t$$]},
          2.432199327357915, 13.188112904939151`}, HoldPattern[
         $CellContext`cachedRes$$[14.08]] :> {10.659206453872489`, {
          
          InterpolatingFunction[{{0., 2.476796360638314}}, {
           3, 11, 1, {72}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGIPBiQg/JF/XZOBPYR2gNIB9g1zXoqzHomA8hPsHR4+
nb3hSQ1UvMPeQOXDhxtdE+0Vql6Hrt88zX5N0MPaOYfX2quUpK3YILbDvlL+
XcfJpQfsH7Cs3GvlcNTe/VXyp9W3TtrvKNxy1mj+BftTDlHpITGX7e/yMzCW
SV6z7zZk6+Dyv2FvEczDP7/llv3TEqFpxrvu2E+aJiF74v09e6awlecSEh/Y
70k41nfX66F9afZjvyiTR/Z6ZQz812Uf2z9vkD0fzP7Efo330YkO4k/tC8Vy
Q3TVn9mbPRQRlzJ/bv9r9Z6bbO4v7PeXpcz5HPbSvsWRJ/5B2iv7K77Zj6tU
39jfXtSRu6T0rf3j70u/nz36zj6Za6qU4sX39kV8h+Ss8j7Yb5puueHx5w/2
nxQ2OvZWfrQ3XqVx2ez/R/ti4wUpD1o+2bMasKRslP1sP10nI7lp22d7Tc0z
ScH+X+x3qxokqbz4Yu+rNCXxa8NX+/tyPxKOSX6zL5SOSZi+6Zs9s8SB+Azv
7/ZTRFTiLZ98t1cT7Ijjqv1hv0XayLw67qd97w41V1POX/apodLB7zf/srf7
xJ+4Mu63vVg/S34y5x/799o/a2S3/LE/fuJt1/W4v/YLUh/NmMj5zz5KOEQh
88I/e9GDR5c7TP9vn7F9tjiPPoODa1/I7fJJDA5KqbzzH39lcGCwOZbkH8no
cFeoXm33HkaHO7MUJqzVYXK4rXTo5/w5TA63ViUnT+JhdrhpxHq2pYbZ4UaE
3ZyqC8wOAD5WCmE=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144}, CompressedData["
1:eJwNzX0w1AkAxvH1MhcttrmbFYlhXWorRfZOcvXLW1eSnC1lr5zSe2tM72Ik
qUhYVNJ1aFfT5tpzKrtGuh45vdDmXbaEjd/aXa/rZX+cits/nj8+M8/M12lv
TOh+IxqNlmUY/9c1CepAEjeapVpNiowo/MVtboXBb6/f3fsoSUYYBU0XpRn8
YJK2KD5eRuiWeI26GizZsiqAHiMjdj1pOda0icSeK8K0vL0yYn1d26JTBue4
JUywwmSEc4atnyqAhMPGxp+HFFKi0GpWfNiXhPuIMi+XJyX4cnayMUFC6Fo/
addRRswu05qUepPgr3GOieOVEfJr3SN7XEg8dLJ6/UlYSnDPMPzPM0mkb6x4
fZxbTOjK20vCzElQEeFGWzruEEuG4jp+MCZxMi6jhBMoILJHLS6coJGY6lIW
b57iA3U7j1QZ/oPPtfsX/CFCem8jw9qOxD7Bx1Qfm1LIRxKnGT8a+iwFuyuq
HPNdvgnaxiUhjmPfGBH/A+d8Zab0DImBN8EmCaxqPHA9+HtuEQnFTMOC/vwX
UNrFFfDaSaxf1SN23FCLXknL461mKsRXuFbv5MvhzTnv7kCooOKuZlb93QB1
VKjvdLwKxomhc66mNMEvcCicCRWW82lLQ/xbwHs8GJhv1ocT/yq+WFq2wTGI
2SU40IdbnGfZ7BXtUCaZmd9/2wf7UlEBeO9Bq/Xbx1inxnhweGm4oANmF7pi
usvVCCuyP9LwqhNbeqtOOHhrUBfg+XDdbDeefRUeevpKA+7i77WmNp9gMuyz
/Gq1FvSl1g4drT1oO3rTqiezH1Tb/UfpViR8PBhF1w8OwCWy+JXKVQV9RXac
1m4Qf+a9zDo7rYKkJ3A4+d0gdC8tP4r/6sPi5YWu53OHwAy/tfWpnxqn85vv
feQNg1vSExtSocYeZ+WyBNYIrGcqK4/TNRCmXtm3cnAEFv3mO+SeGtjMXop+
f1gHJ80VuK/RwFy27Td2pw4tl4TFC8002HGgv8By6yjE+kaBrUiNxhsbH+Y8
GwWrMc83ZK4atMGgBS1Lx0Bv/nw7xr8PyQcEPjM5YxCd0UwlbFdhrPqUVwQ1
hljlf+U5fiRs56+23LVtHJMst85EZi9qd3fvviAZR0UqN+lk8yfsIBk+52bG
4b/CeeJOkhIrr/bG1h+dgO/aY+ED9E7YfLVI2yydACuKvtaS8QHvdtYQamoC
hVlVkamL2pFbL/lAuumRklZpXcRrRUhZgVYYpYfpbarstawJEQVDdZkCPWbZ
kYhOrIeTT/ToYqkejg+2K26N1sI4VzBP16pHclSmi+LlC1w+Fy0OHtejxlRa
cvPQczxZO7twE53Cd8+zu8XWlTAKIx1E9hR0Cg+JKLgMX3+iya2WUVCu7OVZ
yyWYk3q6mMOhoGq09XTIEsGxskRx34tC5+XId1MJ1+B1drWHzpsCK8szSRl/
DMNf8D7AYJLz4mSNxUUi4mxl/RNPCp9rzENrTXKJgepJ8Rt3Ch6mnxMzxguJ
N8Hs2B42BWbD8Pbob+8SF93SnLtYFDjz7Pne4nvE/+E9h9k=
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.476796360638314}}, {
           3, 11, 1, {72}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGIPBiQg/JF/XZOBPYR2gNIB9g1zXoqzHomA8hPsHR4+
nb3hSQ1UvMPeQOXDhxtdE+0Vql6Hrt88zX5N0MPaOYfX2quUpK3YILbDvlL+
XcfJpQfsH7Cs3GvlcNTe/VXyp9W3TtrvKNxy1mj+BftTDlHpITGX7e/yMzCW
SV6z7zZk6+Dyv2FvEczDP7/llv3TEqFpxrvu2E+aJiF74v09e6awlecSEh/Y
70k41nfX66F9afZjvyiTR/Z6ZQz812Uf2z9vkD0fzP7Efo330YkO4k/tC8Vy
Q3TVn9mbPRQRlzJ/bv9r9Z6bbO4v7PeXpcz5HPbSvsWRJ/5B2iv7K77Zj6tU
39jfXtSRu6T0rf3j70u/nz36zj6Za6qU4sX39kV8h+Ss8j7Yb5puueHx5w/2
nxQ2OvZWfrQ3XqVx2ez/R/ti4wUpD1o+2bMasKRslP1sP10nI7lp22d7Tc0z
ScH+X+x3qxokqbz4Yu+rNCXxa8NX+/tyPxKOSX6zL5SOSZi+6Zs9s8SB+Azv
7/ZTRFTiLZ98t1cT7Ijjqv1hv0XayLw67qd97w41V1POX/apodLB7zf/srf7
xJ+4Mu63vVg/S34y5x/799o/a2S3/LE/fuJt1/W4v/YLUh/NmMj5zz5KOEQh
88I/e9GDR5c7TP9vn7F9tjiPPoODa1/I7fJJDA5KqbzzH39lcGCwOZbkH8no
cFeoXm33HkaHO7MUJqzVYXK4rXTo5/w5TA63ViUnT+JhdrhpxHq2pYbZ4UaE
3ZyqC8wOAD5WCmE=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144}, CompressedData["
1:eJwNzHtUjHkAxvGENGn3tMuQRa7Tbjs5kW3pkJ9k6UKRIt1YculCF5Rs1Cqb
S9mpoZaSTKU22i4zhTKeqWlWJdF0cXnfmXmbQqNsY6caxNr54/njc55zvvN2
RXrvGWdkZMQzLLF41XGvg2p0CGabjguVEUftAiv9ATUWTj8XoNkvI3K7cOQZ
nP3vjavtBk+dec/4nwg1TlhsYQkMnk9dXu9kcHmp1CHG4DOh48+nhavxImVo
4RqDdcmthUUhavhec3H12Ssj6raGYASpMfNr9jrPEBmZ6FoufbZVjYs/5w3a
7ZKR5thD1LCXoX9gG+v9DhnpSt4t77ZSY+L3qo2bNspIkm1nmeZND941L/aN
dJARs9NpbY7iHhSlm82caCkj0cvSfTrTelC4WmNfN9xIXh6OXnQ/sAd/uEdL
HB40EsdSknvSogdur6yseccaiVVK/retTxl0k9a2VvtGkmF6m6O5xuACa+pK
U0ZKliWlvNwcy8A+Ifn83QtSMrauUB7qwSBnlv3r3c5S8t+bDxyXeQykooCg
rBcNpKB8xgT1kApZ+x4FDSY1kKBuWmtcpsJk96INz6wbiN0TrvfRcBXY8Y5O
5O96MqFmznZ/rgqBv77O1ATXE9ISoa0fVCIsznJrsVZC6njWZU3lSixl96/f
8IuEiC3MGF2YEnufc34fkYMQ223Pr36nxA9NgeM9cu4R998GovT9ChQab9jh
7yUmxalfdnNuKuDnPSY0H6ojaz5qV2yNUWDn8Jn38cdqiaTmeqhwhQJLQurn
a9/eJuYmJgvcNDSig7m9R1xqiJdx/+OcShqpaztOZFuJyGiCmXtlIo3OG5ES
OVNJZiz1cv0pkMasXo7nK9MK0tzKJGEljf0fms7Gud8kJRWjS36cR6Nkmf7+
nKgS8tdT57xaFg2+8ov2ttRCMi3C5LTfKIUQiaVufHY+yf348h77FQVWWG0y
WX+JOB8asS1/TsH/mdZvkiuPGJ17y8rvoKD3DjfN4h8n3Ng4fXs7hbRJA9KG
UR/wfbdkLuii0OvU+67qVDJ2R9oahyooaDof6lP6MtBVU0RFvKYguJif5VF0
CYPaEbe3YxRsQm7xLBPyET+jJaryKxp1c83Tt2kK0NOUoNvFpXHniJgdPa0Y
gWmz02+50vhk8fBmi1EpDvIyWkbiacQP+ZxKaS8DZ/uVY1EFNKgrc/fF2lQg
9+yETZMf07DlmdN9qyux8aDA0/+z4X/yUXdrcRVWrW3NHF2sQJTObwV7rAr8
PcORiSEG27CFRwVCSM5qrXMuKVC1U9yUaSMCa2Gou/6RAj5PjeRcvgjv266L
4yyUKHUZ8C0dFCE68UECtVkJK4GjiZ11NfgoSJXxlfCv8ZBLXarhwWkf6etS
YsqigGyOWzUOdMToddNVcO7b+6nWsRrCzTHSmu0qnIt6UZhhWY2hgX0pHy6r
8M3V7sId/SJY+Iwb+bNXBfrTiYwpBSIEzxcXFLMZfF6+MqNikwjNglW5zHIG
JXts79TphOA6vPOODGCgC0zy9zsvhEdYaZ76MIO7nm47lU5C/A+sbYDV
            "]}, {
           Automatic}][$CellContext`t$$]}, 2.476796360638314, 
         13.136002814510803`}, HoldPattern[
         $CellContext`cachedRes$$[14.18]] :> {10.520949137590378`, {
          
          InterpolatingFunction[{{0., 2.5139559628624433`}}, {
           3, 11, 1, {64}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGIHBgRI1WhRjugwtIfQjlA60H6GjZtpi08UlJ9ov8FN
3W7Wujr76WDxLvvXWXuW3l0wyb5r+1WDSukZ9gYbj7z4t3etvZ9z/xyF7dvt
mcTjHi1wP2Af01NStnHzEfvtjN1ch+RP2tcu+NOpN+m8/UL57S2+TJftWd7n
H2m2vmafvk+DZVfJTftTvQ+dP6y9Y68bO6tZ7fl9+2DpHUtUPB/a83MsZt82
75H9mS+9We5fHtt3PKw4e8Pzqb3ruWSDrPnP7Bl3+03+/eW5PX8rV5Xtkpf2
Mv7HEuqDX9tfFKi6WbDojX3rJd2gpI9v7a2mPDwV7PDe/vuqUwsXuX+wv9it
Eif9/oP9mpw6qSnTPtq3+d64xmP3yX7ewRtC8b8/2W83vem3ccdn+wsrb3Yx
l32xfyl761io8Vd7pkm3mFZ8+GovxXbb7tfab/bGVberfLK/2/u8u71tnsYP
+9SkO58+PP1hX3ftjp7z4p/207zuZk1N+GUfeSpMq8Xot72014WXRSx/7O+e
9FyZeO2P/XzPwxkBK/7aJ5600bCv+mev4rntua7Pf/viJ9OD+fgZHEKWhGxm
rWBwME0RFP77gMFBTOVc0RdPRofvj7suvd7E6HBjsbvRY2kmB8HF2bWtU5gc
PBf1n1DnZXZoXLhZ+FQrs8OuBdfjcv4xO3QsWPBxigyLAwASj/ZL
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128}, CompressedData["
1:eJwBDQTy+yFib1JlAQAAAIAAAAAGQAyiGBbkv8TxUDuVFr0/l2kU79gV5L98
5odOwRC9PyLO40iZFeS/oW3TquwKvT+XCxQWGhXkv7w5tgVC/7w/jnZtFpsU
5L8/nFmElPO8P6ya/EkcFOS/nlXJJeTnvD/lZ7dYMw/kv10ZtS9icrw/bFT8
nl4K5L9Ih8EHvvu7P87PkE6eBeS/TL2BO/SDuz9MxAea8gDkv64e508BC7s/
653K+cfk47/kpjh0K+G3PxRN4W05zOO/cLw/I5iCtD8URU9yg7fjv0yT3oZe
67A/a6lC3Oam4796GNMC7y6qP/RjzQWpmuO/vVfYiocFoj+AqXh0PpHjv4b/
HpLEl4Q/Kavji7KS47/7HE5XhvGRv5TGKLMQoOO/naHPGbpvqL80/5Thd7rj
v/oTQi4bq7S/xcQ7jhjj47/19DrWCuC9v7g+ODAxG+S/95PJkfbuw7903IaY
PlbkvwO/qWb+Xsi/5DAYpICd5L9V6EuapRTNv82Oecyu8eS//ojeZvAG0b/+
4B97eFPlv2e5TudQo9O/06eHIX/D5b/Yj+3DNVzWv6m0ZCRPQua/NYOkqPAs
2b8IPCMyM/jmvw+PjTfy0ty/IM71UdzG579wAShm3kHgvzGRqT17eOi/dCr7
noqt4b8hu1SLzDjpv6vUHamnD+O/juYRyEcH6r/IvxAjImHkv4JmKqsW4+q/
DPmu4jKa5b+TNxbXDsvrv4QLGfedsua/1rKB06697L/236Q7C6Lnv0xdgBwf
ue2/OOHpMHZg6L/5sBxyQt3uvypjZze68+i/x4jZ0jAD8L8AQYnp+zbpvxSw
ajBUmPC/hJ5w3CEl6b+L3N0LDizxv5pNj6bovOi/yokG9mW88b80nPvsPAHo
vyj5hRaBR/K/e3g8ByX55r8KDbELucvyv8ZmfdA2r+W/UUBFa65H87/ZEPmT
rDDkv9I5pw5VuvO/HxPbKT6M4r8EqbVO+SL0vxvl+1Ls0OC/unREYz6B9L9z
zHpb1Bnev9oXq4eY3fS/m3PMKFo52r/7nxarcS31v59F+p0tfta/PY5i/mdx
9b8V+AXQ6fzSv/fsTXlRqvW/f7KCsSWGz78bW5LkJdn1v6SsaLzfr8m/6kec
Qez+9b+T7OWfcnvEv39GZEysHPa/aA0LWnXLv7//RXoGZDP2v+m1RYO1zLe/
uNMo1QBE9r8fEQxqeOOwv0ewJ5JbT/a/sEH+AYLqpb/N7ZTSNlb2v60c8yZB
mpe/dJzGxT5Z9r8A9Ekjrsd5v//21nrDWPa/S7f8K5L7gz+zk32LxVT2vy3C
lJkdcJc/n8eseepN9r+m2ZV0CjChP1bLPcm8RPa/YNzjZ/CbpT/XKYNuIkL2
vxPCg557kqY/PChGPQ==
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.5139559628624433`}}, {
           3, 11, 1, {64}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGIHBgRI1WhRjugwtIfQjlA60H6GjZtpi08UlJ9ov8FN
3W7Wujr76WDxLvvXWXuW3l0wyb5r+1WDSukZ9gYbj7z4t3etvZ9z/xyF7dvt
mcTjHi1wP2Af01NStnHzEfvtjN1ch+RP2tcu+NOpN+m8/UL57S2+TJftWd7n
H2m2vmafvk+DZVfJTftTvQ+dP6y9Y68bO6tZ7fl9+2DpHUtUPB/a83MsZt82
75H9mS+9We5fHtt3PKw4e8Pzqb3ruWSDrPnP7Bl3+03+/eW5PX8rV5Xtkpf2
Mv7HEuqDX9tfFKi6WbDojX3rJd2gpI9v7a2mPDwV7PDe/vuqUwsXuX+wv9it
Eif9/oP9mpw6qSnTPtq3+d64xmP3yX7ewRtC8b8/2W83vem3ccdn+wsrb3Yx
l32xfyl761io8Vd7pkm3mFZ8+GovxXbb7tfab/bGVberfLK/2/u8u71tnsYP
+9SkO58+PP1hX3ftjp7z4p/207zuZk1N+GUfeSpMq8Xot72014WXRSx/7O+e
9FyZeO2P/XzPwxkBK/7aJ5600bCv+mev4rntua7Pf/viJ9OD+fgZHEKWhGxm
rWBwME0RFP77gMFBTOVc0RdPRofvj7suvd7E6HBjsbvRY2kmB8HF2bWtU5gc
PBf1n1DnZXZoXLhZ+FQrs8OuBdfjcv4xO3QsWPBxigyLAwASj/ZL
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128}, CompressedData["
1:eJwN0H881HccB3AqtemWXxWLNmyx8yse81v5kAcZaZo8Kj/uccjKsiLR5C4p
Pcxwm9/huFxluHPnx7lzK3v7cd/T3Ixlj8j3fn7H48HyUDLHY4p9/3j98fzv
9XrZJV/5KtXQwMDgFhlT46mbeSwC+O2HNzhyDN0Zr6bYkGYrRuZrSFuzGfVP
ygho37ckLyNtqKgXvysl4EhL7Pk80i6e8ZOBpN/ueDN8kXTFKrzOLyFgYqNn
LpY0O2ckYHchAYIIU6IEw1Af232ihkFAjmTpRpsMQ4PfxYrtswkwvHMkTzCM
IaNveHrBt2Qf2Vt+/RCGmjroPzUcJWBZtKoNlmLII/FpafMHBAjj9uTV8TB0
fV/741GVDpqYZm30OgxlPnK5ZSfQAW0xeuLUbQzFbFFVnTd1wNVVJ9t/jSFX
8ZiRkb8O1i9kv/H6nNxb8McZM70W0jlnqZ0rMrQyowkw6NHCIYp3aWaLDL1L
fDm1laGFprQUp7AIGXLmcqOPuWvho3hB4rxqGI2tCfUbOg1sWVsFGtGHUUO6
Pms0TwMPeqRdNQtD6Fyd3NfLSgPTYuUnOalDyCyrKK5IogaLdKPNuWeDKFdP
lZvEqUEsMT7m6TGIxodOvrY1UEMMq//HwfwBxCw2TzBtV8FcIXKxYACaGcit
yA5RwV5ujGlUSj+6av83P3RWCQnRCif13sfo2tXT7gscJYTHUF9xDklReGtu
FUZXgizsoE2EpQQFFjK+cHJUwtnNez2ZL0UopWGhI2kFh4knZgPnH3Yj9kDH
fiGGA3XMYadvaCdyljL7TzThMBvSOnDvAQ+ZfSkXpDFxyGbTeVWNLWj0fZqz
Hx2Hy2G6/b9P3Uda3m7LhkgcHhkpbCrNa1CBIqqdhXAQ8WIUhPld5E2xMFgL
wEE2fTJykR8OYW7S9fogHJ4JHU06LhZBeekC0yEKB3rQGRbNtgaCj1ZZuybh
sLi4fefMPxw4UJLW78rAwbRPkn6J+RB8+raCahtx2PXpq6f/NbVC17ap3DEZ
DvwEbiPtNB+E7ktBbss4lFOiuJ4NQvCfEya0kvvl4/8KmLQu+FlTWPEiWQnz
ZbY7Dgq6waQttXG5WQltnr/s8RvogY9zck+5kf8KbzdvVNeJILX7uZf6MxU4
XHCllaFeuNQZOpl0RQVVQdTfuiW9cBxTrTtLVPCXYHtH6S4x6BV1PoNbKlAc
j99K8hQDy471QhyuhtV8acGHIWIw2TQv7CpXQ971+8OOvmJgYBailBk1hPjU
un9vKYbLq9jhUnsN3OZ7j/TP9oJ3AfXX4msaWPOavkHU9sK2A1YnwjANZE3m
R1ICemHxh7uUMGMt4Jr3/Cr/FEHrBCvHykMLnPkMp2CaCOB5BqPdXwuV8+eK
nYJE8D+lUTeN
            "]}, {Automatic}][$CellContext`t$$]}, 
         2.5139559628624433`, 13.034905100452821`}, HoldPattern[
         $CellContext`cachedRes$$[14.26]] :> {10.414930518554785`, {
          
          InterpolatingFunction[{{0., 2.554740593773344}}, {
           3, 11, 1, {70}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGI3BgQ4fnj5f/k6I3sI7QSlg+xXLa3+r783GspPsvc7
vel/tF6D/WqweLc9i8Oi/4zLJtsbrW37n507037GCv3Vd9TX2fv89V3deGa7
vZpwU0OX0wH7peqx2lfmHbFXtbG4Jvv7hP3UYwr8HBYX7CXyVY0bP122N3aS
WFr+/5q9vyi3eB7PLfusF387UiTv2h+OrajVFX5gH3i8cNuKmQ/t7xtkv1dW
eGyfMytFY/6yJ/bpy/WSCp8+tU/c8mO2s8pz++iDh66KJr+wDzvXw/9i4Uv7
gNthnrsevLL3eqHQ3CP/xl7UmKFs8pK39g9q72fM0nxv37FcZv4/ow/2ChNO
chpc/GC/s6KsJDH/o31govL9Sbyf7F96XvA8svqTfaNR7Zavnp/tpaS15NVf
fLbfxHy9M6Lti73Xm+YvnSpf7R9dMYjffeirffXeuyffJHyzF17WZSL3/5v9
6j7z+f5zv9s7lz/hbLT+YX8nfmLJpps/7Es87O4/Lv9pz2P42lNU7Jf9EskZ
W9y2/LK3ZXKVrwj6bX/11cfOlR9+2+denvflVt8fe9Y93vE8un/tdVf3Trjy
/a99yKzzB+cc+mf/J0dv2vOM//aX5ruZzmRncFDjLJu/L4rBoapoKeeTtQwO
525fKeZkZHRQdmW5pxfC6FC+ztgjZDmjw2nx5E2VvxgdHnhPvphexOTwrf7w
h9BXTA48Wz7zuyQxOyi+UNY3usXsYC4T4qcQxOJgo6lwTbqAxQEAMtMMnA==

           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140}, CompressedData["
1:eJwNkms0lAkAhpG1kdKmdnWR1Z7M1DqtXGZWjj6s3dkcu2molY6aGYlYa0kp
m1TksnSUIaVOkVwa99ZlS7PvTHGQk0WGZIqZz23GZRoz82FL7fx4fzznvOc8
74/XlhfNDjU0MDDI0seZ//XcnhkS5SnmH/NWiokmjQX93TQJzsruyT4zMRFT
XxdRqedGjjjecrmY+PmTE6YWeo73ZU1nG4kJ41TGUMwUiYsmjjqzJRFhech0
pE9JoqNp4WrKvIioK6i0/GeURHc+fQUFETHReDG2+Q2JfGdvu4E0EfFNeI/D
85ckEmOYmq17RcTaZZ3Jml4SN9y+PTuyTkTkBlTsPlpH4kxdyPjAYSHRkTLL
eZdDYrtxzZ2ykEeEa/kuzkw8CRPS1DCV0UQUFLsJYzkkFAKaU+GLvwjPpkq3
dl8SMkWLyRKjlgg4Wdz50JlE4FeWQQfe3iUYkrq4+W0kuMNZ0xXac4TjlWa1
rT0J0/bMZ0YX+KDxyo5scyVxN+h082JROUI/tJqYs0nsjKMkLVH1sPBolQzo
/R9oLnftPYTo+XzHeFkFCfsZuedw2FNc810jKJwlsYFXwb9wpR1hLMuTSs9R
jJpdj6Vv6MKjOxkrenJGUdhk7Dwb2wO2uYtMqxqF9lhLSyX1AjsL7s2MHhzD
v3IPnTCvH9021y9/2TOGrPhnuyN8B+GnORzy2YFxdB5MCy5fJ4Xhe69Dxopx
LDNKYmuVbyCtxq6UmgnMtTTttXeUgX4qqsskcxK9ro4Ogkk5sgNmP1b5KpDj
sdmFod9lXWNd67dRiRSf5+3taWPYvmZr1XpKCf/eQP6WhnG4Pin8UTk0hdAa
eVK1eAKH6m9HB3ZO44dXG+16SibBgyWr9skM9gUZ3vcJUmDJTNK9iFmUpf3H
L3mpQEP4jnkjsQrsfYmrBXrP7KXji43ct0hY8/hjh40SpmzBE678LdIPylad
IRVYbz9o6M1V4716Y+TRMAVU98OH6a/ViJrSFZ+vnoRSKk1XBcwh/GzsPoVw
Ak4ZjvS8tjnsZvhzcm+Ng7PK1sjdWQMV85qDjD0GkzNbaYwCDSII5s3V+p+m
lRCRHxY0uL25Pq4hUo5yp79LvPy0EN5c3m8vG0Hk4lCS9I4WrNe5vP2lb5A+
YvNT14QWp27xH7TmDMFAw0t2p+swIXmWWZz7EpJyq+hfuTpE9MmXWI0SKBSl
x6oLdbCrPpVw4bteXN2UnXBaosNl2tP9amYXmHZ2LoWLOiT7v5r/NLkD6j+l
IeovKMhZcbUWbq0w9lpMXHCgcINb1SYPFiNPHpPj/j2Fqb0ZXju6mhG8UjDp
uZ+CiuUedqKoATf5v3DOcSkw++q0bbRaZPbeS+VFUNi8RZQuvVeKtU4St4Df
KQz+4d/+cM8tyCIT0n+LoyB7kNh8XpCIJcm0t5We/az8H0/HJBNCq5JQG33/
6Mye1qLGfOK6znjO4TiFGB/Dq8PpRYTqWpv/6yMUIkJuP31gXUqUbImkMYP1
+4KKivo3lRH/A3mHhao=
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.554740593773344}}, {
           3, 11, 1, {70}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxTTMoPSmViYGBgBGI3BgQ4fnj5f/k6I3sI7QSlg+xXLa3+r783GspPsvc7
vel/tF6D/WqweLc9i8Oi/4zLJtsbrW37n507037GCv3Vd9TX2fv89V3deGa7
vZpwU0OX0wH7peqx2lfmHbFXtbG4Jvv7hP3UYwr8HBYX7CXyVY0bP122N3aS
WFr+/5q9vyi3eB7PLfusF387UiTv2h+OrajVFX5gH3i8cNuKmQ/t7xtkv1dW
eGyfMytFY/6yJ/bpy/WSCp8+tU/c8mO2s8pz++iDh66KJr+wDzvXw/9i4Uv7
gNthnrsevLL3eqHQ3CP/xl7UmKFs8pK39g9q72fM0nxv37FcZv4/ow/2ChNO
chpc/GC/s6KsJDH/o31govL9Sbyf7F96XvA8svqTfaNR7Zavnp/tpaS15NVf
fLbfxHy9M6Lti73Xm+YvnSpf7R9dMYjffeirffXeuyffJHyzF17WZSL3/5v9
6j7z+f5zv9s7lz/hbLT+YX8nfmLJpps/7Es87O4/Lv9pz2P42lNU7Jf9EskZ
W9y2/LK3ZXKVrwj6bX/11cfOlR9+2+denvflVt8fe9Y93vE8un/tdVf3Trjy
/a99yKzzB+cc+mf/J0dv2vOM//aX5ruZzmRncFDjLJu/L4rBoapoKeeTtQwO
525fKeZkZHRQdmW5pxfC6FC+ztgjZDmjw2nx5E2VvxgdHnhPvphexOTwrf7w
h9BXTA48Wz7zuyQxOyi+UNY3usXsYC4T4qcQxOJgo6lwTbqAxQEAMtMMnA==

           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140}, CompressedData["
1:eJwVzXdQ03cABfCAxirWiGJxnAsBScTmgCou6hetosIpByquAkIlqMFiOoIF
iljQViNLiBQBKwJWGqhQyFCBF0JIlXriQNH8svhhGPUANyOO/vrH++Nz9949
l+j40Bg7Fot1mkl2VWB/ziUa1AFxxjqOjpT/mvfak3FKuv2rDYzdnNretZTT
eOf7JjCIMV/pzhkto9F1VvY4hLHusf9cPuPOtzbeTsYu9Qv40aU0Fgg7VkUw
rs3K0hwspMFvPJKQwTizLzbw21waT4ZPOpYxlkw9cztJQmNNpbCt5P/94qk7
09NoxFXFJ51g3OFPjPFbaewQrxunnsj82XWfinGlcfSHtwWebB0JT27oO/Sy
E+1V1jE5oy1EWHODdaa5E4e9/82rfdpCSm8176VyO7FH1NYd8qiFxHGPz1Wu
7URsX3Zvn4zpNw1S215YULos+a4tvoVEhHlzA2ssSLRHqZ9PC5mcNnqRI7Lg
vMuom61HSz758LVTq7cFWWOa49yztWTmz64rgnvMoCo35RfwtIQn6W6XHTJD
9lxHc2ubycURdjlnyISNv3ukFHk2E/LPbW1XmgkzrVNW1+doyKbDniNXuSYk
cKvCqtga8rh6Xp7wjhFD+6VF74VNJBNF5s+TjKhI7VzpolUTSr204QjPiI2+
qdJzk9Rk/wDPS0AZ8OXBAfvp2Y2k9/IpdUiOAbYCDUfUXU/GFg5d0voZsGcj
/faM/Brx8si/6TZIodiQXqjdoSL5gpWDSXIKDj3zTR5BCuL3vDeZfYzC2Dlv
rIWudeScqDfcLpTCFg2/JrqrhgyXPZ1WwaXgO8nm1DHrCpnStmwCn01h73jr
0crAP8jOEfcOZY8e6g1LvqAiyol4IOZa9B09AuXTi72iLpDJFdsWrYYeyWLB
bZvqLPnU6tkcVKfHC9XsrDWik+Sw5VFuyhU9TpXLfEU3BeSEztx1rVqP6zpB
7gLfJLQqB5IfKvXY57hmXZ5bNhLyZyUWaPXY0dF2qcG5AAmq+Xl4qMcdp4VU
yY0LiA1/3THSr4fg9ED9Ck0ZEk1/Vz6bQKF0yaDlo28uY89Y6YSARRSqJct/
arovw3eiPlX+FgrSu/wP/U/+xMTzqZJjYgru1/fXC+5Vo8InJPK3EgrLUySb
nR3+gp0mpCezjUJ7pJ1KOqsW7ek1Hs8/UDh7IL8khV2HIu6hiTZ/A8Q6P+uT
93XYt6vrpTbdgIis7Q0NGjmUw0FNQw0GhO7qT3UmCqzi8BUBwwawlR6nXxUr
MLOUfHzgMyOuZwhyA2gFwr1UyXPijeAPSlrNHCVYdnorT2bEvUj79cKFSvgf
X/Jod48Rcd9v2B3jqcS0xJEZaa4mlF1d5jF9vhL6+5oZSZEmLPXliKTjlNgq
iwqLkpswfnt08C+3FPAv7qtf72CG8UFFXuOPCrirH5ynw81gx5qffTVXATdu
cBmr2ox5ix2lb2rk4E/TLF3JsqCbF+YTsUqOuKLNW90dLEBO8XvhbDn+A6hZ
aPw=
            "]}, {Automatic}][$CellContext`t$$]}, 2.554740593773344, 
         12.969671112328129`}, HoldPattern[
         $CellContext`cachedRes$$[14.36]] :> {10.250709711686042`, {
          
          InterpolatingFunction[{{0., 2.6396813983557115`}}, {
           3, 11, 1, {79}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyA8slHEcBvD3PXdlyjhL3bSTU+0U1xHNTtb319zOlHalXaNF7jhCZd1U
5s/cVdbVYkJSYjLJyebmjslOhLWJQjNawrijOHcOhzvnXFa2nu3ZZ89DE6RG
CAkYhuFb5WL/QzqvPp2s84d/hmx7EexNQ4IDmujtHQfEmRqzKlUCO//+eUDK
xWeQzzPYkV/qJkoog/lLgpQqagMk+6s0JHYLyMvVYeVZHVBHS3odONIN1W/0
pkG/HvDEcboxfABEDY8v2LAh6Izek+XQNAIuuytqXJNGQdBKH/SgTkBx1H7d
T+9J8LVONXrzp6Cvsi49o0QN19iiUz29GlBKaCf3dUwD1j4QKFTOwNmNnABF
7S94zmL64eW/QX1nnMF9OgvFx1N1sVfmgKO31YvoWliTFVx/sKSFWiHNp6Rt
Hi7TGrVvpTo4xpvrz5TqgfDIU8mVLkBKDKOPzDYALz3sg6XLAFAolE+HLMKR
eklVf9ciJEkjFJP8JZDFH+xeti2BxoOqKs5eBvexvcoTlmWIfOFcP5xuhCKe
Q/XdVSN8IRNfUdJWwP6rtej94grk30+LEuesgitL6x7quAZler7GsWwNPKu/
y4a8TFAbxU0tazYB0+lTgIBthqbu4HWvb2YIzlC0L1xdh07m0dxm3TqETVee
yc60gCXLx9DJ3YCNl3mZzoYtW/Q7YgqsYB3mFr7z3YRNo5xqHtgEm4uLjHPL
BuJSlttnewyJ6XMThkgMMXj4OUoThn7co7QCGUcP5Ux64g0cBYxzivN7cDS5
KwZvPkxAeazbN8ckBBSU+GSUOE5ArgmR4R85dsgQf6gtu8EO9cYZGEEUIqoR
qCpWxUQk5kudFLNEpI/Vh5LdSegPc/Excw==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158}, CompressedData["
1:eJwNkmk8lAkAh0eypXWENtnazX20bK4OkbdLp/ZnZ1eljQodjpKGjCNRFlNS
MeSqSStMJDqcwx8zyDYyrmSRmte4Zq1rvCtlrQ/Ph+fb8+HRcfejn5Kj0Wj3
F/jRrC1Mg0ci0Xnas0BJQIw83JHztILE25LeIN1lAsKX4/H+wILX7JizSF4i
IDTLvj4dVU7CZu/WpZcXCQjd+WjtyjISIY1fQtzn+ETxflKZKiVxzY7D2j3D
J7ys4g9uKSLxLCBorVjAJ9QKrnATuCToFg0/jN/mEytf0VzmM0msiOIHnj/G
JwJNA9kRaSSWRg7yjhrxCURnvdG6SML0AsP9+lQNQas6fvC0I4kW/6CEL3nV
hFLl7GCCCQnzvObEmXtVRGSAvr1IkcTPxav6gl5WEKJO51n6qBiLzHX6uGml
BF3OLV2+ToyNlRnN99ueEZjNP7I0V4xCPWOuxstcgpBd2YW7Yig5FUn0TrGJ
KolofWGSGOOi+iRFm1gUtk8Jb/4hRqSih32lbS7abrtralaJUfDNeP0iyQt8
amXIkrvFEO9UnfJdzEOPVv7cnByJCF1vP/uWGuATJ2HQgkRpyj3S72Md1na/
FnxwI8HLLYnrcmgEW1VZJTSBBGt24mBdmxDq4y8YCk0k3jndUWA4iMBrTh1s
UunH5zvx+6w2tEL7+1Xm2kf6YTAa03J2czvijgm15dP7ETG2fKhosgMphkeY
AWQ/6H5KmztKOyEtHLFMsZAgw5ZhX8vqwkdmEiv+dwlOVxow13l2g10mNGT0
SaC31lcrbHcvnC7G3nBwGUBmNUMjtKAPkwXN9NqeASS4crzeKX+Eq5bQTOY1
iP6+qpvMXWKEZ7hxmmlDuPEgN16bScJlXdHD9ZlDMHRSX3zuUT9us3qTW/cP
Q/FSsjDtlQTlGd4384xH8N0GjyjnNYPIsmL2aGhIcan+bvMa+hDMgy82B3VI
4cJii/aaDSOLOrvd6P7feDvRIxRLh3FspTHXwncUDp2FEW9ZI3B1fFwRY/8P
kuQNvz0rL4XXah/BfxpjYNYFs447S1F/RsXFWToGG5XwKsvLUphY6PGZfuNY
se3qlE+gFDmdQ/HZQ+MY1Ynra7GWwsOrztTmxATmInmmqrwRrOeE+th1TODW
wIGuSOURbOLtsflz9yQU4ubEBgt9OmqN3movJrH9ieyRh/YQxMuUz/22Zgrh
/H3b6kcHoOGqdn35lSkEeB3elJkhwd7DtrHl3VPghj+3LbDuh1axWbKCpQzy
Ffp2+ZVibPeciJZmy7CZ+9JePeIDZiR7LrlMy2DQKJuwf9gLr5U5jRdsp5He
Uu2mdPQvPKs+5M0Mnkaigm3JLutO7GzP0Gt7Oo3PTsJ4ny3tsEw9X/7v+2k0
2HEZNEYLhuknm7yWUFAqozs+4Tdh2tEu+7kJBYOufCM5tYUfzYRnbPZTqDtB
HQ62EmDsss8DfU8KFgGBKQENgL5raq0tk4JYrT75jWUpNOvlszfFUGB7uOTT
2UXAkw3+NXcoRFhrFtc+zoHh6lK+fwqFCXpb+N3QdISl+TaI0im8ji4ymW+N
gjIt5sHGDArtv3JC/HWZhM75+a2xqRQep1TomPETibJCI/t9bAoFxdl77Ew5
xFVOSN5wHIVko1sh3J+yCFGJatiraxRmjNX1vrLMJX451NCXG07h3fElJ13f
c4n/AWuOyDQ=
            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.6396813983557115`}}, {
           3, 11, 1, {79}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyA8slHEcBvD3PXdlyjhL3bSTU+0U1xHNTtb319zOlHalXaNF7jhCZd1U
5s/cVdbVYkJSYjLJyebmjslOhLWJQjNawrijOHcOhzvnXFa2nu3ZZ89DE6RG
CAkYhuFb5WL/QzqvPp2s84d/hmx7EexNQ4IDmujtHQfEmRqzKlUCO//+eUDK
xWeQzzPYkV/qJkoog/lLgpQqagMk+6s0JHYLyMvVYeVZHVBHS3odONIN1W/0
pkG/HvDEcboxfABEDY8v2LAh6Izek+XQNAIuuytqXJNGQdBKH/SgTkBx1H7d
T+9J8LVONXrzp6Cvsi49o0QN19iiUz29GlBKaCf3dUwD1j4QKFTOwNmNnABF
7S94zmL64eW/QX1nnMF9OgvFx1N1sVfmgKO31YvoWliTFVx/sKSFWiHNp6Rt
Hi7TGrVvpTo4xpvrz5TqgfDIU8mVLkBKDKOPzDYALz3sg6XLAFAolE+HLMKR
eklVf9ciJEkjFJP8JZDFH+xeti2BxoOqKs5eBvexvcoTlmWIfOFcP5xuhCKe
Q/XdVSN8IRNfUdJWwP6rtej94grk30+LEuesgitL6x7quAZler7GsWwNPKu/
y4a8TFAbxU0tazYB0+lTgIBthqbu4HWvb2YIzlC0L1xdh07m0dxm3TqETVee
yc60gCXLx9DJ3YCNl3mZzoYtW/Q7YgqsYB3mFr7z3YRNo5xqHtgEm4uLjHPL
BuJSlttnewyJ6XMThkgMMXj4OUoThn7co7QCGUcP5Ux64g0cBYxzivN7cDS5
KwZvPkxAeazbN8ckBBSU+GSUOE5ArgmR4R85dsgQf6gtu8EO9cYZGEEUIqoR
qCpWxUQk5kudFLNEpI/Vh5LdSegPc/Excw==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158}, CompressedData["
1:eJwN0nk41HkcB3BHanM0zdbG7kqOdWVTLDbnt5VjNqJoJqXWta4VtRGmHMVu
x8bDw7YmU44tRo6QzEzIxzHzE8I+NjS/ucxPjvHYESZ2o56dP95/vJ7387z/
eptEng+KVldTUytT5YP0hT67h4CyuMusiSgMva9zyPNR+fPrqRoLKuf/4Ko2
0U1ASUHpUbUfMQS22bNrXQTwiu14ViqPbrcbMlCZqh2zfkxlVkZwszMQMKNp
uZKuMttT4ZPDJuCtWeby+2gMHXd39BtoIKC2cXQuKhZDJ5/N9pGrCLjRWsls
icPQdO4MFnKPgLW8PSPyeAwNBFAf3UggoLBxLH4kCUPlQwmpjS4EBFv/1xN1
AUMpDB3mxFYCXLpFi6mqXtGs9naLQAaUAnn/K9WetQuPR6mRQZ1zW7VXGIZu
R5c6MKkyKDokiKB4YyjrkuO3MZoy6Kyv7pXvxtCg8TJZ0jwJM6GGmQ2zfBRF
Lhlzi5iEbo41a76Cj5ZKEkm95EkgqK2T/b58lHLa3uA7phTC945X/CLnobHV
bZpLTlI46men/LeEh9pemzsdfiUBxfKTrGNuPPTybqLJT8kSeOUe2P5mrBdl
aWUvnLKSgA+7xVuZ0Yu0bR+E1EnEkDllGlJg2Iv8MuX0K3+Iobxd/lfk0x4k
MK4pmwsUg2l7adJurx5UU/rc+1MdMUwEeO7+ebAbWQTd0vb6WwSVl+2NboV3
o6qH0Dl6TwShsaFJ9MUupC69YToaK4K6kTDLPeldKOGbqLM0BxHwdymPc5WA
6veX/ZOsIYJxfXPSgYVOtOeI6giYEAIDGFsc8p6jOP++9Og8IZz5uLn1oH4H
Gs5PmMGoQiA9nDY4kt+GzLT2xR4zFYKHgVi3VsFFQcwYYu8yDjsiaTqvXTmo
r0H/QyYfh9qSeGPGpVZUoONP9y/GYdXqBXmTTQuqNVlomIrBofJmuBG5rwkF
2uimSX1xuLgRdr2jsgH9PkL52PU1DmbrDPKz+4/QZird5v5nOBT2+70dvV6F
zIq01nM1cCC5kDyCIivRQN679ewVAVB2lknfJZQitxGa7M6cAOLHZZbzpCK0
8eeZq/tlAjiZ+syJf+oaciS63ZUSASjn2XkFbzzB7b0Fe0jVY1YzJR1BuTDs
ev4wUy6AMwc1NlenFYFsjpVjvyoA1wMzOXpLpaBoMjcP34JDwlbrxP25lTDx
WENTbogDzm7qOkytAtpqdMRtJxyGH/92PlleA7r7roaqncDBwUNjX6drPVQP
tIZ+SMGBv5CyTv++EabHFwTB9TiwvuTX5tc3w2tFS7E/jkOcc3qEt3oLrIhj
FqJ0hKD3xVdrGXufQvnE2Y+2SAg7DavuLlq3Qprl3KTvJSFcnZ2lC9XZ4LHI
wwIahLCyJNYSPmWD75Jj6/yMEEz1KEtd3hzQTXsu7zcRwbTQYo3O4UCxQhb8
KEYETYNYRbY+F6YMN9jn6kVQtOPJr9doXOi2vLDatiwCF9vgJEY6Fw4ZM2k+
zmJIqmBcKbzGhVib5cLBbDFEaBt1SFO4cCCEMr4dE0PylKfeAyoXEsMWh9/o
SGDT/MkT5RZciB+6Q8o9LYGy9oc3jWQcyFlzV5jXSGDHnZfkrHwOHEwnWA+U
Khde7Iu25cC5DVEmjqTwiTG3YhfGBlt7r4zGW1JgHYej6TQ2ZDPsUrc9loI2
ZdeFJEM2/A/7mrvH
            "]}, {Automatic}][$CellContext`t$$]}, 
         2.6396813983557115`, 12.890391110041753`}, HoldPattern[
         $CellContext`cachedRes$$[14.44]] :> {10.111784355330117`, {
          
          InterpolatingFunction[{{0., 2.6565921395846743`}}, {
           3, 11, 1, {87}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAss1HEAB/A75xVtR96b1zUrKwqHRPr+phTlUtcMqXl1U6lDD7SW7Lgr
adymWo9lHgmtlaKm2NTiTA9Ml7c8/keP8zzuhDuXla3v9t1n3y8rLonL06HR
aPSVhtP+p3RLaH3aYS/8M3DVMMw1pd5ja6JXNw9tQU2NhpUCKP/++chjmfs8
q7gNx6HxkkbuA8SY5aYJHatQO3lEEjleC0PeLSOr/reo4Wrc6QFNiCG8SHl5
C9wFrJanme3wOC4eTXCVwnOPls7q7YKXM9++V9QHb6MB3wL2IGxVZZs3JA/D
NmHgtWAPhZsH3I9y91Iw9hYus4IoCOx6imZWXNR13fUumELKeOaoeB+FmDrn
TW4hFA5cb+e3cSj4R6ZX80Mp5PP148qjKQxn3TQZSqLAvru+wTqTgvBp1ZlD
YgpvsvxxzUOGqYgPJg1SGZy2hI8oU0cRyZBVu9iMIa87WRhfNwZ5sPwSp+M7
gup4Z7f9/IEyl6ETLNov6BQeiTa2kiOa+TVM6TqO+szQkMHdE/AUBjZdfDGJ
zkY7ByOTaaxrvhPVJZlGaIvZnYeXZ5D7MU+a4qlA8+c1ppArwGjP5qwtmQXp
0Ob0RMwhT6p5UjY1h/7OpbYUkRKbehYU/nYqpPfNWxjVqCAZUPp07puHxdBs
VMnwPOJHZjL46b/xXDZV7MtcgHZsolH/0QI4P+XfO3Yswi8oRHF+dhHO5U/U
lo+XcEnVbGLmp0ZrIOXE/KSG461lH+NjGpyT2XAMJjWQsL1iGVeWYZN18IKW
qUViR2LOUpEWg+L3rUvWNHLa+curtlQaWWwYKSyV0sjVcIUozYNOzKfoSfvF
dFIiMg13mKSTrfYszO7XIfUv3TY2V+qQYA5h3jdgEEPLsG6zJAaRfDtZfKOT
QbLLM07p7dQlAckF7IwyXULfXqFWrdUjMQ88YquJHvkDJopQIQ==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174}, CompressedData["
1:eJwNznk4lAkABnAhV1IbhVlRjh5Hy4RK6fFtjRStK0JKNiltq5oubdkipEa1
lZIzkdBIjjUhyiuNWTqQM5TyfeNojGMc30PCzh/vH7/n/eN9VwYc33lwnoyM
TJ40wQVxhQb3KPBvVb+y9xIQGY9ssnPjKKxYuMGlx0NA8OWjuGulLjZpjbrs
LiCKUo79t+0uhYDeBQHVvwmIh6pKWr53KEz2R/bJbRcQ4dx9ycGxFNRSbmls
ZgkINVdOPpNDwZh5381XXUDc8jdvVgqnkP/vip0isprghJZvmQihENXk8nCo
sJoYM+hZSx+lsP5cZWVgeDXhZtxLNhMU8iLzFO1O8Ak/9tRVhgaFOD3donq3
18Tn0tqRIRGJuLv+s6HLq4h8Tn7UBT6JXKef7GNaKglnW07iRBqJsBMXPXcM
VRCWEe5ej4JJiHwODewSPyda41tCl2whYaJlVh7uwiMMPbObT+iTUAkcnp43
94RwSTXM1FlE4i0z68VAejIxUKx8NEGZRN7G4nt1IjbQvrUwXp0Ep0e4OGQm
A2xhy6Hv5iQkvrJZa2R4uHjmTIaKBYm9y66ofpLnQcuui2JIfafmntIVZR70
jy42NpM6yfysnaUaDxFrVNm2UkcamuZ9XsLDyrIP5TukvhJd6M3R5EFYMOIb
LLXPgbPLu1fw4GNuo3xD6qodiW82mPLQzuUKnkqtX2Tsf8eKB/HT3exJJolu
8wyJ/W0eCrkCVUdLEgd1mk3dh3nIFOSkP7Aisfh2N6vU+Rk0JbXWP6xJ1CSM
nzmf+wzRn0xv97Okf+VUhI2nnkOtLj5o6y4SxozJS0/8X8LAR1Xb9A8S9FQI
K7C0Eg6ZTqF5YSS4SSyuuKkKvS6db0UJJBw/Lt1eJluNuDVvzSRvSChExOr9
KqmBPWvEtWY+BfpxwDxDxnt0iiwjhx0pXB1k7y+saMAH/uDPPfEU9rbvPq+4
sAkF9/1tDUco6BYle6qdbYHgWtlKfQ8hthpujtCYbgPfwlL8uUeItlSGQ8CR
TiyQOZ2eeL0HIZYa7NmpLtgoK4YNb+vFrGyM237XbgQlFaxjavUh7fmnFzJG
FF4FpEicZ/qw/8/YkkfjQvCZDrkCuh/8r5CxLuqFU1pa5k05ETadjLwj9OiH
e8zNtfL6A1ghmDLIrvmGZ18aDOczxJjeV6fHaxDBwah5mmQMwvnR9ET94wF4
HWHLFOsPQac9MybSUYy2jX4jnhbD6LtrHs/OFUPzQWQtU28EPb/sqXr3TgyT
WNu23KwRrCrSPlCXLYbE+0BFy2oJWhUut/3YJEZdzJDFoQIJqr2YS33+kf4o
VtcwZo6ikRkX5pomwuFuhWtzOaOI/avDL/rcN1zgXL/WsH4Mq0XyPrzmPnTs
l01OLRsDS2Wzd9D3HsR0JCdyGeOwS4tvUTosRIk1hzp9ahzeLCXlkhoSZlcX
+rfzx5HU0DgzbdgNn6bAN81qE2j39p83qfQFdQdL5S67T+BuvMPHC52duDLw
WqB/YwJvA5zGTN59BDf/mcaPVxOoMgmGEdUC+RT78mMjE5DTDm/csqoJqS8r
TUsMaKQ108ad/Hpcm+ye6XWmUWljyXIU1kLC1j0+dpxGvWxQlkIOHwllO7Xf
xdAQqWnEchZVoktxdM7jAQ0FXYWltEYp5kxmrPzyaGw3Oq6eplOIsa9tMVml
NFJHzXgL1mWh1Naoq6OChtULajyvKR6k0dGrT17R2PRedVIx6CT0WouPDFbS
YGyU89UcjCai3Mrn1r+k0Wrau0evKYFY/rDcVbWERsolC/9lo+nE78oFRW3S
vdmdq/62jsgi/L6IL2rmSPuMrkHOucfE/zaDD+k=
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.6565921395846743`}}, {
           3, 11, 1, {87}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFyAss1HEAB/A75xVtR96b1zUrKwqHRPr+phTlUtcMqXl1U6lDD7SW7Lgr
adymWo9lHgmtlaKm2NTiTA9Ml7c8/keP8zzuhDuXla3v9t1n3y8rLonL06HR
aPSVhtP+p3RLaH3aYS/8M3DVMMw1pd5ja6JXNw9tQU2NhpUCKP/++chjmfs8
q7gNx6HxkkbuA8SY5aYJHatQO3lEEjleC0PeLSOr/reo4Wrc6QFNiCG8SHl5
C9wFrJanme3wOC4eTXCVwnOPls7q7YKXM9++V9QHb6MB3wL2IGxVZZs3JA/D
NmHgtWAPhZsH3I9y91Iw9hYus4IoCOx6imZWXNR13fUumELKeOaoeB+FmDrn
TW4hFA5cb+e3cSj4R6ZX80Mp5PP148qjKQxn3TQZSqLAvru+wTqTgvBp1ZlD
YgpvsvxxzUOGqYgPJg1SGZy2hI8oU0cRyZBVu9iMIa87WRhfNwZ5sPwSp+M7
gup4Z7f9/IEyl6ETLNov6BQeiTa2kiOa+TVM6TqO+szQkMHdE/AUBjZdfDGJ
zkY7ByOTaaxrvhPVJZlGaIvZnYeXZ5D7MU+a4qlA8+c1ppArwGjP5qwtmQXp
0Ob0RMwhT6p5UjY1h/7OpbYUkRKbehYU/nYqpPfNWxjVqCAZUPp07puHxdBs
VMnwPOJHZjL46b/xXDZV7MtcgHZsolH/0QI4P+XfO3Yswi8oRHF+dhHO5U/U
lo+XcEnVbGLmp0ZrIOXE/KSG461lH+NjGpyT2XAMJjWQsL1iGVeWYZN18IKW
qUViR2LOUpEWg+L3rUvWNHLa+curtlQaWWwYKSyV0sjVcIUozYNOzKfoSfvF
dFIiMg13mKSTrfYszO7XIfUv3TY2V+qQYA5h3jdgEEPLsG6zJAaRfDtZfKOT
QbLLM07p7dQlAckF7IwyXULfXqFWrdUjMQ88YquJHvkDJopQIQ==
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174}, CompressedData["
1:eJwN0ntUjHkYB/BuCmUlusnSiEjDtGkQ6ldjTU1FsS2n0YXa0iaSLuMoRs1q
s+k2JLHpZhptuqtpunh0mVcXRbrwTtNbTYYoVOiiDvv+8fzxOed5nnOe53wp
viGH/ZWVlJSKycI0f3sseimHmresEJoAQ3+KulUR6XKPNulh0hHD6UysTw6M
1dt2RJK2IIRtPb1y+Pao9mkd6S5ei/NIjxwWXveuV83H0NeYhdbJbrL/U9Au
FunL4WcNY9vk4FX11nT2PoYORBm5rWiQQyGnKCuxEEPsixnns0RyyDzjG7Ck
GEN2uwszqcVyEDKsbE6VYqhK+y/jPdFysL4UijNrMaTIpiymO8lB3T3kE6UJ
Q7yyb2soBnJQmi8ye/EEQ8pPafHqb4ZBAHwjs1YMUaxUifGKYcA6r05+xjDU
NDr8zuX4MLzgWdCgBkN598f7PmoNg9+G5+0juRhyuxXR8UM8BE/fmH3XvYQh
qjJ3UfnJIfA95e044ISh0lHNSBu9IbhrwE5L1cAQqjNZ1pAwCFrTX3s9yiWo
C2avNHwgYOWrEm0qS4LQ4hlONOkMx6SxWUcJuuh3J2gnaceERbUS0qmDCq+p
cQJWe2+J45OO+afvUBFp+6QFFx/S7udOMwNJfxyNWk4l/ezlWwtijIB+dk+C
xEGCdHPmf3YnPaM7NO1NOti2YFnbewJeuWa6zTIlSO+kbM5fQYDdXIfBFEOC
bvdpjqsMEZDnztFX2EqQ28hHRbaUAFTuz+zaLUH3D9q9Q70EUPjsrKod5Pxa
S35pFgHHtiRXb9OSoJsMRVxKEAFFfZvJNc3oTDRt8g2dgB9D5/aWFTej6Nca
e2qVyftEp6rio5rRuyZjbd3OAfgwYeftsr8Zld+gzqRFDoD9Dh+VxKEmJI97
6TNiPACVdaYnBkObkOcEt9qsQwa7Ihc4dbONKCnioCg9Sgbbw34PzwpvROta
Wpy9qTKgzwkjFisaELrHjC0d7IcXovhqLqsB+edzmSe4/TC/Ko/VF/QYnb+d
lua4oR8ezN19cmj8EVJ7tqhd0SmFfKZl2fveOmTB87eq4Uoh1507vYlfg5o0
zkiYO6Wwz7nlRjalGslGI22WTONg7muKq8ZVorVzE43n63AYe0y97NhYjnqK
f1VRScAhOOCafn5lCZIbHmOlBOJwwXxqIrH+P9Rpvom+zAUHuaPwnppAgIyv
OsVk0HEYSec4p0RkoymDuwusjTiwBPTWhrCbSOeZ1wFTIxz6BQVH903/jY7I
BFqb9XGQhnm46Nz2QLScdtfdhjjEJ7CXztJiQEDJKram4KDu780LjuGDq5pJ
55dtOHx9bpTcqPkvWOZcCt7KwCEgtMBnXWou2OsEnv3jOA6nlURjD0VCKLeW
sIRXcJAcNyzoDXkAGvXKFd1CHNr1jLbypCWQYeJvWtGBw8UKRuhwVBkcyHZ3
+0D+Iznc3NlzpBxOnPQrMzORQsoshzlj8hAcNnevWXFYCpxkRtR120rw86r8
dpAnheSVHDbfqgp0Pkc58aukMO8smBZriOC7MDUwaUwKrdExwYY1Ilja7Nm0
17If9Lmf82bDqqF1SfrRJxf6gYFn57b9qCZzvz+/uLkf6G4PXEp8xUDdGK4W
u1wGP9Wv52bmiCF4u9Ungi0DB59OuX2DGFhZrivO5suAzfK48F4iBjvj2DXj
kzKwHrdNia4Qw9YvIamrbAZg1LPF7FyiGFKt2hKPJJP5pJ/OCHYTw0IW7bpo
iLRZQCGuIgbaSjeaxi8E3OowNmkRVgOzKl977WUCdByOqXfZV8Oda7wcWQcB
hknmrqbdIlBk69VbfiFAl6PH25Ahgv8BpFP8CA==
            "]}, {
           Automatic}][$CellContext`t$$]}, 2.6565921395846743`, 
         12.768376494914792`}, HoldPattern[
         $CellContext`cachedRes$$[14.9]] :> {7.6504839072767705`, {
          
          InterpolatingFunction[{{0., 3.6184824086123}}, {
           3, 11, 1, {112}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFxX1Q03UcwPE9/B636WikcoBLRB5C8CSQkbS+H0QOOOcDnKCcIOFtZwOv
MW4GWNwsT0txIidCaoKBkCJlyzwdYjhh6gA73DGMp8kEG6EuBCbjabS7/uh9
976X3z5FiozFYDCY7vMY/9cStN4oituM/nMn4q9rT6VbStCZtaJe86HziH+p
7YhnSS26L9VoOH1a9GVRdHqJXYd8HioFx5h6VJicUPiAa0CJ3r4BFmMnOql0
js7GmZDDvK+F8O9BmRsfnxWw+pChSnRAaB1E5LscR3WIFV3b7bzxi3QYbb/4
V76+6gWatHaHm/60ocrA1vHngjEUk6u9Pil5heaO6h4/bbOjzK4hR2bVOLo7
OILt6HuDVr4c9dy0fBIVO1+tjkyZQoP4m/DAUw4k9nSAV/tbdHHVzHYO4UQL
YQt752NnUEYM8zN78SxqTsSLh3RzyDeNPmlyzKMs76kM5cMFVGOxhHmcc6EX
NUbXzzmLqDyizxYoZMCP8WO3Vx9kgG7X7HFhJwM65Zw93v5MePaFd+jyQ0zY
Mt1l/1vPhNv532jv0iwIsItVZcksKJNPRcnOscA10jATbWVB7ifZzbz32fC0
f4V6KI8NFp0krMfAhrpyzqprTAwOKB4JDosxuJAh037v1pjE2qFzOx1VbTe7
DVzzkWbC7c53etfyP8ZA+1IgT3S79IGk/iu3OZeODTe5pYONCdOAwdXr3MaI
OAwSRds88uIxsP1+WtWYgIGQG5JF7cUgbVdrklSFgaY2I/LeCQza/nEIfX/A
YD6mlC68hcGc4rm+ZRiDrJsFZadwHFpnedmZQTgEQc360CQcVtQ2hqdIcSCJ
Wx8UqnFwfqqPqDqPw2hHR2TbTRx61/VsGOvC4T7eixdM4dA40G9mexFw9oal
7nQMAeoT1oMrswiQZ4/EN3xNQEq0bZmonoDgBvF40R8EuHzK25vfEtCtGbu8
KCShYRHUmxJIOKysTD+qICFt+HXEo0oSQlM3L+XeIyH2jCpfPEFC6pPLPYo1
FMj55o01aRQUb8Wru7+loKxkA5u8Q0GdUbb/w9cUNJEVHbnv0cCmAnwMe2iQ
UL/lCL+joYKKayropuEZZaKfeHAgmM5OD9nKASU9fuXIcQ7codXOAQMH6iSy
qM+5XCgt3aLiJ3OhyBT+65UKLkiXeY3HDnBh225XWL8fD6IvjOSq9vPA39J+
dclPPFjip7XVT/DgX+ergPE=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174, 176, 178, 180, 182, 184, 186, 188, 190, 
            192, 194, 196, 198, 200, 202, 204, 206, 208, 210, 212, 214, 216, 
            218, 220, 222, 224}, CompressedData["
1:eJwN02kg1PkDx/GR5CjT1q7SNdO1XWrt0qqs9V0i6aARIh0TJbYcK2kXq8T/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            "]}, {Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 3.6184824086123}}, {
           3, 11, 1, {112}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJxFxX1Q03UcwPE9/B636WikcoBLRB5C8CSQkbS+H0QOOOcDnKCcIOFtZwOv
MW4GWNwsT0txIidCaoKBkCJlyzwdYjhh6gA73DGMp8kEG6EuBCbjabS7/uh9
976X3z5FiozFYDCY7vMY/9cStN4oituM/nMn4q9rT6VbStCZtaJe86HziH+p
7YhnSS26L9VoOH1a9GVRdHqJXYd8HioFx5h6VJicUPiAa0CJ3r4BFmMnOql0
js7GmZDDvK+F8O9BmRsfnxWw+pChSnRAaB1E5LscR3WIFV3b7bzxi3QYbb/4
V76+6gWatHaHm/60ocrA1vHngjEUk6u9Pil5heaO6h4/bbOjzK4hR2bVOLo7
OILt6HuDVr4c9dy0fBIVO1+tjkyZQoP4m/DAUw4k9nSAV/tbdHHVzHYO4UQL
YQt752NnUEYM8zN78SxqTsSLh3RzyDeNPmlyzKMs76kM5cMFVGOxhHmcc6EX
NUbXzzmLqDyizxYoZMCP8WO3Vx9kgG7X7HFhJwM65Zw93v5MePaFd+jyQ0zY
Mt1l/1vPhNv532jv0iwIsItVZcksKJNPRcnOscA10jATbWVB7ifZzbz32fC0
f4V6KI8NFp0krMfAhrpyzqprTAwOKB4JDosxuJAh037v1pjE2qFzOx1VbTe7
DVzzkWbC7c53etfyP8ZA+1IgT3S79IGk/iu3OZeODTe5pYONCdOAwdXr3MaI
OAwSRds88uIxsP1+WtWYgIGQG5JF7cUgbVdrklSFgaY2I/LeCQza/nEIfX/A
YD6mlC68hcGc4rm+ZRiDrJsFZadwHFpnedmZQTgEQc360CQcVtQ2hqdIcSCJ
Wx8UqnFwfqqPqDqPw2hHR2TbTRx61/VsGOvC4T7eixdM4dA40G9mexFw9oal
7nQMAeoT1oMrswiQZ4/EN3xNQEq0bZmonoDgBvF40R8EuHzK25vfEtCtGbu8
KCShYRHUmxJIOKysTD+qICFt+HXEo0oSQlM3L+XeIyH2jCpfPEFC6pPLPYo1
FMj55o01aRQUb8Wru7+loKxkA5u8Q0GdUbb/w9cUNJEVHbnv0cCmAnwMe2iQ
UL/lCL+joYKKayropuEZZaKfeHAgmM5OD9nKASU9fuXIcQ7codXOAQMH6iSy
qM+5XCgt3aLiJ3OhyBT+65UKLkiXeY3HDnBh225XWL8fD6IvjOSq9vPA39J+
dclPPFjip7XVT/DgX+ergPE=
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174, 176, 178, 180, 182, 184, 186, 188, 190, 
            192, 194, 196, 198, 200, 202, 204, 206, 208, 210, 212, 214, 216, 
            218, 220, 222, 224}, CompressedData["
1:eJwN1H04lPkaB3CiRJb13lma1TKyWCxXDUf8mvXSqjO4SsipLFZbJ2rkZVOI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            "]}, {Automatic}][$CellContext`t$$]}, 
         3.6184824086123, 11.26896631588907}, HoldPattern[
         $CellContext`cachedRes$$[15.]] :> {3.1966880020385164`, {
          
          InterpolatingFunction[{{0., 2.966885840198088}}, {
           3, 11, 1, {91}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwB6QIW/SFib1JlAgAAAAEAAABbAAAAAAAAAAAAAADzztTVSAhDP/PO1NVI
CFM/xbKKBgxWgz/WZS15hyWSP0pyFe8IoJo/RPCcLtkXqT+yk9fy1m+yP0Kv
YE7BU7g/0crpqas3vj9ia79jIx3EP1zxifJwHsk/VndUgb4fzj+ofg8IhpDR
P6XBdM8sEdQ/f60DPFCm1z9ZmZKoczvbPzSFIRWX0N4/hzjYQN0y4T90rh/3
bv3iP2EkZ60AyOQ/jvVL8Z3R5j+7xjA1O9voP+iXFXnY5Oo/Fmn6vHXu7D9D
Ot8AE/juP7gFYiLYgPA/Tm5UxKaF8T/l1kZmdYryP3w/OQhEj/M/EqgrqhKU
9D+0Q0Y5BXz1P6TU5UZxLvY/k2WFVN3g9j99VA80u2/3P2dDmROZ/vc/UjIj
83aN+D88Ia3SVBz5PyYQN7Iyq/k/kNXzKQUh+j/6mrCh15b6P2VgbRmqDPs/
zyUqkXyC+z856+YIT/j7P6Owo4Ahbvw/DnZg+PPj/D94Ox1wxln9P3xHVGTz
uv0/f1OLWCAc/j+DX8JMTX3+P4dr+UB63v4/i3cwNac//z+Og2cp1KD/P8lH
z44AAQBAy83qCJcxAEDNUwaDLWIAQM/ZIf3DkgBA0V89d1rDAECUgUlSJ+sA
QFejVS30EgFAGsVhCME6AUDd5m3jjWIBQKAIer5aigFAYyqGmSeyAUAmTJJ0
9NkBQMGvukiMDAJAXBPjHCQ/AkD3dgvxu3ECQJLaM8VTpAJALT5cmevWAkDI
oYRtgwkDQGMFrUEbPANA/mjVFbNuA0CZzP3pSqEDQDQwJr7i0wNAKuJ4384O
BEAflMsAu0kEQBVGHiKnhARAC/hwQ5O/BEAAqsNkf/oEQPZbFoZrNQVA7A1p
p1dwBUDiv7vIQ6sFQNdxDuov5gVAzSNhCxwhBkB/656b2WsGQDGz3CuXtgZA
4noavFQBB0CUQlhMEkwHQEYKltzPlgdAH+60pC68B0Dc0kuW
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174, 176, 178, 180, 182}, CompressedData["
1:eJwN1Gs01HkYB/AxuhDLYGNRJi0pihXZKZfnf1A0LnVsbaST0rhUJiqSCW1i
11BnK2uokSJRIlEjtvipcS3FfzBDs5gZl0pqwjB/Ijsvnhef8z3Pec75vnjM
Q6MDwtRIJFK1akKDzrU2VMjQ6gQOW2cIh4k10gNRD2VoZIN//ZgMB8PK8Smj
clV+Mce8RWUHjXS6xQ0Zkla/oEolOATOR17Z/JcMRRmVJK8ZxKHyGf+me6wM
HV84wUnrx+Gw253SUpCh4NuGIb19OJzizb001ZKhOM1KeZAIh90+DceuCaWI
9/EPFwMhDtsdhfMrCqUozSqmWkfl5LwLXOQtRc/W0WQrVPsKytD+YLkEFXbU
amqp7hsHREe2ZUtQR5C5IOgTDgGjuowpZwlSH99Y4/cNh9Px9Y4p/EFkv1Y3
nk4RgIHx5Qu5aABd8hgqJtEEcKBiynxVbT9aqsguT4kSQJ9TzHXviv/QZYfk
/EcVAnD1tlh0LhAjXtmDpW/UuwA7rPv66+V3SE+PLbxyvAsi3KtynWL7UNiU
2UH3MZVdINPKuhex8/01dnK74XPtFDO9S4guCGzX2ZzpAbPsRc9jzB7Efj2R
WHhRCOZvu0Wg6EJ3uoZPx74VwRjjYHzNEQHq9n5h9eVIH8SyZkyuVXeis5Vn
Kaw9Yig6VW37sv0NOnVCofPbk36IcLj3nSNsQzZtOsc2+EuAf/clmxnfhA5k
FodHrpQBda/m3bc5Deih8GriNvdhMO6oaC1NfopcTXzj6LmjEObkLxH/+RAx
D3xF3MoPoCxjO0cs5qIzvTU2V4w+wZJ7tO2FjxOAWpIkZ2CfIf95rmW8fRF4
n3HxSyySQ5lHbknzzsew+OVW6PjPE2DZ1OzFwuogeYurHs6ZhByTB2ldyxuB
F48bNtsogJv+gK7V0wpPKE26tKxpcNzAXpmhfANcbuNcBUUJ5e3LTQ3/xeGS
eP0520ICdvVo3L9e0g0D0SxOuOcczFZq0IkmEWySLHNjTn6DaHn+5CZDMfhW
2V+NuLsAAnxrtm/uAHSaf/Bw37MI67uDOrmWUhCWUbkNCSTsydktjKw6GSgU
bx22mahhiSUtP1AZw5Cqe4jlVKaG2Xcm7ywyGgUWlqUtsiZjy5IO2eoK30PL
0bj1S66SMbO90fyOvI9wa7NYXtpHxhiZrgYDkZ+gpSW9Uoukju23uwDNTp+h
IPVDsIHK5zX30+vIcmCpeRFPhWRspNrPLoTxFUZG/bb6pZAxZU//7X3uE8AR
9/U2ksnYi1eXn3kaT8LFvLSEjiA1jFgZ/Kj+5STsCF4US6tIGG2eGuYVNgX0
07c6LccWYc+kqWQFSQG0NhM/F6/vcPuqb8a+awo472Hati91HnijFG6B6TSs
MEzaTb8/B0XRg9Wp3GkwFKqXa9cT4LGrRsTXm4FPteysyFczYFGsYadxYwb+
oA0GcvwVUHtJdIKnrwT7D9/fewxMwDb+xv20RCXg42ZJfRpyeM4UUJ1FSrj5
9B/rhWtj8PhWk222BQGZPv0BL8JHYVPJwR7nMAJCDJqxPZky8D/2Nd/xBgGR
u35pEC0fAJca/xl2IwHorhpOKRCBxn0KzX2EgE3MLRknVf/jccqq1UELBDT+
tIvhdrQN2ixjFpDuLGz3aIizvVkHsxsrdmgaz0K76SQ1a28xOAfqH400mQUe
K/dpqE8WKnZo1v/84yw47Qg/GXivCvkl8nNSNWdhbbdzmvJmPSq5Lzo4TxAQ
IJCdnGc1InOqtmjJMAE6Njnpk9OtiDdUl+f4mgAt6QTm+K4drTWjcLQqVDYN
3BhG7URx1lzZ9N8EiO0y+EIujqYZEf2DDAKeBIT+6uPWharWqs26ORHwbjxB
K7+4G7VFvQ+5tIQA63PWv3+U9KCOZs9Cq05Vf+GlOfpKIXJY3BESfF0JzBir
ic0TItSgvWxmTZISegMtmgbDetH/mJ/0Ww==
            "]}, {
           Automatic}][$CellContext`t$$], 
          
          InterpolatingFunction[{{0., 2.966885840198088}}, {
           3, 11, 1, {91}, {4}, 0, 0, 0, 0}, CompressedData["
1:eJwB6QIW/SFib1JlAgAAAAEAAABbAAAAAAAAAAAAAADzztTVSAhDP/PO1NVI
CFM/xbKKBgxWgz/WZS15hyWSP0pyFe8IoJo/RPCcLtkXqT+yk9fy1m+yP0Kv
YE7BU7g/0crpqas3vj9ia79jIx3EP1zxifJwHsk/VndUgb4fzj+ofg8IhpDR
P6XBdM8sEdQ/f60DPFCm1z9ZmZKoczvbPzSFIRWX0N4/hzjYQN0y4T90rh/3
bv3iP2EkZ60AyOQ/jvVL8Z3R5j+7xjA1O9voP+iXFXnY5Oo/Fmn6vHXu7D9D
Ot8AE/juP7gFYiLYgPA/Tm5UxKaF8T/l1kZmdYryP3w/OQhEj/M/EqgrqhKU
9D+0Q0Y5BXz1P6TU5UZxLvY/k2WFVN3g9j99VA80u2/3P2dDmROZ/vc/UjIj
83aN+D88Ia3SVBz5PyYQN7Iyq/k/kNXzKQUh+j/6mrCh15b6P2VgbRmqDPs/
zyUqkXyC+z856+YIT/j7P6Owo4Ahbvw/DnZg+PPj/D94Ox1wxln9P3xHVGTz
uv0/f1OLWCAc/j+DX8JMTX3+P4dr+UB63v4/i3cwNac//z+Og2cp1KD/P8lH
z44AAQBAy83qCJcxAEDNUwaDLWIAQM/ZIf3DkgBA0V89d1rDAECUgUlSJ+sA
QFejVS30EgFAGsVhCME6AUDd5m3jjWIBQKAIer5aigFAYyqGmSeyAUAmTJJ0
9NkBQMGvukiMDAJAXBPjHCQ/AkD3dgvxu3ECQJLaM8VTpAJALT5cmevWAkDI
oYRtgwkDQGMFrUEbPANA/mjVFbNuA0CZzP3pSqEDQDQwJr7i0wNAKuJ4384O
BEAflMsAu0kEQBVGHiKnhARAC/hwQ5O/BEAAqsNkf/oEQPZbFoZrNQVA7A1p
p1dwBUDiv7vIQ6sFQNdxDuov5gVAzSNhCxwhBkB/656b2WsGQDGz3CuXtgZA
4noavFQBB0CUQlhMEkwHQEYKltzPlgdAH+60pC68B0Dc0kuW
           "], {
           Developer`PackedArrayForm, {0, 2, 4, 6, 8, 10, 12, 14, 16, 18, 20, 
            22, 24, 26, 28, 30, 32, 34, 36, 38, 40, 42, 44, 46, 48, 50, 52, 
            54, 56, 58, 60, 62, 64, 66, 68, 70, 72, 74, 76, 78, 80, 82, 84, 
            86, 88, 90, 92, 94, 96, 98, 100, 102, 104, 106, 108, 110, 112, 
            114, 116, 118, 120, 122, 124, 126, 128, 130, 132, 134, 136, 138, 
            140, 142, 144, 146, 148, 150, 152, 154, 156, 158, 160, 162, 164, 
            166, 168, 170, 172, 174, 176, 178, 180, 182}, CompressedData["
1:eJwNzWk8FAgYgHHH2mUTCm2HUk3RdkiHCHmRQoUcqQg1RmEQtkTJli5XoyI1
SkNrFEY0OTu8SRhzmDFmMM45I9Kh+/LbPjwf/p+eRcTDPmHqampqtb/qqUhz
GXBXoFl9okbHUhaM1DPjPrkpUJ2rsrppxoJjL9ZeM/jlDVEmIZHmLBgPihx1
tFNgWE2hm2wtC0iZJ5aRLRQYcfKtz04HFojizwZmL1KgLCOAWefOAqtD1nrV
P+Xonnuk0SmCBVdIGxPLJHLM8HpTn5fGggSGkSK+Ro7K7KC5j+6wwG5q9Mr0
y3K0jtWjPmhlQT935nKOjxwTz++6PPWNBYaGxbt/N5JjQbTpvncW7VAV4NaD
IhnSh2o0S4jt4FdduPhLrgwTJUfBJq8dwp3nkyv9ZDhysLSxpb0dWnNsC9s+
S1GdSBGzDdmgzVxeJqZKsVz6g3o4mA2cNH5Kt60UHYtcpv9dxgaTy2HlGTXD
GHMr7HzyZzbkBLM5G94P4TV/gq+mKwcMeycsaBZDOF3CeRJD5cCWbzfiF+0Y
xPWVXVqPvnOgWmAVHHlwAFeMBw3bkLjAP+vMdTzZj3TzHNPrIi7sdw9N2nep
DymW8hVyTx54Nk6IiDQJHp1L8c8W88DP/MwMRWkvOqjuvS4kd8CkiWSbd2UP
no21Dm0y4oOw7kaaWmU3puwpCCOL+cC7mR86764Yp6mOE7P2CiC7m697gyrC
8/V+l+z7BPAnObKsqKgLa1sXGHwI7oQIxmpi3KAQVVcvmn0UdkJyzOmxF4ZC
LNN4TdDcJYSlgXsItjGdqPYRdWgsIVzvF332eS5Aos6mm3TXLmCHTJq2GgtQ
EBfluqOrC1K5P2Jtn3cgAokmiRJB14q0CwxvHhJu5JnRjMXADnpY1TOLiyZc
+va1FWLQoXNs3gvZmJW03PDJzm7wdwsfcz/XjgmJxVmjaj0Q/YGQMn8VCx01
2pZtaeyBra3FIXfbW1GL8ka2Kb0XLIx9tywMaEEqIz5dmyiBoHkhzQ2Dzbj4
uGdyjlsfWFrxvzN8nyGpheoeZ98Pa5yzTkk1mzA0M8BJTX8A9POfGvB8EedR
cknbXg7A26bZCzoyHiP8sz5uO3sQrm2f7WDJaEByHh9rq4aAs9UnL7WuFq/2
NWt8yh+GV9+ynVIYD5Bnv844b7MU5OONTN3MKnxakUG51SCF/SfT7PJLynDs
D+O90RYyCLzlzbGcVox2xUlETqEMSiPrE3Qz8vG0C/t5sr4cdDNsrcf803H+
s3JPjyQ5PBSrguvdvfHARIPoIkcOVvZOq38eOge3gx+k2MxRgHnMQ+bu8jyg
U43SOw8owIv1bsLwUBEI1SfuThYr4NkwIehY1h2wpN/V9JAr4DU/2F79eQUY
tawyKpujhEp+TcOIFhOuBob8O75NCfWfXT109WqBauA+VnFKCYEXZORe04dQ
23zMtJShBLznnU/a2AgvZno6r+Ir4YzKJjVmZRPolyQHVo4qIaxlWLHZoRkm
U2buwK9KWBPxqoTk3QJdl7Z5TWmoQFsnMdYwrA22Lkq4NktLBQs/RA/+l9gO
u0Zu76lWUwGDciD6eCYHelMP7Tn1SQnxHXGfphXwwEjgPTlvRAkuuxMq29QF
8NdxSV/Ur7/L0fH+M+s64bcv9uRAphJGL2a+iQ0VwkQ2Iar8khJexjROel3u
gunh9CIdshKK/J3txh+LIHtJpFDXWQndBpR1xi/EED7nB9F6lhIqDGLt7+j2
wH0e3+XriAIGuj0Zpyx7Yfz21qn7dQrQ1jN6dc5bArsu1JUyzykg06Spina4
DzzKid3g88vVAa1W3f2wau9iW0d9BXjUvk/vtR4E85VHHt1hy2FviIZedO4Q
HDl8wrX5rBwW0GYcHBwfBmuuz03+JjksNUtjT6NJYQl5yvnHRxk0pfVxCyal
sJ5wJYvdKYP/AXTB/k8=
            "]}, {Automatic}][$CellContext`t$$]}, 
         2.966885840198088, 6.163573842236604}, HoldPattern[
         $CellContext`cachedRes$$[
          Pattern[$CellContext`tau$, 
           
           Blank[]]]] :> ($CellContext`cachedRes$$[$CellContext`tau$] = \
$CellContext`G3[
          $CellContext`home[$CellContext`tau$], $CellContext`Aref, \
$CellContext`t$$])}}, {
    DownValues[$CellContext`ttupperbound$$] = {HoldPattern[
         $CellContext`ttupperbound$$[
          Pattern[$CellContext`tau$, 
           Blank[]]]] :> Part[
         $CellContext`cachedRes$$[$CellContext`tau$], 3]}}}]], "Output",
 CellChangeTimes->{
  3.464347423974959*^9, {3.464347470073078*^9, 3.464347508152225*^9}, 
   3.4643480181929903`*^9, 3.46435219032655*^9, 3.464352271650028*^9, 
   3.464352409129513*^9, 3.464431592495235*^9, 3.465207764948668*^9, 
   3.465209875595265*^9, 3.4652221660099297`*^9, 3.465226028777896*^9, 
   3.4652326282784443`*^9}]
}, Open  ]],

Cell["\<\
NB: Location on the home-trajectory labelled zero is different than in \
previous slides.\
\>", "Text",
 CellChangeTimes->{{3.4652205344615097`*^9, 3.46522063918154*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
The time resetting map can be iterated to determine the neural response to \
periodic shock trains\
\>", "Section",
 CellChangeTimes->{{3.465180055008205*^9, 3.4651800625814543`*^9}, {
  3.465204648476519*^9, 3.4652046605830793`*^9}, {3.465216113100884*^9, 
  3.46521614594233*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"cobWebT", "[", 
    RowBox[{"T", ",", " ", 
     RowBox[{"{", 
      RowBox[{"100", ",", " ", "0"}], "}"}]}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"T", ",", " ", "3.1115", ",", " ", "15.3746"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.464403055521214*^9, 3.464403059599847*^9}, {
   3.464403231290009*^9, 3.464403232502221*^9}, {3.464403307792469*^9, 
   3.464403336925886*^9}, {3.4651801598866777`*^9, 3.4651802145893087`*^9}, {
   3.46518025568513*^9, 3.46518026041289*^9}, 3.4651803653694553`*^9, {
   3.4651804930445232`*^9, 3.465180495154292*^9}, {3.465181786764409*^9, 
   3.465181788890135*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`T$$ = 3.1115, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`T$$], 3.1115, 15.3746}}, Typeset`size$$ = {
    405., {198., 205.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`T$64834$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`T$$ = 3.1115}, 
      "ControllerVariables" :> {
        Hold[$CellContext`T$$, $CellContext`T$64834$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`cobWebT[$CellContext`T$$, {100, 0}], 
      "Specifications" :> {{$CellContext`T$$, 3.1115, 15.3746}}, 
      "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{458., {252.21875, 258.78125}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.4651802082196293`*^9, 3.465180215360156*^9}, 
   3.465180262389222*^9, 3.4651803664028*^9, 3.465180495743557*^9, 
   3.465181727912826*^9, 3.4651817899016533`*^9, 3.4652040766296053`*^9, 
   3.465209879589501*^9, 3.465209974592544*^9, 3.465222174601857*^9, 
   3.465233790222569*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Close Agreement Between Resetting Map Prediction and Differential Equation \
Prediction\
\>", "Section",
 CellChangeTimes->{{3.4652146548421907`*^9, 3.465214685508955*^9}, {
  3.4652222580124483`*^9, 3.465222277114747*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", 
        RowBox[{
         RowBox[{"countList1", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "200"}]}], "}"}], "]"}], ",", "  ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.007", "]"}], ",", " ", 
        RowBox[{"GrayLevel", "[", "0.8", "]"}]}], "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\!\(\*SubscriptBox[\(N\), \(spike\)]\)/\!\(\*SubscriptBox[\(N\), \
\(pulse\)]\)\>\""}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", "rateMapDatab"}], "}"}], "]"}], ",", "  ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", " ", "Black"}], 
       "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\!\(\*SubscriptBox[\(N\), \(spike\)]\)/\!\(\*SubscriptBox[\(N\), \
\(pulse\)]\)\>\""}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "4.994145750178575`"}], "}"}], ",", " ", 
      "Automatic"}], "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.8], Thickness[0.007], LineBox[CompressedData["
1:eJxd2HlcjF0bB/A01GRpUTLJFvEQSmOJkjtG2VqsqZi2J4WUhLQoMk+rUEoL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     "]]}, 
   {GrayLevel[0], Thickness[0.005], LineBox[CompressedData["
1:eJxd13lcTPv/B/BqpCnaSCZZirgJpSFRcmKUpQ0pFdN2Keq2CCkJmduKFGmh
LNFGpQYpUWnQIlqEFiMp0TYVlVLq19T9ndf34fPPPJ5/nM/5fN7bY46ivduO
fUICAgLfBQUE+L+XY/grhxD4bwWvt/1SMT+X9LHWRerU1MekncI7jxMaeaQt
19wv9szLJ33LXUfs/c0C0rHPFDI89j8lHUGbZC6xrJD02X++DqX0wKyC0ht6
WRzSx2XSNzUee0b60H7+AZ6Tdn58+CJt0gvSf0tZjJ0Ittqr3WByroi0afZc
//btxaS3ThVaEihbQnoD//r1sBb/etdKSdOpqbOt9r4krbLnfGGfchlpxbHb
hnfCcvzrsl+RluYfz/M1aVH+dtrlpCdWBenfKT1VRvbwgGlTwpVncO/vaq/W
RZWku5NeGGgGwx3b+ReG+dGuMqoi3Ty2m0IG/MnkXJTrtDekPwyecHp8GK65
yU8w/MbIfizi1aTLf/IPCL8cy+aP33DR2OnW274lPRa8sQjC+ddmqXGV3pHO
3cJPEPzwB//C8L24rrEbvyfNrxaZdPg2P3xSNaQT+df1gG+OHw++xt9Os5b0
RH/AkYwzYxULX+C3g3Ud6dCx6LEK4Il+qic9VnxjCYH9LvE3hE+M7fZoy4c/
+g8+cpHfQFzSB/nt5g67jCcYPjDerx9Jj7dDFGzHP90gzOSX856GP/q74Y94
fiKdzC+39Z/+iC88MQ/g+PF4w9f56Z7cSPrqePzhifnR+Ec+4Gh+uEsb/8gP
PDFvPv+RLzhsvADhc+P5gyfm0+c/8tlEOlC29vVYyZMOGM8vPDHP4NPj+YZP
OvEHWDNp3/H8wz7j8w/2Hq8H+Ggev2Hgifr48se8hCfqBXbjh+8GPFE/8MR8
bSE9vp0G7OjAX7BoWJFIdi58O0c5RVT6K2nDpuCtux3gzqnt7am58PlVhudG
pL6RXm6bprrNAa4Klqi4kQsfvud28IdUK+kZ3Ippeg7ww8n0+5G5sMXyi2bf
pNpI/7Ls7V/jAMeyzKLP5MI6aVlruFLtpBvezaxXdYBPCXgfP5ULz1epm1Ml
1UGaY6qdv8ABdvCNtT2SC1OTfgsWSXWSTqmwvklzgA1+5W90yoU7Fii25Erx
iKXKLSkVldlEqNHpQHEHHpGomNI/EPCUUDvapGyTyyMq7/S4+TPfEpXXN5Zm
SHX95+fEodIEZyGHLqJ2JFtrodFzQqZ3svjOXLheYuX7HdRu0nduNicN0bsJ
WtSPsAWlzwjf1Ze8bjG7CcuocNWdEgWE8Su9LUZB3cRrRqiyaWQOMde+X66f
3U2cEn6+dobWI6KrP7HtKrebODpiYPzB4TFRcGZX7iZqD7EtjKYrr11IhCtQ
z3bTewi3DxrOlwefEnYPsvfEMHuIou4XzHuJJQR964FlG4J6CKcCBYFy42KC
0iA30sbuIQqrM79/HSonqg+Vvr7I7SHU51Yn7netJBKoPtfWUr8TYgmy83xf
VxGecUvcv9C/E2bj6y2hT/+gG8qEZxadldYMgr/t1vncwIZzujvZQVw4xP8q
S536g7TVLJOddXR4yd1RJRYTHmZk9C0Jgl/V2L6oZsNXXaSjfLmwq1Ch4yJq
L2kiymN1OR2WWrpA1IsJNxa8qVUIgjPN/r1dwoZPt6308eDCpie/GMhT+0gr
yUTOfkaH+5L1O/9hws91fj6ZEQRHViWF5rFhR0cLG0cuvHqYulyK2k9aNDxH
IIcO1y50qrRjwrcfzYoXC4J9TF563GPDhs0+jD1ceI73Uhlh6k/SneLc5jQ6
nBd/7oE5Ez6vuS5gNBC2LeOZJ7Ph5XbX/trOhQX7TQYGRQaI2FnLqQX33hBV
IQIl8fQBoqzlvpUBo4q4NS8zxoA58F9/vCWO3Ldz6g0cIJ/X2zJNO449QOTU
FPrWxr4jZD8WTtHnDhB7xhvkHfHV49AHnsggwUyerdC38S2RLaKUFkUfJISD
Be9nLqglgmOrfXWZg4RdTpJ0pE8dYanub9waOEhscAlpkX1SR6i80Jh3gT1I
pJ4Xz7oh9ZEYsmrp0uIO/tcPDURZV2RBk8gv0nH/bgo/S4dd5AbsNJjwuvRk
+sdAWJJhSQlkw5/ei1arceGMfx7dqhEZIu0n6HzEjw7viJTXV2HCC5aUyb4J
hHvzj3/1YcPPdi7LVuLCl1q5Qa9Ehkk7nAi19KTDmtMJlXlMmJrc9asoEK5Z
e/2lOxtOqdwWK8eFjzkIuhSK/CZtMJSp40yHZ4fZS8gw4Q6l6Q2PA+EnOZy7
+9hwqPHhUxJc2KZJaftDkRHSal5vFW3psIB4wHcqE668sYqTGQjHr/p60YoN
H3oZtZfChRm2mzVSRUZJy/QNCJvR4S/BKe9+74Gz5lolJQbCgffEvEzY8K7N
uZsHPsARvAdnKygCuv/v36sl+pTk4H0sB6a3KvzqVd7zVwx4FW2m6nxL+Kq9
W6SnKyySVjRSyoLdfs5znBcDv1/vVX4oHdY9W6FZzIGT3ylfn10LSyv6UQ/y
YG/nWvfnFEHSjQ/Ua+Xk4K0CIetdVWH21s8phQxY/pLWtJmWMKvhwjFnV7hj
cfvnfBa88zDDQCYGfpx35d7+dFhJtFf+CQc+Z2r4r3Qt3Bd3q2MfD7b+Nrzz
EUWI9Au62RMJOVjNN23h36pwdJFw6EMGLDDNun+KJXxgT5a1rStckShRdJ8F
r+lxUBONgW9o50cx02GxgJkCbA7sUeG2f3ItXD+ruMKKBzP2Kay5S6GQTr3r
dYMiB8v8qhC1UIWPb1zskcqAm0P96gQsYaPa2g1mrvCDBfQ7KSx4rmvI9JFo
OCD7s8+OdLhLSLs5kQPvMrpoOFQDF0S13zfhwcqfGXNuUSaRDlsa6z9Agwc8
ezsNVWG7p4bmNxhwyZSEvD4LmG7+e9FWV/jydbPzV1kwpT3t5/do2Fljsu2m
dLj6pHXxFQ6sXZq1vLsGviUjGbORB0+1cRSMoQiTPpKSf6CTBnN/zKxarwrr
r3PXimTA6UHF8W0W8Mw3ClMIV/jkHO9DF1nwN8fK+q/RsAl78ca16XD2sF9q
GAdW2FQn86UGDg6n+67hwT31IV/OUSaTtlrUZPSZBhe6a2etUoWX5F6ce4YB
Rwh3BDRYwEMmG7tWuMJ/X47dFcSCy5p78z9EwxpqRsrq6XCcd0KYPwee/Oz3
QG0N7CphbqfKg99bpJecpoiQJm5Opr+nwUmd1peXqMKSqx8KnWLAXqclnast
4E9ljm+UXeEtMwu0fVlwph3tVmU0PCvVfeqidPh0f/HhYxy4XVeR+7oGNj3j
rbeAB+e+rUw7SqGSXqCgIltGg886nT6hoErVnfi/84XovV/XcpgBM0fpJiUW
8PMtZx7OcYVVI5rmebDgyI/aQS+i4VHliO5Z6bDDoQ4LNw5c/mTjU04NrEmN
W0zjUXXDbYT7O4e/Etd39IX/QxElTY0z+lVAgw9+TbCfoSqqO/G90krUqo+U
HmDAG46br8izENXdWrA9Myu1jbj9Iv3KNFdRXZXLu3udhtuJ6dIikxxZoroB
pYI7THZ2Esd22/yTGy2qO/F11k00JTyslkyHDboldfZy4Pta+xOya+DZ/gXi
4jzYv5zmaUcRI90pd/DjAxpsvrdEX0wVzk9XvGvNgBcNes+8ZwGHMqpOirjC
P8+pfNvNgm1rTm/LiIaL59dnT0qH1V1WKFpy4JiHZ4LTamAhoeYeQR7sZLjW
ypwyhfSbyIjC2zRYq7FDZXQZfHOJ3kVTBjzFM24oyQI+XND397AL/EHMuGwb
C9YzS1yZEA2nXRuJHUyDZdvMhY058ImVd13ia+CWEyLv+jth4xKbdQaUqaQf
Ts9OvEaD51lLSfYug4OS9x/dzIC7vxc0xFrAljpym3tc4KeBBzP0WLBKVQnt
cjR8YfZ8P14a/MvhWOsGDmyfWbU9qgZ+OaTyqL0TXqHPmq9LEScdG1YfEkGD
J9Wv+PFtGeyy8OxuHQb81q2ZE24Br3u0dmmLC5ww6VKEFguWMOkcDo2GPWP0
9jWlwQ1Nca80OfAm1X6NszVwhpfx1U+dMI2TOFmDIkHaT3zUNZgGt+7a9Z67
DN4Rf5egM+CcDpHkAAt4vqatVL0LHOKX7aXGgn+8lGpkRcNrl38UWpUJ+0fc
UfpWAr8a8NK//BmWZervNxyCbZ5ODxmZLkk6aWHjnYylcE9w+it7PXgNz6dL
xho+vWOLdJEn/DJLdoX3eXi6fPPOJcnwnpOZntwCOKHpRPT5Wrhzk+Gj9d9h
+XdTed7CUqSJoB8jVdLwXq06yaVz4aCOAgV/FTj1apL6x1Vw5bbQDZoMuE/o
iGmYCSz3YPfe1t3wOscNRzbsh+3lFgdcOQwHvJSM6j0F3/HtTzI6B5ercbMT
Y+DeRk7JaAJMi7hdZ8GG1+qHt2fmwXYDR4fFXsL+t63F976HU/bozX3SBL+W
WKom2w1/L5im6zYMyx4a3FZMlSatvfCTneIM2Ob9C49jijArOI31ZhmcrB0R
sVQLLus8luCvD/dcs8v6uAOesWNzkaYNvGaSWk2YM2ydNaO19Sh8ev/w4IZ/
4cRZTWKxYXBpWYl8XyzcdSJjqXEKPF09SifpAazZ5GssUAgzL+21sXwN+20y
cGfXwQmD6n5Tvv7P++7QLuz9AfOYo/FPRuFpUi33ZKdOw/sKy5650eDdh++9
LVaCTy663KKoDt+sOfXzmA5cHOJIrd4Cd6w1lltmDkt1rVQJsIc1bshrN7jC
lqZChqt9YF/h1j3hgXD8w3KXtovwiwNZJxjX4Tb5uPOxqbDka9b1vmx4xSmn
TOPn8C769sKkSvh4s+YbgY/w9ci5zZZt8LPNwn3sfrj1V7vwVMp00uJpVbL7
JGF1m5y/8uRhM+nrq2cqwz6cgC3uK+FrR1ysSnRhzl87necbwd9qtY77WMJT
zyqeq94HL19HvbrM43/e181LDzgBe8e/zW8IgeN2Pq5YHQUXTr7ZGH4TbskO
/t52FxZzdqdsfAyrzdklE1cMm5brLOyvho/6Ka0yaYRjV0zZlNwJF3zp2SX4
C/4/O7ZGTg==
     "]]}},
  AspectRatio->0.3,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"T\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*SubscriptBox[\\(t\\), \\(r\\)]\\)\"", TraditionalForm], 
    FormBox[
    "\"\\!\\(\\*SubscriptBox[\\(N\\), \
\\(spike\\)]\\)/\\!\\(\\*SubscriptBox[\\(N\\), \\(pulse\\)]\\)\"", 
     TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{0.5, 4.994145750178575}, Automatic},
  PlotRangeClipping->True]], "Output",
 CellChangeTimes->{3.465176936781933*^9, 3.4652079513110323`*^9, 
  3.465208893147744*^9, 3.465209025294159*^9, 3.46520986613601*^9}]
}, {2}]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", 
        RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", " ", "2"}], "\[RightDoubleBracket]"}]}], "}"}], 
      "]"}], ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", " ", 
        RowBox[{"GrayLevel", "[", "0.6", "]"}]}], "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\[Lambda]\>\""}], "}"}]}], ",", " ", 
     RowBox[{"Prolog", "\[Rule]", 
      RowBox[{"Line", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", " ", "0"}], "}"}], ",", " ", 
         RowBox[{"{", 
          RowBox[{"4.994145750178575`", ",", " ", "0"}], "}"}]}], "}"}], 
       "]"}]}]}], "]"}], ",", " ", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"TLambdaList1chop", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", " ", "1"}], "\[RightDoubleBracket]"}], "/", 
         "tr"}], ",", " ", "lceMapDatab"}], "}"}], "]"}], ",", " ", 
     RowBox[{"Joined", "\[Rule]", "True"}], ",", " ", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", " ", "Black"}], 
       "]"}]}], ",", " ", 
     RowBox[{"AspectRatio", "\[Rule]", "0.3"}], ",", " ", 
     RowBox[{"FrameLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*
StyleBox[\"T\",
FontSlant->\"Italic\"]\)/\!\(\*SubscriptBox[\(t\), \(r\)]\)\>\"", ",", " ", 
        "\"\<\[Lambda]\>\""}], "}"}]}]}], "]"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.5", ",", "4.994145750178575`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.7"}], ",", "0.11535638937726764`"}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465155729888483*^9, 3.465155841879208*^9}, {
  3.4651559246611023`*^9, 3.4651559320156717`*^9}, {3.465155969509884*^9, 
  3.46515600631553*^9}, {3.465156048084021*^9, 3.4651560928964987`*^9}, {
  3.465156991371931*^9, 3.4651570351777287`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {GrayLevel[0.6], Thickness[0.005], LineBox[CompressedData["
1:eJwtV3c41e0bx7HnMTIaRslbkaJXKul5UFKRdnapUERCRUplZ1fejIyorGwy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     "]]}, 
   {GrayLevel[0], Thickness[0.005], LineBox[CompressedData["
1:eJwtV3lYzF8Xr6Zl2pspCaEUP0IbKYV7FdlKhDZKklBaSBSyFO2LSEIiraJV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     "]]}},
  AspectRatio->0.3,
  BaseStyle->{FontFamily -> "Arial"},
  Frame->{True, True, False, False},
  FrameLabel->{
    FormBox[
    "\"\\!\\(\\*\\nStyleBox[\\\"T\\\",\\nFontSlant->\\\"Italic\\\"]\\)/\\!\\(\
\\*SubscriptBox[\\(t\\), \\(r\\)]\\)\"", TraditionalForm], 
    FormBox["\"\[Lambda]\"", TraditionalForm]},
  FrameStyle->AbsoluteThickness[0.5],
  PlotRange->{{0.5, 4.994145750178575}, {-0.7, 0.11535638937726764`}},
  PlotRangeClipping->True,
  Prolog->LineBox[{{0, 0}, {4.994145750178575, 0}}]]], "Output",
 CellChangeTimes->{
  3.465155981560594*^9, 3.465156093667206*^9, {3.465156992051538*^9, 
   3.465157035815701*^9}, 3.465177248562879*^9, 3.4652079513411703`*^9, 
   3.465208893180688*^9, 3.4652090253306828`*^9, 3.465209866269717*^9}]
}, {2}]],

Cell["\<\
Key: Black\[LongDash]Map     Gray\[LongDash]FN Differential Equation \
\>", "Text",
 CellChangeTimes->{{3.4652148968496933`*^9, 3.4652149587255898`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Form of Resetting Map Similar Across Models", "Section",
 CellChangeTimes->{{3.465214989933425*^9, 3.465214997053011*^9}, {
  3.465215096061427*^9, 3.465215101693655*^9}, {3.465215179316136*^9, 
  3.4652151918201313`*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[0.006], LineBox[CompressedData["
1:eJwl13c81d8fB3CrMi9l731t7r24uNZL4iupkITsNJQKkaJSKpmVUDKSktBA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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{5., 2.},
      BaseStyle->{FontFamily -> "Arial"},
      Frame->{True, True, False, False},
      FrameLabel->{
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
         TraditionalForm]},
      FrameStyle->AbsoluteThickness[0.5],
      PlotLabel->FormBox["\"FN Model\"", TraditionalForm],
      PlotRange->{{2, 25}, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {175, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360, 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[0.006], LineBox[CompressedData["
1:eJwV13c81d8bAPB7jXDNkLRVSDIyK5XnNGSlUFFIKpWkjEgp37pXZqFk75Uk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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0, 0},
      BaseStyle->{FontFamily -> "Arial"},
      Frame->{True, True, False, False},
      FrameLabel->{
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
         TraditionalForm]},
      FrameStyle->AbsoluteThickness[0.5],
      PlotLabel->FormBox["\"Modified HH Model\"", TraditionalForm],
      PlotRange->{{0, 2.2}, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {525, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360, 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{521.6000000000001, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4651734669175797`*^9, {3.465173503695491*^9, 3.465173531110013*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Section",
 CellChangeTimes->{{3.4652152413046837`*^9, 3.4652152427835484`*^9}}],

Cell["\<\
Neural response to electric shocks can be well-approximated by a \
one-dimensional time-resetting map (this insight is built on work of \
Fitzhugh, Winfree, Rabinovitch, many others)\
\>", "Subsection",
 CellChangeTimes->{{3.465215274943287*^9, 3.4652153927425823`*^9}, {
  3.4652157657700644`*^9, 3.4652158947911253`*^9}, {3.4652159792051487`*^9, 
  3.465215998027073*^9}, {3.465220799381455*^9, 3.465220802197392*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 "Recent features of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " are useful in this context for:"
}], "Subsection",
 CellChangeTimes->{{3.465215408670381*^9, 3.465215438742559*^9}, 
   3.465222298945726*^9}],

Cell[CellGroupData[{

Cell["\<\
Computing the time-resetting maps from highly nonlinear differential equations\
\>", "Subsubsection",
 CellChangeTimes->{{3.4652154422941513`*^9, 3.465215470134856*^9}}],

Cell["\<\
The built-in Nearest function for rapidly determining the distance from the \
state point to the home trajectory\
\>", "Text",
 CellChangeTimes->{{3.465215528216679*^9, 3.4652155618487263`*^9}, {
  3.465216645222836*^9, 3.4652166687876167`*^9}}],

Cell["\<\
NDSolve with Event Detection to determine when and where the state point \
joins the home trajectory\
\>", "Text",
 CellChangeTimes->{{3.4652154809371967`*^9, 3.465215521736278*^9}, {
  3.465216671700025*^9, 3.465216692300955*^9}}]
}, Open  ]],

Cell["Exploring the complex dynamics using Manipulate", "Subsubsection",
 CellChangeTimes->{{3.465215574516178*^9, 3.465215589490139*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
My current research focus: Can the analysis of the geometrical form of \
time-resetting maps allow for the systematic optimization of neuro-electrical \
stimulation (e.g., improving cochlear implants)?  \
\>", "Subsection",
 CellChangeTimes->{{3.465215613711097*^9, 3.4652156517395687`*^9}, {
  3.465215682336091*^9, 3.465215751050816*^9}, {3.465216016666135*^9, 
  3.465216019409265*^9}, {3.465216585014091*^9, 3.465216585412719*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[0.006], LineBox[CompressedData["
1:eJwl13c81d8fB3CrMi9l731t7r24uNZL4iupkITsNJQKkaJSKpmVUDKSktBA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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{5., 2.},
      BaseStyle->{FontFamily -> "Arial"},
      Frame->{True, True, False, False},
      FrameLabel->{
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
         TraditionalForm]},
      FrameStyle->AbsoluteThickness[0.5],
      PlotLabel->FormBox["\"FN Model\"", TraditionalForm],
      PlotRange->{{2, 25}, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {175, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360, 222.49223594996212`}], InsetBox[
     GraphicsBox[{{}, {}, 
       {Hue[0.67, 0.6, 0.6], Thickness[0.006], LineBox[CompressedData["
1:eJwV13c81d8bAPB7jXDNkLRVSDIyK5XnNGSlUFFIKpWkjEgp37pXZqFk75Uk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         "]]}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0, 0},
      BaseStyle->{FontFamily -> "Arial"},
      Frame->{True, True, False, False},
      FrameLabel->{
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(pre\\)]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Tau]\\), \\(post\\)]\\)\"", 
         TraditionalForm]},
      FrameStyle->AbsoluteThickness[0.5],
      PlotLabel->FormBox["\"Modified HH Model\"", TraditionalForm],
      PlotRange->{{0, 2.2}, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {525, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360, 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->{521.6000000000001, Automatic},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.4651734669175797`*^9, {3.465173503695491*^9, 3.465173531110013*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Acknowledgments", "Section",
 CellChangeTimes->{{3.46522019374643*^9, 3.4652201970158033`*^9}}],

Cell["Andrew Moylan of Wolfram Research", "Subsection",
 CellChangeTimes->{{3.465220201423398*^9, 3.465220212470441*^9}}],

Cell[TextData[{
 "People at the Advanced ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " Summer School 2009, including Roger, Onkar, Stephanie"
}], "Subsection",
 CellChangeTimes->{{3.465220216799459*^9, 3.465220262888954*^9}, {
   3.465220314070643*^9, 3.465220316137905*^9}, 3.465220397760619*^9, {
   3.465226900011774*^9, 3.4652269014001827`*^9}}],

Cell["\<\
Prof. H. Steven Colburn and others at the Hearing Research Center at Boston \
University\
\>", "Subsection",
 CellChangeTimes->{{3.4652202706890507`*^9, 3.465220302809997*^9}, {
  3.465220402888596*^9, 3.465220410120614*^9}, {3.465220840900044*^9, 
  3.465220841844393*^9}}]
}, Open  ]]
},
WindowSize->{1217, 840},
WindowMargins->{{Automatic, 52}, {Automatic, 0}},
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 152, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[744, 28, 225, 3, 42, "Subsection"],
Cell[CellGroupData[{
Cell[994, 35, 103, 1, 30, "Subsubsection"],
Cell[1100, 38, 306, 5, 51, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1443, 48, 37, 0, 30, "Subsubsection"],
Cell[1483, 50, 174, 4, 33, "Input"],
Cell[1660, 56, 171, 5, 33, "Input"],
Cell[1834, 63, 1142, 23, 72, "Input"]
}, Open  ]],
Cell[2991, 89, 87, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[3103, 94, 114, 1, 21, "Subsubsection"],
Cell[3220, 97, 136, 3, 33, "Input"],
Cell[3359, 102, 175, 4, 33, "Input"],
Cell[3537, 108, 155, 4, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3729, 117, 98, 1, 30, "Subsubsection"],
Cell[3830, 120, 205, 5, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4072, 130, 109, 1, 30, "Subsubsection"],
Cell[4184, 133, 247, 7, 33, "Input"],
Cell[4434, 142, 282, 7, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4753, 154, 120, 1, 30, "Subsubsection"],
Cell[4876, 157, 275, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[5176, 167, 1581, 44, 111, "Input"],
Cell[6760, 213, 1144, 30, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7941, 248, 577, 14, 53, "Input"],
Cell[8521, 264, 30173, 501, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38731, 770, 590, 14, 53, "Input"],
Cell[39324, 786, 17151, 285, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56512, 1076, 586, 14, 33, "Input"],
Cell[57101, 1092, 17189, 288, 70, "Output"]
}, Open  ]],
Cell[74305, 1383, 114, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[74444, 1388, 196, 4, 33, "Input"],
Cell[74643, 1394, 740, 16, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75420, 1415, 149, 3, 33, "Input"],
Cell[75572, 1420, 748, 16, 70, "Output"]
}, Open  ]],
Cell[76335, 1439, 177, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[76537, 1447, 354, 9, 33, "Input"],
Cell[76894, 1458, 726, 14, 70, "Output"]
}, Open  ]],
Cell[77635, 1475, 266, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[77926, 1484, 137, 2, 33, "Input"],
Cell[78066, 1488, 395, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78498, 1498, 178, 3, 33, "Input"],
Cell[78679, 1503, 674, 12, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[79402, 1521, 121, 1, 30, "Subsubsection"],
Cell[79526, 1524, 1882, 56, 127, "Text"],
Cell[CellGroupData[{
Cell[81433, 1584, 169, 3, 33, "Input"],
Cell[81605, 1589, 584, 8, 70, "Output"]
}, Open  ]],
Cell[82204, 1600, 221, 5, 32, "Text"],
Cell[82428, 1607, 465, 14, 55, "Input"],
Cell[82896, 1623, 109, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[83030, 1628, 703, 16, 33, "Input"],
Cell[83736, 1646, 600, 10, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[84373, 1661, 2038, 55, 167, "Input"],
Cell[86414, 1718, 62020, 1021, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148471, 2744, 1985, 54, 167, "Input"],
Cell[150459, 2800, 61913, 1020, 70, "Output"]
}, Open  ]],
Cell[212387, 3823, 133, 1, 32, "Text"],
Cell[212523, 3826, 112, 1, 32, "Text"],
Cell[212638, 3829, 539, 13, 33, "Input"],
Cell[213180, 3844, 179, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[213384, 3852, 475, 11, 33, "Input"],
Cell[213862, 3865, 1637, 30, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215536, 3900, 446, 10, 33, "Input"],
Cell[215985, 3912, 68858, 1132, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[284892, 5050, 202, 3, 30, "Subsubsection"],
Cell[285097, 5055, 1190, 25, 107, "Text"],
Cell[286290, 5082, 2334, 59, 167, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[288661, 5146, 205, 3, 30, "Subsubsection"],
Cell[288869, 5151, 1912, 35, 201, "Text"],
Cell[290784, 5188, 495, 8, 51, "Text"],
Cell[291282, 5198, 5765, 138, 523, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[297084, 5341, 202, 3, 30, "Subsubsection"],
Cell[297289, 5346, 1190, 25, 107, "Text"],
Cell[298482, 5373, 2334, 59, 167, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[300853, 5437, 205, 3, 30, "Subsubsection"],
Cell[301061, 5442, 1912, 35, 201, "Text"],
Cell[302976, 5479, 495, 8, 51, "Text"],
Cell[303474, 5489, 5765, 138, 523, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309276, 5632, 134, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[309435, 5637, 137, 2, 33, "Input"],
Cell[309575, 5641, 368, 5, 70, "Output"]
}, Open  ]],
Cell[309958, 5649, 257, 5, 51, "Text"],
Cell[310218, 5656, 508, 12, 33, "Input"],
Cell[CellGroupData[{
Cell[310751, 5672, 165, 3, 33, "Input"],
Cell[310919, 5677, 512, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[311468, 5690, 300, 7, 33, "Input"],
Cell[311771, 5699, 999, 22, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[312807, 5726, 132, 3, 33, "Input"],
Cell[312942, 5731, 597, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[313576, 5747, 2800, 66, 167, "Input"],
Cell[316379, 5815, 19673, 330, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[336101, 6151, 127, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[336253, 6156, 132, 2, 33, "Input"],
Cell[336388, 6160, 523, 10, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[336972, 6177, 232, 3, 31, "Subsection"],
Cell[CellGroupData[{
Cell[337229, 6184, 103, 1, 30, "Subsubsection"],
Cell[337335, 6187, 364, 7, 51, "Text"],
Cell[337702, 6196, 243, 5, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337982, 6206, 37, 0, 30, "Subsubsection"],
Cell[338022, 6208, 174, 4, 33, "Input"],
Cell[338199, 6214, 171, 5, 33, "Input"],
Cell[338373, 6221, 1142, 23, 72, "Input"]
}, Open  ]],
Cell[339530, 6247, 87, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[339642, 6252, 114, 1, 21, "Subsubsection"],
Cell[339759, 6255, 136, 3, 33, "Input"],
Cell[339898, 6260, 175, 4, 33, "Input"],
Cell[340076, 6266, 155, 4, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[340268, 6275, 98, 1, 30, "Subsubsection"],
Cell[340369, 6278, 205, 5, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[340611, 6288, 109, 1, 30, "Subsubsection"],
Cell[340723, 6291, 247, 7, 33, "Input"],
Cell[340973, 6300, 282, 7, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[341292, 6312, 120, 1, 30, "Subsubsection"],
Cell[341415, 6315, 275, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[341715, 6325, 1581, 44, 111, "Input"],
Cell[343299, 6371, 1116, 30, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[344452, 6406, 577, 14, 53, "Input"],
Cell[345032, 6422, 30144, 501, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[375213, 6928, 590, 14, 53, "Input"],
Cell[375806, 6944, 17125, 285, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[392968, 7234, 586, 14, 33, "Input"],
Cell[393557, 7250, 17177, 288, 70, "Output"]
}, Open  ]],
Cell[410749, 7541, 114, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[410888, 7546, 196, 4, 33, "Input"],
Cell[411087, 7552, 713, 15, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[411837, 7572, 149, 3, 33, "Input"],
Cell[411989, 7577, 721, 15, 70, "Output"]
}, Open  ]],
Cell[412725, 7595, 177, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[412927, 7603, 354, 9, 33, "Input"],
Cell[413284, 7614, 706, 14, 70, "Output"]
}, Open  ]],
Cell[414005, 7631, 266, 5, 51, "Text"],
Cell[CellGroupData[{
Cell[414296, 7640, 137, 2, 33, "Input"],
Cell[414436, 7644, 368, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[414841, 7654, 178, 3, 33, "Input"],
Cell[415022, 7659, 649, 11, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[415720, 7676, 121, 1, 30, "Subsubsection"],
Cell[415844, 7679, 1882, 56, 127, "Text"],
Cell[CellGroupData[{
Cell[417751, 7739, 169, 3, 33, "Input"],
Cell[417923, 7744, 569, 8, 70, "Output"]
}, Open  ]],
Cell[418507, 7755, 221, 5, 32, "Text"],
Cell[418731, 7762, 465, 14, 55, "Input"],
Cell[419199, 7778, 109, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[419333, 7783, 703, 16, 33, "Input"],
Cell[420039, 7801, 584, 9, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[420660, 7815, 2038, 55, 167, "Input"],
Cell[422701, 7872, 61998, 1021, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[484736, 8898, 1985, 54, 167, "Input"],
Cell[486724, 8954, 61885, 1020, 70, "Output"]
}, Open  ]],
Cell[548624, 9977, 133, 1, 32, "Text"],
Cell[548760, 9980, 112, 1, 32, "Text"],
Cell[548875, 9983, 539, 13, 33, "Input"],
Cell[549417, 9998, 179, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[549621, 10006, 475, 11, 33, "Input"],
Cell[550099, 10019, 1610, 30, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[551746, 10054, 446, 10, 33, "Input"],
Cell[552195, 10066, 68844, 1132, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[621088, 11204, 202, 3, 30, "Subsubsection"],
Cell[621293, 11209, 1190, 25, 107, "Text"],
Cell[622486, 11236, 2334, 59, 167, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[624857, 11300, 205, 3, 30, "Subsubsection"],
Cell[625065, 11305, 1912, 35, 201, "Text"],
Cell[626980, 11342, 495, 8, 51, "Text"],
Cell[627478, 11352, 5765, 138, 523, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[633280, 11495, 134, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[633439, 11500, 137, 2, 33, "Input"],
Cell[633579, 11504, 348, 5, 70, "Output"]
}, Open  ]],
Cell[633942, 11512, 257, 5, 51, "Text"],
Cell[634202, 11519, 508, 12, 33, "Input"],
Cell[CellGroupData[{
Cell[634735, 11535, 165, 3, 33, "Input"],
Cell[634903, 11540, 489, 8, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[635429, 11553, 300, 7, 33, "Input"],
Cell[635732, 11562, 964, 22, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[636733, 11589, 132, 3, 33, "Input"],
Cell[636868, 11594, 571, 11, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637476, 11610, 2586, 61, 167, "Input"],
Cell[640065, 11673, 19496, 326, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[659610, 12005, 153, 2, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[659788, 12011, 158, 3, 33, "Input"],
Cell[659949, 12016, 351, 7, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[660361, 12030, 169, 2, 31, "Subsection"],
Cell[CellGroupData[{
Cell[660555, 12036, 105, 1, 30, "Subsubsection"],
Cell[660663, 12039, 215, 4, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[660915, 12048, 37, 0, 30, "Subsubsection"],
Cell[660955, 12050, 80, 2, 33, "Input"],
Cell[661038, 12054, 171, 5, 33, "Input"],
Cell[661212, 12061, 1142, 23, 53, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[662391, 12089, 54, 0, 30, "Subsubsection"],
Cell[662448, 12091, 161, 4, 33, "Input"],
Cell[662612, 12097, 127, 3, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[662776, 12105, 188, 2, 30, "Subsubsection"],
Cell[662967, 12109, 171, 2, 32, "Text"],
Cell[663141, 12113, 273, 6, 33, "Input"],
Cell[663417, 12121, 485, 8, 70, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[663939, 12134, 122, 1, 30, "Subsubsection"],
Cell[664064, 12137, 164, 4, 53, "Input"],
Cell[664231, 12143, 476, 12, 33, "Input"],
Cell[664710, 12157, 534, 13, 33, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[665281, 12175, 103, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[665409, 12180, 521, 15, 33, "Input"],
Cell[665933, 12197, 17149, 287, 303, "Output"]
}, Open  ]],
Cell[683097, 12487, 106, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[683228, 12492, 486, 15, 33, "Input"],
Cell[683717, 12509, 342, 7, 33, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[684108, 12522, 133, 1, 30, "Subsubsection"],
Cell[684244, 12525, 1656, 42, 72, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[685937, 12572, 105, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[686067, 12577, 1077, 28, 72, "Input"],
Cell[687147, 12607, 63923, 1136, 189, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[751119, 13749, 119, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[751263, 13754, 2324, 58, 136, "Input"],
Cell[753590, 13814, 11076, 190, 182, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[764703, 14009, 2809, 71, 129, "Input"],
Cell[767515, 14082, 21459, 358, 176, "Output"]
}, Open  ]]
}, Open  ]],
Cell[789001, 14444, 161, 2, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[789187, 14450, 183, 2, 21, "Subsubsection"],
Cell[789373, 14454, 130, 2, 33, "Input"],
Cell[789506, 14458, 3935, 91, 110, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[793478, 14554, 106, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[793609, 14559, 115, 2, 33, "Input"],
Cell[793727, 14563, 229, 3, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[793993, 14571, 120, 2, 33, "Input"],
Cell[794116, 14575, 226, 3, 33, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[794379, 14583, 285, 7, 33, "Input"],
Cell[794667, 14592, 39685, 702, 423, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834389, 15299, 287, 7, 33, "Input"],
Cell[834679, 15308, 38533, 688, 423, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[873261, 16002, 112, 1, 30, "Subsubsection"],
Cell[CellGroupData[{
Cell[873398, 16007, 382, 8, 33, "Input"],
Cell[873783, 16017, 40146, 706, 423, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[913966, 16728, 336, 8, 33, "Input"],
Cell[914305, 16738, 38503, 688, 423, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[952845, 17431, 334, 8, 33, "Input"],
Cell[953182, 17441, 38994, 683, 423, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[992249, 18132, 241, 3, 83, "Section"],
Cell[CellGroupData[{
Cell[992515, 18139, 2123, 56, 186, "Input"],
Cell[994641, 18197, 2365, 47, 439, "Output"]
}, {2}]],
Cell[997018, 18247, 180, 4, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[997235, 18256, 188, 2, 83, "Section"],
Cell[CellGroupData[{
Cell[997448, 18262, 5436, 139, 224, "Input"],
Cell[1002887, 18403, 225960, 3851, 507, "Output"]
}, Open  ]],
Cell[1228862, 22257, 180, 4, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1229079, 22266, 292, 6, 83, "Section"],
Cell[CellGroupData[{
Cell[1229396, 22276, 689, 15, 33, "Input"],
Cell[1230088, 22293, 1820, 36, 531, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1231957, 22335, 233, 5, 83, "Section"],
Cell[CellGroupData[{
Cell[1232215, 22344, 2324, 58, 176, "Input"],
Cell[1234542, 22404, 11027, 189, 182, "Output"]
}, {2}]],
Cell[CellGroupData[{
Cell[1245603, 22598, 2809, 71, 167, "Input"],
Cell[1248415, 22671, 21411, 357, 176, "Output"]
}, {2}]],
Cell[1269838, 23031, 163, 3, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1270038, 23039, 228, 3, 83, "Section"],
Cell[1270269, 23044, 38603, 648, 242, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1308909, 23697, 99, 1, 83, "Section"],
Cell[1309011, 23700, 430, 7, 61, "Subsection"],
Cell[CellGroupData[{
Cell[1309466, 23711, 234, 7, 31, "Subsection"],
Cell[CellGroupData[{
Cell[1309725, 23722, 179, 3, 30, "Subsubsection"],
Cell[1309907, 23727, 255, 5, 32, "Text"],
Cell[1310165, 23734, 241, 5, 32, "Text"]
}, Open  ]],
Cell[1310421, 23742, 138, 1, 30, "Subsubsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1310596, 23748, 445, 7, 61, "Subsection"],
Cell[1311044, 23757, 38603, 648, 242, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1349696, 24411, 101, 1, 83, "Section"],
Cell[1349800, 24414, 121, 1, 42, "Subsection"],
Cell[1349924, 24417, 358, 8, 31, "Subsection"],
Cell[1350285, 24427, 284, 6, 31, "Subsection"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
